/* Generated by Cython 3.2.4 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "define_macros": [
            [
                "CYTHON_FAST_THREAD_STATE",
                "0"
            ]
        ],
        "depends": [
            "src/gevent/_gevent_clocal.pxd"
        ],
        "include_dirs": [
            "/usr/include/python3.14",
            "/usr/include/python3.14",
            "/build/python-gevent/src/python-gevent/deps"
        ],
        "name": "gevent._gevent_clocal",
        "sources": [
            "src/gevent/local.py"
        ]
    },
    "module_name": "gevent._gevent_clocal"
}
END: Cython Metadata */

#ifndef PY_SSIZE_T_CLEAN
#define PY_SSIZE_T_CLEAN
#endif /* PY_SSIZE_T_CLEAN */
/* InitLimitedAPI */
#if defined(Py_LIMITED_API)
  #if !defined(CYTHON_LIMITED_API)
  #define CYTHON_LIMITED_API 1
  #endif
#elif defined(CYTHON_LIMITED_API)
  #ifdef _MSC_VER
  #pragma message ("Limited API usage is enabled with 'CYTHON_LIMITED_API' but 'Py_LIMITED_API' does not define a Python target version. Consider setting 'Py_LIMITED_API' instead.")
  #else
  #warning Limited API usage is enabled with 'CYTHON_LIMITED_API' but 'Py_LIMITED_API' does not define a Python target version. Consider setting 'Py_LIMITED_API' instead.
  #endif
#endif

#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x03080000
    #error Cython requires Python 3.8+.
#else
#define __PYX_ABI_VERSION "3_2_4"
#define CYTHON_HEX_VERSION 0x030204F0
#define CYTHON_FUTURE_DIVISION 1
/* CModulePreamble */
#include "src/gevent/_generated_include/CModulePreamble_impl_67ff8da3bafbaee898fb2680a081f9cf07617f9b80d936bf5254c02966774c38.h"
/* CInitCode */
#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

/* PythonCompatibility */
#include "src/gevent/_generated_include/PythonCompatibility_impl_9f6bc6a154e6d1f4d1d9250f48a0e6d407560d70233eabffbe0fccfe1f684e75.h"
/* MathInitCode */
#if defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)
  #ifndef _USE_MATH_DEFINES
    #define _USE_MATH_DEFINES
  #endif
#endif
#include <math.h>
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#ifndef CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#define CYTHON_CLINE_IN_TRACEBACK_RUNTIME 0
#endif
#ifndef CYTHON_CLINE_IN_TRACEBACK
#define CYTHON_CLINE_IN_TRACEBACK CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#endif
#if CYTHON_CLINE_IN_TRACEBACK
#define __PYX_MARK_ERR_POS(f_index, lineno)  { __pyx_filename = __pyx_f[f_index]; (void) __pyx_filename; __pyx_lineno = lineno; (void) __pyx_lineno; __pyx_clineno = __LINE__; (void) __pyx_clineno; }
#else
#define __PYX_MARK_ERR_POS(f_index, lineno)  { __pyx_filename = __pyx_f[f_index]; (void) __pyx_filename; __pyx_lineno = lineno; (void) __pyx_lineno; (void) __pyx_clineno; }
#endif
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifdef CYTHON_EXTERN_C
    #undef __PYX_EXTERN_C
    #define __PYX_EXTERN_C CYTHON_EXTERN_C
#elif defined(__PYX_EXTERN_C)
    #ifdef _MSC_VER
    #pragma message ("Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.")
    #else
    #warning Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.
    #endif
#else
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__gevent___gevent_clocal
#define __PYX_HAVE_API__gevent___gevent_clocal
/* Early includes */
#include <string.h>
#include <stdio.h>
#include "greenlet/greenlet.h"
#include "_compat.h"
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

#ifdef CYTHON_FREETHREADING_COMPATIBLE
#if CYTHON_FREETHREADING_COMPATIBLE
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_NOT_USED
#else
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_USED
#endif
#else
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_USED
#endif
#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s);
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char*);
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyByteArray_AsString(s) PyByteArray_AS_STRING(s)
#else
    #define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AsString(s))
    #define __Pyx_PyByteArray_AsString(s) PyByteArray_AsString(s)
#endif
#define __Pyx_PyObject_AsWritableString(s)    ((char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
#define __Pyx_PyUnicode_FromOrdinal(o)       PyUnicode_FromOrdinal((int)o)
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
static CYTHON_INLINE PyObject *__Pyx_NewRef(PyObject *obj) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030a0000 || defined(Py_NewRef)
    return Py_NewRef(obj);
#else
    Py_INCREF(obj);
    return obj;
#endif
}
static CYTHON_INLINE PyObject *__Pyx_XNewRef(PyObject *obj) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030a0000 || defined(Py_XNewRef)
    return Py_XNewRef(obj);
#else
    Py_XINCREF(obj);
    return obj;
#endif
}
static CYTHON_INLINE PyObject *__Pyx_Owned_Py_None(int b);
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Long(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyLong_FromSize_t(size_t);
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject*);
#if CYTHON_ASSUME_SAFE_MACROS
#define __Pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#define __Pyx_PyFloat_AS_DOUBLE(x) PyFloat_AS_DOUBLE(x)
#else
#define __Pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#define __Pyx_PyFloat_AS_DOUBLE(x) PyFloat_AsDouble(x)
#endif
#define __Pyx_PyFloat_AsFloat(x) ((float) __Pyx_PyFloat_AsDouble(x))
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_VERSION_HEX >= 0x030C00A7
  #ifndef _PyLong_SIGN_MASK
    #define _PyLong_SIGN_MASK 3
  #endif
  #ifndef _PyLong_NON_SIZE_BITS
    #define _PyLong_NON_SIZE_BITS 3
  #endif
  #define __Pyx_PyLong_Sign(x)  (((PyLongObject*)x)->long_value.lv_tag & _PyLong_SIGN_MASK)
  #define __Pyx_PyLong_IsNeg(x)  ((__Pyx_PyLong_Sign(x) & 2) != 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (!__Pyx_PyLong_IsNeg(x))
  #define __Pyx_PyLong_IsZero(x)  (__Pyx_PyLong_Sign(x) & 1)
  #define __Pyx_PyLong_IsPos(x)  (__Pyx_PyLong_Sign(x) == 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  (__Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  ((Py_ssize_t) (((PyLongObject*)x)->long_value.lv_tag >> _PyLong_NON_SIZE_BITS))
  #define __Pyx_PyLong_SignedDigitCount(x)\
        ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * __Pyx_PyLong_DigitCount(x))
  #if defined(PyUnstable_Long_IsCompact) && defined(PyUnstable_Long_CompactValue)
    #define __Pyx_PyLong_IsCompact(x)     PyUnstable_Long_IsCompact((PyLongObject*) x)
    #define __Pyx_PyLong_CompactValue(x)  PyUnstable_Long_CompactValue((PyLongObject*) x)
  #else
    #define __Pyx_PyLong_IsCompact(x)     (((PyLongObject*)x)->long_value.lv_tag < (2 << _PyLong_NON_SIZE_BITS))
    #define __Pyx_PyLong_CompactValue(x)  ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * (Py_ssize_t) __Pyx_PyLong_Digits(x)[0])
  #endif
  typedef Py_ssize_t  __Pyx_compact_pylong;
  typedef size_t  __Pyx_compact_upylong;
  #else
  #define __Pyx_PyLong_IsNeg(x)  (Py_SIZE(x) < 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (Py_SIZE(x) >= 0)
  #define __Pyx_PyLong_IsZero(x)  (Py_SIZE(x) == 0)
  #define __Pyx_PyLong_IsPos(x)  (Py_SIZE(x) > 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  ((Py_SIZE(x) == 0) ? 0 : __Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  __Pyx_sst_abs(Py_SIZE(x))
  #define __Pyx_PyLong_SignedDigitCount(x)  Py_SIZE(x)
  #define __Pyx_PyLong_IsCompact(x)  (Py_SIZE(x) == 0 || Py_SIZE(x) == 1 || Py_SIZE(x) == -1)
  #define __Pyx_PyLong_CompactValue(x)\
        ((Py_SIZE(x) == 0) ? (sdigit) 0 : ((Py_SIZE(x) < 0) ? -(sdigit)__Pyx_PyLong_Digits(x)[0] : (sdigit)__Pyx_PyLong_Digits(x)[0]))
  typedef sdigit  __Pyx_compact_pylong;
  typedef digit  __Pyx_compact_upylong;
  #endif
  #if PY_VERSION_HEX >= 0x030C00A5
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->long_value.ob_digit)
  #else
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->ob_digit)
  #endif
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#elif __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeASCII(c_str, size, NULL)
#else
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
/* PretendToInitialize */
#ifdef __cplusplus
#if __cplusplus > 201103L
#include <type_traits>
#endif
template <typename T>
static void __Pyx_pretend_to_initialize(T* ptr) {
#if __cplusplus > 201103L
    if ((std::is_trivially_default_constructible<T>::value))
#endif
        *ptr = T();
    (void)ptr;
}
#else
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }
#endif


#if !CYTHON_USE_MODULE_STATE
static PyObject *__pyx_m = NULL;
#endif
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * const __pyx_cfilenm = __FILE__;
static const char *__pyx_filename;

/* #### Code section: filename_table ### */

static const char* const __pyx_f[] = {
  "src/gevent/local.py",
  "src/gevent/_gevent_c_greenlet_primitives.pxd",
  "src/gevent/_gevent_c_waiter.pxd",
  "src/gevent/_gevent_cgreenlet.pxd",
  "src/gevent/_gevent_clocal.pxd",
  "cpython/type.pxd",
  "src/gevent/_gevent_c_ident.pxd",
};
/* #### Code section: utility_code_proto_before_types ### */
/* Atomics.proto (used by UnpackUnboundCMethod) */
#include "src/gevent/_generated_include/Atomics_proto_3c6d386cad499e8bf66734864569013c6cb59adf2353bb94c6c6798eea3c07cc.h"
/* CriticalSectionsDefinition.proto (used by CriticalSections) */
#if !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyCriticalSection void*
#define __Pyx_PyCriticalSection2 void*
#define __Pyx_PyCriticalSection_End(cs)
#define __Pyx_PyCriticalSection2_End(cs)
#else
#define __Pyx_PyCriticalSection PyCriticalSection
#define __Pyx_PyCriticalSection2 PyCriticalSection2
#define __Pyx_PyCriticalSection_End PyCriticalSection_End
#define __Pyx_PyCriticalSection2_End PyCriticalSection2_End
#endif

/* CriticalSections.proto (used by ParseKeywordsImpl) */
#if !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyCriticalSection_Begin(cs, arg) (void)(cs)
#define __Pyx_PyCriticalSection2_Begin(cs, arg1, arg2) (void)(cs)
#else
#define __Pyx_PyCriticalSection_Begin PyCriticalSection_Begin
#define __Pyx_PyCriticalSection2_Begin PyCriticalSection2_Begin
#endif
#if PY_VERSION_HEX < 0x030d0000 || CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_BEGIN_CRITICAL_SECTION(o) {
#define __Pyx_END_CRITICAL_SECTION() }
#else
#define __Pyx_BEGIN_CRITICAL_SECTION Py_BEGIN_CRITICAL_SECTION
#define __Pyx_END_CRITICAL_SECTION Py_END_CRITICAL_SECTION
#endif

/* IncludeStructmemberH.proto */
#include <structmember.h>

/* #### Code section: numeric_typedefs ### */
/* #### Code section: complex_type_declarations ### */
/* #### Code section: type_declarations ### */

/*--- Type declarations ---*/
struct __pyx_obj_6gevent_15_gevent_c_ident_ValuedWeakRef;
struct __pyx_obj_6gevent_15_gevent_c_ident_IdentRegistry;
struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet;
struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop;
struct __pyx_obj_6gevent_16_gevent_c_waiter_Waiter;
struct __pyx_obj_6gevent_16_gevent_c_waiter_MultipleWaiter;
struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink;
struct __pyx_obj_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink;
struct __pyx_obj_6gevent_17_gevent_cgreenlet_FailureSpawnedLink;
struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame;
struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet;
struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event;
struct __pyx_obj_6gevent_14_gevent_clocal__wrefdict;
struct __pyx_obj_6gevent_14_gevent_clocal__greenlet_deleted;
struct __pyx_obj_6gevent_14_gevent_clocal__local_deleted;
struct __pyx_obj_6gevent_14_gevent_clocal__localimpl;
struct __pyx_obj_6gevent_14_gevent_clocal__localimpl_dict_entry;
struct __pyx_obj_6gevent_14_gevent_clocal_local;
struct __pyx_opt_args_6gevent_17_gevent_cgreenlet_8Greenlet_join;
struct __pyx_opt_args_6gevent_17_gevent_cgreenlet_8Greenlet_kill;
struct __pyx_opt_args_6gevent_17_gevent_cgreenlet_joinall;

/* "gevent/_gevent_cgreenlet.pxd":72
 *         _greenlet_imported = True
 * 
 * ctypedef object CodeType             # <<<<<<<<<<<<<<
 * ctypedef object FrameType
 * 
*/
typedef PyObject *__pyx_t_6gevent_17_gevent_cgreenlet_CodeType;

/* "gevent/_gevent_cgreenlet.pxd":73
 * 
 * ctypedef object CodeType
 * ctypedef object FrameType             # <<<<<<<<<<<<<<
 * 
 * cdef extern from "_compat.h":
*/
typedef PyObject *__pyx_t_6gevent_17_gevent_cgreenlet_FrameType;

/* "gevent/_gevent_cgreenlet.pxd":144
 * 
 *     cpdef bint has_links(self)
 *     cpdef join(self, timeout=*)             # <<<<<<<<<<<<<<
 *     cpdef kill(self, exception=*, block=*, timeout=*)
 *     cpdef bint ready(self)
*/
struct __pyx_opt_args_6gevent_17_gevent_cgreenlet_8Greenlet_join {
  int __pyx_n;
  PyObject *timeout;
};

/* "gevent/_gevent_cgreenlet.pxd":145
 *     cpdef bint has_links(self)
 *     cpdef join(self, timeout=*)
 *     cpdef kill(self, exception=*, block=*, timeout=*)             # <<<<<<<<<<<<<<
 *     cpdef bint ready(self)
 *     cpdef bint successful(self)
*/
struct __pyx_opt_args_6gevent_17_gevent_cgreenlet_8Greenlet_kill {
  int __pyx_n;
  PyObject *exception;
  PyObject *block;
  PyObject *timeout;
};

/* "gevent/_gevent_cgreenlet.pxd":219
 * 
 * @cython.locals(done=list)
 * cpdef joinall(greenlets, timeout=*, raise_error=*, count=*)             # <<<<<<<<<<<<<<
 * 
 * cdef set _spawn_callbacks
*/
struct __pyx_opt_args_6gevent_17_gevent_cgreenlet_joinall {
  int __pyx_n;
  PyObject *timeout;
  PyObject *raise_error;
  PyObject *count;
};

/* "gevent/_gevent_c_ident.pxd":13
 * cdef type ref
 * 
 * @cython.internal             # <<<<<<<<<<<<<<
 * @cython.final
 * cdef class ValuedWeakRef(ref):
*/
struct __pyx_obj_6gevent_15_gevent_c_ident_ValuedWeakRef {
  PyWeakReference __pyx_base;
  PyObject *value;
};


/* "gevent/_gevent_c_ident.pxd":18
 *     cdef object value
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class IdentRegistry:
 *     cdef object _registry
*/
struct __pyx_obj_6gevent_15_gevent_c_ident_IdentRegistry {
  PyObject_HEAD
  struct __pyx_vtabstruct_6gevent_15_gevent_c_ident_IdentRegistry *__pyx_vtab;
  PyObject *_registry;
  PyObject *_available_idents;
};


/* "gevent/_gevent_c_greenlet_primitives.pxd":37
 *     return PyGreenlet_Switch(self, NULL, NULL)
 * 
 * cdef class TrackedRawGreenlet(greenlet):             # <<<<<<<<<<<<<<
 *     pass
 * 
*/
struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet {
  PyGreenlet __pyx_base;
};


/* "gevent/_gevent_c_greenlet_primitives.pxd":40
 *     pass
 * 
 * cdef class SwitchOutGreenletWithLoop(TrackedRawGreenlet):             # <<<<<<<<<<<<<<
 *     cdef public loop
 * 
*/
struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop {
  struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet __pyx_base;
  struct __pyx_vtabstruct_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *__pyx_vtab;
  PyObject *loop;
};


/* "gevent/_gevent_c_waiter.pxd":33
 *         _greenlet_imported = True
 * 
 * cdef class Waiter:             # <<<<<<<<<<<<<<
 *     cdef readonly SwitchOutGreenletWithLoop hub
 *     cdef readonly greenlet greenlet
*/
struct __pyx_obj_6gevent_16_gevent_c_waiter_Waiter {
  PyObject_HEAD
  struct __pyx_vtabstruct_6gevent_16_gevent_c_waiter_Waiter *__pyx_vtab;
  struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *hub;
  PyGreenlet *greenlet;
  PyObject *value;
  PyObject *_exception;
};


/* "gevent/_gevent_c_waiter.pxd":45
 *     #cpdef switch(self, value)
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * @cython.internal
 * cdef class MultipleWaiter(Waiter):
*/
struct __pyx_obj_6gevent_16_gevent_c_waiter_MultipleWaiter {
  struct __pyx_obj_6gevent_16_gevent_c_waiter_Waiter __pyx_base;
  PyObject *_values;
};


/* "gevent/_gevent_cgreenlet.pxd":100
 * cdef void _init()
 * 
 * cdef class SpawnedLink:             # <<<<<<<<<<<<<<
 *     cdef public object callback
 * 
*/
struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink {
  PyObject_HEAD
  PyObject *callback;
};


/* "gevent/_gevent_cgreenlet.pxd":104
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class SuccessSpawnedLink(SpawnedLink):
 *     pass
*/
struct __pyx_obj_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink {
  struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink __pyx_base;
};


/* "gevent/_gevent_cgreenlet.pxd":108
 *     pass
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class FailureSpawnedLink(SpawnedLink):
 *     pass
*/
struct __pyx_obj_6gevent_17_gevent_cgreenlet_FailureSpawnedLink {
  struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink __pyx_base;
};


/* "gevent/_gevent_cgreenlet.pxd":112
 *     pass
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * @cython.internal
 * @cython.freelist(1000)
*/
struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame {
  PyObject_HEAD
  __pyx_t_6gevent_17_gevent_cgreenlet_CodeType f_code;
  int f_lineno;
  struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *f_back;
};


/* "gevent/_gevent_cgreenlet.pxd":128
 * cdef _Frame _extract_stack(int limit)
 * 
 * cdef class Greenlet(greenlet):             # <<<<<<<<<<<<<<
 *     cdef readonly object value
 *     cdef readonly tuple args
*/
struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet {
  PyGreenlet __pyx_base;
  struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_vtab;
  PyObject *value;
  PyObject *args;
  PyObject *kwargs;
  PyObject *spawning_greenlet;
  struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *spawning_stack;
  PyObject *spawn_tree_locals;
  PyObject *_links;
  PyObject *_exc_info;
  PyObject *_notifier;
  PyObject *_start_event;
  PyObject *_formatted_info;
  PyObject *_ident;
};


/* "gevent/_gevent_cgreenlet.pxd":199
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * @cython.internal
 * cdef class _dummy_event:
*/
struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event {
  PyObject_HEAD
  struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet__dummy_event *__pyx_vtab;
  int pending;
  int active;
};


/* "gevent/_gevent_clocal.pxd":38
 * cdef void _init()
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * @cython.internal
 * cdef class _wrefdict(dict):
*/
struct __pyx_obj_6gevent_14_gevent_clocal__wrefdict {
  PyDictObject __pyx_base;
  PyObject *__weakref__;
};


/* "gevent/_gevent_clocal.pxd":43
 *    cdef object __weakref__
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * @cython.internal
 * cdef class _greenlet_deleted:
*/
struct __pyx_obj_6gevent_14_gevent_clocal__greenlet_deleted {
  PyObject_HEAD
  PyObject *idt;
  PyObject *wrdicts;
};


/* "gevent/_gevent_clocal.pxd":50
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * @cython.internal
 * cdef class _local_deleted:
*/
struct __pyx_obj_6gevent_14_gevent_clocal__local_deleted {
  PyObject_HEAD
  PyObject *key;
  PyObject *wrthread;
  struct __pyx_obj_6gevent_14_gevent_clocal__greenlet_deleted *greenlet_deleted;
};


/* "gevent/_gevent_clocal.pxd":57
 *     cdef _greenlet_deleted greenlet_deleted
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * @cython.internal
 * cdef class _localimpl:
*/
struct __pyx_obj_6gevent_14_gevent_clocal__localimpl {
  PyObject_HEAD
  PyObject *key;
  PyObject *dicts;
  PyObject *localargs;
  PyObject *localkwargs;
  PyObject *localtypeid;
  PyObject *__weakref__;
};


/* "gevent/_gevent_clocal.pxd":68
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * @cython.internal
 * cdef class _localimpl_dict_entry:
*/
struct __pyx_obj_6gevent_14_gevent_clocal__localimpl_dict_entry {
  PyObject_HEAD
  PyObject *wrgreenlet;
  PyObject *localdict;
};


/* "gevent/_gevent_clocal.pxd":83
 * cdef set _local_attrs
 * 
 * cdef class local:             # <<<<<<<<<<<<<<
 *     cdef _localimpl _local__impl
 *     cdef set _local_type_get_descriptors
*/
struct __pyx_obj_6gevent_14_gevent_clocal_local {
  PyObject_HEAD
  struct __pyx_vtabstruct_6gevent_14_gevent_clocal_local *__pyx_vtab;
  struct __pyx_obj_6gevent_14_gevent_clocal__localimpl *_local__impl;
  PyObject *_local_type_get_descriptors;
  PyObject *_local_type_set_or_del_descriptors;
  PyObject *_local_type_del_descriptors;
  PyObject *_local_type_set_descriptors;
  PyObject *_local_type_vars;
  PyTypeObject *_local_type;
};



/* "gevent/_gevent_c_ident.pxd":18
 *     cdef object value
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class IdentRegistry:
 *     cdef object _registry
*/

struct __pyx_vtabstruct_6gevent_15_gevent_c_ident_IdentRegistry {
  PyObject *(*get_ident)(struct __pyx_obj_6gevent_15_gevent_c_ident_IdentRegistry *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*_return_ident)(struct __pyx_obj_6gevent_15_gevent_c_ident_IdentRegistry *, struct __pyx_obj_6gevent_15_gevent_c_ident_ValuedWeakRef *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6gevent_15_gevent_c_ident_IdentRegistry *__pyx_vtabptr_6gevent_15_gevent_c_ident_IdentRegistry;


/* "gevent/_gevent_c_greenlet_primitives.pxd":40
 *     pass
 * 
 * cdef class SwitchOutGreenletWithLoop(TrackedRawGreenlet):             # <<<<<<<<<<<<<<
 *     cdef public loop
 * 
*/

struct __pyx_vtabstruct_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop {
  PyObject *(*__pyx_switch)(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *, int __pyx_skip_dispatch);
  PyObject *(*switch_out)(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *__pyx_vtabptr_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop;


/* "gevent/_gevent_c_waiter.pxd":33
 *         _greenlet_imported = True
 * 
 * cdef class Waiter:             # <<<<<<<<<<<<<<
 *     cdef readonly SwitchOutGreenletWithLoop hub
 *     cdef readonly greenlet greenlet
*/

struct __pyx_vtabstruct_6gevent_16_gevent_c_waiter_Waiter {
  PyObject *(*get)(struct __pyx_obj_6gevent_16_gevent_c_waiter_Waiter *, int __pyx_skip_dispatch);
  PyObject *(*clear)(struct __pyx_obj_6gevent_16_gevent_c_waiter_Waiter *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6gevent_16_gevent_c_waiter_Waiter *__pyx_vtabptr_6gevent_16_gevent_c_waiter_Waiter;


/* "gevent/_gevent_c_waiter.pxd":45
 *     #cpdef switch(self, value)
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * @cython.internal
 * cdef class MultipleWaiter(Waiter):
*/

struct __pyx_vtabstruct_6gevent_16_gevent_c_waiter_MultipleWaiter {
  struct __pyx_vtabstruct_6gevent_16_gevent_c_waiter_Waiter __pyx_base;
};
static struct __pyx_vtabstruct_6gevent_16_gevent_c_waiter_MultipleWaiter *__pyx_vtabptr_6gevent_16_gevent_c_waiter_MultipleWaiter;


/* "gevent/_gevent_cgreenlet.pxd":128
 * cdef _Frame _extract_stack(int limit)
 * 
 * cdef class Greenlet(greenlet):             # <<<<<<<<<<<<<<
 *     cdef readonly object value
 *     cdef readonly tuple args
*/

struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet {
  int (*has_links)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, int __pyx_skip_dispatch);
  PyObject *(*join)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, int __pyx_skip_dispatch, struct __pyx_opt_args_6gevent_17_gevent_cgreenlet_8Greenlet_join *__pyx_optional_args);
  PyObject *(*kill)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, int __pyx_skip_dispatch, struct __pyx_opt_args_6gevent_17_gevent_cgreenlet_8Greenlet_kill *__pyx_optional_args);
  int (*ready)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, int __pyx_skip_dispatch);
  int (*successful)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, int __pyx_skip_dispatch);
  PyObject *(*rawlink)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*_formatinfo)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, int __pyx_skip_dispatch);
  int (*_maybe_kill_before_start)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*_get_minimal_ident)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *);
  int (*_Greenlet__started_but_aborted)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *);
  int (*_Greenlet__start_cancelled_by_kill)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *);
  int (*_Greenlet__start_pending)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *);
  int (*_Greenlet__never_started_or_killed)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *);
  int (*_Greenlet__start_completed)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *);
  PyObject *(*_Greenlet__handle_death_before_start)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, PyObject *);
  void (*_Greenlet__free)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *);
  PyObject *(*_Greenlet__cancel_start)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *);
  PyObject *(*_Greenlet__report_result)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, PyObject *);
  PyObject *(*_Greenlet__report_error)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, PyObject *);
  PyObject *(*_notify_links)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_vtabptr_6gevent_17_gevent_cgreenlet_Greenlet;


/* "gevent/_gevent_cgreenlet.pxd":199
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * @cython.internal
 * cdef class _dummy_event:
*/

struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet__dummy_event {
  PyObject *(*stop)(struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *, int __pyx_skip_dispatch);
  PyObject *(*start)(struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*close)(struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet__dummy_event *__pyx_vtabptr_6gevent_17_gevent_cgreenlet__dummy_event;


/* "src/gevent/local.py":363
 * }
 * 
 * class local(object):             # <<<<<<<<<<<<<<
 *     """
 *     An object whose attributes are greenlet-local.
*/

struct __pyx_vtabstruct_6gevent_14_gevent_clocal_local {
  struct __pyx_obj_6gevent_14_gevent_clocal_local *(*__pyx___copy__)(struct __pyx_obj_6gevent_14_gevent_clocal_local *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6gevent_14_gevent_clocal_local *__pyx_vtabptr_6gevent_14_gevent_clocal_local;
/* #### Code section: utility_code_proto ### */

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#include "src/gevent/_generated_include/Refnanny_proto_00d2ab1aa529311d487a88a16574063b4d3b8ffa11a25109d76165964b208920.h"
/* PyErrExceptionMatches.proto (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* PyThreadStateGet.proto (used by PyErrFetchRestore) */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#if PY_VERSION_HEX >= 0x030C00A6
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->current_exception != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->current_exception ? (PyObject*) Py_TYPE(__pyx_tstate->current_exception) : (PyObject*) NULL)
#else
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->curexc_type != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->curexc_type)
#endif
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  (PyErr_Occurred() != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto (used by PyObjectGetAttrStrNoError) */
#include "src/gevent/_generated_include/PyErrFetchRestore_proto_b219ba96ee79f73e7240a9715dc835e7e817ccd9f4f99ab4145b09780817bd8a.h"
/* PyObjectGetAttrStr.proto (used by PyObjectGetAttrStrNoError) */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* PyObjectGetAttrStrNoError.proto (used by GetBuiltinName) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name);

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* TupleAndListFromArray.proto (used by fastcall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n);
#endif
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject* __Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n);
#endif

/* IncludeStringH.proto (used by BytesEquals) */
#include <string.h>

/* BytesEquals.proto (used by UnicodeEquals) */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto (used by fastcall) */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* fastcall.proto */
#include "src/gevent/_generated_include/fastcall_proto_66690a1464eb22fa574c56237a11be9953f14c69fdee2df9c4141aa9c5e2a76d.h"
/* ExtTypeTest.proto */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type);

/* PyObjectCall.proto (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyObjectCallMethO.proto (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectFastCall.proto */
#define __Pyx_PyObject_FastCall(func, args, nargs)  __Pyx_PyObject_FastCallDict(func, args, (size_t)(nargs), NULL)
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject * const*args, size_t nargs, PyObject *kwargs);

/* RaiseUnexpectedTypeError.proto */
static int __Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj);

/* IterFinish.proto (used by dict_iter) */
static CYTHON_INLINE int __Pyx_IterFinish(void);

/* PyObjectCallNoArg.proto (used by PyObjectCallMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);

/* PyObjectCallOneArg.proto (used by PyObjectCallMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* PyObjectGetMethod.proto (used by PyObjectCallMethod0) */
#if !(CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000)))
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method);
#endif

/* PyObjectCallMethod0.proto (used by dict_iter) */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name);

/* RaiseNeedMoreValuesToUnpack.proto (used by UnpackTuple2) */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

/* RaiseTooManyValuesToUnpack.proto (used by UnpackItemEndCheck) */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

/* UnpackItemEndCheck.proto (used by UnpackTuple2) */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected);

/* RaiseNoneIterError.proto (used by UnpackTupleError) */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void);

/* UnpackTupleError.proto (used by UnpackTuple2) */
static void __Pyx_UnpackTupleError(PyObject *, Py_ssize_t index);

/* UnpackTuple2.proto (used by dict_iter) */
static CYTHON_INLINE int __Pyx_unpack_tuple2(
    PyObject* tuple, PyObject** value1, PyObject** value2, int is_tuple, int has_known_size, int decref_tuple);
static CYTHON_INLINE int __Pyx_unpack_tuple2_exact(
    PyObject* tuple, PyObject** value1, PyObject** value2, int decref_tuple);
static int __Pyx_unpack_tuple2_generic(
    PyObject* tuple, PyObject** value1, PyObject** value2, int has_known_size, int decref_tuple);

/* dict_iter.proto */
static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* dict, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_is_dict);
static CYTHON_INLINE int __Pyx_dict_iter_next(PyObject* dict_or_iter, Py_ssize_t orig_length, Py_ssize_t* ppos,
                                              PyObject** pkey, PyObject** pvalue, PyObject** pitem, int is_dict);

/* unicode_tailmatch.proto */
static int __Pyx_PyUnicode_Tailmatch(
    PyObject* s, PyObject* substr, Py_ssize_t start, Py_ssize_t end, int direction);

/* dict_getitem_default.proto */
static PyObject* __Pyx_PyDict_GetItemDefault(PyObject* d, PyObject* key, PyObject* default_value);

/* CallCFunction.proto (used by CallUnboundCMethod1) */
#define __Pyx_CallCFunction(cfunc, self, args)\
    ((PyCFunction)(void(*)(void))(cfunc)->func)(self, args)
#define __Pyx_CallCFunctionWithKeywords(cfunc, self, args, kwargs)\
    ((PyCFunctionWithKeywords)(void(*)(void))(cfunc)->func)(self, args, kwargs)
#define __Pyx_CallCFunctionFast(cfunc, self, args, nargs)\
    ((__Pyx_PyCFunctionFast)(void(*)(void))(PyCFunction)(cfunc)->func)(self, args, nargs)
#define __Pyx_CallCFunctionFastWithKeywords(cfunc, self, args, nargs, kwnames)\
    ((__Pyx_PyCFunctionFastWithKeywords)(void(*)(void))(PyCFunction)(cfunc)->func)(self, args, nargs, kwnames)

/* PyObjectCall2Args.proto (used by CallUnboundCMethod1) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2);

/* UnpackUnboundCMethod.proto (used by CallUnboundCMethod1) */
typedef struct {
    PyObject *type;
    PyObject **method_name;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && CYTHON_ATOMICS
    __pyx_atomic_int_type initialized;
#endif
    PyCFunction func;
    PyObject *method;
    int flag;
} __Pyx_CachedCFunction;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
static CYTHON_INLINE int __Pyx_CachedCFunction_GetAndSetInitializing(__Pyx_CachedCFunction *cfunc) {
#if !CYTHON_ATOMICS
    return 1;
#else
    __pyx_nonatomic_int_type expected = 0;
    if (__pyx_atomic_int_cmp_exchange(&cfunc->initialized, &expected, 1)) {
        return 0;
    }
    return expected;
#endif
}
static CYTHON_INLINE void __Pyx_CachedCFunction_SetFinishedInitializing(__Pyx_CachedCFunction *cfunc) {
#if CYTHON_ATOMICS
    __pyx_atomic_store(&cfunc->initialized, 2);
#endif
}
#else
#define __Pyx_CachedCFunction_GetAndSetInitializing(cfunc) 2
#define __Pyx_CachedCFunction_SetFinishedInitializing(cfunc)
#endif

/* CallUnboundCMethod1.proto */
CYTHON_UNUSED
static PyObject* __Pyx__CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#else
#define __Pyx_CallUnboundCMethod1(cfunc, self, arg)  __Pyx__CallUnboundCMethod1(cfunc, self, arg)
#endif

/* CallUnboundCMethod2.proto */
CYTHON_UNUSED
static PyObject* __Pyx__CallUnboundCMethod2(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg1, PyObject* arg2);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject *__Pyx_CallUnboundCMethod2(__Pyx_CachedCFunction *cfunc, PyObject *self, PyObject *arg1, PyObject *arg2);
#else
#define __Pyx_CallUnboundCMethod2(cfunc, self, arg1, arg2)  __Pyx__CallUnboundCMethod2(cfunc, self, arg1, arg2)
#endif

/* AssertionsEnabled.proto */
#if CYTHON_COMPILING_IN_LIMITED_API  ||  PY_VERSION_HEX >= 0x030C0000
  static int __pyx_assertions_enabled_flag;
  #define __pyx_assertions_enabled() (__pyx_assertions_enabled_flag)
  #if __clang__ || __GNUC__
  __attribute__((no_sanitize("thread")))
  #endif
  static int __Pyx_init_assertions_enabled(void) {
    PyObject *builtins, *debug, *debug_str;
    int flag;
    builtins = PyEval_GetBuiltins();
    if (!builtins) goto bad;
    debug_str = PyUnicode_FromStringAndSize("__debug__", 9);
    if (!debug_str) goto bad;
    debug = PyObject_GetItem(builtins, debug_str);
    Py_DECREF(debug_str);
    if (!debug) goto bad;
    flag = PyObject_IsTrue(debug);
    Py_DECREF(debug);
    if (flag == -1) goto bad;
    __pyx_assertions_enabled_flag = flag;
    return 0;
  bad:
    __pyx_assertions_enabled_flag = 1;
    return -1;
  }
#else
  #define __Pyx_init_assertions_enabled()  (0)
  #define __pyx_assertions_enabled()  (!Py_OptimizeFlag)
#endif

/* PyAssertionError_Check.proto */
#define __Pyx_PyExc_AssertionError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_AssertionError)

/* RaiseException.export */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* ListAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
        L->ob_item[len] = x;
        #else
        PyList_SET_ITEM(list, len, x);
        #endif
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

/* ArgTypeTestFunc.export */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact);

/* ArgTypeTest.proto */
#define __Pyx_ArgTypeTest(obj, type, none_allowed, name, exact)\
    ((likely(__Pyx_IS_TYPE(obj, type) | (none_allowed && (obj == Py_None)))) ? 1 :\
        __Pyx__ArgTypeTest(obj, type, name, exact))

/* py_dict_items.proto (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Items(PyObject* d);

/* CallUnboundCMethod0.proto */
CYTHON_UNUSED
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#else
#define __Pyx_CallUnboundCMethod0(cfunc, self)  __Pyx__CallUnboundCMethod0(cfunc, self)
#endif

/* py_dict_values.proto (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Values(PyObject* d);

/* OwnedDictNext.proto (used by ParseKeywordsImpl) */
#if CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, PyObject **ppos, PyObject **pkey, PyObject **pvalue);
#else
CYTHON_INLINE
static int __Pyx_PyDict_NextRef(PyObject *p, Py_ssize_t *ppos, PyObject **pkey, PyObject **pvalue);
#endif

/* RaiseDoubleKeywords.proto (used by ParseKeywordsImpl) */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywordsImpl.export */
static int __Pyx_ParseKeywordsTuple(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);
static int __Pyx_ParseKeywordDictToDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name
);
static int __Pyx_ParseKeywordDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);

/* ParseKeywords.proto */
static CYTHON_INLINE int __Pyx_ParseKeywords(
    PyObject *kwds, PyObject *const *kwvalues, PyObject ** const argnames[],
    PyObject *kwds2, PyObject *values[],
    Py_ssize_t num_pos_args, Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* PyObjectFastCallMethod.proto */
#if CYTHON_VECTORCALL && PY_VERSION_HEX >= 0x03090000
#define __Pyx_PyObject_FastCallMethod(name, args, nargsf) PyObject_VectorcallMethod(name, args, nargsf, NULL)
#else
static PyObject *__Pyx_PyObject_FastCallMethod(PyObject *name, PyObject *const *args, size_t nargsf);
#endif

/* GetTopmostException.proto (used by SaveResetException) */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem * __Pyx_PyErr_GetTopmostException(PyThreadState *tstate);
#endif

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* PyAttributeError_Check.proto */
#define __Pyx_PyExc_AttributeError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_AttributeError)

/* PyObject_Unicode.proto */
#define __Pyx_PyObject_Unicode(obj)\
    (likely(PyUnicode_CheckExact(obj)) ? __Pyx_NewRef(obj) : PyObject_Str(obj))

/* GetAttr3.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *, PyObject *, PyObject *);

/* DictGetItem.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key);
#define __Pyx_PyObject_Dict_GetItem(obj, name)\
    (likely(PyDict_CheckExact(obj)) ?\
     __Pyx_PyDict_GetItem(obj, name) : PyObject_GetItem(obj, name))
#else
#define __Pyx_PyDict_GetItem(d, key) PyObject_GetItem(d, key)
#define __Pyx_PyObject_Dict_GetItem(obj, name)  PyObject_GetItem(obj, name)
#endif

/* PyKeyError_Check.proto */
#define __Pyx_PyExc_KeyError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_KeyError)

/* GetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_GetException(type, value, tb)  __Pyx__GetException(__pyx_tstate, type, value, tb)
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* KeywordStringCheck.proto */
static CYTHON_INLINE int __Pyx_CheckKeywordStrings(const char* function_name, PyObject *kw);

/* PyTypeError_Check.proto */
#define __Pyx_PyExc_TypeError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_TypeError)

/* pyfrozenset_new.proto (used by PySetContains) */
static CYTHON_INLINE PyObject* __Pyx_PyFrozenSet_New(PyObject* it);

/* PySetContains.proto */
static CYTHON_INLINE int __Pyx_PySet_ContainsTF(PyObject* key, PyObject* set, int eq);

/* PyDictContains.proto */
static CYTHON_INLINE int __Pyx_PyDict_ContainsTF(PyObject* item, PyObject* dict, int eq) {
    int result = PyDict_Contains(dict, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* GetAttr.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *, PyObject *);

/* PySequenceContains.proto */
static CYTHON_INLINE int __Pyx_PySequence_ContainsTF(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* GetItemInt.proto */
#include "src/gevent/_generated_include/GetItemInt_proto_3b42f7f7de85b71eab2f8b6ae51ddc7168a53d31d56dd1f1e34c94c36c959f55.h"
/* ObjectGetItem.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject *key);
#else
#define __Pyx_PyObject_GetItem(obj, key)  PyObject_GetItem(obj, key)
#endif

/* HasAttr.proto */
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
#define __Pyx_HasAttr(o, n)  PyObject_HasAttrWithError(o, n)
#else
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *, PyObject *);
#endif

/* PyObjectFormatAndDecref.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatSimpleAndDecref(PyObject* s, PyObject* f);
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatAndDecref(PyObject* s, PyObject* f);

/* JoinPyUnicode.export */
static PyObject* __Pyx_PyUnicode_Join(PyObject** values, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char);

/* PyDictVersioning.proto */
#include "src/gevent/_generated_include/PyDictVersioning_proto_fc9ab32633f390bb88d05edfc7599e60bc4df8ea122afe432e3adec504912045.h"
/* SliceTupleAndList.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyList_GetSlice(PyObject* src, Py_ssize_t start, Py_ssize_t stop);
static CYTHON_INLINE PyObject* __Pyx_PyTuple_GetSlice(PyObject* src, Py_ssize_t start, Py_ssize_t stop);
#else
#define __Pyx_PyList_GetSlice(seq, start, stop)   PySequence_GetSlice(seq, start, stop)
#define __Pyx_PyTuple_GetSlice(seq, start, stop)  PySequence_GetSlice(seq, start, stop)
#endif

/* PyTrashcan.proto */
#include "src/gevent/_generated_include/PyTrashcan_proto_a7510f0e71c46fdd034badc37001935c9794ef07aa050305f02167c2ac82459b.h"
/* CallTypeTraverse.proto */
#if !CYTHON_USE_TYPE_SPECS || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x03090000)
#define __Pyx_call_type_traverse(o, always_call, visit, arg) 0
#else
static int __Pyx_call_type_traverse(PyObject *o, int always_call, visitproc visit, void *arg);
#endif

/* AllocateExtensionType.proto */
static PyObject *__Pyx_AllocateExtensionType(PyTypeObject *t, int is_final);

/* VoidPtrExport.proto */
static int __Pyx_ExportVoidPtr(PyObject *api_dict, const char *name, void *p, const char *sig);

/* GetApiDict.proto */
static PyObject *__Pyx_ApiExport_GetApiDict(void);

/* FunctionExport.proto */
static int __Pyx_ExportFunction(PyObject *api_dict, const char *name, void (*f)(void), const char *sig);

/* TypeImport.proto */
#ifndef __PYX_HAVE_RT_ImportType_proto_3_2_4
#define __PYX_HAVE_RT_ImportType_proto_3_2_4
#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#include <stdalign.h>
#endif
#if (defined (__STDC_VERSION__) && __STDC_VERSION__ >= 201112L) || __cplusplus >= 201103L
#define __PYX_GET_STRUCT_ALIGNMENT_3_2_4(s) alignof(s)
#else
#define __PYX_GET_STRUCT_ALIGNMENT_3_2_4(s) sizeof(void*)
#endif
enum __Pyx_ImportType_CheckSize_3_2_4 {
   __Pyx_ImportType_CheckSize_Error_3_2_4 = 0,
   __Pyx_ImportType_CheckSize_Warn_3_2_4 = 1,
   __Pyx_ImportType_CheckSize_Ignore_3_2_4 = 2
};
static PyTypeObject *__Pyx_ImportType_3_2_4(PyObject* module, const char *module_name, const char *class_name, size_t size, size_t alignment, enum __Pyx_ImportType_CheckSize_3_2_4 check_size);
#endif

/* LimitedApiGetTypeDict.proto (used by SetItemOnTypeDict) */
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_GetTypeDict(PyTypeObject *tp);
#endif

/* SetItemOnTypeDict.proto (used by FixUpExtensionType) */
static int __Pyx__SetItemOnTypeDict(PyTypeObject *tp, PyObject *k, PyObject *v);
#define __Pyx_SetItemOnTypeDict(tp, k, v) __Pyx__SetItemOnTypeDict((PyTypeObject*)tp, k, v)

/* FixUpExtensionType.proto */
static CYTHON_INLINE int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type);

/* FormatTypeName.proto (used by ValidateExternBase) */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%U"
#define __Pyx_DECREF_TypeName(obj) Py_XDECREF(obj)
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
#define __Pyx_PyType_GetFullyQualifiedName PyType_GetFullyQualifiedName
#else
static __Pyx_TypeName __Pyx_PyType_GetFullyQualifiedName(PyTypeObject* tp);
#endif
#else  // !LIMITED_API
typedef const char *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%.200s"
#define __Pyx_PyType_GetFullyQualifiedName(tp) ((tp)->tp_name)
#define __Pyx_DECREF_TypeName(obj)
#endif

/* ValidateExternBase.proto */
static int __Pyx_validate_extern_base(PyTypeObject *base);

/* ValidateBasesTuple.proto (used by PyType_Ready) */
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_USE_TYPE_SPECS
static int __Pyx_validate_bases_tuple(const char *type_name, Py_ssize_t dictoffset, PyObject *bases);
#endif

/* PyType_Ready.proto */
CYTHON_UNUSED static int __Pyx_PyType_Ready(PyTypeObject *t);

/* SetVTable.proto */
static int __Pyx_SetVtable(PyTypeObject* typeptr , void* vtable);

/* GetVTable.proto (used by MergeVTables) */
static void* __Pyx_GetVtable(PyTypeObject *type);

/* MergeVTables.proto */
static int __Pyx_MergeVtables(PyTypeObject *type);

/* VoidPtrImport.proto */
static int __Pyx_ImportVoidPtr_3_2_4(PyObject *module, const char *name, void **p, const char *sig);

/* FunctionImport.proto */
static int __Pyx_ImportFunction_3_2_4(PyObject *module, const char *funcname, void (**f)(void), const char *sig);

/* ImportImpl.export */
static PyObject *__Pyx__Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, PyObject *moddict, int level);

/* Import.proto */
static CYTHON_INLINE PyObject *__Pyx_Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, int level);

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* dict_setdefault.proto (used by FetchCommonType) */
static CYTHON_INLINE PyObject *__Pyx_PyDict_SetDefault(PyObject *d, PyObject *key, PyObject *default_value);

/* AddModuleRef.proto (used by FetchSharedCythonModule) */
#if ((CYTHON_COMPILING_IN_CPYTHON_FREETHREADING ) ||\
     __PYX_LIMITED_VERSION_HEX < 0x030d0000)
  static PyObject *__Pyx_PyImport_AddModuleRef(const char *name);
#else
  #define __Pyx_PyImport_AddModuleRef(name) PyImport_AddModuleRef(name)
#endif

/* FetchSharedCythonModule.proto (used by FetchCommonType) */
static PyObject *__Pyx_FetchSharedCythonABIModule(void);

/* FetchCommonType.proto (used by CommonTypesMetaclass) */
static PyTypeObject* __Pyx_FetchCommonTypeFromSpec(PyTypeObject *metaclass, PyObject *module, PyType_Spec *spec, PyObject *bases);

/* CommonTypesMetaclass.proto (used by CythonFunctionShared) */
static int __pyx_CommonTypesMetaclass_init(PyObject *module);
#define __Pyx_CommonTypesMetaclass_USED

/* PyMethodNew.proto (used by CythonFunctionShared) */
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ);

/* PyVectorcallFastCallDict.proto (used by CythonFunctionShared) */
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw);
#endif

/* CythonFunctionShared.proto (used by CythonFunction) */
#include "src/gevent/_generated_include/CythonFunctionShared_proto_cfd16e7b1cdcce8e6454094d94c7459b788326000c3b790f09af3662926ca152.h"
/* CythonFunction.proto */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);

/* ListPack.proto */
static PyObject *__Pyx_PyList_Pack(Py_ssize_t n, ...);

/* GetModuleGlobalName.proto */
#include "src/gevent/_generated_include/GetModuleGlobalName_proto_35020a92d25e00989051b6cce92e00e13fc50c1cb05740bd074404c24babc545.h"
/* PyObjectDelAttr.proto (used by PyObjectSetAttrStr) */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030d0000
#define __Pyx_PyObject_DelAttr(o, n) PyObject_SetAttr(o, n, NULL)
#else
#define __Pyx_PyObject_DelAttr(o, n) PyObject_DelAttr(o, n)
#endif

/* PyObjectSetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o, n, NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value);
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   __Pyx_PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

/* Globals.proto */
static PyObject* __Pyx_Globals(void);

/* CLineInTraceback.proto (used by AddTraceback) */
#if CYTHON_CLINE_IN_TRACEBACK && CYTHON_CLINE_IN_TRACEBACK_RUNTIME
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#else
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#endif

/* CodeObjectCache.proto (used by AddTraceback) */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject __Pyx_CachedCodeObjectType;
#else
typedef PyCodeObject __Pyx_CachedCodeObjectType;
#endif
typedef struct {
    __Pyx_CachedCodeObjectType* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_atomic_int_type accessor_count;
  #endif
};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static __Pyx_CachedCodeObjectType *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, __Pyx_CachedCodeObjectType* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* GCCDiagnostics.proto (used by CIntToPy) */
#if !defined(__INTEL_COMPILER) && defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6))
#define __Pyx_HAS_GCC_DIAGNOSTIC
#endif

/* PyObjectVectorCallKwBuilder.proto (used by CIntToPy) */
CYTHON_UNUSED static int __Pyx_VectorcallBuilder_AddArg_Check(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n);
#if CYTHON_VECTORCALL
#if PY_VERSION_HEX >= 0x03090000
#define __Pyx_Object_Vectorcall_CallFromBuilder PyObject_Vectorcall
#else
#define __Pyx_Object_Vectorcall_CallFromBuilder _PyObject_Vectorcall
#endif
#define __Pyx_MakeVectorcallBuilderKwds(n) PyTuple_New(n)
static int __Pyx_VectorcallBuilder_AddArg(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n);
static int __Pyx_VectorcallBuilder_AddArgStr(const char *key, PyObject *value, PyObject *builder, PyObject **args, int n);
#else
#define __Pyx_Object_Vectorcall_CallFromBuilder __Pyx_PyObject_FastCallDict
#define __Pyx_MakeVectorcallBuilderKwds(n) __Pyx_PyDict_NewPresized(n)
#define __Pyx_VectorcallBuilder_AddArg(key, value, builder, args, n) PyDict_SetItem(builder, key, value)
#define __Pyx_VectorcallBuilder_AddArgStr(key, value, builder, args, n) PyDict_SetItemString(builder, key, value)
#endif

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_long(long value);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyLong_As_long(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyLong_As_int(PyObject *);

/* FastTypeChecks.proto */
#include "src/gevent/_generated_include/FastTypeChecks_proto_b6a1eb5ffa2a3fc9ebedcc671e034de99427399b8e4cbe35bbcd118ac87e0e6e.h"
/* GetRuntimeVersion.proto */
#if __PYX_LIMITED_VERSION_HEX < 0x030b0000
static unsigned long __Pyx_cached_runtime_version = 0;
static void __Pyx_init_runtime_version(void);
#else
#define __Pyx_init_runtime_version()
#endif
static unsigned long __Pyx_get_runtime_version(void);

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer);

/* DecompressString.proto */
static PyObject *__Pyx_DecompressString(const char *s, Py_ssize_t length, int algo);

/* MultiPhaseInitModuleState.proto */
#if CYTHON_PEP489_MULTI_PHASE_INIT && CYTHON_USE_MODULE_STATE
static PyObject *__Pyx_State_FindModule(void*);
static int __Pyx_State_AddModule(PyObject* module, void*);
static int __Pyx_State_RemoveModule(void*);
#elif CYTHON_USE_MODULE_STATE
#define __Pyx_State_FindModule PyState_FindModule
#define __Pyx_State_AddModule PyState_AddModule
#define __Pyx_State_RemoveModule PyState_RemoveModule
#endif

/* #### Code section: module_declarations ### */
/* CythonABIVersion.proto */
#include "src/gevent/_generated_include/CythonABIVersion_proto_6de230514e3c249dc5d32a29298796e6371a56c148e74d1832d78a4b882841b1.h"
static struct __pyx_obj_6gevent_14_gevent_clocal_local *__pyx_f_6gevent_14_gevent_clocal_5local___copy__(struct __pyx_obj_6gevent_14_gevent_clocal_local *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/

/* Module declarations from "cython" */

/* Module declarations from "libc.string" */

/* Module declarations from "libc.stdio" */

/* Module declarations from "__builtin__" */

/* Module declarations from "cpython.type" */

/* Module declarations from "cpython" */

/* Module declarations from "cpython.object" */

/* Module declarations from "cpython.ref" */

/* Module declarations from "weakref" */

/* Module declarations from "gevent._gevent_c_ident" */
static PyObject **__pyx_vp_6gevent_15_gevent_c_ident_heappop = 0;
#define __pyx_v_6gevent_15_gevent_c_ident_heappop (*__pyx_vp_6gevent_15_gevent_c_ident_heappop)
static PyObject **__pyx_vp_6gevent_15_gevent_c_ident_heappush = 0;
#define __pyx_v_6gevent_15_gevent_c_ident_heappush (*__pyx_vp_6gevent_15_gevent_c_ident_heappush)
static PyObject **__pyx_vp_6gevent_15_gevent_c_ident_WeakKeyDictionary = 0;
#define __pyx_v_6gevent_15_gevent_c_ident_WeakKeyDictionary (*__pyx_vp_6gevent_15_gevent_c_ident_WeakKeyDictionary)

/* Module declarations from "greenlet" */

/* Module declarations from "gevent._gevent_c_greenlet_primitives" */
static PyObject **__pyx_vp_6gevent_29_gevent_c_greenlet_primitives_get_objects = 0;
#define __pyx_v_6gevent_29_gevent_c_greenlet_primitives_get_objects (*__pyx_vp_6gevent_29_gevent_c_greenlet_primitives_get_objects)
static PyObject **__pyx_vp_6gevent_29_gevent_c_greenlet_primitives_wref = 0;
#define __pyx_v_6gevent_29_gevent_c_greenlet_primitives_wref (*__pyx_vp_6gevent_29_gevent_c_greenlet_primitives_wref)
static PyObject **__pyx_vp_6gevent_29_gevent_c_greenlet_primitives_BlockingSwitchOutError = 0;
#define __pyx_v_6gevent_29_gevent_c_greenlet_primitives_BlockingSwitchOutError (*__pyx_vp_6gevent_29_gevent_c_greenlet_primitives_BlockingSwitchOutError)
static int *__pyx_vp_6gevent_29_gevent_c_greenlet_primitives__greenlet_imported = 0;
#define __pyx_v_6gevent_29_gevent_c_greenlet_primitives__greenlet_imported (*__pyx_vp_6gevent_29_gevent_c_greenlet_primitives__greenlet_imported)
static PyTypeObject **__pyx_vp_6gevent_29_gevent_c_greenlet_primitives__memoryview = 0;
#define __pyx_v_6gevent_29_gevent_c_greenlet_primitives__memoryview (*__pyx_vp_6gevent_29_gevent_c_greenlet_primitives__memoryview)
static PyTypeObject **__pyx_vp_6gevent_29_gevent_c_greenlet_primitives__buffer = 0;
#define __pyx_v_6gevent_29_gevent_c_greenlet_primitives__buffer (*__pyx_vp_6gevent_29_gevent_c_greenlet_primitives__buffer)

/* Module declarations from "gevent._gevent_c_hub_local" */
static PyObject **__pyx_vp_6gevent_19_gevent_c_hub_local__threadlocal = 0;
#define __pyx_v_6gevent_19_gevent_c_hub_local__threadlocal (*__pyx_vp_6gevent_19_gevent_c_hub_local__threadlocal)
static struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *(*__pyx_f_6gevent_19_gevent_c_hub_local_get_hub_noargs)(int __pyx_skip_dispatch); /*proto*/

/* Module declarations from "gevent._gevent_c_waiter" */
static PyObject **__pyx_vp_6gevent_16_gevent_c_waiter_sys = 0;
#define __pyx_v_6gevent_16_gevent_c_waiter_sys (*__pyx_vp_6gevent_16_gevent_c_waiter_sys)
static PyObject **__pyx_vp_6gevent_16_gevent_c_waiter_ConcurrentObjectUseError = 0;
#define __pyx_v_6gevent_16_gevent_c_waiter_ConcurrentObjectUseError (*__pyx_vp_6gevent_16_gevent_c_waiter_ConcurrentObjectUseError)
static int *__pyx_vp_6gevent_16_gevent_c_waiter__greenlet_imported = 0;
#define __pyx_v_6gevent_16_gevent_c_waiter__greenlet_imported (*__pyx_vp_6gevent_16_gevent_c_waiter__greenlet_imported)
static PyObject **__pyx_vp_6gevent_16_gevent_c_waiter__NONE = 0;
#define __pyx_v_6gevent_16_gevent_c_waiter__NONE (*__pyx_vp_6gevent_16_gevent_c_waiter__NONE)

/* Module declarations from "gevent._gevent_cgreenlet" */
static int *__pyx_vp_6gevent_17_gevent_cgreenlet__PYPY = 0;
#define __pyx_v_6gevent_17_gevent_cgreenlet__PYPY (*__pyx_vp_6gevent_17_gevent_cgreenlet__PYPY)
static PyObject **__pyx_vp_6gevent_17_gevent_cgreenlet_sys_getframe = 0;
#define __pyx_v_6gevent_17_gevent_cgreenlet_sys_getframe (*__pyx_vp_6gevent_17_gevent_cgreenlet_sys_getframe)
static PyObject **__pyx_vp_6gevent_17_gevent_cgreenlet_sys_exc_info = 0;
#define __pyx_v_6gevent_17_gevent_cgreenlet_sys_exc_info (*__pyx_vp_6gevent_17_gevent_cgreenlet_sys_exc_info)
static PyObject **__pyx_vp_6gevent_17_gevent_cgreenlet_Timeout = 0;
#define __pyx_v_6gevent_17_gevent_cgreenlet_Timeout (*__pyx_vp_6gevent_17_gevent_cgreenlet_Timeout)
static PyObject **__pyx_vp_6gevent_17_gevent_cgreenlet_GreenletExit = 0;
#define __pyx_v_6gevent_17_gevent_cgreenlet_GreenletExit (*__pyx_vp_6gevent_17_gevent_cgreenlet_GreenletExit)
static PyObject **__pyx_vp_6gevent_17_gevent_cgreenlet_InvalidSwitchError = 0;
#define __pyx_v_6gevent_17_gevent_cgreenlet_InvalidSwitchError (*__pyx_vp_6gevent_17_gevent_cgreenlet_InvalidSwitchError)
static int *__pyx_vp_6gevent_17_gevent_cgreenlet__greenlet_imported = 0;
#define __pyx_v_6gevent_17_gevent_cgreenlet__greenlet_imported (*__pyx_vp_6gevent_17_gevent_cgreenlet__greenlet_imported)
static PyObject **__pyx_vp_6gevent_17_gevent_cgreenlet__greenlet__init__ = 0;
#define __pyx_v_6gevent_17_gevent_cgreenlet__greenlet__init__ (*__pyx_vp_6gevent_17_gevent_cgreenlet__greenlet__init__)
static PyObject **__pyx_vp_6gevent_17_gevent_cgreenlet__threadlocal = 0;
#define __pyx_v_6gevent_17_gevent_cgreenlet__threadlocal (*__pyx_vp_6gevent_17_gevent_cgreenlet__threadlocal)
static PyObject **__pyx_vp_6gevent_17_gevent_cgreenlet_get_hub_class = 0;
#define __pyx_v_6gevent_17_gevent_cgreenlet_get_hub_class (*__pyx_vp_6gevent_17_gevent_cgreenlet_get_hub_class)
static PyObject **__pyx_vp_6gevent_17_gevent_cgreenlet_wref = 0;
#define __pyx_v_6gevent_17_gevent_cgreenlet_wref (*__pyx_vp_6gevent_17_gevent_cgreenlet_wref)
static PyObject **__pyx_vp_6gevent_17_gevent_cgreenlet_dump_traceback = 0;
#define __pyx_v_6gevent_17_gevent_cgreenlet_dump_traceback (*__pyx_vp_6gevent_17_gevent_cgreenlet_dump_traceback)
static PyObject **__pyx_vp_6gevent_17_gevent_cgreenlet_load_traceback = 0;
#define __pyx_v_6gevent_17_gevent_cgreenlet_load_traceback (*__pyx_vp_6gevent_17_gevent_cgreenlet_load_traceback)
static PyObject **__pyx_vp_6gevent_17_gevent_cgreenlet_wait = 0;
#define __pyx_v_6gevent_17_gevent_cgreenlet_wait (*__pyx_vp_6gevent_17_gevent_cgreenlet_wait)
static PyObject **__pyx_vp_6gevent_17_gevent_cgreenlet_iwait = 0;
#define __pyx_v_6gevent_17_gevent_cgreenlet_iwait (*__pyx_vp_6gevent_17_gevent_cgreenlet_iwait)
static PyObject **__pyx_vp_6gevent_17_gevent_cgreenlet_reraise = 0;
#define __pyx_v_6gevent_17_gevent_cgreenlet_reraise (*__pyx_vp_6gevent_17_gevent_cgreenlet_reraise)
static PyObject **__pyx_vp_6gevent_17_gevent_cgreenlet_GEVENT_CONFIG = 0;
#define __pyx_v_6gevent_17_gevent_cgreenlet_GEVENT_CONFIG (*__pyx_vp_6gevent_17_gevent_cgreenlet_GEVENT_CONFIG)
static struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event **__pyx_vp_6gevent_17_gevent_cgreenlet__cancelled_start_event = 0;
#define __pyx_v_6gevent_17_gevent_cgreenlet__cancelled_start_event (*__pyx_vp_6gevent_17_gevent_cgreenlet__cancelled_start_event)
static struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event **__pyx_vp_6gevent_17_gevent_cgreenlet__start_completed_event = 0;
#define __pyx_v_6gevent_17_gevent_cgreenlet__start_completed_event (*__pyx_vp_6gevent_17_gevent_cgreenlet__start_completed_event)
static PyObject **__pyx_vp_6gevent_17_gevent_cgreenlet__spawn_callbacks = 0;
#define __pyx_v_6gevent_17_gevent_cgreenlet__spawn_callbacks (*__pyx_vp_6gevent_17_gevent_cgreenlet__spawn_callbacks)

/* Module declarations from "gevent._gevent_clocal" */
static int __pyx_v_6gevent_14_gevent_clocal__PYPY;
static PyObject *__pyx_v_6gevent_14_gevent_clocal_ref = 0;
static PyObject *__pyx_v_6gevent_14_gevent_clocal_copy = 0;
static PyObject *__pyx_v_6gevent_14_gevent_clocal__marker = 0;
static PyObject *__pyx_v_6gevent_14_gevent_clocal_key_prefix = 0;
static int __pyx_v_6gevent_14_gevent_clocal__greenlet_imported;
static PyObject *__pyx_v_6gevent_14_gevent_clocal__local_attrs = 0;
static CYTHON_INLINE PyGreenlet *__pyx_f_6gevent_14_gevent_clocal_getcurrent(void); /*proto*/
static CYTHON_INLINE void __pyx_f_6gevent_14_gevent_clocal_greenlet_init(void); /*proto*/
static void __pyx_f_6gevent_14_gevent_clocal__init(void); /*proto*/
static PyObject *__pyx_f_6gevent_14_gevent_clocal__localimpl_create_dict(struct __pyx_obj_6gevent_14_gevent_clocal__localimpl *, PyGreenlet *, PyObject *); /*proto*/
static CYTHON_INLINE PyObject *__pyx_f_6gevent_14_gevent_clocal__local_get_dict(struct __pyx_obj_6gevent_14_gevent_clocal_local *); /*proto*/
static PyObject *__pyx_f_6gevent_14_gevent_clocal__local__copy_dict_from(struct __pyx_obj_6gevent_14_gevent_clocal_local *, struct __pyx_obj_6gevent_14_gevent_clocal__localimpl *, PyObject *); /*proto*/
static PyObject *__pyx_f_6gevent_14_gevent_clocal__local_find_descriptors(struct __pyx_obj_6gevent_14_gevent_clocal_local *); /*proto*/
static PyObject *__pyx_f_6gevent_14_gevent_clocal_all_local_dicts_for_greenlet(PyGreenlet *, int __pyx_skip_dispatch); /*proto*/
/* #### Code section: typeinfo ### */
/* #### Code section: before_global_var ### */
#define __Pyx_MODULE_NAME "gevent._gevent_clocal"
extern int __pyx_module_is_main_gevent___gevent_clocal;
int __pyx_module_is_main_gevent___gevent_clocal = 0;

/* Implementation of "gevent._gevent_clocal" */
/* #### Code section: global_var ### */
static PyObject *__pyx_builtin___import__;
static PyObject *__pyx_builtin_object;
static PyObject *__pyx_builtin_classmethod;
static PyObject *__pyx_builtin_id;
static PyObject *__pyx_builtin_super;
/* #### Code section: string_decls ### */
static const char __pyx_k_Greenlet_local_objects_This_mod[] = "\nGreenlet-local objects.\n\nThis module is based on `_threading_local.py`__ from the standard\nlibrary of Python 3.4.\n\n__ https://github.com/python/cpython/blob/3.4/Lib/_threading_local.py\n\nGreenlet-local objects support the management of greenlet-local data.\nIf you have data that you want to be local to a greenlet, simply create\na greenlet-local object and use its attributes:\n\n  >>> import gevent\n  >>> from gevent.local import local\n  >>> mydata = local()\n  >>> mydata.number = 42\n  >>> mydata.number\n  42\n\nYou can also access the local-object's dictionary:\n\n  >>> mydata.__dict__\n  {'number': 42}\n  >>> mydata.__dict__.setdefault('widgets', [])\n  []\n  >>> mydata.widgets\n  []\n\nWhat's important about greenlet-local objects is that their data are\nlocal to a greenlet. If we access the data in a different greenlet:\n\n  >>> log = []\n  >>> def f():\n  ...     items = list(mydata.__dict__.items())\n  ...     items.sort()\n  ...     log.append(items)\n  ...     mydata.number = 11\n  ...     log.append(mydata.number)\n  >>> greenlet = gevent.spawn(f)\n  >>> greenlet.join()\n  >>> log\n  [[], 11]\n\nwe get different data.  Furthermore, changes made in the other greenlet\ndon't affect data seen in this greenlet:\n\n  >>> mydata.number\n  42\n\nOf course, values you get from a local object, including a __dict__\nattribute, are for whatever greenlet was current at the time the\nattribute was read.  For that reason, you generally don't want to save\nthese values across greenlets, as they apply only to the greenlet they\ncame from.\n\nYou can create custom local objects by subclassing the local class:\n\n  >>> class MyLocal(local):\n  ...     number = 2\n  ...     initialized = False\n  ...     def __init__(self, **kw):\n  ...         if self.initialized:\n  ...             raise SystemError('__init__ called too many times')\n  ...         self.initialized = True\n  ...         self.__dict__.update(kw)\n  ...     def squared(self):\n  ...         return se""lf.number ** 2\n\nThis can be useful to support default values, methods and\ninitialization.  Note that if you define an __init__ method, it will be\ncalled each time the local object is used in a separate greenlet.  This\nis necessary to initialize each greenlet's dictionary.\n\nNow if we create a local object:\n\n  >>> mydata = MyLocal(color='red')\n\nNow we have a default number:\n\n  >>> mydata.number\n  2\n\nan initial color:\n\n  >>> mydata.color\n  'red'\n  >>> del mydata.color\n\nAnd a method that operates on the data:\n\n  >>> mydata.squared()\n  4\n\nAs before, we can access the data in a separate greenlet:\n\n  >>> log = []\n  >>> greenlet = gevent.spawn(f)\n  >>> greenlet.join()\n  >>> log\n  [[('color', 'red'), ('initialized', True)], 11]\n\nwithout affecting this greenlet's data:\n\n  >>> mydata.number\n  2\n  >>> mydata.color\n  Traceback (most recent call last):\n  ...\n  AttributeError: 'MyLocal' object has no attribute 'color'\n\nNote that subclasses can define slots, but they are not greenlet\nlocal. They are shared across greenlets::\n\n  >>> class MyLocal(local):\n  ...     __slots__ = 'number'\n\n  >>> mydata = MyLocal()\n  >>> mydata.number = 42\n  >>> mydata.color = 'red'\n\nSo, the separate greenlet:\n\n  >>> greenlet = gevent.spawn(f)\n  >>> greenlet.join()\n\naffects what we see:\n\n  >>> mydata.number\n  11\n\n>>> del mydata\n\n.. versionchanged:: 1.1a2\n   Update the implementation to match Python 3.4 instead of Python 2.5.\n   This results in locals being eligible for garbage collection as soon\n   as their greenlet exits.\n\n.. versionchanged:: 1.2.3\n   Use a weak-reference to clear the greenlet link we establish in case\n   the local object dies before the greenlet does.\n\n.. versionchanged:: 1.3a1\n   Implement the methods for attribute access directly, handling\n   descriptors directly here. This allows removing the use of a lock\n   and facilitates greatly improved performance.\n\n.. versionchanged:: 1.3a1\n   The ``__init__`` me""thod of subclasses of ``local`` is no longer\n   called with a lock held. CPython does not use such a lock in its\n   native implementation. This could potentially show as a difference\n   if code that uses multiple dependent attributes in ``__slots__``\n   (which are shared across all greenlets) switches during ``__init__``.\n\n";
/* #### Code section: decls ### */
static PyObject *__pyx_lambda_funcdef_6gevent_14_gevent_clocal_lambda(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_6gevent_14_gevent_clocal_all_local_dicts_for_greenlet(CYTHON_UNUSED PyObject *__pyx_self, PyGreenlet *__pyx_v_greenlet); /* proto */
static int __pyx_pf_6gevent_14_gevent_clocal_17_greenlet_deleted___init__(struct __pyx_obj_6gevent_14_gevent_clocal__greenlet_deleted *__pyx_v_self, PyObject *__pyx_v_idt, PyObject *__pyx_v_wrdicts); /* proto */
static PyObject *__pyx_pf_6gevent_14_gevent_clocal_17_greenlet_deleted_2__call__(struct __pyx_obj_6gevent_14_gevent_clocal__greenlet_deleted *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v__unused); /* proto */
static int __pyx_pf_6gevent_14_gevent_clocal_14_local_deleted___init__(struct __pyx_obj_6gevent_14_gevent_clocal__local_deleted *__pyx_v_self, PyObject *__pyx_v_key, PyObject *__pyx_v_wrthread, PyObject *__pyx_v_greenlet_deleted); /* proto */
static PyObject *__pyx_pf_6gevent_14_gevent_clocal_14_local_deleted_2__call__(struct __pyx_obj_6gevent_14_gevent_clocal__local_deleted *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v__unused); /* proto */
static int __pyx_pf_6gevent_14_gevent_clocal_10_localimpl___init__(struct __pyx_obj_6gevent_14_gevent_clocal__localimpl *__pyx_v_self, PyObject *__pyx_v_args, PyObject *__pyx_v_kwargs, PyObject *__pyx_v_local_type, PyObject *__pyx_v_id_local); /* proto */
static int __pyx_pf_6gevent_14_gevent_clocal_21_localimpl_dict_entry___init__(struct __pyx_obj_6gevent_14_gevent_clocal__localimpl_dict_entry *__pyx_v_self, PyObject *__pyx_v_wrgreenlet, PyObject *__pyx_v_localdict); /* proto */
static int __pyx_pf_6gevent_14_gevent_clocal_5local___cinit__(struct __pyx_obj_6gevent_14_gevent_clocal_local *__pyx_v_self, PyObject *__pyx_v_args, PyObject *__pyx_v_kw); /* proto */
static PyObject *__pyx_pf_6gevent_14_gevent_clocal_5local_2__getattribute__(struct __pyx_obj_6gevent_14_gevent_clocal_local *__pyx_v_self, PyObject *__pyx_v_name); /* proto */
static int __pyx_pf_6gevent_14_gevent_clocal_5local_4__setattr__(struct __pyx_obj_6gevent_14_gevent_clocal_local *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6gevent_14_gevent_clocal_5local_6__delattr__(struct __pyx_obj_6gevent_14_gevent_clocal_local *__pyx_v_self, PyObject *__pyx_v_name); /* proto */
static PyObject *__pyx_pf_6gevent_14_gevent_clocal_5local_8__copy__(struct __pyx_obj_6gevent_14_gevent_clocal_local *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_14_gevent_clocal_2__new__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls, PyObject *__pyx_v_args, PyObject *__pyx_v_kw); /* proto */
static PyObject *__pyx_tp_new_6gevent_14_gevent_clocal__wrefdict(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6gevent_14_gevent_clocal__greenlet_deleted(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6gevent_14_gevent_clocal__local_deleted(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6gevent_14_gevent_clocal__localimpl(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6gevent_14_gevent_clocal__localimpl_dict_entry(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6gevent_14_gevent_clocal_local(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
/* #### Code section: late_includes ### */
/* #### Code section: module_state ### */
/* SmallCodeConfig */
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif

typedef struct {
  PyObject *__pyx_d;
  PyObject *__pyx_b;
  PyObject *__pyx_cython_runtime;
  PyObject *__pyx_empty_tuple;
  PyObject *__pyx_empty_bytes;
  PyObject *__pyx_empty_unicode;
  PyTypeObject *__pyx_ptype_7cpython_4type_type;
  PyTypeObject *__pyx_ptype_6gevent_15_gevent_c_ident_ref;
  PyTypeObject *__pyx_ptype_6gevent_15_gevent_c_ident_ValuedWeakRef;
  PyTypeObject *__pyx_ptype_6gevent_15_gevent_c_ident_IdentRegistry;
  PyTypeObject *__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_greenlet;
  PyTypeObject *__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet;
  PyTypeObject *__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop;
  PyTypeObject *__pyx_ptype_6gevent_16_gevent_c_waiter_greenlet;
  PyTypeObject *__pyx_ptype_6gevent_16_gevent_c_waiter_Waiter;
  PyTypeObject *__pyx_ptype_6gevent_16_gevent_c_waiter_MultipleWaiter;
  PyTypeObject *__pyx_ptype_6gevent_17_gevent_cgreenlet_greenlet;
  PyTypeObject *__pyx_ptype_6gevent_17_gevent_cgreenlet_SpawnedLink;
  PyTypeObject *__pyx_ptype_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink;
  PyTypeObject *__pyx_ptype_6gevent_17_gevent_cgreenlet_FailureSpawnedLink;
  PyTypeObject *__pyx_ptype_6gevent_17_gevent_cgreenlet__Frame;
  PyTypeObject *__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet;
  PyTypeObject *__pyx_ptype_6gevent_17_gevent_cgreenlet__dummy_event;
  PyObject *__pyx_type_6gevent_14_gevent_clocal__wrefdict;
  PyObject *__pyx_type_6gevent_14_gevent_clocal__greenlet_deleted;
  PyObject *__pyx_type_6gevent_14_gevent_clocal__local_deleted;
  PyObject *__pyx_type_6gevent_14_gevent_clocal__localimpl;
  PyObject *__pyx_type_6gevent_14_gevent_clocal__localimpl_dict_entry;
  PyObject *__pyx_type_6gevent_14_gevent_clocal_local;
  PyTypeObject *__pyx_ptype_6gevent_14_gevent_clocal_greenlet;
  PyTypeObject *__pyx_ptype_6gevent_14_gevent_clocal__wrefdict;
  PyTypeObject *__pyx_ptype_6gevent_14_gevent_clocal__greenlet_deleted;
  PyTypeObject *__pyx_ptype_6gevent_14_gevent_clocal__local_deleted;
  PyTypeObject *__pyx_ptype_6gevent_14_gevent_clocal__localimpl;
  PyTypeObject *__pyx_ptype_6gevent_14_gevent_clocal__localimpl_dict_entry;
  PyTypeObject *__pyx_ptype_6gevent_14_gevent_clocal_local;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_get;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_items;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_pop;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_values;
  PyObject *__pyx_tuple[4];
  PyObject *__pyx_codeobj_tab[4];
  PyObject *__pyx_string_tab[118];
/* #### Code section: module_state_contents ### */
/* CommonTypesMetaclass.module_state_decls */
PyTypeObject *__pyx_CommonTypesMetaclassType;

/* CachedMethodType.module_state_decls */
#if CYTHON_COMPILING_IN_LIMITED_API
PyObject *__Pyx_CachedMethodType;
#endif

/* CythonFunctionShared.module_state_decls */
PyTypeObject *__pyx_CyFunctionType;

/* CodeObjectCache.module_state_decls */
struct __Pyx_CodeObjectCache __pyx_code_cache;

/* #### Code section: module_state_end ### */
} __pyx_mstatetype;

#if CYTHON_USE_MODULE_STATE
#ifdef __cplusplus
namespace {
extern struct PyModuleDef __pyx_moduledef;
} /* anonymous namespace */
#else
static struct PyModuleDef __pyx_moduledef;
#endif

#define __pyx_mstate_global (__Pyx_PyModule_GetState(__Pyx_State_FindModule(&__pyx_moduledef)))

#define __pyx_m (__Pyx_State_FindModule(&__pyx_moduledef))
#else
static __pyx_mstatetype __pyx_mstate_global_static =
#ifdef __cplusplus
    {};
#else
    {0};
#endif
static __pyx_mstatetype * const __pyx_mstate_global = &__pyx_mstate_global_static;
#endif
/* #### Code section: constant_name_defines ### */
#define __pyx_kp_u_ __pyx_string_tab[0]
#define __pyx_kp_u_Initialization_arguments_are_not __pyx_string_tab[1]
#define __pyx_kp_u_Module_names_changed_local __pyx_string_tab[2]
#define __pyx_kp_u_Note_that_Cython_is_deliberately __pyx_string_tab[3]
#define __pyx_kp_u__2 __pyx_string_tab[4]
#define __pyx_kp_u__3 __pyx_string_tab[5]
#define __pyx_kp_u_add_note __pyx_string_tab[6]
#define __pyx_kp_u_disable __pyx_string_tab[7]
#define __pyx_kp_u_enable __pyx_string_tab[8]
#define __pyx_kp_u_gc __pyx_string_tab[9]
#define __pyx_kp_u_gevent__gevent_clocal __pyx_string_tab[10]
#define __pyx_kp_u_gevent__local __pyx_string_tab[11]
#define __pyx_kp_u_gevent_local __pyx_string_tab[12]
#define __pyx_kp_u_isenabled __pyx_string_tab[13]
#define __pyx_kp_u_name_2 __pyx_string_tab[14]
#define __pyx_kp_u_object_has_no_attribute __pyx_string_tab[15]
#define __pyx_kp_u_r_object_attribute___dict___is __pyx_string_tab[16]
#define __pyx_kp_u_revisit_this_code __pyx_string_tab[17]
#define __pyx_kp_u_src_gevent_local_py __pyx_string_tab[18]
#define __pyx_n_u_Pyx_PyDict_NextRef __pyx_string_tab[19]
#define __pyx_n_u_all __pyx_string_tab[20]
#define __pyx_n_u_all_local_dicts_for_greenlet __pyx_string_tab[21]
#define __pyx_n_u_args __pyx_string_tab[22]
#define __pyx_n_u_asyncio_coroutines __pyx_string_tab[23]
#define __pyx_n_u_cinit __pyx_string_tab[24]
#define __pyx_n_u_class __pyx_string_tab[25]
#define __pyx_n_u_class_getitem __pyx_string_tab[26]
#define __pyx_n_u_classmethod __pyx_string_tab[27]
#define __pyx_n_u_cline_in_traceback __pyx_string_tab[28]
#define __pyx_n_u_cls __pyx_string_tab[29]
#define __pyx_n_u_copy __pyx_string_tab[30]
#define __pyx_n_u_copy_2 __pyx_string_tab[31]
#define __pyx_n_u_delete __pyx_string_tab[32]
#define __pyx_n_u_dict __pyx_string_tab[33]
#define __pyx_n_u_dicts __pyx_string_tab[34]
#define __pyx_n_u_func __pyx_string_tab[35]
#define __pyx_n_u_get __pyx_string_tab[36]
#define __pyx_n_u_get_2 __pyx_string_tab[37]
#define __pyx_n_u_getattr __pyx_string_tab[38]
#define __pyx_n_u_getattribute __pyx_string_tab[39]
#define __pyx_n_u_getcurrent __pyx_string_tab[40]
#define __pyx_n_u_gevent__gevent_clocal __pyx_string_tab[41]
#define __pyx_n_u_gevent__util __pyx_string_tab[42]
#define __pyx_n_u_gevent_local_localimpl __pyx_string_tab[43]
#define __pyx_n_u_greenlet __pyx_string_tab[44]
#define __pyx_n_u_greenlet_deleted __pyx_string_tab[45]
#define __pyx_n_u_greenlet_deleted_2 __pyx_string_tab[46]
#define __pyx_n_u_greenlet_init __pyx_string_tab[47]
#define __pyx_n_u_id __pyx_string_tab[48]
#define __pyx_n_u_id_local __pyx_string_tab[49]
#define __pyx_n_u_idt __pyx_string_tab[50]
#define __pyx_n_u_import __pyx_string_tab[51]
#define __pyx_n_u_import_c_accel __pyx_string_tab[52]
#define __pyx_n_u_init __pyx_string_tab[53]
#define __pyx_n_u_is_coroutine __pyx_string_tab[54]
#define __pyx_n_u_items __pyx_string_tab[55]
#define __pyx_n_u_key __pyx_string_tab[56]
#define __pyx_n_u_kw __pyx_string_tab[57]
#define __pyx_n_u_kwargs __pyx_string_tab[58]
#define __pyx_n_u_lambda __pyx_string_tab[59]
#define __pyx_n_u_local __pyx_string_tab[60]
#define __pyx_n_u_local___copy __pyx_string_tab[61]
#define __pyx_n_u_local__impl __pyx_string_tab[62]
#define __pyx_n_u_local_deleted __pyx_string_tab[63]
#define __pyx_n_u_local_type __pyx_string_tab[64]
#define __pyx_n_u_local_type_2 __pyx_string_tab[65]
#define __pyx_n_u_local_type_del_descriptors __pyx_string_tab[66]
#define __pyx_n_u_local_type_get_descriptors __pyx_string_tab[67]
#define __pyx_n_u_local_type_set_descriptors __pyx_string_tab[68]
#define __pyx_n_u_local_type_set_or_del_descripto __pyx_string_tab[69]
#define __pyx_n_u_local_type_vars __pyx_string_tab[70]
#define __pyx_n_u_localargs __pyx_string_tab[71]
#define __pyx_n_u_localdict __pyx_string_tab[72]
#define __pyx_n_u_localimpl __pyx_string_tab[73]
#define __pyx_n_u_localimpl_dict_entry __pyx_string_tab[74]
#define __pyx_n_u_localkwargs __pyx_string_tab[75]
#define __pyx_n_u_localtypeid __pyx_string_tab[76]
#define __pyx_n_u_main __pyx_string_tab[77]
#define __pyx_n_u_module __pyx_string_tab[78]
#define __pyx_n_u_mro __pyx_string_tab[79]
#define __pyx_n_u_name __pyx_string_tab[80]
#define __pyx_n_u_new __pyx_string_tab[81]
#define __pyx_n_u_object __pyx_string_tab[82]
#define __pyx_n_u_pop __pyx_string_tab[83]
#define __pyx_n_u_pyx_capi __pyx_string_tab[84]
#define __pyx_n_u_pyx_vtable __pyx_string_tab[85]
#define __pyx_n_u_qualname __pyx_string_tab[86]
#define __pyx_n_u_rawlink __pyx_string_tab[87]
#define __pyx_n_u_ref __pyx_string_tab[88]
#define __pyx_n_u_self __pyx_string_tab[89]
#define __pyx_n_u_set __pyx_string_tab[90]
#define __pyx_n_u_set_name __pyx_string_tab[91]
#define __pyx_n_u_setattr __pyx_string_tab[92]
#define __pyx_n_u_setdefault __pyx_string_tab[93]
#define __pyx_n_u_slots __pyx_string_tab[94]
#define __pyx_n_u_super __pyx_string_tab[95]
#define __pyx_n_u_test __pyx_string_tab[96]
#define __pyx_n_u_unlink __pyx_string_tab[97]
#define __pyx_n_u_unused __pyx_string_tab[98]
#define __pyx_n_u_values __pyx_string_tab[99]
#define __pyx_n_u_weakref __pyx_string_tab[100]
#define __pyx_n_u_weakref_2 __pyx_string_tab[101]
#define __pyx_n_u_wrdicts __pyx_string_tab[102]
#define __pyx_n_u_wrefdict __pyx_string_tab[103]
#define __pyx_n_u_wrgreenlet __pyx_string_tab[104]
#define __pyx_n_u_wrthread __pyx_string_tab[105]
#define __pyx_kp_b_PyObject_PyGreenlet_int___pyx_sk __pyx_string_tab[106]
#define __pyx_kp_b_PyObject_PyTypeObject_int_Blocki __pyx_string_tab[107]
#define __pyx_kp_b_PyObject_WeakKeyDictionary_heapp __pyx_string_tab[108]
#define __pyx_kp_b_PyObject__threadlocal __pyx_string_tab[109]
#define __pyx_kp_b_PyObject_int_ConcurrentObjectUse __pyx_string_tab[110]
#define __pyx_kp_b_PyObject_int__local_attrs__marke __pyx_string_tab[111]
#define __pyx_kp_b_PyObject_int_struct___pyx_obj_6g __pyx_string_tab[112]
#define __pyx_kp_b_iso88591_5_HAQ_D_1 __pyx_string_tab[113]
#define __pyx_kp_b_iso88591_A_t1_F_2Qj_e1_D_d_1_3b_N_a_az_q __pyx_string_tab[114]
#define __pyx_kp_b_iso88591_HA __pyx_string_tab[115]
#define __pyx_kp_b_iso88591_Q_AQ_HA_5_V1_4q_1A_Qa_c_AQ_6_A __pyx_string_tab[116]
#define __pyx_kp_b_struct___pyx_obj_6gevent_29_geve __pyx_string_tab[117]
/* #### Code section: module_state_clear ### */
#if CYTHON_USE_MODULE_STATE
static CYTHON_SMALL_CODE int __pyx_m_clear(PyObject *m) {
  __pyx_mstatetype *clear_module_state = __Pyx_PyModule_GetState(m);
  if (!clear_module_state) return 0;
  Py_CLEAR(clear_module_state->__pyx_d);
  Py_CLEAR(clear_module_state->__pyx_b);
  Py_CLEAR(clear_module_state->__pyx_cython_runtime);
  Py_CLEAR(clear_module_state->__pyx_empty_tuple);
  Py_CLEAR(clear_module_state->__pyx_empty_bytes);
  Py_CLEAR(clear_module_state->__pyx_empty_unicode);
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __Pyx_State_RemoveModule(NULL);
  #endif
  Py_CLEAR(clear_module_state->__pyx_ptype_7cpython_4type_type);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_15_gevent_c_ident_ref);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_15_gevent_c_ident_ValuedWeakRef);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_15_gevent_c_ident_IdentRegistry);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_greenlet);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_16_gevent_c_waiter_greenlet);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_16_gevent_c_waiter_Waiter);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_16_gevent_c_waiter_MultipleWaiter);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet_greenlet);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet_SpawnedLink);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet_FailureSpawnedLink);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet__Frame);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet__dummy_event);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_14_gevent_clocal_greenlet);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_14_gevent_clocal__wrefdict);
  Py_CLEAR(clear_module_state->__pyx_type_6gevent_14_gevent_clocal__wrefdict);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_14_gevent_clocal__greenlet_deleted);
  Py_CLEAR(clear_module_state->__pyx_type_6gevent_14_gevent_clocal__greenlet_deleted);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_14_gevent_clocal__local_deleted);
  Py_CLEAR(clear_module_state->__pyx_type_6gevent_14_gevent_clocal__local_deleted);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_14_gevent_clocal__localimpl);
  Py_CLEAR(clear_module_state->__pyx_type_6gevent_14_gevent_clocal__localimpl);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_14_gevent_clocal__localimpl_dict_entry);
  Py_CLEAR(clear_module_state->__pyx_type_6gevent_14_gevent_clocal__localimpl_dict_entry);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_14_gevent_clocal_local);
  Py_CLEAR(clear_module_state->__pyx_type_6gevent_14_gevent_clocal_local);
  for (int i=0; i<4; ++i) { Py_CLEAR(clear_module_state->__pyx_tuple[i]); }
  for (int i=0; i<4; ++i) { Py_CLEAR(clear_module_state->__pyx_codeobj_tab[i]); }
  for (int i=0; i<118; ++i) { Py_CLEAR(clear_module_state->__pyx_string_tab[i]); }
/* #### Code section: module_state_clear_contents ### */
/* CommonTypesMetaclass.module_state_clear */
Py_CLEAR(clear_module_state->__pyx_CommonTypesMetaclassType);

/* CythonFunctionShared.module_state_clear */
Py_CLEAR(clear_module_state->__pyx_CyFunctionType);

/* #### Code section: module_state_clear_end ### */
return 0;
}
#endif
/* #### Code section: module_state_traverse ### */
#if CYTHON_USE_MODULE_STATE
static CYTHON_SMALL_CODE int __pyx_m_traverse(PyObject *m, visitproc visit, void *arg) {
  __pyx_mstatetype *traverse_module_state = __Pyx_PyModule_GetState(m);
  if (!traverse_module_state) return 0;
  Py_VISIT(traverse_module_state->__pyx_d);
  Py_VISIT(traverse_module_state->__pyx_b);
  Py_VISIT(traverse_module_state->__pyx_cython_runtime);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_tuple);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_bytes);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_unicode);
  Py_VISIT(traverse_module_state->__pyx_ptype_7cpython_4type_type);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_15_gevent_c_ident_ref);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_15_gevent_c_ident_ValuedWeakRef);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_15_gevent_c_ident_IdentRegistry);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_greenlet);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_16_gevent_c_waiter_greenlet);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_16_gevent_c_waiter_Waiter);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_16_gevent_c_waiter_MultipleWaiter);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet_greenlet);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet_SpawnedLink);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet_FailureSpawnedLink);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet__Frame);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet__dummy_event);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_14_gevent_clocal_greenlet);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_14_gevent_clocal__wrefdict);
  Py_VISIT(traverse_module_state->__pyx_type_6gevent_14_gevent_clocal__wrefdict);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_14_gevent_clocal__greenlet_deleted);
  Py_VISIT(traverse_module_state->__pyx_type_6gevent_14_gevent_clocal__greenlet_deleted);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_14_gevent_clocal__local_deleted);
  Py_VISIT(traverse_module_state->__pyx_type_6gevent_14_gevent_clocal__local_deleted);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_14_gevent_clocal__localimpl);
  Py_VISIT(traverse_module_state->__pyx_type_6gevent_14_gevent_clocal__localimpl);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_14_gevent_clocal__localimpl_dict_entry);
  Py_VISIT(traverse_module_state->__pyx_type_6gevent_14_gevent_clocal__localimpl_dict_entry);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_14_gevent_clocal_local);
  Py_VISIT(traverse_module_state->__pyx_type_6gevent_14_gevent_clocal_local);
  for (int i=0; i<4; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_tuple[i]); }
  for (int i=0; i<4; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_codeobj_tab[i]); }
  for (int i=0; i<118; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_string_tab[i]); }
/* #### Code section: module_state_traverse_contents ### */
/* CommonTypesMetaclass.module_state_traverse */
Py_VISIT(traverse_module_state->__pyx_CommonTypesMetaclassType);

/* CythonFunctionShared.module_state_traverse */
Py_VISIT(traverse_module_state->__pyx_CyFunctionType);

/* #### Code section: module_state_traverse_end ### */
return 0;
}
#endif
/* #### Code section: module_code ### */

/* "src/gevent/local.py":163
 * 
 * locals()['getcurrent'] = __import__('greenlet').getcurrent
 * locals()['greenlet_init'] = lambda: None             # <<<<<<<<<<<<<<
 * 
 * __all__ = [
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_14_gevent_clocal_4lambda(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_6gevent_14_gevent_clocal_4lambda = {"lambda", (PyCFunction)__pyx_pw_6gevent_14_gevent_clocal_4lambda, METH_NOARGS, 0};
static PyObject *__pyx_pw_6gevent_14_gevent_clocal_4lambda(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_lambda_funcdef_6gevent_14_gevent_clocal_lambda(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_6gevent_14_gevent_clocal_lambda(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/_gevent_c_greenlet_primitives.pxd":22
 *     void PyGreenlet_Import()
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef inline greenlet getcurrent():
 *     return PyGreenlet_GetCurrent()
*/

static CYTHON_INLINE PyGreenlet *__pyx_f_6gevent_29_gevent_c_greenlet_primitives_getcurrent(void) {
  PyGreenlet *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getcurrent", 0);

  /* "gevent/_gevent_c_greenlet_primitives.pxd":24
 * @cython.final
 * cdef inline greenlet getcurrent():
 *     return PyGreenlet_GetCurrent()             # <<<<<<<<<<<<<<
 * 
 * cdef bint _greenlet_imported
*/
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __pyx_t_1 = ((PyObject *)PyGreenlet_GetCurrent()); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = ((PyGreenlet *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "gevent/_gevent_c_greenlet_primitives.pxd":22
 *     void PyGreenlet_Import()
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef inline greenlet getcurrent():
 *     return PyGreenlet_GetCurrent()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_c_greenlet_primitives.getcurrent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/_gevent_c_greenlet_primitives.pxd":28
 * cdef bint _greenlet_imported
 * 
 * cdef inline void greenlet_init():             # <<<<<<<<<<<<<<
 *     global _greenlet_imported
 *     if not _greenlet_imported:
*/

static CYTHON_INLINE void __pyx_f_6gevent_29_gevent_c_greenlet_primitives_greenlet_init(void) {
  int __pyx_t_1;

  /* "gevent/_gevent_c_greenlet_primitives.pxd":30
 * cdef inline void greenlet_init():
 *     global _greenlet_imported
 *     if not _greenlet_imported:             # <<<<<<<<<<<<<<
 *         PyGreenlet_Import()
 *         _greenlet_imported = True
*/
  __pyx_t_1 = (!__pyx_v_6gevent_29_gevent_c_greenlet_primitives__greenlet_imported);
  if (__pyx_t_1) {

    /* "gevent/_gevent_c_greenlet_primitives.pxd":31
 *     global _greenlet_imported
 *     if not _greenlet_imported:
 *         PyGreenlet_Import()             # <<<<<<<<<<<<<<
 *         _greenlet_imported = True
 * 
*/
    PyGreenlet_Import();

    /* "gevent/_gevent_c_greenlet_primitives.pxd":32
 *     if not _greenlet_imported:
 *         PyGreenlet_Import()
 *         _greenlet_imported = True             # <<<<<<<<<<<<<<
 * 
 * cdef inline object _greenlet_switch(greenlet self):
*/
    __pyx_v_6gevent_29_gevent_c_greenlet_primitives__greenlet_imported = 1;

    /* "gevent/_gevent_c_greenlet_primitives.pxd":30
 * cdef inline void greenlet_init():
 *     global _greenlet_imported
 *     if not _greenlet_imported:             # <<<<<<<<<<<<<<
 *         PyGreenlet_Import()
 *         _greenlet_imported = True
*/
  }

  /* "gevent/_gevent_c_greenlet_primitives.pxd":28
 * cdef bint _greenlet_imported
 * 
 * cdef inline void greenlet_init():             # <<<<<<<<<<<<<<
 *     global _greenlet_imported
 *     if not _greenlet_imported:
*/

  /* function exit code */
}

/* "gevent/_gevent_c_greenlet_primitives.pxd":34
 *         _greenlet_imported = True
 * 
 * cdef inline object _greenlet_switch(greenlet self):             # <<<<<<<<<<<<<<
 *     return PyGreenlet_Switch(self, NULL, NULL)
 * 
*/

static CYTHON_INLINE PyObject *__pyx_f_6gevent_29_gevent_c_greenlet_primitives__greenlet_switch(PyGreenlet *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_greenlet_switch", 0);

  /* "gevent/_gevent_c_greenlet_primitives.pxd":35
 * 
 * cdef inline object _greenlet_switch(greenlet self):
 *     return PyGreenlet_Switch(self, NULL, NULL)             # <<<<<<<<<<<<<<
 * 
 * cdef class TrackedRawGreenlet(greenlet):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyGreenlet_Switch(__pyx_v_self, NULL, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 35, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "gevent/_gevent_c_greenlet_primitives.pxd":34
 *         _greenlet_imported = True
 * 
 * cdef inline object _greenlet_switch(greenlet self):             # <<<<<<<<<<<<<<
 *     return PyGreenlet_Switch(self, NULL, NULL)
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_c_greenlet_primitives._greenlet_switch", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/_gevent_c_waiter.pxd":24
 *     void PyGreenlet_Import()
 * 
 * cdef inline greenlet getcurrent():             # <<<<<<<<<<<<<<
 *     return PyGreenlet_GetCurrent()
 * 
*/

static CYTHON_INLINE PyGreenlet *__pyx_f_6gevent_16_gevent_c_waiter_getcurrent(void) {
  PyGreenlet *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getcurrent", 0);

  /* "gevent/_gevent_c_waiter.pxd":25
 * 
 * cdef inline greenlet getcurrent():
 *     return PyGreenlet_GetCurrent()             # <<<<<<<<<<<<<<
 * 
 * cdef inline void greenlet_init():
*/
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __pyx_t_1 = ((PyObject *)PyGreenlet_GetCurrent()); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = ((PyGreenlet *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "gevent/_gevent_c_waiter.pxd":24
 *     void PyGreenlet_Import()
 * 
 * cdef inline greenlet getcurrent():             # <<<<<<<<<<<<<<
 *     return PyGreenlet_GetCurrent()
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_c_waiter.getcurrent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/_gevent_c_waiter.pxd":27
 *     return PyGreenlet_GetCurrent()
 * 
 * cdef inline void greenlet_init():             # <<<<<<<<<<<<<<
 *     global _greenlet_imported
 *     if not _greenlet_imported:
*/

static CYTHON_INLINE void __pyx_f_6gevent_16_gevent_c_waiter_greenlet_init(void) {
  int __pyx_t_1;

  /* "gevent/_gevent_c_waiter.pxd":29
 * cdef inline void greenlet_init():
 *     global _greenlet_imported
 *     if not _greenlet_imported:             # <<<<<<<<<<<<<<
 *         PyGreenlet_Import()
 *         _greenlet_imported = True
*/
  __pyx_t_1 = (!__pyx_v_6gevent_16_gevent_c_waiter__greenlet_imported);
  if (__pyx_t_1) {

    /* "gevent/_gevent_c_waiter.pxd":30
 *     global _greenlet_imported
 *     if not _greenlet_imported:
 *         PyGreenlet_Import()             # <<<<<<<<<<<<<<
 *         _greenlet_imported = True
 * 
*/
    PyGreenlet_Import();

    /* "gevent/_gevent_c_waiter.pxd":31
 *     if not _greenlet_imported:
 *         PyGreenlet_Import()
 *         _greenlet_imported = True             # <<<<<<<<<<<<<<
 * 
 * cdef class Waiter:
*/
    __pyx_v_6gevent_16_gevent_c_waiter__greenlet_imported = 1;

    /* "gevent/_gevent_c_waiter.pxd":29
 * cdef inline void greenlet_init():
 *     global _greenlet_imported
 *     if not _greenlet_imported:             # <<<<<<<<<<<<<<
 *         PyGreenlet_Import()
 *         _greenlet_imported = True
*/
  }

  /* "gevent/_gevent_c_waiter.pxd":27
 *     return PyGreenlet_GetCurrent()
 * 
 * cdef inline void greenlet_init():             # <<<<<<<<<<<<<<
 *     global _greenlet_imported
 *     if not _greenlet_imported:
*/

  /* function exit code */
}

/* "gevent/_gevent_cgreenlet.pxd":36
 *     void PyGreenlet_Import()
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef inline greenlet getcurrent():
 *     return PyGreenlet_GetCurrent()
*/

static CYTHON_INLINE PyGreenlet *__pyx_f_6gevent_17_gevent_cgreenlet_getcurrent(void) {
  PyGreenlet *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getcurrent", 0);

  /* "gevent/_gevent_cgreenlet.pxd":38
 * @cython.final
 * cdef inline greenlet getcurrent():
 *     return PyGreenlet_GetCurrent()             # <<<<<<<<<<<<<<
 * 
 * cdef inline object get_generic_parent(greenlet s):
*/
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __pyx_t_1 = ((PyObject *)PyGreenlet_GetCurrent()); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 38, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = ((PyGreenlet *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "gevent/_gevent_cgreenlet.pxd":36
 *     void PyGreenlet_Import()
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef inline greenlet getcurrent():
 *     return PyGreenlet_GetCurrent()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.getcurrent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/_gevent_cgreenlet.pxd":40
 *     return PyGreenlet_GetCurrent()
 * 
 * cdef inline object get_generic_parent(greenlet s):             # <<<<<<<<<<<<<<
 *     # We don't use any typed functions on the return of this,
 *     # so save the type check by making it just an object.
*/

static CYTHON_INLINE PyObject *__pyx_f_6gevent_17_gevent_cgreenlet_get_generic_parent(PyGreenlet *__pyx_v_s) {
  PyObject *__pyx_v_result = 0;
  void *__pyx_v_parent;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("get_generic_parent", 0);

  /* "gevent/_gevent_cgreenlet.pxd":44
 *     # so save the type check by making it just an object.
 *     cdef object result
 *     cdef void* parent = PyGreenlet_GetParent(s)             # <<<<<<<<<<<<<<
 *     if parent != NULL:
 *         # The cast will perform an incref; but the GetParent
*/
  __pyx_v_parent = PyGreenlet_GetParent(__pyx_v_s);

  /* "gevent/_gevent_cgreenlet.pxd":45
 *     cdef object result
 *     cdef void* parent = PyGreenlet_GetParent(s)
 *     if parent != NULL:             # <<<<<<<<<<<<<<
 *         # The cast will perform an incref; but the GetParent
 *         # function already did an incref if we got it (and not NULL).
*/
  __pyx_t_1 = (__pyx_v_parent != NULL);
  if (__pyx_t_1) {

    /* "gevent/_gevent_cgreenlet.pxd":49
 *         # function already did an incref if we got it (and not NULL).
 *         # Therefore, we must DECREF immediately.
 *         result = <object>parent             # <<<<<<<<<<<<<<
 *         Py_DECREF(result)
 *         return result
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_parent);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v_result = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "gevent/_gevent_cgreenlet.pxd":50
 *         # Therefore, we must DECREF immediately.
 *         result = <object>parent
 *         Py_DECREF(result)             # <<<<<<<<<<<<<<
 *         return result
 * 
*/
    Py_DECREF(__pyx_v_result);

    /* "gevent/_gevent_cgreenlet.pxd":51
 *         result = <object>parent
 *         Py_DECREF(result)
 *         return result             # <<<<<<<<<<<<<<
 * 
 * cdef inline SwitchOutGreenletWithLoop get_my_hub(greenlet s):
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_result);
    __pyx_r = __pyx_v_result;
    goto __pyx_L0;

    /* "gevent/_gevent_cgreenlet.pxd":45
 *     cdef object result
 *     cdef void* parent = PyGreenlet_GetParent(s)
 *     if parent != NULL:             # <<<<<<<<<<<<<<
 *         # The cast will perform an incref; but the GetParent
 *         # function already did an incref if we got it (and not NULL).
*/
  }

  /* "gevent/_gevent_cgreenlet.pxd":40
 *     return PyGreenlet_GetCurrent()
 * 
 * cdef inline object get_generic_parent(greenlet s):             # <<<<<<<<<<<<<<
 *     # We don't use any typed functions on the return of this,
 *     # so save the type check by making it just an object.
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/_gevent_cgreenlet.pxd":53
 *         return result
 * 
 * cdef inline SwitchOutGreenletWithLoop get_my_hub(greenlet s):             # <<<<<<<<<<<<<<
 *     # This one we do want type checked on the return value.
 *     # Must not be called with s = None
*/

static CYTHON_INLINE struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *__pyx_f_6gevent_17_gevent_cgreenlet_get_my_hub(PyGreenlet *__pyx_v_s) {
  PyObject *__pyx_v_result = 0;
  void *__pyx_v_parent;
  struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_my_hub", 0);

  /* "gevent/_gevent_cgreenlet.pxd":57
 *     # Must not be called with s = None
 *     cdef object result
 *     cdef void* parent = PyGreenlet_GetParent(s)             # <<<<<<<<<<<<<<
 *     if parent != NULL:
 *         result = <object>parent
*/
  __pyx_v_parent = PyGreenlet_GetParent(__pyx_v_s);

  /* "gevent/_gevent_cgreenlet.pxd":58
 *     cdef object result
 *     cdef void* parent = PyGreenlet_GetParent(s)
 *     if parent != NULL:             # <<<<<<<<<<<<<<
 *         result = <object>parent
 *         # See above
*/
  __pyx_t_1 = (__pyx_v_parent != NULL);
  if (__pyx_t_1) {

    /* "gevent/_gevent_cgreenlet.pxd":59
 *     cdef void* parent = PyGreenlet_GetParent(s)
 *     if parent != NULL:
 *         result = <object>parent             # <<<<<<<<<<<<<<
 *         # See above
 *         Py_DECREF(result)
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_parent);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v_result = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "gevent/_gevent_cgreenlet.pxd":61
 *         result = <object>parent
 *         # See above
 *         Py_DECREF(result)             # <<<<<<<<<<<<<<
 *         return result
 * 
*/
    Py_DECREF(__pyx_v_result);

    /* "gevent/_gevent_cgreenlet.pxd":62
 *         # See above
 *         Py_DECREF(result)
 *         return result             # <<<<<<<<<<<<<<
 * 
 * cdef bint _greenlet_imported
*/
    __Pyx_XDECREF((PyObject *)__pyx_r);
    if (!(likely(((__pyx_v_result) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_result, __pyx_mstate_global->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop))))) __PYX_ERR(3, 62, __pyx_L1_error)
    __Pyx_INCREF(__pyx_v_result);
    __pyx_r = ((struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *)__pyx_v_result);
    goto __pyx_L0;

    /* "gevent/_gevent_cgreenlet.pxd":58
 *     cdef object result
 *     cdef void* parent = PyGreenlet_GetParent(s)
 *     if parent != NULL:             # <<<<<<<<<<<<<<
 *         result = <object>parent
 *         # See above
*/
  }

  /* "gevent/_gevent_cgreenlet.pxd":53
 *         return result
 * 
 * cdef inline SwitchOutGreenletWithLoop get_my_hub(greenlet s):             # <<<<<<<<<<<<<<
 *     # This one we do want type checked on the return value.
 *     # Must not be called with s = None
*/

  /* function exit code */
  __pyx_r = ((struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *)Py_None); __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.get_my_hub", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/_gevent_cgreenlet.pxd":66
 * cdef bint _greenlet_imported
 * 
 * cdef inline void greenlet_init():             # <<<<<<<<<<<<<<
 *     global _greenlet_imported
 *     if not _greenlet_imported:
*/

static CYTHON_INLINE void __pyx_f_6gevent_17_gevent_cgreenlet_greenlet_init(void) {
  int __pyx_t_1;

  /* "gevent/_gevent_cgreenlet.pxd":68
 * cdef inline void greenlet_init():
 *     global _greenlet_imported
 *     if not _greenlet_imported:             # <<<<<<<<<<<<<<
 *         PyGreenlet_Import()
 *         _greenlet_imported = True
*/
  __pyx_t_1 = (!__pyx_v_6gevent_17_gevent_cgreenlet__greenlet_imported);
  if (__pyx_t_1) {

    /* "gevent/_gevent_cgreenlet.pxd":69
 *     global _greenlet_imported
 *     if not _greenlet_imported:
 *         PyGreenlet_Import()             # <<<<<<<<<<<<<<
 *         _greenlet_imported = True
 * 
*/
    PyGreenlet_Import();

    /* "gevent/_gevent_cgreenlet.pxd":70
 *     if not _greenlet_imported:
 *         PyGreenlet_Import()
 *         _greenlet_imported = True             # <<<<<<<<<<<<<<
 * 
 * ctypedef object CodeType
*/
    __pyx_v_6gevent_17_gevent_cgreenlet__greenlet_imported = 1;

    /* "gevent/_gevent_cgreenlet.pxd":68
 * cdef inline void greenlet_init():
 *     global _greenlet_imported
 *     if not _greenlet_imported:             # <<<<<<<<<<<<<<
 *         PyGreenlet_Import()
 *         _greenlet_imported = True
*/
  }

  /* "gevent/_gevent_cgreenlet.pxd":66
 * cdef bint _greenlet_imported
 * 
 * cdef inline void greenlet_init():             # <<<<<<<<<<<<<<
 *     global _greenlet_imported
 *     if not _greenlet_imported:
*/

  /* function exit code */
}

/* "gevent/_gevent_clocal.pxd":26
 *     void PyGreenlet_Import()
 * 
 * cdef inline greenlet getcurrent():             # <<<<<<<<<<<<<<
 *     return PyGreenlet_GetCurrent()
 * 
*/

static CYTHON_INLINE PyGreenlet *__pyx_f_6gevent_14_gevent_clocal_getcurrent(void) {
  PyGreenlet *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getcurrent", 0);

  /* "gevent/_gevent_clocal.pxd":27
 * 
 * cdef inline greenlet getcurrent():
 *     return PyGreenlet_GetCurrent()             # <<<<<<<<<<<<<<
 * 
 * cdef inline void greenlet_init():
*/
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __pyx_t_1 = ((PyObject *)PyGreenlet_GetCurrent()); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 27, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = ((PyGreenlet *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "gevent/_gevent_clocal.pxd":26
 *     void PyGreenlet_Import()
 * 
 * cdef inline greenlet getcurrent():             # <<<<<<<<<<<<<<
 *     return PyGreenlet_GetCurrent()
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_clocal.getcurrent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/_gevent_clocal.pxd":29
 *     return PyGreenlet_GetCurrent()
 * 
 * cdef inline void greenlet_init():             # <<<<<<<<<<<<<<
 *     global _greenlet_imported
 *     if not _greenlet_imported:
*/

static CYTHON_INLINE void __pyx_f_6gevent_14_gevent_clocal_greenlet_init(void) {
  int __pyx_t_1;

  /* "gevent/_gevent_clocal.pxd":31
 * cdef inline void greenlet_init():
 *     global _greenlet_imported
 *     if not _greenlet_imported:             # <<<<<<<<<<<<<<
 *         PyGreenlet_Import()
 *         _greenlet_imported = True
*/
  __pyx_t_1 = (!__pyx_v_6gevent_14_gevent_clocal__greenlet_imported);
  if (__pyx_t_1) {

    /* "gevent/_gevent_clocal.pxd":32
 *     global _greenlet_imported
 *     if not _greenlet_imported:
 *         PyGreenlet_Import()             # <<<<<<<<<<<<<<
 *         _greenlet_imported = True
 * 
*/
    PyGreenlet_Import();

    /* "gevent/_gevent_clocal.pxd":33
 *     if not _greenlet_imported:
 *         PyGreenlet_Import()
 *         _greenlet_imported = True             # <<<<<<<<<<<<<<
 * 
 * 
*/
    __pyx_v_6gevent_14_gevent_clocal__greenlet_imported = 1;

    /* "gevent/_gevent_clocal.pxd":31
 * cdef inline void greenlet_init():
 *     global _greenlet_imported
 *     if not _greenlet_imported:             # <<<<<<<<<<<<<<
 *         PyGreenlet_Import()
 *         _greenlet_imported = True
*/
  }

  /* "gevent/_gevent_clocal.pxd":29
 *     return PyGreenlet_GetCurrent()
 * 
 * cdef inline void greenlet_init():             # <<<<<<<<<<<<<<
 *     global _greenlet_imported
 *     if not _greenlet_imported:
*/

  /* function exit code */
}

/* "src/gevent/local.py":181
 * # That final tuple is actually a localimpl_dict_entry object.
 * 
 * def all_local_dicts_for_greenlet(greenlet):             # <<<<<<<<<<<<<<
 *     """
 *     Internal debug helper for getting the local values associated
*/

static PyObject *__pyx_pw_6gevent_14_gevent_clocal_1all_local_dicts_for_greenlet(PyObject *__pyx_self, PyObject *__pyx_v_greenlet); /*proto*/
static PyObject *__pyx_f_6gevent_14_gevent_clocal_all_local_dicts_for_greenlet(PyGreenlet *__pyx_v_greenlet, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_v_result = 0;
  struct __pyx_obj_6gevent_14_gevent_clocal__localimpl *__pyx_v_local_impl = 0;
  struct __pyx_obj_6gevent_14_gevent_clocal__localimpl_dict_entry *__pyx_v_entry = 0;
  PyObject *__pyx_v_k = 0;
  PyObject *__pyx_v_greenlet_dict = 0;
  PyObject *__pyx_v_id_greenlet = NULL;
  PyObject *__pyx_v_v = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("all_local_dicts_for_greenlet", 0);

  /* "src/gevent/local.py":193
 *     """
 * 
 *     result = []             # <<<<<<<<<<<<<<
 *     id_greenlet = id(greenlet)
 *     greenlet_dict = greenlet.__dict__
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_result = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "src/gevent/local.py":194
 * 
 *     result = []
 *     id_greenlet = id(greenlet)             # <<<<<<<<<<<<<<
 *     greenlet_dict = greenlet.__dict__
 *     for k, v in greenlet_dict.items():
*/
  __pyx_t_2 = NULL;
  __pyx_t_3 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, ((PyObject *)__pyx_v_greenlet)};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_id, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 194, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_id_greenlet = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "src/gevent/local.py":195
 *     result = []
 *     id_greenlet = id(greenlet)
 *     greenlet_dict = greenlet.__dict__             # <<<<<<<<<<<<<<
 *     for k, v in greenlet_dict.items():
 *         if not k.startswith(key_prefix):
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_greenlet), __pyx_mstate_global->__pyx_n_u_dict); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 195, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyDict_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("dict", __pyx_t_1))) __PYX_ERR(0, 195, __pyx_L1_error)
  __pyx_v_greenlet_dict = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "src/gevent/local.py":196
 *     id_greenlet = id(greenlet)
 *     greenlet_dict = greenlet.__dict__
 *     for k, v in greenlet_dict.items():             # <<<<<<<<<<<<<<
 *         if not k.startswith(key_prefix):
 *             continue
*/
  __pyx_t_4 = 0;
  if (unlikely(__pyx_v_greenlet_dict == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "items");
    __PYX_ERR(0, 196, __pyx_L1_error)
  }
  __pyx_t_2 = __Pyx_dict_iterator(__pyx_v_greenlet_dict, 1, __pyx_mstate_global->__pyx_n_u_items, (&__pyx_t_5), (&__pyx_t_6)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 196, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_2;
  __pyx_t_2 = 0;
  while (1) {
    __pyx_t_8 = __Pyx_dict_iter_next(__pyx_t_1, __pyx_t_5, &__pyx_t_4, &__pyx_t_2, &__pyx_t_7, NULL, __pyx_t_6);
    if (unlikely(__pyx_t_8 == 0)) break;
    if (unlikely(__pyx_t_8 == -1)) __PYX_ERR(0, 196, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GOTREF(__pyx_t_7);
    if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None) || __Pyx_RaiseUnexpectedTypeError("str", __pyx_t_2))) __PYX_ERR(0, 196, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_k, ((PyObject*)__pyx_t_2));
    __pyx_t_2 = 0;
    __Pyx_XDECREF_SET(__pyx_v_v, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "src/gevent/local.py":197
 *     greenlet_dict = greenlet.__dict__
 *     for k, v in greenlet_dict.items():
 *         if not k.startswith(key_prefix):             # <<<<<<<<<<<<<<
 *             continue
 *         local_impl = v()
*/
    if (unlikely(__pyx_v_k == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "startswith");
      __PYX_ERR(0, 197, __pyx_L1_error)
    }
    __pyx_t_9 = __Pyx_PyUnicode_Tailmatch(__pyx_v_k, __pyx_v_6gevent_14_gevent_clocal_key_prefix, 0, PY_SSIZE_T_MAX, -1); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 197, __pyx_L1_error)
    __pyx_t_10 = (!__pyx_t_9);
    if (__pyx_t_10) {

      /* "src/gevent/local.py":198
 *     for k, v in greenlet_dict.items():
 *         if not k.startswith(key_prefix):
 *             continue             # <<<<<<<<<<<<<<
 *         local_impl = v()
 *         if local_impl is None:
*/
      goto __pyx_L3_continue;

      /* "src/gevent/local.py":197
 *     greenlet_dict = greenlet.__dict__
 *     for k, v in greenlet_dict.items():
 *         if not k.startswith(key_prefix):             # <<<<<<<<<<<<<<
 *             continue
 *         local_impl = v()
*/
    }

    /* "src/gevent/local.py":199
 *         if not k.startswith(key_prefix):
 *             continue
 *         local_impl = v()             # <<<<<<<<<<<<<<
 *         if local_impl is None:
 *             continue
*/
    __pyx_t_2 = NULL;
    __Pyx_INCREF(__pyx_v_v);
    __pyx_t_11 = __pyx_v_v; 
    __pyx_t_3 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_11))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_11);
      assert(__pyx_t_2);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_11);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_11, __pyx__function);
      __pyx_t_3 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_7 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_11, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 199, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
    }
    if (!(likely(((__pyx_t_7) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_7, __pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_clocal__localimpl))))) __PYX_ERR(0, 199, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_local_impl, ((struct __pyx_obj_6gevent_14_gevent_clocal__localimpl *)__pyx_t_7));
    __pyx_t_7 = 0;

    /* "src/gevent/local.py":200
 *             continue
 *         local_impl = v()
 *         if local_impl is None:             # <<<<<<<<<<<<<<
 *             continue
 *         entry = local_impl.dicts.get(id_greenlet)
*/
    __pyx_t_10 = (((PyObject *)__pyx_v_local_impl) == Py_None);
    if (__pyx_t_10) {

      /* "src/gevent/local.py":201
 *         local_impl = v()
 *         if local_impl is None:
 *             continue             # <<<<<<<<<<<<<<
 *         entry = local_impl.dicts.get(id_greenlet)
 *         if entry is None:
*/
      goto __pyx_L3_continue;

      /* "src/gevent/local.py":200
 *             continue
 *         local_impl = v()
 *         if local_impl is None:             # <<<<<<<<<<<<<<
 *             continue
 *         entry = local_impl.dicts.get(id_greenlet)
*/
    }

    /* "src/gevent/local.py":202
 *         if local_impl is None:
 *             continue
 *         entry = local_impl.dicts.get(id_greenlet)             # <<<<<<<<<<<<<<
 *         if entry is None:
 *             # Not yet used in this greenlet.
*/
    if (unlikely(__pyx_v_local_impl->dicts == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "get");
      __PYX_ERR(0, 202, __pyx_L1_error)
    }
    __pyx_t_7 = __Pyx_PyDict_GetItemDefault(__pyx_v_local_impl->dicts, __pyx_v_id_greenlet, Py_None); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 202, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (!(likely(((__pyx_t_7) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_7, __pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_clocal__localimpl_dict_entry))))) __PYX_ERR(0, 202, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_entry, ((struct __pyx_obj_6gevent_14_gevent_clocal__localimpl_dict_entry *)__pyx_t_7));
    __pyx_t_7 = 0;

    /* "src/gevent/local.py":203
 *             continue
 *         entry = local_impl.dicts.get(id_greenlet)
 *         if entry is None:             # <<<<<<<<<<<<<<
 *             # Not yet used in this greenlet.
 *             continue
*/
    __pyx_t_10 = (((PyObject *)__pyx_v_entry) == Py_None);
    if (__pyx_t_10) {

      /* "src/gevent/local.py":205
 *         if entry is None:
 *             # Not yet used in this greenlet.
 *             continue             # <<<<<<<<<<<<<<
 *         assert entry.wrgreenlet() is greenlet
 *         result.append((local_impl.localtypeid, entry.localdict))
*/
      goto __pyx_L3_continue;

      /* "src/gevent/local.py":203
 *             continue
 *         entry = local_impl.dicts.get(id_greenlet)
 *         if entry is None:             # <<<<<<<<<<<<<<
 *             # Not yet used in this greenlet.
 *             continue
*/
    }

    /* "src/gevent/local.py":206
 *             # Not yet used in this greenlet.
 *             continue
 *         assert entry.wrgreenlet() is greenlet             # <<<<<<<<<<<<<<
 *         result.append((local_impl.localtypeid, entry.localdict))
 * 
*/
    #ifndef CYTHON_WITHOUT_ASSERTIONS
    if (unlikely(__pyx_assertions_enabled())) {
      __pyx_t_11 = NULL;
      __Pyx_INCREF(__pyx_v_entry->wrgreenlet);
      __pyx_t_2 = __pyx_v_entry->wrgreenlet; 
      __pyx_t_3 = 1;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_2);
        assert(__pyx_t_11);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_11);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
        __pyx_t_3 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_11, NULL};
        __pyx_t_7 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 206, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
      }
      __pyx_t_10 = (__pyx_t_7 == ((PyObject *)__pyx_v_greenlet));
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_10)) {
        __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_AssertionError))), 0, 0, 0);
        __PYX_ERR(0, 206, __pyx_L1_error)
      }
    }
    #else
    if ((1)); else __PYX_ERR(0, 206, __pyx_L1_error)
    #endif

    /* "src/gevent/local.py":207
 *             continue
 *         assert entry.wrgreenlet() is greenlet
 *         result.append((local_impl.localtypeid, entry.localdict))             # <<<<<<<<<<<<<<
 * 
 *     return result
*/
    __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 207, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_INCREF(__pyx_v_local_impl->localtypeid);
    __Pyx_GIVEREF(__pyx_v_local_impl->localtypeid);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_v_local_impl->localtypeid) != (0)) __PYX_ERR(0, 207, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_entry->localdict);
    __Pyx_GIVEREF(__pyx_v_entry->localdict);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_v_entry->localdict) != (0)) __PYX_ERR(0, 207, __pyx_L1_error);
    __pyx_t_12 = __Pyx_PyList_Append(__pyx_v_result, __pyx_t_7); if (unlikely(__pyx_t_12 == ((int)-1))) __PYX_ERR(0, 207, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_L3_continue:;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "src/gevent/local.py":209
 *         result.append((local_impl.localtypeid, entry.localdict))
 * 
 *     return result             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "src/gevent/local.py":181
 * # That final tuple is actually a localimpl_dict_entry object.
 * 
 * def all_local_dicts_for_greenlet(greenlet):             # <<<<<<<<<<<<<<
 *     """
 *     Internal debug helper for getting the local values associated
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("gevent._gevent_clocal.all_local_dicts_for_greenlet", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF((PyObject *)__pyx_v_local_impl);
  __Pyx_XDECREF((PyObject *)__pyx_v_entry);
  __Pyx_XDECREF(__pyx_v_k);
  __Pyx_XDECREF(__pyx_v_greenlet_dict);
  __Pyx_XDECREF(__pyx_v_id_greenlet);
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_14_gevent_clocal_1all_local_dicts_for_greenlet(PyObject *__pyx_self, PyObject *__pyx_v_greenlet); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_14_gevent_clocal_all_local_dicts_for_greenlet, "all_local_dicts_for_greenlet(greenlet greenlet)\n\nInternal debug helper for getting the local values associated\nwith a greenlet. This is subject to change or removal at any time.\n\n:return: A list of ((type, id), {}) pairs, where the first element\n  is the type and id of the local object and the second object is its\n  instance dictionary, as seen from this greenlet.\n\n.. versionadded:: 1.3a2");
static PyMethodDef __pyx_mdef_6gevent_14_gevent_clocal_1all_local_dicts_for_greenlet = {"all_local_dicts_for_greenlet", (PyCFunction)__pyx_pw_6gevent_14_gevent_clocal_1all_local_dicts_for_greenlet, METH_O, __pyx_doc_6gevent_14_gevent_clocal_all_local_dicts_for_greenlet};
static PyObject *__pyx_pw_6gevent_14_gevent_clocal_1all_local_dicts_for_greenlet(PyObject *__pyx_self, PyObject *__pyx_v_greenlet) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("all_local_dicts_for_greenlet (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_greenlet), __pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_clocal_greenlet, 1, "greenlet", 0))) __PYX_ERR(0, 181, __pyx_L1_error)
  __pyx_r = __pyx_pf_6gevent_14_gevent_clocal_all_local_dicts_for_greenlet(__pyx_self, ((PyGreenlet *)__pyx_v_greenlet));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  goto __pyx_L5_cleaned_up;
  __pyx_L0:;
  __pyx_L5_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_14_gevent_clocal_all_local_dicts_for_greenlet(CYTHON_UNUSED PyObject *__pyx_self, PyGreenlet *__pyx_v_greenlet) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("all_local_dicts_for_greenlet", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6gevent_14_gevent_clocal_all_local_dicts_for_greenlet(__pyx_v_greenlet, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_clocal.all_local_dicts_for_greenlet", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/local.py":226
 *     __slots__ = ('idt', 'wrdicts')
 * 
 *     def __init__(self, idt, wrdicts):             # <<<<<<<<<<<<<<
 *         self.idt = idt
 *         self.wrdicts = wrdicts
*/

/* Python wrapper */
static int __pyx_pw_6gevent_14_gevent_clocal_17_greenlet_deleted_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6gevent_14_gevent_clocal_17_greenlet_deleted_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_idt = 0;
  PyObject *__pyx_v_wrdicts = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_idt,&__pyx_mstate_global->__pyx_n_u_wrdicts,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 226, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 226, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 226, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__init__", 0) < (0)) __PYX_ERR(0, 226, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, i); __PYX_ERR(0, 226, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 226, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 226, __pyx_L3_error)
    }
    __pyx_v_idt = values[0];
    __pyx_v_wrdicts = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 226, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("gevent._gevent_clocal._greenlet_deleted.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6gevent_14_gevent_clocal_17_greenlet_deleted___init__(((struct __pyx_obj_6gevent_14_gevent_clocal__greenlet_deleted *)__pyx_v_self), __pyx_v_idt, __pyx_v_wrdicts);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6gevent_14_gevent_clocal_17_greenlet_deleted___init__(struct __pyx_obj_6gevent_14_gevent_clocal__greenlet_deleted *__pyx_v_self, PyObject *__pyx_v_idt, PyObject *__pyx_v_wrdicts) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "src/gevent/local.py":227
 * 
 *     def __init__(self, idt, wrdicts):
 *         self.idt = idt             # <<<<<<<<<<<<<<
 *         self.wrdicts = wrdicts
 * 
*/
  __Pyx_INCREF(__pyx_v_idt);
  __Pyx_GIVEREF(__pyx_v_idt);
  __Pyx_GOTREF(__pyx_v_self->idt);
  __Pyx_DECREF(__pyx_v_self->idt);
  __pyx_v_self->idt = __pyx_v_idt;

  /* "src/gevent/local.py":228
 *     def __init__(self, idt, wrdicts):
 *         self.idt = idt
 *         self.wrdicts = wrdicts             # <<<<<<<<<<<<<<
 * 
 *     def __call__(self, _unused):
*/
  __Pyx_INCREF(__pyx_v_wrdicts);
  __Pyx_GIVEREF(__pyx_v_wrdicts);
  __Pyx_GOTREF(__pyx_v_self->wrdicts);
  __Pyx_DECREF(__pyx_v_self->wrdicts);
  __pyx_v_self->wrdicts = __pyx_v_wrdicts;

  /* "src/gevent/local.py":226
 *     __slots__ = ('idt', 'wrdicts')
 * 
 *     def __init__(self, idt, wrdicts):             # <<<<<<<<<<<<<<
 *         self.idt = idt
 *         self.wrdicts = wrdicts
*/

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/local.py":230
 *         self.wrdicts = wrdicts
 * 
 *     def __call__(self, _unused):             # <<<<<<<<<<<<<<
 *         dicts = self.wrdicts()
 *         if dicts:
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_14_gevent_clocal_17_greenlet_deleted_3__call__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6gevent_14_gevent_clocal_17_greenlet_deleted_3__call__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v__unused = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__call__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_unused,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 230, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 230, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__call__", 0) < (0)) __PYX_ERR(0, 230, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__call__", 1, 1, 1, i); __PYX_ERR(0, 230, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 230, __pyx_L3_error)
    }
    __pyx_v__unused = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__call__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 230, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("gevent._gevent_clocal._greenlet_deleted.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6gevent_14_gevent_clocal_17_greenlet_deleted_2__call__(((struct __pyx_obj_6gevent_14_gevent_clocal__greenlet_deleted *)__pyx_v_self), __pyx_v__unused);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_14_gevent_clocal_17_greenlet_deleted_2__call__(struct __pyx_obj_6gevent_14_gevent_clocal__greenlet_deleted *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v__unused) {
  PyObject *__pyx_v_dicts = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__call__", 0);

  /* "src/gevent/local.py":231
 * 
 *     def __call__(self, _unused):
 *         dicts = self.wrdicts()             # <<<<<<<<<<<<<<
 *         if dicts:
 *             dicts.pop(self.idt, None)
*/
  __pyx_t_2 = NULL;
  __Pyx_INCREF(__pyx_v_self->wrdicts);
  __pyx_t_3 = __pyx_v_self->wrdicts; 
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 231, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_dicts = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "src/gevent/local.py":232
 *     def __call__(self, _unused):
 *         dicts = self.wrdicts()
 *         if dicts:             # <<<<<<<<<<<<<<
 *             dicts.pop(self.idt, None)
 * 
*/
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_dicts); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 232, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "src/gevent/local.py":233
 *         dicts = self.wrdicts()
 *         if dicts:
 *             dicts.pop(self.idt, None)             # <<<<<<<<<<<<<<
 * 
 * class _local_deleted(object):
*/
    __pyx_t_3 = __pyx_v_dicts;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_self->idt, Py_None};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_pop, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 233, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "src/gevent/local.py":232
 *     def __call__(self, _unused):
 *         dicts = self.wrdicts()
 *         if dicts:             # <<<<<<<<<<<<<<
 *             dicts.pop(self.idt, None)
 * 
*/
  }

  /* "src/gevent/local.py":230
 *         self.wrdicts = wrdicts
 * 
 *     def __call__(self, _unused):             # <<<<<<<<<<<<<<
 *         dicts = self.wrdicts()
 *         if dicts:
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("gevent._gevent_clocal._greenlet_deleted.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_dicts);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/local.py":238
 *     __slots__ = ('key', 'wrthread', 'greenlet_deleted')
 * 
 *     def __init__(self, key, wrthread, greenlet_deleted):             # <<<<<<<<<<<<<<
 *         self.key = key
 *         self.wrthread = wrthread
*/

/* Python wrapper */
static int __pyx_pw_6gevent_14_gevent_clocal_14_local_deleted_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6gevent_14_gevent_clocal_14_local_deleted_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_key = 0;
  PyObject *__pyx_v_wrthread = 0;
  PyObject *__pyx_v_greenlet_deleted = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_key,&__pyx_mstate_global->__pyx_n_u_wrthread,&__pyx_mstate_global->__pyx_n_u_greenlet_deleted,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 238, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_VARARGS(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 238, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 238, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 238, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__init__", 0) < (0)) __PYX_ERR(0, 238, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, i); __PYX_ERR(0, 238, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 238, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 238, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_VARARGS(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 238, __pyx_L3_error)
    }
    __pyx_v_key = values[0];
    __pyx_v_wrthread = values[1];
    __pyx_v_greenlet_deleted = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 238, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("gevent._gevent_clocal._local_deleted.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6gevent_14_gevent_clocal_14_local_deleted___init__(((struct __pyx_obj_6gevent_14_gevent_clocal__local_deleted *)__pyx_v_self), __pyx_v_key, __pyx_v_wrthread, __pyx_v_greenlet_deleted);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6gevent_14_gevent_clocal_14_local_deleted___init__(struct __pyx_obj_6gevent_14_gevent_clocal__local_deleted *__pyx_v_self, PyObject *__pyx_v_key, PyObject *__pyx_v_wrthread, PyObject *__pyx_v_greenlet_deleted) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "src/gevent/local.py":239
 * 
 *     def __init__(self, key, wrthread, greenlet_deleted):
 *         self.key = key             # <<<<<<<<<<<<<<
 *         self.wrthread = wrthread
 *         self.greenlet_deleted = greenlet_deleted
*/
  __pyx_t_1 = __pyx_v_key;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PyUnicode_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("str", __pyx_t_1))) __PYX_ERR(0, 239, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->key);
  __Pyx_DECREF(__pyx_v_self->key);
  __pyx_v_self->key = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "src/gevent/local.py":240
 *     def __init__(self, key, wrthread, greenlet_deleted):
 *         self.key = key
 *         self.wrthread = wrthread             # <<<<<<<<<<<<<<
 *         self.greenlet_deleted = greenlet_deleted
 * 
*/
  __Pyx_INCREF(__pyx_v_wrthread);
  __Pyx_GIVEREF(__pyx_v_wrthread);
  __Pyx_GOTREF(__pyx_v_self->wrthread);
  __Pyx_DECREF(__pyx_v_self->wrthread);
  __pyx_v_self->wrthread = __pyx_v_wrthread;

  /* "src/gevent/local.py":241
 *         self.key = key
 *         self.wrthread = wrthread
 *         self.greenlet_deleted = greenlet_deleted             # <<<<<<<<<<<<<<
 * 
 *     def __call__(self, _unused):
*/
  __pyx_t_1 = __pyx_v_greenlet_deleted;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_clocal__greenlet_deleted))))) __PYX_ERR(0, 241, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->greenlet_deleted);
  __Pyx_DECREF((PyObject *)__pyx_v_self->greenlet_deleted);
  __pyx_v_self->greenlet_deleted = ((struct __pyx_obj_6gevent_14_gevent_clocal__greenlet_deleted *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "src/gevent/local.py":238
 *     __slots__ = ('key', 'wrthread', 'greenlet_deleted')
 * 
 *     def __init__(self, key, wrthread, greenlet_deleted):             # <<<<<<<<<<<<<<
 *         self.key = key
 *         self.wrthread = wrthread
*/

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_clocal._local_deleted.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/local.py":243
 *         self.greenlet_deleted = greenlet_deleted
 * 
 *     def __call__(self, _unused):             # <<<<<<<<<<<<<<
 *         thread = self.wrthread()
 *         if thread is not None:
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_14_gevent_clocal_14_local_deleted_3__call__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6gevent_14_gevent_clocal_14_local_deleted_3__call__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v__unused = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__call__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_unused,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 243, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 243, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__call__", 0) < (0)) __PYX_ERR(0, 243, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__call__", 1, 1, 1, i); __PYX_ERR(0, 243, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 243, __pyx_L3_error)
    }
    __pyx_v__unused = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__call__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 243, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("gevent._gevent_clocal._local_deleted.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6gevent_14_gevent_clocal_14_local_deleted_2__call__(((struct __pyx_obj_6gevent_14_gevent_clocal__local_deleted *)__pyx_v_self), __pyx_v__unused);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_14_gevent_clocal_14_local_deleted_2__call__(struct __pyx_obj_6gevent_14_gevent_clocal__local_deleted *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v__unused) {
  PyObject *__pyx_v_thread = NULL;
  PyObject *__pyx_v_unlink = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__call__", 0);

  /* "src/gevent/local.py":244
 * 
 *     def __call__(self, _unused):
 *         thread = self.wrthread()             # <<<<<<<<<<<<<<
 *         if thread is not None:
 *             try:
*/
  __pyx_t_2 = NULL;
  __Pyx_INCREF(__pyx_v_self->wrthread);
  __pyx_t_3 = __pyx_v_self->wrthread; 
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 244, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_thread = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "src/gevent/local.py":245
 *     def __call__(self, _unused):
 *         thread = self.wrthread()
 *         if thread is not None:             # <<<<<<<<<<<<<<
 *             try:
 *                 unlink = thread.unlink
*/
  __pyx_t_5 = (__pyx_v_thread != Py_None);
  if (__pyx_t_5) {

    /* "src/gevent/local.py":246
 *         thread = self.wrthread()
 *         if thread is not None:
 *             try:             # <<<<<<<<<<<<<<
 *                 unlink = thread.unlink
 *             except AttributeError:
*/
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_8);
      /*try:*/ {

        /* "src/gevent/local.py":247
 *         if thread is not None:
 *             try:
 *                 unlink = thread.unlink             # <<<<<<<<<<<<<<
 *             except AttributeError:
 *                 pass
*/
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_thread, __pyx_mstate_global->__pyx_n_u_unlink); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 247, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_v_unlink = __pyx_t_1;
        __pyx_t_1 = 0;

        /* "src/gevent/local.py":246
 *         thread = self.wrthread()
 *         if thread is not None:
 *             try:             # <<<<<<<<<<<<<<
 *                 unlink = thread.unlink
 *             except AttributeError:
*/
      }

      /* "src/gevent/local.py":251
 *                 pass
 *             else:
 *                 unlink(self.greenlet_deleted)             # <<<<<<<<<<<<<<
 *             del thread.__dict__[self.key]
 * 
*/
      /*else:*/ {
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_v_unlink);
        __pyx_t_2 = __pyx_v_unlink; 
        __pyx_t_4 = 1;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_2))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
          __pyx_t_4 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, ((PyObject *)__pyx_v_self->greenlet_deleted)};
          __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 251, __pyx_L6_except_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L9_try_end;
      __pyx_L4_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "src/gevent/local.py":248
 *             try:
 *                 unlink = thread.unlink
 *             except AttributeError:             # <<<<<<<<<<<<<<
 *                 pass
 *             else:
*/
      __pyx_t_9 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_AttributeError))));
      if (__pyx_t_9) {
        __Pyx_ErrRestore(0,0,0);
        goto __pyx_L5_exception_handled;
      }
      goto __pyx_L6_except_error;

      /* "src/gevent/local.py":246
 *         thread = self.wrthread()
 *         if thread is not None:
 *             try:             # <<<<<<<<<<<<<<
 *                 unlink = thread.unlink
 *             except AttributeError:
*/
      __pyx_L6_except_error:;
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
      goto __pyx_L1_error;
      __pyx_L5_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
      __pyx_L9_try_end:;
    }

    /* "src/gevent/local.py":252
 *             else:
 *                 unlink(self.greenlet_deleted)
 *             del thread.__dict__[self.key]             # <<<<<<<<<<<<<<
 * 
 * class _localimpl(object):
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_thread, __pyx_mstate_global->__pyx_n_u_dict); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 252, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely((PyObject_DelItem(__pyx_t_1, __pyx_v_self->key) < 0))) __PYX_ERR(0, 252, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "src/gevent/local.py":245
 *     def __call__(self, _unused):
 *         thread = self.wrthread()
 *         if thread is not None:             # <<<<<<<<<<<<<<
 *             try:
 *                 unlink = thread.unlink
*/
  }

  /* "src/gevent/local.py":243
 *         self.greenlet_deleted = greenlet_deleted
 * 
 *     def __call__(self, _unused):             # <<<<<<<<<<<<<<
 *         thread = self.wrthread()
 *         if thread is not None:
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("gevent._gevent_clocal._local_deleted.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_thread);
  __Pyx_XDECREF(__pyx_v_unlink);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/local.py":261
 *                  '__weakref__',)
 * 
 *     def __init__(self, args, kwargs, local_type, id_local):             # <<<<<<<<<<<<<<
 *         self.key = key_prefix + str(id(self))
 *         # { id(greenlet) -> _localimpl_dict_entry(ref(greenlet), greenlet-local dict) }
*/

/* Python wrapper */
static int __pyx_pw_6gevent_14_gevent_clocal_10_localimpl_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6gevent_14_gevent_clocal_10_localimpl_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_v_kwargs = 0;
  PyObject *__pyx_v_local_type = 0;
  PyObject *__pyx_v_id_local = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_args,&__pyx_mstate_global->__pyx_n_u_kwargs,&__pyx_mstate_global->__pyx_n_u_local_type,&__pyx_mstate_global->__pyx_n_u_id_local,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 261, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  4:
        values[3] = __Pyx_ArgRef_VARARGS(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 261, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_VARARGS(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 261, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 261, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 261, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__init__", 0) < (0)) __PYX_ERR(0, 261, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 4; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__init__", 1, 4, 4, i); __PYX_ERR(0, 261, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 4)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 261, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 261, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_VARARGS(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 261, __pyx_L3_error)
      values[3] = __Pyx_ArgRef_VARARGS(__pyx_args, 3);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 261, __pyx_L3_error)
    }
    __pyx_v_args = values[0];
    __pyx_v_kwargs = values[1];
    __pyx_v_local_type = values[2];
    __pyx_v_id_local = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 4, 4, __pyx_nargs); __PYX_ERR(0, 261, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("gevent._gevent_clocal._localimpl.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6gevent_14_gevent_clocal_10_localimpl___init__(((struct __pyx_obj_6gevent_14_gevent_clocal__localimpl *)__pyx_v_self), __pyx_v_args, __pyx_v_kwargs, __pyx_v_local_type, __pyx_v_id_local);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6gevent_14_gevent_clocal_10_localimpl___init__(struct __pyx_obj_6gevent_14_gevent_clocal__localimpl *__pyx_v_self, PyObject *__pyx_v_args, PyObject *__pyx_v_kwargs, PyObject *__pyx_v_local_type, PyObject *__pyx_v_id_local) {
  PyGreenlet *__pyx_v_greenlet = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "src/gevent/local.py":262
 * 
 *     def __init__(self, args, kwargs, local_type, id_local):
 *         self.key = key_prefix + str(id(self))             # <<<<<<<<<<<<<<
 *         # { id(greenlet) -> _localimpl_dict_entry(ref(greenlet), greenlet-local dict) }
 *         self.dicts = _wrefdict()
*/
  __pyx_t_2 = NULL;
  __pyx_t_3 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, ((PyObject *)__pyx_v_self)};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_id, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 262, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_t_2 = __Pyx_PyObject_Unicode(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 262, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyUnicode_ConcatSafe(__pyx_v_6gevent_14_gevent_clocal_key_prefix, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 262, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->key);
  __Pyx_DECREF(__pyx_v_self->key);
  __pyx_v_self->key = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "src/gevent/local.py":264
 *         self.key = key_prefix + str(id(self))
 *         # { id(greenlet) -> _localimpl_dict_entry(ref(greenlet), greenlet-local dict) }
 *         self.dicts = _wrefdict()             # <<<<<<<<<<<<<<
 *         self.localargs = args
 *         self.localkwargs = kwargs
*/
  __pyx_t_2 = NULL;
  __pyx_t_3 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_clocal__wrefdict, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 264, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_1);
  }
  __Pyx_GIVEREF((PyObject *)__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->dicts);
  __Pyx_DECREF(__pyx_v_self->dicts);
  __pyx_v_self->dicts = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "src/gevent/local.py":265
 *         # { id(greenlet) -> _localimpl_dict_entry(ref(greenlet), greenlet-local dict) }
 *         self.dicts = _wrefdict()
 *         self.localargs = args             # <<<<<<<<<<<<<<
 *         self.localkwargs = kwargs
 *         self.localtypeid = local_type, id_local
*/
  __pyx_t_1 = __pyx_v_args;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PyTuple_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_t_1))) __PYX_ERR(0, 265, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->localargs);
  __Pyx_DECREF(__pyx_v_self->localargs);
  __pyx_v_self->localargs = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "src/gevent/local.py":266
 *         self.dicts = _wrefdict()
 *         self.localargs = args
 *         self.localkwargs = kwargs             # <<<<<<<<<<<<<<
 *         self.localtypeid = local_type, id_local
 * 
*/
  __pyx_t_1 = __pyx_v_kwargs;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PyDict_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("dict", __pyx_t_1))) __PYX_ERR(0, 266, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->localkwargs);
  __Pyx_DECREF(__pyx_v_self->localkwargs);
  __pyx_v_self->localkwargs = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "src/gevent/local.py":267
 *         self.localargs = args
 *         self.localkwargs = kwargs
 *         self.localtypeid = local_type, id_local             # <<<<<<<<<<<<<<
 * 
 *         # We need to create the thread dict in anticipation of
*/
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_local_type);
  __Pyx_GIVEREF(__pyx_v_local_type);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_local_type) != (0)) __PYX_ERR(0, 267, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_id_local);
  __Pyx_GIVEREF(__pyx_v_id_local);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_id_local) != (0)) __PYX_ERR(0, 267, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->localtypeid);
  __Pyx_DECREF(__pyx_v_self->localtypeid);
  __pyx_v_self->localtypeid = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "src/gevent/local.py":272
 *         # __init__ being called, to make sure we don't call it
 *         # again ourselves. MUST do this before setting any attributes.
 *         greenlet = getcurrent() # pylint:disable=undefined-variable             # <<<<<<<<<<<<<<
 *         _localimpl_create_dict(self, greenlet, id(greenlet))
 * 
*/
  __pyx_t_1 = ((PyObject *)__pyx_f_6gevent_14_gevent_clocal_getcurrent()); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 272, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_greenlet = ((PyGreenlet *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "src/gevent/local.py":273
 *         # again ourselves. MUST do this before setting any attributes.
 *         greenlet = getcurrent() # pylint:disable=undefined-variable
 *         _localimpl_create_dict(self, greenlet, id(greenlet))             # <<<<<<<<<<<<<<
 * 
 * class _localimpl_dict_entry(object):
*/
  __pyx_t_2 = NULL;
  __pyx_t_3 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, ((PyObject *)__pyx_v_greenlet)};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_id, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 273, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_t_2 = __pyx_f_6gevent_14_gevent_clocal__localimpl_create_dict(__pyx_v_self, __pyx_v_greenlet, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 273, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/local.py":261
 *                  '__weakref__',)
 * 
 *     def __init__(self, args, kwargs, local_type, id_local):             # <<<<<<<<<<<<<<
 *         self.key = key_prefix + str(id(self))
 *         # { id(greenlet) -> _localimpl_dict_entry(ref(greenlet), greenlet-local dict) }
*/

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("gevent._gevent_clocal._localimpl.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_greenlet);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/local.py":284
 *     __slots__ = ('wrgreenlet', 'localdict')
 * 
 *     def __init__(self, wrgreenlet, localdict):             # <<<<<<<<<<<<<<
 *         self.wrgreenlet = wrgreenlet
 *         self.localdict = localdict
*/

/* Python wrapper */
static int __pyx_pw_6gevent_14_gevent_clocal_21_localimpl_dict_entry_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6gevent_14_gevent_clocal_21_localimpl_dict_entry_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_wrgreenlet = 0;
  PyObject *__pyx_v_localdict = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_wrgreenlet,&__pyx_mstate_global->__pyx_n_u_localdict,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 284, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 284, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 284, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__init__", 0) < (0)) __PYX_ERR(0, 284, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, i); __PYX_ERR(0, 284, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 284, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 284, __pyx_L3_error)
    }
    __pyx_v_wrgreenlet = values[0];
    __pyx_v_localdict = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 284, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("gevent._gevent_clocal._localimpl_dict_entry.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6gevent_14_gevent_clocal_21_localimpl_dict_entry___init__(((struct __pyx_obj_6gevent_14_gevent_clocal__localimpl_dict_entry *)__pyx_v_self), __pyx_v_wrgreenlet, __pyx_v_localdict);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6gevent_14_gevent_clocal_21_localimpl_dict_entry___init__(struct __pyx_obj_6gevent_14_gevent_clocal__localimpl_dict_entry *__pyx_v_self, PyObject *__pyx_v_wrgreenlet, PyObject *__pyx_v_localdict) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "src/gevent/local.py":285
 * 
 *     def __init__(self, wrgreenlet, localdict):
 *         self.wrgreenlet = wrgreenlet             # <<<<<<<<<<<<<<
 *         self.localdict = localdict
 * 
*/
  __Pyx_INCREF(__pyx_v_wrgreenlet);
  __Pyx_GIVEREF(__pyx_v_wrgreenlet);
  __Pyx_GOTREF(__pyx_v_self->wrgreenlet);
  __Pyx_DECREF(__pyx_v_self->wrgreenlet);
  __pyx_v_self->wrgreenlet = __pyx_v_wrgreenlet;

  /* "src/gevent/local.py":286
 *     def __init__(self, wrgreenlet, localdict):
 *         self.wrgreenlet = wrgreenlet
 *         self.localdict = localdict             # <<<<<<<<<<<<<<
 * 
 * # We use functions instead of methods so that they can be cdef'd in
*/
  __pyx_t_1 = __pyx_v_localdict;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PyDict_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("dict", __pyx_t_1))) __PYX_ERR(0, 286, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->localdict);
  __Pyx_DECREF(__pyx_v_self->localdict);
  __pyx_v_self->localdict = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "src/gevent/local.py":284
 *     __slots__ = ('wrgreenlet', 'localdict')
 * 
 *     def __init__(self, wrgreenlet, localdict):             # <<<<<<<<<<<<<<
 *         self.wrgreenlet = wrgreenlet
 *         self.localdict = localdict
*/

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_clocal._localimpl_dict_entry.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/local.py":296
 * 
 * 
 * def _localimpl_create_dict(self, greenlet, id_greenlet):             # <<<<<<<<<<<<<<
 *     """Create a new dict for the current thread, and return it."""
 *     localdict = {}
*/

static PyObject *__pyx_f_6gevent_14_gevent_clocal__localimpl_create_dict(struct __pyx_obj_6gevent_14_gevent_clocal__localimpl *__pyx_v_self, PyGreenlet *__pyx_v_greenlet, PyObject *__pyx_v_id_greenlet) {
  PyObject *__pyx_v_localdict = 0;
  PyObject *__pyx_v_key = 0;
  struct __pyx_obj_6gevent_14_gevent_clocal__greenlet_deleted *__pyx_v_greenlet_deleted = 0;
  struct __pyx_obj_6gevent_14_gevent_clocal__local_deleted *__pyx_v_local_deleted = 0;
  PyObject *__pyx_v_wrdicts = NULL;
  PyObject *__pyx_v_rawlink = NULL;
  PyObject *__pyx_v_wrthread = NULL;
  PyObject *__pyx_v_wrlocal = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_localimpl_create_dict", 0);

  /* "src/gevent/local.py":298
 * def _localimpl_create_dict(self, greenlet, id_greenlet):
 *     """Create a new dict for the current thread, and return it."""
 *     localdict = {}             # <<<<<<<<<<<<<<
 *     key = self.key
 * 
*/
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_localdict = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "src/gevent/local.py":299
 *     """Create a new dict for the current thread, and return it."""
 *     localdict = {}
 *     key = self.key             # <<<<<<<<<<<<<<
 * 
 *     wrdicts = ref(self.dicts)
*/
  __pyx_t_1 = __pyx_v_self->key;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_key = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "src/gevent/local.py":301
 *     key = self.key
 * 
 *     wrdicts = ref(self.dicts)             # <<<<<<<<<<<<<<
 * 
 *     # When the greenlet is deleted, remove the local dict.
*/
  __pyx_t_2 = NULL;
  __Pyx_INCREF(__pyx_v_6gevent_14_gevent_clocal_ref);
  __pyx_t_3 = __pyx_v_6gevent_14_gevent_clocal_ref; 
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_self->dicts};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 301, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_wrdicts = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "src/gevent/local.py":312
 *     # issue described above. Use rawlink to avoid spawning any
 *     # more greenlets.
 *     greenlet_deleted = _greenlet_deleted(id_greenlet, wrdicts)             # <<<<<<<<<<<<<<
 * 
 *     rawlink = getattr(greenlet, 'rawlink', None)
*/
  __pyx_t_3 = NULL;
  __pyx_t_4 = 1;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_id_greenlet, __pyx_v_wrdicts};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_clocal__greenlet_deleted, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 312, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_1);
  }
  __pyx_v_greenlet_deleted = ((struct __pyx_obj_6gevent_14_gevent_clocal__greenlet_deleted *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "src/gevent/local.py":314
 *     greenlet_deleted = _greenlet_deleted(id_greenlet, wrdicts)
 * 
 *     rawlink = getattr(greenlet, 'rawlink', None)             # <<<<<<<<<<<<<<
 *     if rawlink is not None:
 *         rawlink(greenlet_deleted)
*/
  __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_greenlet), __pyx_mstate_global->__pyx_n_u_rawlink, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_rawlink = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "src/gevent/local.py":315
 * 
 *     rawlink = getattr(greenlet, 'rawlink', None)
 *     if rawlink is not None:             # <<<<<<<<<<<<<<
 *         rawlink(greenlet_deleted)
 *         wrthread = ref(greenlet)
*/
  __pyx_t_5 = (__pyx_v_rawlink != Py_None);
  if (__pyx_t_5) {

    /* "src/gevent/local.py":316
 *     rawlink = getattr(greenlet, 'rawlink', None)
 *     if rawlink is not None:
 *         rawlink(greenlet_deleted)             # <<<<<<<<<<<<<<
 *         wrthread = ref(greenlet)
 *     else:
*/
    __pyx_t_3 = NULL;
    __Pyx_INCREF(__pyx_v_rawlink);
    __pyx_t_2 = __pyx_v_rawlink; 
    __pyx_t_4 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      assert(__pyx_t_3);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
      __pyx_t_4 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, ((PyObject *)__pyx_v_greenlet_deleted)};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 316, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "src/gevent/local.py":317
 *     if rawlink is not None:
 *         rawlink(greenlet_deleted)
 *         wrthread = ref(greenlet)             # <<<<<<<<<<<<<<
 *     else:
 *         wrthread = ref(greenlet, greenlet_deleted)
*/
    __pyx_t_2 = NULL;
    __Pyx_INCREF(__pyx_v_6gevent_14_gevent_clocal_ref);
    __pyx_t_3 = __pyx_v_6gevent_14_gevent_clocal_ref; 
    __pyx_t_4 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      assert(__pyx_t_2);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
      __pyx_t_4 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, ((PyObject *)__pyx_v_greenlet)};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 317, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_v_wrthread = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "src/gevent/local.py":315
 * 
 *     rawlink = getattr(greenlet, 'rawlink', None)
 *     if rawlink is not None:             # <<<<<<<<<<<<<<
 *         rawlink(greenlet_deleted)
 *         wrthread = ref(greenlet)
*/
    goto __pyx_L3;
  }

  /* "src/gevent/local.py":319
 *         wrthread = ref(greenlet)
 *     else:
 *         wrthread = ref(greenlet, greenlet_deleted)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*else*/ {
    __pyx_t_3 = NULL;
    __Pyx_INCREF(__pyx_v_6gevent_14_gevent_clocal_ref);
    __pyx_t_2 = __pyx_v_6gevent_14_gevent_clocal_ref; 
    __pyx_t_4 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      assert(__pyx_t_3);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
      __pyx_t_4 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_3, ((PyObject *)__pyx_v_greenlet), ((PyObject *)__pyx_v_greenlet_deleted)};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 319, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_v_wrthread = __pyx_t_1;
    __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "src/gevent/local.py":323
 * 
 *     # When the localimpl is deleted, remove the thread attribute.
 *     local_deleted = _local_deleted(key, wrthread, greenlet_deleted)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_2 = NULL;
  __pyx_t_4 = 1;
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_2, __pyx_v_key, __pyx_v_wrthread, ((PyObject *)__pyx_v_greenlet_deleted)};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_clocal__local_deleted, __pyx_callargs+__pyx_t_4, (4-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 323, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_1);
  }
  __pyx_v_local_deleted = ((struct __pyx_obj_6gevent_14_gevent_clocal__local_deleted *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "src/gevent/local.py":326
 * 
 * 
 *     wrlocal = ref(self, local_deleted)             # <<<<<<<<<<<<<<
 *     greenlet.__dict__[key] = wrlocal
 * 
*/
  __pyx_t_2 = NULL;
  __Pyx_INCREF(__pyx_v_6gevent_14_gevent_clocal_ref);
  __pyx_t_3 = __pyx_v_6gevent_14_gevent_clocal_ref; 
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, ((PyObject *)__pyx_v_self), ((PyObject *)__pyx_v_local_deleted)};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 326, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_wrlocal = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "src/gevent/local.py":327
 * 
 *     wrlocal = ref(self, local_deleted)
 *     greenlet.__dict__[key] = wrlocal             # <<<<<<<<<<<<<<
 * 
 *     self.dicts[id_greenlet] = _localimpl_dict_entry(wrthread, localdict)
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_greenlet), __pyx_mstate_global->__pyx_n_u_dict); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 327, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyObject_SetItem(__pyx_t_1, __pyx_v_key, __pyx_v_wrlocal) < 0))) __PYX_ERR(0, 327, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "src/gevent/local.py":329
 *     greenlet.__dict__[key] = wrlocal
 * 
 *     self.dicts[id_greenlet] = _localimpl_dict_entry(wrthread, localdict)             # <<<<<<<<<<<<<<
 *     return localdict
 * 
*/
  __pyx_t_3 = NULL;
  __pyx_t_4 = 1;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_wrthread, __pyx_v_localdict};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_clocal__localimpl_dict_entry, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 329, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_1);
  }
  if (unlikely(__pyx_v_self->dicts == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 329, __pyx_L1_error)
  }
  if (unlikely((PyDict_SetItem(__pyx_v_self->dicts, __pyx_v_id_greenlet, ((PyObject *)__pyx_t_1)) < 0))) __PYX_ERR(0, 329, __pyx_L1_error)
  __Pyx_DECREF((PyObject *)__pyx_t_1); __pyx_t_1 = 0;

  /* "src/gevent/local.py":330
 * 
 *     self.dicts[id_greenlet] = _localimpl_dict_entry(wrthread, localdict)
 *     return localdict             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_localdict);
  __pyx_r = __pyx_v_localdict;
  goto __pyx_L0;

  /* "src/gevent/local.py":296
 * 
 * 
 * def _localimpl_create_dict(self, greenlet, id_greenlet):             # <<<<<<<<<<<<<<
 *     """Create a new dict for the current thread, and return it."""
 *     localdict = {}
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("gevent._gevent_clocal._localimpl_create_dict", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_localdict);
  __Pyx_XDECREF(__pyx_v_key);
  __Pyx_XDECREF((PyObject *)__pyx_v_greenlet_deleted);
  __Pyx_XDECREF((PyObject *)__pyx_v_local_deleted);
  __Pyx_XDECREF(__pyx_v_wrdicts);
  __Pyx_XDECREF(__pyx_v_rawlink);
  __Pyx_XDECREF(__pyx_v_wrthread);
  __Pyx_XDECREF(__pyx_v_wrlocal);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/local.py":335
 * _marker = object()
 * 
 * def _local_get_dict(self):             # <<<<<<<<<<<<<<
 *     impl = self._local__impl
 *     # Cython can optimize dict[], but not dict.get()
*/

static CYTHON_INLINE PyObject *__pyx_f_6gevent_14_gevent_clocal__local_get_dict(struct __pyx_obj_6gevent_14_gevent_clocal_local *__pyx_v_self) {
  struct __pyx_obj_6gevent_14_gevent_clocal__localimpl *__pyx_v_impl = 0;
  PyObject *__pyx_v_dct = 0;
  struct __pyx_obj_6gevent_14_gevent_clocal__localimpl_dict_entry *__pyx_v_entry = 0;
  PyGreenlet *__pyx_v_greenlet = NULL;
  PyObject *__pyx_v_idg = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_local_get_dict", 0);

  /* "src/gevent/local.py":336
 * 
 * def _local_get_dict(self):
 *     impl = self._local__impl             # <<<<<<<<<<<<<<
 *     # Cython can optimize dict[], but not dict.get()
 *     greenlet = getcurrent() # pylint:disable=undefined-variable
*/
  __pyx_t_1 = ((PyObject *)__pyx_v_self->_local__impl);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_impl = ((struct __pyx_obj_6gevent_14_gevent_clocal__localimpl *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "src/gevent/local.py":338
 *     impl = self._local__impl
 *     # Cython can optimize dict[], but not dict.get()
 *     greenlet = getcurrent() # pylint:disable=undefined-variable             # <<<<<<<<<<<<<<
 *     idg = id(greenlet)
 *     try:
*/
  __pyx_t_1 = ((PyObject *)__pyx_f_6gevent_14_gevent_clocal_getcurrent()); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 338, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_greenlet = ((PyGreenlet *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "src/gevent/local.py":339
 *     # Cython can optimize dict[], but not dict.get()
 *     greenlet = getcurrent() # pylint:disable=undefined-variable
 *     idg = id(greenlet)             # <<<<<<<<<<<<<<
 *     try:
 *         entry = impl.dicts[idg]
*/
  __pyx_t_2 = NULL;
  __pyx_t_3 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, ((PyObject *)__pyx_v_greenlet)};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_id, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 339, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_idg = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "src/gevent/local.py":340
 *     greenlet = getcurrent() # pylint:disable=undefined-variable
 *     idg = id(greenlet)
 *     try:             # <<<<<<<<<<<<<<
 *         entry = impl.dicts[idg]
 *         dct = entry.localdict
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    /*try:*/ {

      /* "src/gevent/local.py":341
 *     idg = id(greenlet)
 *     try:
 *         entry = impl.dicts[idg]             # <<<<<<<<<<<<<<
 *         dct = entry.localdict
 *     except KeyError:
*/
      if (unlikely(__pyx_v_impl->dicts == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 341, __pyx_L3_error)
      }
      __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_impl->dicts, __pyx_v_idg); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 341, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_clocal__localimpl_dict_entry))))) __PYX_ERR(0, 341, __pyx_L3_error)
      __pyx_v_entry = ((struct __pyx_obj_6gevent_14_gevent_clocal__localimpl_dict_entry *)__pyx_t_1);
      __pyx_t_1 = 0;

      /* "src/gevent/local.py":342
 *     try:
 *         entry = impl.dicts[idg]
 *         dct = entry.localdict             # <<<<<<<<<<<<<<
 *     except KeyError:
 *         dct = _localimpl_create_dict(impl, greenlet, idg)
*/
      __pyx_t_1 = __pyx_v_entry->localdict;
      __Pyx_INCREF(__pyx_t_1);
      __pyx_v_dct = ((PyObject*)__pyx_t_1);
      __pyx_t_1 = 0;

      /* "src/gevent/local.py":340
 *     greenlet = getcurrent() # pylint:disable=undefined-variable
 *     idg = id(greenlet)
 *     try:             # <<<<<<<<<<<<<<
 *         entry = impl.dicts[idg]
 *         dct = entry.localdict
*/
    }
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "src/gevent/local.py":343
 *         entry = impl.dicts[idg]
 *         dct = entry.localdict
 *     except KeyError:             # <<<<<<<<<<<<<<
 *         dct = _localimpl_create_dict(impl, greenlet, idg)
 *         self.__init__(*impl.localargs, **impl.localkwargs)
*/
    __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_KeyError))));
    if (__pyx_t_7) {
      __Pyx_AddTraceback("gevent._gevent_clocal._local_get_dict", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_2, &__pyx_t_8) < 0) __PYX_ERR(0, 343, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_1);
      __Pyx_XGOTREF(__pyx_t_2);
      __Pyx_XGOTREF(__pyx_t_8);

      /* "src/gevent/local.py":344
 *         dct = entry.localdict
 *     except KeyError:
 *         dct = _localimpl_create_dict(impl, greenlet, idg)             # <<<<<<<<<<<<<<
 *         self.__init__(*impl.localargs, **impl.localkwargs)
 *     return dct
*/
      __pyx_t_9 = __pyx_f_6gevent_14_gevent_clocal__localimpl_create_dict(__pyx_v_impl, __pyx_v_greenlet, __pyx_v_idg); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 344, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_XDECREF_SET(__pyx_v_dct, ((PyObject*)__pyx_t_9));
      __pyx_t_9 = 0;

      /* "src/gevent/local.py":345
 *     except KeyError:
 *         dct = _localimpl_create_dict(impl, greenlet, idg)
 *         self.__init__(*impl.localargs, **impl.localkwargs)             # <<<<<<<<<<<<<<
 *     return dct
 * 
*/
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_init); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 345, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      if (unlikely(__pyx_v_impl->localargs == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
        __PYX_ERR(0, 345, __pyx_L5_except_error)
      }
      if (unlikely(__pyx_v_impl->localkwargs == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "argument after ** must be a mapping, not NoneType");
        __PYX_ERR(0, 345, __pyx_L5_except_error)
      }
      __pyx_t_10 = PyDict_Copy(__pyx_v_impl->localkwargs); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 345, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_11 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_v_impl->localargs, __pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 345, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;

    /* "src/gevent/local.py":340
 *     greenlet = getcurrent() # pylint:disable=undefined-variable
 *     idg = id(greenlet)
 *     try:             # <<<<<<<<<<<<<<
 *         entry = impl.dicts[idg]
 *         dct = entry.localdict
*/
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    __pyx_L8_try_end:;
  }

  /* "src/gevent/local.py":346
 *         dct = _localimpl_create_dict(impl, greenlet, idg)
 *         self.__init__(*impl.localargs, **impl.localkwargs)
 *     return dct             # <<<<<<<<<<<<<<
 * 
 * def _init():
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_dct);
  __pyx_r = __pyx_v_dct;
  goto __pyx_L0;

  /* "src/gevent/local.py":335
 * _marker = object()
 * 
 * def _local_get_dict(self):             # <<<<<<<<<<<<<<
 *     impl = self._local__impl
 *     # Cython can optimize dict[], but not dict.get()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("gevent._gevent_clocal._local_get_dict", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_impl);
  __Pyx_XDECREF(__pyx_v_dct);
  __Pyx_XDECREF((PyObject *)__pyx_v_entry);
  __Pyx_XDECREF((PyObject *)__pyx_v_greenlet);
  __Pyx_XDECREF(__pyx_v_idg);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/local.py":348
 *     return dct
 * 
 * def _init():             # <<<<<<<<<<<<<<
 *     greenlet_init() # pylint:disable=undefined-variable
 * 
*/

static void __pyx_f_6gevent_14_gevent_clocal__init(void) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;

  /* "src/gevent/local.py":349
 * 
 * def _init():
 *     greenlet_init() # pylint:disable=undefined-variable             # <<<<<<<<<<<<<<
 * 
 * _local_attrs = {
*/
  __pyx_f_6gevent_14_gevent_clocal_greenlet_init(); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 349, __pyx_L1_error)

  /* "src/gevent/local.py":348
 *     return dct
 * 
 * def _init():             # <<<<<<<<<<<<<<
 *     greenlet_init() # pylint:disable=undefined-variable
 * 
*/

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("gevent._gevent_clocal._init", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
}

/* "src/gevent/local.py":369
 *     __slots__ = tuple(_local_attrs - {'__class__', '__cinit__'})
 * 
 *     def __cinit__(self, *args, **kw): # pylint:disable=bad-dunder-name             # <<<<<<<<<<<<<<
 *         if args or kw:
 *             if type(self).__init__ == object.__init__: # pylint:disable=comparison-with-callable
*/

/* Python wrapper */
static int __pyx_pw_6gevent_14_gevent_clocal_5local_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6gevent_14_gevent_clocal_5local_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_v_kw = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return -1;
  if (__pyx_kwds_len > 0) {
    if (unlikely(__Pyx_CheckKeywordStrings("__cinit__", __pyx_kwds) == -1)) return -1;
    __pyx_v_kw = __Pyx_KwargsAsDict_VARARGS(__pyx_kwds, __pyx_kwvalues);
    if (unlikely(!__pyx_v_kw)) return -1;
    __Pyx_GOTREF(__pyx_v_kw);
  } else {
    __pyx_v_kw = PyDict_New();
    if (unlikely(!__pyx_v_kw)) return -1;
    __Pyx_GOTREF(__pyx_v_kw);
  }
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6gevent_14_gevent_clocal_5local___cinit__(((struct __pyx_obj_6gevent_14_gevent_clocal_local *)__pyx_v_self), __pyx_v_args, __pyx_v_kw);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_DECREF(__pyx_v_kw);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6gevent_14_gevent_clocal_5local___cinit__(struct __pyx_obj_6gevent_14_gevent_clocal_local *__pyx_v_self, PyObject *__pyx_v_args, PyObject *__pyx_v_kw) {
  struct __pyx_obj_6gevent_14_gevent_clocal__localimpl *__pyx_v_impl = NULL;
  PyObject *__pyx_v_get = NULL;
  PyObject *__pyx_v_dels = NULL;
  PyObject *__pyx_v_sets_or_dels = NULL;
  PyObject *__pyx_v_sets = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "src/gevent/local.py":370
 * 
 *     def __cinit__(self, *args, **kw): # pylint:disable=bad-dunder-name
 *         if args or kw:             # <<<<<<<<<<<<<<
 *             if type(self).__init__ == object.__init__: # pylint:disable=comparison-with-callable
 *                 raise TypeError("Initialization arguments are not supported", args, kw)
*/
  {
    Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_v_args);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 370, __pyx_L1_error)
    __pyx_t_2 = (__pyx_temp != 0);
  }

  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_kw); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 370, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "src/gevent/local.py":371
 *     def __cinit__(self, *args, **kw): # pylint:disable=bad-dunder-name
 *         if args or kw:
 *             if type(self).__init__ == object.__init__: # pylint:disable=comparison-with-callable             # <<<<<<<<<<<<<<
 *                 raise TypeError("Initialization arguments are not supported", args, kw)
 *         impl = _localimpl(args, kw, type(self), id(self))
*/
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))), __pyx_mstate_global->__pyx_n_u_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 371, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_builtin_object, __pyx_mstate_global->__pyx_n_u_init); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 371, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyObject_RichCompare(__pyx_t_3, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 371, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 371, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(__pyx_t_1)) {

      /* "src/gevent/local.py":372
 *         if args or kw:
 *             if type(self).__init__ == object.__init__: # pylint:disable=comparison-with-callable
 *                 raise TypeError("Initialization arguments are not supported", args, kw)             # <<<<<<<<<<<<<<
 *         impl = _localimpl(args, kw, type(self), id(self))
 *         # pylint:disable=attribute-defined-outside-init
*/
      __pyx_t_4 = NULL;
      __pyx_t_6 = 1;
      {
        PyObject *__pyx_callargs[4] = {__pyx_t_4, __pyx_mstate_global->__pyx_kp_u_Initialization_arguments_are_not, __pyx_v_args, __pyx_v_kw};
        __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_TypeError)), __pyx_callargs+__pyx_t_6, (4-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 372, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
      }
      __Pyx_Raise(__pyx_t_5, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __PYX_ERR(0, 372, __pyx_L1_error)

      /* "src/gevent/local.py":371
 *     def __cinit__(self, *args, **kw): # pylint:disable=bad-dunder-name
 *         if args or kw:
 *             if type(self).__init__ == object.__init__: # pylint:disable=comparison-with-callable             # <<<<<<<<<<<<<<
 *                 raise TypeError("Initialization arguments are not supported", args, kw)
 *         impl = _localimpl(args, kw, type(self), id(self))
*/
    }

    /* "src/gevent/local.py":370
 * 
 *     def __cinit__(self, *args, **kw): # pylint:disable=bad-dunder-name
 *         if args or kw:             # <<<<<<<<<<<<<<
 *             if type(self).__init__ == object.__init__: # pylint:disable=comparison-with-callable
 *                 raise TypeError("Initialization arguments are not supported", args, kw)
*/
  }

  /* "src/gevent/local.py":373
 *             if type(self).__init__ == object.__init__: # pylint:disable=comparison-with-callable
 *                 raise TypeError("Initialization arguments are not supported", args, kw)
 *         impl = _localimpl(args, kw, type(self), id(self))             # <<<<<<<<<<<<<<
 *         # pylint:disable=attribute-defined-outside-init
 *         self._local__impl = impl
*/
  __pyx_t_4 = NULL;
  __pyx_t_7 = NULL;
  __pyx_t_6 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, ((PyObject *)__pyx_v_self)};
    __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_id, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 373, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_t_6 = 1;
  {
    PyObject *__pyx_callargs[5] = {__pyx_t_4, __pyx_v_args, __pyx_v_kw, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))), __pyx_t_3};
    __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_clocal__localimpl, __pyx_callargs+__pyx_t_6, (5-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 373, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_5);
  }
  __pyx_v_impl = ((struct __pyx_obj_6gevent_14_gevent_clocal__localimpl *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "src/gevent/local.py":375
 *         impl = _localimpl(args, kw, type(self), id(self))
 *         # pylint:disable=attribute-defined-outside-init
 *         self._local__impl = impl             # <<<<<<<<<<<<<<
 *         get, dels, sets_or_dels, sets = _local_find_descriptors(self)
 *         self._local_type_get_descriptors = get
*/
  __Pyx_INCREF((PyObject *)__pyx_v_impl);
  __Pyx_GIVEREF((PyObject *)__pyx_v_impl);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->_local__impl);
  __Pyx_DECREF((PyObject *)__pyx_v_self->_local__impl);
  __pyx_v_self->_local__impl = __pyx_v_impl;

  /* "src/gevent/local.py":376
 *         # pylint:disable=attribute-defined-outside-init
 *         self._local__impl = impl
 *         get, dels, sets_or_dels, sets = _local_find_descriptors(self)             # <<<<<<<<<<<<<<
 *         self._local_type_get_descriptors = get
 *         self._local_type_set_or_del_descriptors = sets_or_dels
*/
  __pyx_t_5 = __pyx_f_6gevent_14_gevent_clocal__local_find_descriptors(__pyx_v_self); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 376, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (likely(__pyx_t_5 != Py_None)) {
    PyObject* sequence = __pyx_t_5;
    Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(sequence);
    if (unlikely(size != 4)) {
      if (size > 4) __Pyx_RaiseTooManyValuesError(4);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 376, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_7 = PyTuple_GET_ITEM(sequence, 2);
    __Pyx_INCREF(__pyx_t_7);
    __pyx_t_8 = PyTuple_GET_ITEM(sequence, 3);
    __Pyx_INCREF(__pyx_t_8);
    #else
    {
      Py_ssize_t i;
      PyObject** temps[4] = {&__pyx_t_3,&__pyx_t_4,&__pyx_t_7,&__pyx_t_8};
      for (i=0; i < 4; i++) {
        PyObject* item = __Pyx_PySequence_ITEM(sequence, i); if (unlikely(!item)) __PYX_ERR(0, 376, __pyx_L1_error)
        __Pyx_GOTREF(item);
        *(temps[i]) = item;
      }
    }
    #endif
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else {
    __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(0, 376, __pyx_L1_error)
  }
  __pyx_v_get = __pyx_t_3;
  __pyx_t_3 = 0;
  __pyx_v_dels = __pyx_t_4;
  __pyx_t_4 = 0;
  __pyx_v_sets_or_dels = __pyx_t_7;
  __pyx_t_7 = 0;
  __pyx_v_sets = __pyx_t_8;
  __pyx_t_8 = 0;

  /* "src/gevent/local.py":377
 *         self._local__impl = impl
 *         get, dels, sets_or_dels, sets = _local_find_descriptors(self)
 *         self._local_type_get_descriptors = get             # <<<<<<<<<<<<<<
 *         self._local_type_set_or_del_descriptors = sets_or_dels
 *         self._local_type_del_descriptors = dels
*/
  __pyx_t_5 = __pyx_v_get;
  __Pyx_INCREF(__pyx_t_5);
  if (!(likely(PySet_CheckExact(__pyx_t_5))||((__pyx_t_5) == Py_None) || __Pyx_RaiseUnexpectedTypeError("set", __pyx_t_5))) __PYX_ERR(0, 377, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_5);
  __Pyx_GOTREF(__pyx_v_self->_local_type_get_descriptors);
  __Pyx_DECREF(__pyx_v_self->_local_type_get_descriptors);
  __pyx_v_self->_local_type_get_descriptors = ((PyObject*)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "src/gevent/local.py":378
 *         get, dels, sets_or_dels, sets = _local_find_descriptors(self)
 *         self._local_type_get_descriptors = get
 *         self._local_type_set_or_del_descriptors = sets_or_dels             # <<<<<<<<<<<<<<
 *         self._local_type_del_descriptors = dels
 *         self._local_type_set_descriptors = sets
*/
  __pyx_t_5 = __pyx_v_sets_or_dels;
  __Pyx_INCREF(__pyx_t_5);
  if (!(likely(PySet_CheckExact(__pyx_t_5))||((__pyx_t_5) == Py_None) || __Pyx_RaiseUnexpectedTypeError("set", __pyx_t_5))) __PYX_ERR(0, 378, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_5);
  __Pyx_GOTREF(__pyx_v_self->_local_type_set_or_del_descriptors);
  __Pyx_DECREF(__pyx_v_self->_local_type_set_or_del_descriptors);
  __pyx_v_self->_local_type_set_or_del_descriptors = ((PyObject*)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "src/gevent/local.py":379
 *         self._local_type_get_descriptors = get
 *         self._local_type_set_or_del_descriptors = sets_or_dels
 *         self._local_type_del_descriptors = dels             # <<<<<<<<<<<<<<
 *         self._local_type_set_descriptors = sets
 *         self._local_type = type(self)
*/
  __pyx_t_5 = __pyx_v_dels;
  __Pyx_INCREF(__pyx_t_5);
  if (!(likely(PySet_CheckExact(__pyx_t_5))||((__pyx_t_5) == Py_None) || __Pyx_RaiseUnexpectedTypeError("set", __pyx_t_5))) __PYX_ERR(0, 379, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_5);
  __Pyx_GOTREF(__pyx_v_self->_local_type_del_descriptors);
  __Pyx_DECREF(__pyx_v_self->_local_type_del_descriptors);
  __pyx_v_self->_local_type_del_descriptors = ((PyObject*)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "src/gevent/local.py":380
 *         self._local_type_set_or_del_descriptors = sets_or_dels
 *         self._local_type_del_descriptors = dels
 *         self._local_type_set_descriptors = sets             # <<<<<<<<<<<<<<
 *         self._local_type = type(self)
 *         self._local_type_vars = set(dir(self._local_type))
*/
  __pyx_t_5 = __pyx_v_sets;
  __Pyx_INCREF(__pyx_t_5);
  if (!(likely(PySet_CheckExact(__pyx_t_5))||((__pyx_t_5) == Py_None) || __Pyx_RaiseUnexpectedTypeError("set", __pyx_t_5))) __PYX_ERR(0, 380, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_5);
  __Pyx_GOTREF(__pyx_v_self->_local_type_set_descriptors);
  __Pyx_DECREF(__pyx_v_self->_local_type_set_descriptors);
  __pyx_v_self->_local_type_set_descriptors = ((PyObject*)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "src/gevent/local.py":381
 *         self._local_type_del_descriptors = dels
 *         self._local_type_set_descriptors = sets
 *         self._local_type = type(self)             # <<<<<<<<<<<<<<
 *         self._local_type_vars = set(dir(self._local_type))
 * 
*/
  __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
  __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
  __Pyx_GOTREF((PyObject *)__pyx_v_self->_local_type);
  __Pyx_DECREF((PyObject *)__pyx_v_self->_local_type);
  __pyx_v_self->_local_type = ((PyTypeObject*)((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));

  /* "src/gevent/local.py":382
 *         self._local_type_set_descriptors = sets
 *         self._local_type = type(self)
 *         self._local_type_vars = set(dir(self._local_type))             # <<<<<<<<<<<<<<
 * 
 *     def __getattribute__(self, name): # pylint:disable=too-many-return-statements
*/
  __pyx_t_5 = ((PyObject *)__pyx_v_self->_local_type);
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_8 = PyObject_Dir(__pyx_t_5); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 382, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PySet_New(__pyx_t_8); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 382, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_GIVEREF(__pyx_t_5);
  __Pyx_GOTREF(__pyx_v_self->_local_type_vars);
  __Pyx_DECREF(__pyx_v_self->_local_type_vars);
  __pyx_v_self->_local_type_vars = ((PyObject*)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "src/gevent/local.py":369
 *     __slots__ = tuple(_local_attrs - {'__class__', '__cinit__'})
 * 
 *     def __cinit__(self, *args, **kw): # pylint:disable=bad-dunder-name             # <<<<<<<<<<<<<<
 *         if args or kw:
 *             if type(self).__init__ == object.__init__: # pylint:disable=comparison-with-callable
*/

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("gevent._gevent_clocal.local.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_impl);
  __Pyx_XDECREF(__pyx_v_get);
  __Pyx_XDECREF(__pyx_v_dels);
  __Pyx_XDECREF(__pyx_v_sets_or_dels);
  __Pyx_XDECREF(__pyx_v_sets);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/local.py":384
 *         self._local_type_vars = set(dir(self._local_type))
 * 
 *     def __getattribute__(self, name): # pylint:disable=too-many-return-statements             # <<<<<<<<<<<<<<
 *         if name in _local_attrs:
 *             # The _local__impl,  __cinit__, etc, won't be hit by the
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_14_gevent_clocal_5local_3__getattribute__(PyObject *__pyx_v_self, PyObject *__pyx_v_name); /*proto*/
static PyObject *__pyx_pw_6gevent_14_gevent_clocal_5local_3__getattribute__(PyObject *__pyx_v_self, PyObject *__pyx_v_name) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getattribute__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_14_gevent_clocal_5local_2__getattribute__(((struct __pyx_obj_6gevent_14_gevent_clocal_local *)__pyx_v_self), ((PyObject *)__pyx_v_name));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_14_gevent_clocal_5local_2__getattribute__(struct __pyx_obj_6gevent_14_gevent_clocal_local *__pyx_v_self, PyObject *__pyx_v_name) {
  PyObject *__pyx_v_dct = NULL;
  PyObject *__pyx_v_type_attr = NULL;
  PyObject *__pyx_v_base = NULL;
  PyObject *__pyx_v_bd = NULL;
  PyObject *__pyx_v_attr_on_type = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9[4];
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getattribute__", 0);

  /* "src/gevent/local.py":385
 * 
 *     def __getattribute__(self, name): # pylint:disable=too-many-return-statements
 *         if name in _local_attrs:             # <<<<<<<<<<<<<<
 *             # The _local__impl,  __cinit__, etc, won't be hit by the
 *             # Cython version, if we've done things right. If we haven't,
*/
  if (unlikely(__pyx_v_6gevent_14_gevent_clocal__local_attrs == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 385, __pyx_L1_error)
  }
  __pyx_t_1 = (__Pyx_PySet_ContainsTF(__pyx_v_name, __pyx_v_6gevent_14_gevent_clocal__local_attrs, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 385, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "src/gevent/local.py":389
 *             # Cython version, if we've done things right. If we haven't,
 *             # they will be, and this will produce an error.
 *             return object.__getattribute__(self, name)             # <<<<<<<<<<<<<<
 * 
 *         dct = _local_get_dict(self)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __pyx_builtin_object;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_3, ((PyObject *)__pyx_v_self), __pyx_v_name};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_getattribute, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 389, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "src/gevent/local.py":385
 * 
 *     def __getattribute__(self, name): # pylint:disable=too-many-return-statements
 *         if name in _local_attrs:             # <<<<<<<<<<<<<<
 *             # The _local__impl,  __cinit__, etc, won't be hit by the
 *             # Cython version, if we've done things right. If we haven't,
*/
  }

  /* "src/gevent/local.py":391
 *             return object.__getattribute__(self, name)
 * 
 *         dct = _local_get_dict(self)             # <<<<<<<<<<<<<<
 * 
 *         if name == '__dict__':
*/
  __pyx_t_2 = __pyx_f_6gevent_14_gevent_clocal__local_get_dict(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 391, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_dct = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "src/gevent/local.py":393
 *         dct = _local_get_dict(self)
 * 
 *         if name == '__dict__':             # <<<<<<<<<<<<<<
 *             return dct
 *         # If there's no possible way we can switch, because this
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_mstate_global->__pyx_n_u_dict, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 393, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "src/gevent/local.py":394
 * 
 *         if name == '__dict__':
 *             return dct             # <<<<<<<<<<<<<<
 *         # If there's no possible way we can switch, because this
 *         # attribute is *not* found in the class where it might be a
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_dct);
    __pyx_r = __pyx_v_dct;
    goto __pyx_L0;

    /* "src/gevent/local.py":393
 *         dct = _local_get_dict(self)
 * 
 *         if name == '__dict__':             # <<<<<<<<<<<<<<
 *             return dct
 *         # If there's no possible way we can switch, because this
*/
  }

  /* "src/gevent/local.py":409
 *         # there can be no descriptors except for methods, which will
 *         # never need to use __dict__.
 *         if self._local_type is local:             # <<<<<<<<<<<<<<
 *             return dct[name] if name in dct else object.__getattribute__(self, name)
 * 
*/
  __pyx_t_1 = (__pyx_v_self->_local_type == __pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_clocal_local);
  if (__pyx_t_1) {

    /* "src/gevent/local.py":410
 *         # never need to use __dict__.
 *         if self._local_type is local:
 *             return dct[name] if name in dct else object.__getattribute__(self, name)             # <<<<<<<<<<<<<<
 * 
 *         # NOTE: If this is a descriptor, this will invoke its __get__.
*/
    __Pyx_XDECREF(__pyx_r);
    if (unlikely(__pyx_v_dct == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(0, 410, __pyx_L1_error)
    }
    __pyx_t_1 = (__Pyx_PyDict_ContainsTF(__pyx_v_name, __pyx_v_dct, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 410, __pyx_L1_error)
    if (__pyx_t_1) {
      if (unlikely(__pyx_v_dct == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 410, __pyx_L1_error)
      }
      __pyx_t_3 = __Pyx_PyDict_GetItem(__pyx_v_dct, __pyx_v_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 410, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = __pyx_t_3;
      __pyx_t_3 = 0;
    } else {
      __pyx_t_5 = __pyx_builtin_object;
      __Pyx_INCREF(__pyx_t_5);
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_5, ((PyObject *)__pyx_v_self), __pyx_v_name};
        __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_getattribute, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 410, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __pyx_t_2 = __pyx_t_3;
      __pyx_t_3 = 0;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "src/gevent/local.py":409
 *         # there can be no descriptors except for methods, which will
 *         # never need to use __dict__.
 *         if self._local_type is local:             # <<<<<<<<<<<<<<
 *             return dct[name] if name in dct else object.__getattribute__(self, name)
 * 
*/
  }

  /* "src/gevent/local.py":417
 *         # But this is faster than a loop over mro() checking each class __dict__
 *         # manually.
 *         if name in dct:             # <<<<<<<<<<<<<<
 *             if name not in self._local_type_vars:
 *                 # If there is a dict value, and nothing in the type,
*/
  if (unlikely(__pyx_v_dct == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 417, __pyx_L1_error)
  }
  __pyx_t_1 = (__Pyx_PyDict_ContainsTF(__pyx_v_name, __pyx_v_dct, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 417, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "src/gevent/local.py":418
 *         # manually.
 *         if name in dct:
 *             if name not in self._local_type_vars:             # <<<<<<<<<<<<<<
 *                 # If there is a dict value, and nothing in the type,
 *                 # it can't possibly be a descriptor, so it is just returned.
*/
    if (unlikely(__pyx_v_self->_local_type_vars == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(0, 418, __pyx_L1_error)
    }
    __pyx_t_1 = (__Pyx_PySet_ContainsTF(__pyx_v_name, __pyx_v_self->_local_type_vars, Py_NE)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 418, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "src/gevent/local.py":421
 *                 # If there is a dict value, and nothing in the type,
 *                 # it can't possibly be a descriptor, so it is just returned.
 *                 return dct[name]             # <<<<<<<<<<<<<<
 * 
 *             # It's in the type *and* in the dict. If the type value is
*/
      __Pyx_XDECREF(__pyx_r);
      if (unlikely(__pyx_v_dct == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 421, __pyx_L1_error)
      }
      __pyx_t_2 = __Pyx_PyDict_GetItem(__pyx_v_dct, __pyx_v_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 421, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      goto __pyx_L0;

      /* "src/gevent/local.py":418
 *         # manually.
 *         if name in dct:
 *             if name not in self._local_type_vars:             # <<<<<<<<<<<<<<
 *                 # If there is a dict value, and nothing in the type,
 *                 # it can't possibly be a descriptor, so it is just returned.
*/
    }

    /* "src/gevent/local.py":430
 *             # NOTE that the docs for descriptors say that these methods must be
 *             # defined on the *class* of the object in the type.
 *             if name not in self._local_type_get_descriptors:             # <<<<<<<<<<<<<<
 *                 # Entirely not a descriptor. Instance wins.
 *                 return dct[name]
*/
    if (unlikely(__pyx_v_self->_local_type_get_descriptors == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(0, 430, __pyx_L1_error)
    }
    __pyx_t_1 = (__Pyx_PySet_ContainsTF(__pyx_v_name, __pyx_v_self->_local_type_get_descriptors, Py_NE)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 430, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "src/gevent/local.py":432
 *             if name not in self._local_type_get_descriptors:
 *                 # Entirely not a descriptor. Instance wins.
 *                 return dct[name]             # <<<<<<<<<<<<<<
 *             if name in self._local_type_set_or_del_descriptors:
 *                 # A data descriptor.
*/
      __Pyx_XDECREF(__pyx_r);
      if (unlikely(__pyx_v_dct == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 432, __pyx_L1_error)
      }
      __pyx_t_2 = __Pyx_PyDict_GetItem(__pyx_v_dct, __pyx_v_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 432, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      goto __pyx_L0;

      /* "src/gevent/local.py":430
 *             # NOTE that the docs for descriptors say that these methods must be
 *             # defined on the *class* of the object in the type.
 *             if name not in self._local_type_get_descriptors:             # <<<<<<<<<<<<<<
 *                 # Entirely not a descriptor. Instance wins.
 *                 return dct[name]
*/
    }

    /* "src/gevent/local.py":433
 *                 # Entirely not a descriptor. Instance wins.
 *                 return dct[name]
 *             if name in self._local_type_set_or_del_descriptors:             # <<<<<<<<<<<<<<
 *                 # A data descriptor.
 *                 # arbitrary code execution while these run. If they touch self again,
*/
    if (unlikely(__pyx_v_self->_local_type_set_or_del_descriptors == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(0, 433, __pyx_L1_error)
    }
    __pyx_t_1 = (__Pyx_PySet_ContainsTF(__pyx_v_name, __pyx_v_self->_local_type_set_or_del_descriptors, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 433, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "src/gevent/local.py":437
 *                 # arbitrary code execution while these run. If they touch self again,
 *                 # they'll call back into us and we'll repeat the dance.
 *                 type_attr = getattr(self._local_type, name)             # <<<<<<<<<<<<<<
 *                 return type(type_attr).__get__(type_attr, self, self._local_type)
 *             # Last case is a non-data descriptor. Instance wins.
*/
      __pyx_t_2 = ((PyObject *)__pyx_v_self->_local_type);
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_3 = __Pyx_GetAttr(__pyx_t_2, __pyx_v_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 437, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_v_type_attr = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "src/gevent/local.py":438
 *                 # they'll call back into us and we'll repeat the dance.
 *                 type_attr = getattr(self._local_type, name)
 *                 return type(type_attr).__get__(type_attr, self, self._local_type)             # <<<<<<<<<<<<<<
 *             # Last case is a non-data descriptor. Instance wins.
 *             return dct[name]
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_2 = ((PyObject *)Py_TYPE(__pyx_v_type_attr));
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[4] = {__pyx_t_2, __pyx_v_type_attr, ((PyObject *)__pyx_v_self), ((PyObject *)__pyx_v_self->_local_type)};
        __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_get, __pyx_callargs+__pyx_t_4, (4-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 438, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __pyx_r = __pyx_t_3;
      __pyx_t_3 = 0;
      goto __pyx_L0;

      /* "src/gevent/local.py":433
 *                 # Entirely not a descriptor. Instance wins.
 *                 return dct[name]
 *             if name in self._local_type_set_or_del_descriptors:             # <<<<<<<<<<<<<<
 *                 # A data descriptor.
 *                 # arbitrary code execution while these run. If they touch self again,
*/
    }

    /* "src/gevent/local.py":440
 *                 return type(type_attr).__get__(type_attr, self, self._local_type)
 *             # Last case is a non-data descriptor. Instance wins.
 *             return dct[name]             # <<<<<<<<<<<<<<
 * 
 *         if name in self._local_type_vars:
*/
    __Pyx_XDECREF(__pyx_r);
    if (unlikely(__pyx_v_dct == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 440, __pyx_L1_error)
    }
    __pyx_t_3 = __Pyx_PyDict_GetItem(__pyx_v_dct, __pyx_v_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 440, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "src/gevent/local.py":417
 *         # But this is faster than a loop over mro() checking each class __dict__
 *         # manually.
 *         if name in dct:             # <<<<<<<<<<<<<<
 *             if name not in self._local_type_vars:
 *                 # If there is a dict value, and nothing in the type,
*/
  }

  /* "src/gevent/local.py":442
 *             return dct[name]
 * 
 *         if name in self._local_type_vars:             # <<<<<<<<<<<<<<
 *             # Not in the dictionary, but is found in the type. It could be
 *             # a non-data descriptor still. Some descriptors, like @staticmethod,
*/
  if (unlikely(__pyx_v_self->_local_type_vars == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 442, __pyx_L1_error)
  }
  __pyx_t_1 = (__Pyx_PySet_ContainsTF(__pyx_v_name, __pyx_v_self->_local_type_vars, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 442, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "src/gevent/local.py":449
 *             # So we can't rely on getattr() on the type for them, we have to
 *             # look through the MRO dicts ourself.
 *             if name not in self._local_type_get_descriptors:             # <<<<<<<<<<<<<<
 *                 # Not a descriptor, can't execute code. So all we need is
 *                 # the return value of getattr() on our type.
*/
    if (unlikely(__pyx_v_self->_local_type_get_descriptors == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(0, 449, __pyx_L1_error)
    }
    __pyx_t_1 = (__Pyx_PySet_ContainsTF(__pyx_v_name, __pyx_v_self->_local_type_get_descriptors, Py_NE)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 449, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "src/gevent/local.py":452
 *                 # Not a descriptor, can't execute code. So all we need is
 *                 # the return value of getattr() on our type.
 *                 return getattr(self._local_type, name)             # <<<<<<<<<<<<<<
 * 
 *             for base in self._local_type.mro():
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_3 = ((PyObject *)__pyx_v_self->_local_type);
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_2 = __Pyx_GetAttr(__pyx_t_3, __pyx_v_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 452, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      goto __pyx_L0;

      /* "src/gevent/local.py":449
 *             # So we can't rely on getattr() on the type for them, we have to
 *             # look through the MRO dicts ourself.
 *             if name not in self._local_type_get_descriptors:             # <<<<<<<<<<<<<<
 *                 # Not a descriptor, can't execute code. So all we need is
 *                 # the return value of getattr() on our type.
*/
    }

    /* "src/gevent/local.py":454
 *                 return getattr(self._local_type, name)
 * 
 *             for base in self._local_type.mro():             # <<<<<<<<<<<<<<
 *                 bd = base.__dict__
 *                 if name in bd:
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_self->_local_type);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_mro, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 454, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
      __pyx_t_3 = __pyx_t_2; __Pyx_INCREF(__pyx_t_3);
      __pyx_t_6 = 0;
      __pyx_t_7 = NULL;
    } else {
      __pyx_t_6 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 454, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_7 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 454, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    for (;;) {
      if (likely(!__pyx_t_7)) {
        if (likely(PyList_CheckExact(__pyx_t_3))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 454, __pyx_L1_error)
            #endif
            if (__pyx_t_6 >= __pyx_temp) break;
          }
          __pyx_t_2 = __Pyx_PyList_GetItemRefFast(__pyx_t_3, __pyx_t_6, __Pyx_ReferenceSharing_OwnStrongReference);
          ++__pyx_t_6;
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 454, __pyx_L1_error)
            #endif
            if (__pyx_t_6 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_6));
          #else
          __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_6);
          #endif
          ++__pyx_t_6;
        }
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 454, __pyx_L1_error)
      } else {
        __pyx_t_2 = __pyx_t_7(__pyx_t_3);
        if (unlikely(!__pyx_t_2)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 454, __pyx_L1_error)
            PyErr_Clear();
          }
          break;
        }
      }
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_XDECREF_SET(__pyx_v_base, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "src/gevent/local.py":455
 * 
 *             for base in self._local_type.mro():
 *                 bd = base.__dict__             # <<<<<<<<<<<<<<
 *                 if name in bd:
 *                     attr_on_type = bd[name]
*/
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_base, __pyx_mstate_global->__pyx_n_u_dict); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 455, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_XDECREF_SET(__pyx_v_bd, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "src/gevent/local.py":456
 *             for base in self._local_type.mro():
 *                 bd = base.__dict__
 *                 if name in bd:             # <<<<<<<<<<<<<<
 *                     attr_on_type = bd[name]
 *                     result = type(attr_on_type).__get__(attr_on_type, self, self._local_type)
*/
      __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_v_name, __pyx_v_bd, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 456, __pyx_L1_error)
      if (__pyx_t_1) {

        /* "src/gevent/local.py":457
 *                 bd = base.__dict__
 *                 if name in bd:
 *                     attr_on_type = bd[name]             # <<<<<<<<<<<<<<
 *                     result = type(attr_on_type).__get__(attr_on_type, self, self._local_type)
 *                     return result
*/
        __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_v_bd, __pyx_v_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 457, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_v_attr_on_type = __pyx_t_2;
        __pyx_t_2 = 0;

        /* "src/gevent/local.py":458
 *                 if name in bd:
 *                     attr_on_type = bd[name]
 *                     result = type(attr_on_type).__get__(attr_on_type, self, self._local_type)             # <<<<<<<<<<<<<<
 *                     return result
 * 
*/
        __pyx_t_5 = ((PyObject *)Py_TYPE(__pyx_v_attr_on_type));
        __Pyx_INCREF(__pyx_t_5);
        __pyx_t_4 = 0;
        {
          PyObject *__pyx_callargs[4] = {__pyx_t_5, __pyx_v_attr_on_type, ((PyObject *)__pyx_v_self), ((PyObject *)__pyx_v_self->_local_type)};
          __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_get, __pyx_callargs+__pyx_t_4, (4-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 458, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_v_result = __pyx_t_2;
        __pyx_t_2 = 0;

        /* "src/gevent/local.py":459
 *                     attr_on_type = bd[name]
 *                     result = type(attr_on_type).__get__(attr_on_type, self, self._local_type)
 *                     return result             # <<<<<<<<<<<<<<
 * 
 *         # It wasn't in the dict and it wasn't in the type.
*/
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_v_result);
        __pyx_r = __pyx_v_result;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        goto __pyx_L0;

        /* "src/gevent/local.py":456
 *             for base in self._local_type.mro():
 *                 bd = base.__dict__
 *                 if name in bd:             # <<<<<<<<<<<<<<
 *                     attr_on_type = bd[name]
 *                     result = type(attr_on_type).__get__(attr_on_type, self, self._local_type)
*/
      }

      /* "src/gevent/local.py":454
 *                 return getattr(self._local_type, name)
 * 
 *             for base in self._local_type.mro():             # <<<<<<<<<<<<<<
 *                 bd = base.__dict__
 *                 if name in bd:
*/
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "src/gevent/local.py":442
 *             return dct[name]
 * 
 *         if name in self._local_type_vars:             # <<<<<<<<<<<<<<
 *             # Not in the dictionary, but is found in the type. It could be
 *             # a non-data descriptor still. Some descriptors, like @staticmethod,
*/
  }

  /* "src/gevent/local.py":465
 *         # exists, otherwise raise an AttributeError.
 *         # we will invoke type(self).__getattr__ or raise an attribute error.
 *         if hasattr(self._local_type, '__getattr__'):             # <<<<<<<<<<<<<<
 *             return self._local_type.__getattr__(self, name)
 *         raise AttributeError("%r object has no attribute '%s'"
*/
  __pyx_t_3 = ((PyObject *)__pyx_v_self->_local_type);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_HasAttr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_getattr); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 465, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_1) {

    /* "src/gevent/local.py":466
 *         # we will invoke type(self).__getattr__ or raise an attribute error.
 *         if hasattr(self._local_type, '__getattr__'):
 *             return self._local_type.__getattr__(self, name)             # <<<<<<<<<<<<<<
 *         raise AttributeError("%r object has no attribute '%s'"
 *                              % (self._local_type.__name__, name))
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = ((PyObject *)__pyx_v_self->_local_type);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_2, ((PyObject *)__pyx_v_self), __pyx_v_name};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_getattr, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 466, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "src/gevent/local.py":465
 *         # exists, otherwise raise an AttributeError.
 *         # we will invoke type(self).__getattr__ or raise an attribute error.
 *         if hasattr(self._local_type, '__getattr__'):             # <<<<<<<<<<<<<<
 *             return self._local_type.__getattr__(self, name)
 *         raise AttributeError("%r object has no attribute '%s'"
*/
  }

  /* "src/gevent/local.py":467
 *         if hasattr(self._local_type, '__getattr__'):
 *             return self._local_type.__getattr__(self, name)
 *         raise AttributeError("%r object has no attribute '%s'"             # <<<<<<<<<<<<<<
 *                              % (self._local_type.__name__, name))
 * 
*/
  __pyx_t_2 = NULL;

  /* "src/gevent/local.py":468
 *             return self._local_type.__getattr__(self, name)
 *         raise AttributeError("%r object has no attribute '%s'"
 *                              % (self._local_type.__name__, name))             # <<<<<<<<<<<<<<
 * 
 *     def __setattr__(self, name, value):
*/
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->_local_type), __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 468, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_8 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_t_5), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 468, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_v_name), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 468, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_9[0] = __pyx_t_8;
  __pyx_t_9[1] = __pyx_mstate_global->__pyx_kp_u_object_has_no_attribute;
  __pyx_t_9[2] = __pyx_t_5;
  __pyx_t_9[3] = __pyx_mstate_global->__pyx_kp_u_;

  /* "src/gevent/local.py":467
 *         if hasattr(self._local_type, '__getattr__'):
 *             return self._local_type.__getattr__(self, name)
 *         raise AttributeError("%r object has no attribute '%s'"             # <<<<<<<<<<<<<<
 *                              % (self._local_type.__name__, name))
 * 
*/
  __pyx_t_10 = __Pyx_PyUnicode_Join(__pyx_t_9, 4, __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8) + 26 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5) + 1, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5));
  if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_4 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_10};
    __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_AttributeError)), __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 467, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __Pyx_Raise(__pyx_t_3, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __PYX_ERR(0, 467, __pyx_L1_error)

  /* "src/gevent/local.py":384
 *         self._local_type_vars = set(dir(self._local_type))
 * 
 *     def __getattribute__(self, name): # pylint:disable=too-many-return-statements             # <<<<<<<<<<<<<<
 *         if name in _local_attrs:
 *             # The _local__impl,  __cinit__, etc, won't be hit by the
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("gevent._gevent_clocal.local.__getattribute__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_dct);
  __Pyx_XDECREF(__pyx_v_type_attr);
  __Pyx_XDECREF(__pyx_v_base);
  __Pyx_XDECREF(__pyx_v_bd);
  __Pyx_XDECREF(__pyx_v_attr_on_type);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/local.py":470
 *                              % (self._local_type.__name__, name))
 * 
 *     def __setattr__(self, name, value):             # <<<<<<<<<<<<<<
 *         if name == '__dict__':
 *             raise AttributeError(
*/

/* Python wrapper */
static int __pyx_pw_6gevent_14_gevent_clocal_5local_5__setattr__(PyObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6gevent_14_gevent_clocal_5local_5__setattr__(PyObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setattr__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_14_gevent_clocal_5local_4__setattr__(((struct __pyx_obj_6gevent_14_gevent_clocal_local *)__pyx_v_self), ((PyObject *)__pyx_v_name), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6gevent_14_gevent_clocal_5local_4__setattr__(struct __pyx_obj_6gevent_14_gevent_clocal_local *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_value) {
  PyObject *__pyx_v_dct = NULL;
  PyObject *__pyx_v_type_attr = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setattr__", 0);

  /* "src/gevent/local.py":471
 * 
 *     def __setattr__(self, name, value):
 *         if name == '__dict__':             # <<<<<<<<<<<<<<
 *             raise AttributeError(
 *                 "%r object attribute '__dict__' is read-only"
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_mstate_global->__pyx_n_u_dict, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 471, __pyx_L1_error)
  if (unlikely(__pyx_t_1)) {

    /* "src/gevent/local.py":472
 *     def __setattr__(self, name, value):
 *         if name == '__dict__':
 *             raise AttributeError(             # <<<<<<<<<<<<<<
 *                 "%r object attribute '__dict__' is read-only"
 *                 % type(self))
*/
    __pyx_t_3 = NULL;

    /* "src/gevent/local.py":474
 *             raise AttributeError(
 *                 "%r object attribute '__dict__' is read-only"
 *                 % type(self))             # <<<<<<<<<<<<<<
 * 
 *         if name in _local_attrs:
*/
    __pyx_t_4 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_r_object_attribute___dict___is, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self)))); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 474, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_4};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_AttributeError)), __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 472, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 472, __pyx_L1_error)

    /* "src/gevent/local.py":471
 * 
 *     def __setattr__(self, name, value):
 *         if name == '__dict__':             # <<<<<<<<<<<<<<
 *             raise AttributeError(
 *                 "%r object attribute '__dict__' is read-only"
*/
  }

  /* "src/gevent/local.py":476
 *                 % type(self))
 * 
 *         if name in _local_attrs:             # <<<<<<<<<<<<<<
 *             object.__setattr__(self, name, value)
 *             return
*/
  if (unlikely(__pyx_v_6gevent_14_gevent_clocal__local_attrs == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 476, __pyx_L1_error)
  }
  __pyx_t_1 = (__Pyx_PySet_ContainsTF(__pyx_v_name, __pyx_v_6gevent_14_gevent_clocal__local_attrs, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 476, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "src/gevent/local.py":477
 * 
 *         if name in _local_attrs:
 *             object.__setattr__(self, name, value)             # <<<<<<<<<<<<<<
 *             return
 * 
*/
    __pyx_t_4 = __pyx_builtin_object;
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_4, ((PyObject *)__pyx_v_self), __pyx_v_name, __pyx_v_value};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_setattr, __pyx_callargs+__pyx_t_5, (4-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 477, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "src/gevent/local.py":478
 *         if name in _local_attrs:
 *             object.__setattr__(self, name, value)
 *             return             # <<<<<<<<<<<<<<
 * 
 *         dct = _local_get_dict(self)
*/
    __pyx_r = 0;
    goto __pyx_L0;

    /* "src/gevent/local.py":476
 *                 % type(self))
 * 
 *         if name in _local_attrs:             # <<<<<<<<<<<<<<
 *             object.__setattr__(self, name, value)
 *             return
*/
  }

  /* "src/gevent/local.py":480
 *             return
 * 
 *         dct = _local_get_dict(self)             # <<<<<<<<<<<<<<
 * 
 *         if self._local_type is local:
*/
  __pyx_t_2 = __pyx_f_6gevent_14_gevent_clocal__local_get_dict(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 480, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_dct = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "src/gevent/local.py":482
 *         dct = _local_get_dict(self)
 * 
 *         if self._local_type is local:             # <<<<<<<<<<<<<<
 *             # Optimization: If we're not subclassed, we can't
 *             # have data descriptors, so this goes right in the dict.
*/
  __pyx_t_1 = (__pyx_v_self->_local_type == __pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_clocal_local);
  if (__pyx_t_1) {

    /* "src/gevent/local.py":485
 *             # Optimization: If we're not subclassed, we can't
 *             # have data descriptors, so this goes right in the dict.
 *             dct[name] = value             # <<<<<<<<<<<<<<
 *             return
 * 
*/
    if (unlikely(__pyx_v_dct == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 485, __pyx_L1_error)
    }
    if (unlikely((PyDict_SetItem(__pyx_v_dct, __pyx_v_name, __pyx_v_value) < 0))) __PYX_ERR(0, 485, __pyx_L1_error)

    /* "src/gevent/local.py":486
 *             # have data descriptors, so this goes right in the dict.
 *             dct[name] = value
 *             return             # <<<<<<<<<<<<<<
 * 
 *         if name in self._local_type_vars:
*/
    __pyx_r = 0;
    goto __pyx_L0;

    /* "src/gevent/local.py":482
 *         dct = _local_get_dict(self)
 * 
 *         if self._local_type is local:             # <<<<<<<<<<<<<<
 *             # Optimization: If we're not subclassed, we can't
 *             # have data descriptors, so this goes right in the dict.
*/
  }

  /* "src/gevent/local.py":488
 *             return
 * 
 *         if name in self._local_type_vars:             # <<<<<<<<<<<<<<
 *             if name in self._local_type_set_descriptors:
 *                 type_attr = getattr(self._local_type, name, _marker)
*/
  if (unlikely(__pyx_v_self->_local_type_vars == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 488, __pyx_L1_error)
  }
  __pyx_t_1 = (__Pyx_PySet_ContainsTF(__pyx_v_name, __pyx_v_self->_local_type_vars, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 488, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "src/gevent/local.py":489
 * 
 *         if name in self._local_type_vars:
 *             if name in self._local_type_set_descriptors:             # <<<<<<<<<<<<<<
 *                 type_attr = getattr(self._local_type, name, _marker)
 *                 # A data descriptor, like a property or a slot.
*/
    if (unlikely(__pyx_v_self->_local_type_set_descriptors == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(0, 489, __pyx_L1_error)
    }
    __pyx_t_1 = (__Pyx_PySet_ContainsTF(__pyx_v_name, __pyx_v_self->_local_type_set_descriptors, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 489, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "src/gevent/local.py":490
 *         if name in self._local_type_vars:
 *             if name in self._local_type_set_descriptors:
 *                 type_attr = getattr(self._local_type, name, _marker)             # <<<<<<<<<<<<<<
 *                 # A data descriptor, like a property or a slot.
 *                 type(type_attr).__set__(type_attr, self, value)
*/
      __pyx_t_2 = ((PyObject *)__pyx_v_self->_local_type);
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_4 = __pyx_v_6gevent_14_gevent_clocal__marker;
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_3 = __Pyx_GetAttr3(__pyx_t_2, __pyx_v_name, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 490, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_v_type_attr = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "src/gevent/local.py":492
 *                 type_attr = getattr(self._local_type, name, _marker)
 *                 # A data descriptor, like a property or a slot.
 *                 type(type_attr).__set__(type_attr, self, value)             # <<<<<<<<<<<<<<
 *                 return
 *         # Otherwise it goes directly in the dict
*/
      __pyx_t_4 = ((PyObject *)Py_TYPE(__pyx_v_type_attr));
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[4] = {__pyx_t_4, __pyx_v_type_attr, ((PyObject *)__pyx_v_self), __pyx_v_value};
        __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_set, __pyx_callargs+__pyx_t_5, (4-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 492, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "src/gevent/local.py":493
 *                 # A data descriptor, like a property or a slot.
 *                 type(type_attr).__set__(type_attr, self, value)
 *                 return             # <<<<<<<<<<<<<<
 *         # Otherwise it goes directly in the dict
 *         dct[name] = value
*/
      __pyx_r = 0;
      goto __pyx_L0;

      /* "src/gevent/local.py":489
 * 
 *         if name in self._local_type_vars:
 *             if name in self._local_type_set_descriptors:             # <<<<<<<<<<<<<<
 *                 type_attr = getattr(self._local_type, name, _marker)
 *                 # A data descriptor, like a property or a slot.
*/
    }

    /* "src/gevent/local.py":488
 *             return
 * 
 *         if name in self._local_type_vars:             # <<<<<<<<<<<<<<
 *             if name in self._local_type_set_descriptors:
 *                 type_attr = getattr(self._local_type, name, _marker)
*/
  }

  /* "src/gevent/local.py":495
 *                 return
 *         # Otherwise it goes directly in the dict
 *         dct[name] = value             # <<<<<<<<<<<<<<
 * 
 *     def __delattr__(self, name):
*/
  if (unlikely(__pyx_v_dct == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 495, __pyx_L1_error)
  }
  if (unlikely((PyDict_SetItem(__pyx_v_dct, __pyx_v_name, __pyx_v_value) < 0))) __PYX_ERR(0, 495, __pyx_L1_error)

  /* "src/gevent/local.py":470
 *                              % (self._local_type.__name__, name))
 * 
 *     def __setattr__(self, name, value):             # <<<<<<<<<<<<<<
 *         if name == '__dict__':
 *             raise AttributeError(
*/

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("gevent._gevent_clocal.local.__setattr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_dct);
  __Pyx_XDECREF(__pyx_v_type_attr);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/local.py":497
 *         dct[name] = value
 * 
 *     def __delattr__(self, name):             # <<<<<<<<<<<<<<
 *         if name == '__dict__':
 *             raise AttributeError(
*/

/* Python wrapper */
static int __pyx_pw_6gevent_14_gevent_clocal_5local_7__delattr__(PyObject *__pyx_v_self, PyObject *__pyx_v_name); /*proto*/
static int __pyx_pw_6gevent_14_gevent_clocal_5local_7__delattr__(PyObject *__pyx_v_self, PyObject *__pyx_v_name) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__delattr__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_14_gevent_clocal_5local_6__delattr__(((struct __pyx_obj_6gevent_14_gevent_clocal_local *)__pyx_v_self), ((PyObject *)__pyx_v_name));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6gevent_14_gevent_clocal_5local_6__delattr__(struct __pyx_obj_6gevent_14_gevent_clocal_local *__pyx_v_self, PyObject *__pyx_v_name) {
  PyObject *__pyx_v_type_attr = NULL;
  PyObject *__pyx_v_dct = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__delattr__", 0);

  /* "src/gevent/local.py":498
 * 
 *     def __delattr__(self, name):
 *         if name == '__dict__':             # <<<<<<<<<<<<<<
 *             raise AttributeError(
 *                 "%r object attribute '__dict__' is read-only"
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_mstate_global->__pyx_n_u_dict, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 498, __pyx_L1_error)
  if (unlikely(__pyx_t_1)) {

    /* "src/gevent/local.py":499
 *     def __delattr__(self, name):
 *         if name == '__dict__':
 *             raise AttributeError(             # <<<<<<<<<<<<<<
 *                 "%r object attribute '__dict__' is read-only"
 *                 % self.__class__.__name__)
*/
    __pyx_t_3 = NULL;

    /* "src/gevent/local.py":501
 *             raise AttributeError(
 *                 "%r object attribute '__dict__' is read-only"
 *                 % self.__class__.__name__)             # <<<<<<<<<<<<<<
 * 
 *         if name in self._local_type_vars:
*/
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_class); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 501, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 501, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyUnicode_FormatSafe(__pyx_mstate_global->__pyx_kp_u_r_object_attribute___dict___is, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 501, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_4};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_AttributeError)), __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 499, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 499, __pyx_L1_error)

    /* "src/gevent/local.py":498
 * 
 *     def __delattr__(self, name):
 *         if name == '__dict__':             # <<<<<<<<<<<<<<
 *             raise AttributeError(
 *                 "%r object attribute '__dict__' is read-only"
*/
  }

  /* "src/gevent/local.py":503
 *                 % self.__class__.__name__)
 * 
 *         if name in self._local_type_vars:             # <<<<<<<<<<<<<<
 *             if name in self._local_type_del_descriptors:
 *                 # A data descriptor, like a property or a slot.
*/
  if (unlikely(__pyx_v_self->_local_type_vars == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 503, __pyx_L1_error)
  }
  __pyx_t_1 = (__Pyx_PySet_ContainsTF(__pyx_v_name, __pyx_v_self->_local_type_vars, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 503, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "src/gevent/local.py":504
 * 
 *         if name in self._local_type_vars:
 *             if name in self._local_type_del_descriptors:             # <<<<<<<<<<<<<<
 *                 # A data descriptor, like a property or a slot.
 *                 type_attr = getattr(self._local_type, name, _marker)
*/
    if (unlikely(__pyx_v_self->_local_type_del_descriptors == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(0, 504, __pyx_L1_error)
    }
    __pyx_t_1 = (__Pyx_PySet_ContainsTF(__pyx_v_name, __pyx_v_self->_local_type_del_descriptors, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 504, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "src/gevent/local.py":506
 *             if name in self._local_type_del_descriptors:
 *                 # A data descriptor, like a property or a slot.
 *                 type_attr = getattr(self._local_type, name, _marker)             # <<<<<<<<<<<<<<
 *                 type(type_attr).__delete__(type_attr, self)
 *                 return
*/
      __pyx_t_2 = ((PyObject *)__pyx_v_self->_local_type);
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_4 = __pyx_v_6gevent_14_gevent_clocal__marker;
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_3 = __Pyx_GetAttr3(__pyx_t_2, __pyx_v_name, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 506, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_v_type_attr = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "src/gevent/local.py":507
 *                 # A data descriptor, like a property or a slot.
 *                 type_attr = getattr(self._local_type, name, _marker)
 *                 type(type_attr).__delete__(type_attr, self)             # <<<<<<<<<<<<<<
 *                 return
 *         # Otherwise it goes directly in the dict
*/
      __pyx_t_4 = ((PyObject *)Py_TYPE(__pyx_v_type_attr));
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_v_type_attr, ((PyObject *)__pyx_v_self)};
        __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_delete, __pyx_callargs+__pyx_t_6, (3-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 507, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "src/gevent/local.py":508
 *                 type_attr = getattr(self._local_type, name, _marker)
 *                 type(type_attr).__delete__(type_attr, self)
 *                 return             # <<<<<<<<<<<<<<
 *         # Otherwise it goes directly in the dict
 * 
*/
      __pyx_r = 0;
      goto __pyx_L0;

      /* "src/gevent/local.py":504
 * 
 *         if name in self._local_type_vars:
 *             if name in self._local_type_del_descriptors:             # <<<<<<<<<<<<<<
 *                 # A data descriptor, like a property or a slot.
 *                 type_attr = getattr(self._local_type, name, _marker)
*/
    }

    /* "src/gevent/local.py":503
 *                 % self.__class__.__name__)
 * 
 *         if name in self._local_type_vars:             # <<<<<<<<<<<<<<
 *             if name in self._local_type_del_descriptors:
 *                 # A data descriptor, like a property or a slot.
*/
  }

  /* "src/gevent/local.py":512
 * 
 *         # Begin inlined function _get_dict()
 *         dct = _local_get_dict(self)             # <<<<<<<<<<<<<<
 * 
 *         try:
*/
  __pyx_t_3 = __pyx_f_6gevent_14_gevent_clocal__local_get_dict(__pyx_v_self); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_dct = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "src/gevent/local.py":514
 *         dct = _local_get_dict(self)
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             del dct[name]
 *         except KeyError:
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
    __Pyx_XGOTREF(__pyx_t_7);
    __Pyx_XGOTREF(__pyx_t_8);
    __Pyx_XGOTREF(__pyx_t_9);
    /*try:*/ {

      /* "src/gevent/local.py":515
 * 
 *         try:
 *             del dct[name]             # <<<<<<<<<<<<<<
 *         except KeyError:
 *             raise AttributeError(name)
*/
      if (unlikely(__pyx_v_dct == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 515, __pyx_L6_error)
      }
      if (unlikely((PyDict_DelItem(__pyx_v_dct, __pyx_v_name) < 0))) __PYX_ERR(0, 515, __pyx_L6_error)

      /* "src/gevent/local.py":514
 *         dct = _local_get_dict(self)
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             del dct[name]
 *         except KeyError:
*/
    }
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    goto __pyx_L11_try_end;
    __pyx_L6_error:;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "src/gevent/local.py":516
 *         try:
 *             del dct[name]
 *         except KeyError:             # <<<<<<<<<<<<<<
 *             raise AttributeError(name)
 * 
*/
    __pyx_t_10 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_KeyError))));
    if (__pyx_t_10) {
      __Pyx_AddTraceback("gevent._gevent_clocal.local.__delattr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_4, &__pyx_t_2) < 0) __PYX_ERR(0, 516, __pyx_L8_except_error)
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_2);

      /* "src/gevent/local.py":517
 *             del dct[name]
 *         except KeyError:
 *             raise AttributeError(name)             # <<<<<<<<<<<<<<
 * 
 *     def __copy__(self):
*/
      __pyx_t_11 = NULL;
      __pyx_t_6 = 1;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_v_name};
        __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_AttributeError)), __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 517, __pyx_L8_except_error)
        __Pyx_GOTREF(__pyx_t_5);
      }
      __Pyx_Raise(__pyx_t_5, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __PYX_ERR(0, 517, __pyx_L8_except_error)
    }
    goto __pyx_L8_except_error;

    /* "src/gevent/local.py":514
 *         dct = _local_get_dict(self)
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             del dct[name]
 *         except KeyError:
*/
    __pyx_L8_except_error:;
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
    goto __pyx_L1_error;
    __pyx_L11_try_end:;
  }

  /* "src/gevent/local.py":497
 *         dct[name] = value
 * 
 *     def __delattr__(self, name):             # <<<<<<<<<<<<<<
 *         if name == '__dict__':
 *             raise AttributeError(
*/

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("gevent._gevent_clocal.local.__delattr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_type_attr);
  __Pyx_XDECREF(__pyx_v_dct);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/local.py":519
 *             raise AttributeError(name)
 * 
 *     def __copy__(self):             # <<<<<<<<<<<<<<
 *         impl = self._local__impl
 *         entry = impl.dicts[id(getcurrent())]  # pylint:disable=undefined-variable
*/

static PyObject *__pyx_pw_6gevent_14_gevent_clocal_5local_9__copy__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static struct __pyx_obj_6gevent_14_gevent_clocal_local *__pyx_f_6gevent_14_gevent_clocal_5local___copy__(struct __pyx_obj_6gevent_14_gevent_clocal_local *__pyx_v_self, int __pyx_skip_dispatch) {
  struct __pyx_obj_6gevent_14_gevent_clocal__localimpl_dict_entry *__pyx_v_entry = 0;
  PyObject *__pyx_v_dct = 0;
  PyObject *__pyx_v_duplicate = 0;
  struct __pyx_obj_6gevent_14_gevent_clocal_local *__pyx_v_instance = 0;
  struct __pyx_obj_6gevent_14_gevent_clocal__localimpl *__pyx_v_impl = NULL;
  PyTypeObject *__pyx_v_cls = NULL;
  struct __pyx_obj_6gevent_14_gevent_clocal_local *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__copy__", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (
  #if !CYTHON_USE_TYPE_SLOTS
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_clocal_local &&
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
  #else
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
  #endif
  ) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_copy); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 519, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_6gevent_14_gevent_clocal_5local_9__copy__)) {
        __Pyx_XDECREF((PyObject *)__pyx_r);
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 519, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_clocal_local))))) __PYX_ERR(0, 519, __pyx_L1_error)
        __pyx_r = ((struct __pyx_obj_6gevent_14_gevent_clocal_local *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "src/gevent/local.py":520
 * 
 *     def __copy__(self):
 *         impl = self._local__impl             # <<<<<<<<<<<<<<
 *         entry = impl.dicts[id(getcurrent())]  # pylint:disable=undefined-variable
 * 
*/
  __pyx_t_1 = ((PyObject *)__pyx_v_self->_local__impl);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_impl = ((struct __pyx_obj_6gevent_14_gevent_clocal__localimpl *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "src/gevent/local.py":521
 *     def __copy__(self):
 *         impl = self._local__impl
 *         entry = impl.dicts[id(getcurrent())]  # pylint:disable=undefined-variable             # <<<<<<<<<<<<<<
 * 
 *         dct = entry.localdict
*/
  if (unlikely(__pyx_v_impl->dicts == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 521, __pyx_L1_error)
  }
  __pyx_t_2 = NULL;
  __pyx_t_4 = ((PyObject *)__pyx_f_6gevent_14_gevent_clocal_getcurrent()); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_4};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_id, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 521, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_t_4 = __Pyx_PyDict_GetItem(__pyx_v_impl->dicts, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(((__pyx_t_4) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_4, __pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_clocal__localimpl_dict_entry))))) __PYX_ERR(0, 521, __pyx_L1_error)
  __pyx_v_entry = ((struct __pyx_obj_6gevent_14_gevent_clocal__localimpl_dict_entry *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "src/gevent/local.py":523
 *         entry = impl.dicts[id(getcurrent())]  # pylint:disable=undefined-variable
 * 
 *         dct = entry.localdict             # <<<<<<<<<<<<<<
 *         duplicate = copy(dct)
 * 
*/
  __pyx_t_4 = __pyx_v_entry->localdict;
  __Pyx_INCREF(__pyx_t_4);
  __pyx_v_dct = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "src/gevent/local.py":524
 * 
 *         dct = entry.localdict
 *         duplicate = copy(dct)             # <<<<<<<<<<<<<<
 * 
 *         cls = type(self)
*/
  __pyx_t_1 = NULL;
  __Pyx_INCREF(__pyx_v_6gevent_14_gevent_clocal_copy);
  __pyx_t_2 = __pyx_v_6gevent_14_gevent_clocal_copy; 
  __pyx_t_5 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
    assert(__pyx_t_1);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
    __pyx_t_5 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_dct};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 524, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (!(likely(PyDict_CheckExact(__pyx_t_4))||((__pyx_t_4) == Py_None) || __Pyx_RaiseUnexpectedTypeError("dict", __pyx_t_4))) __PYX_ERR(0, 524, __pyx_L1_error)
  __pyx_v_duplicate = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "src/gevent/local.py":526
 *         duplicate = copy(dct)
 * 
 *         cls = type(self)             # <<<<<<<<<<<<<<
 *         instance = cls(*impl.localargs, **impl.localkwargs)
 *         _local__copy_dict_from(instance, impl, duplicate)
*/
  __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
  __pyx_v_cls = ((PyTypeObject*)((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));

  /* "src/gevent/local.py":527
 * 
 *         cls = type(self)
 *         instance = cls(*impl.localargs, **impl.localkwargs)             # <<<<<<<<<<<<<<
 *         _local__copy_dict_from(instance, impl, duplicate)
 *         return instance
*/
  if (unlikely(__pyx_v_impl->localargs == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 527, __pyx_L1_error)
  }
  if (unlikely(__pyx_v_impl->localkwargs == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "argument after ** must be a mapping, not NoneType");
    __PYX_ERR(0, 527, __pyx_L1_error)
  }
  __pyx_t_4 = PyDict_Copy(__pyx_v_impl->localkwargs); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_v_cls), __pyx_v_impl->localargs, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_clocal_local))))) __PYX_ERR(0, 527, __pyx_L1_error)
  __pyx_v_instance = ((struct __pyx_obj_6gevent_14_gevent_clocal_local *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "src/gevent/local.py":528
 *         cls = type(self)
 *         instance = cls(*impl.localargs, **impl.localkwargs)
 *         _local__copy_dict_from(instance, impl, duplicate)             # <<<<<<<<<<<<<<
 *         return instance
 * 
*/
  __pyx_t_2 = __pyx_f_6gevent_14_gevent_clocal__local__copy_dict_from(__pyx_v_instance, __pyx_v_impl, __pyx_v_duplicate); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 528, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/local.py":529
 *         instance = cls(*impl.localargs, **impl.localkwargs)
 *         _local__copy_dict_from(instance, impl, duplicate)
 *         return instance             # <<<<<<<<<<<<<<
 * 
 * def _local__copy_dict_from(self, impl, duplicate):
*/
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_instance);
  __pyx_r = __pyx_v_instance;
  goto __pyx_L0;

  /* "src/gevent/local.py":519
 *             raise AttributeError(name)
 * 
 *     def __copy__(self):             # <<<<<<<<<<<<<<
 *         impl = self._local__impl
 *         entry = impl.dicts[id(getcurrent())]  # pylint:disable=undefined-variable
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("gevent._gevent_clocal.local.__copy__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_entry);
  __Pyx_XDECREF(__pyx_v_dct);
  __Pyx_XDECREF(__pyx_v_duplicate);
  __Pyx_XDECREF((PyObject *)__pyx_v_instance);
  __Pyx_XDECREF((PyObject *)__pyx_v_impl);
  __Pyx_XDECREF((PyObject *)__pyx_v_cls);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_14_gevent_clocal_5local_9__copy__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_14_gevent_clocal_5local_8__copy__, "local.__copy__(self) -> local");
static PyMethodDef __pyx_mdef_6gevent_14_gevent_clocal_5local_9__copy__ = {"__copy__", (PyCFunction)__pyx_pw_6gevent_14_gevent_clocal_5local_9__copy__, METH_NOARGS, __pyx_doc_6gevent_14_gevent_clocal_5local_8__copy__};
static PyObject *__pyx_pw_6gevent_14_gevent_clocal_5local_9__copy__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__copy__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_14_gevent_clocal_5local_8__copy__(((struct __pyx_obj_6gevent_14_gevent_clocal_local *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_14_gevent_clocal_5local_8__copy__(struct __pyx_obj_6gevent_14_gevent_clocal_local *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__copy__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_6gevent_14_gevent_clocal_5local___copy__(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_clocal.local.__copy__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/local.py":531
 *         return instance
 * 
 * def _local__copy_dict_from(self, impl, duplicate):             # <<<<<<<<<<<<<<
 *     current = getcurrent() # pylint:disable=undefined-variable
 *     currentId = id(current)
*/

static PyObject *__pyx_f_6gevent_14_gevent_clocal__local__copy_dict_from(struct __pyx_obj_6gevent_14_gevent_clocal_local *__pyx_v_self, struct __pyx_obj_6gevent_14_gevent_clocal__localimpl *__pyx_v_impl, PyObject *__pyx_v_duplicate) {
  struct __pyx_obj_6gevent_14_gevent_clocal__localimpl_dict_entry *__pyx_v_entry = 0;
  PyGreenlet *__pyx_v_current = NULL;
  PyObject *__pyx_v_currentId = NULL;
  struct __pyx_obj_6gevent_14_gevent_clocal__localimpl *__pyx_v_new_impl = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_local__copy_dict_from", 0);

  /* "src/gevent/local.py":532
 * 
 * def _local__copy_dict_from(self, impl, duplicate):
 *     current = getcurrent() # pylint:disable=undefined-variable             # <<<<<<<<<<<<<<
 *     currentId = id(current)
 *     new_impl = self._local__impl
*/
  __pyx_t_1 = ((PyObject *)__pyx_f_6gevent_14_gevent_clocal_getcurrent()); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_current = ((PyGreenlet *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "src/gevent/local.py":533
 * def _local__copy_dict_from(self, impl, duplicate):
 *     current = getcurrent() # pylint:disable=undefined-variable
 *     currentId = id(current)             # <<<<<<<<<<<<<<
 *     new_impl = self._local__impl
 *     assert new_impl is not impl
*/
  __pyx_t_2 = NULL;
  __pyx_t_3 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, ((PyObject *)__pyx_v_current)};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_id, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 533, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_currentId = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "src/gevent/local.py":534
 *     current = getcurrent() # pylint:disable=undefined-variable
 *     currentId = id(current)
 *     new_impl = self._local__impl             # <<<<<<<<<<<<<<
 *     assert new_impl is not impl
 *     entry = new_impl.dicts[currentId]
*/
  __pyx_t_1 = ((PyObject *)__pyx_v_self->_local__impl);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_new_impl = ((struct __pyx_obj_6gevent_14_gevent_clocal__localimpl *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "src/gevent/local.py":535
 *     currentId = id(current)
 *     new_impl = self._local__impl
 *     assert new_impl is not impl             # <<<<<<<<<<<<<<
 *     entry = new_impl.dicts[currentId]
 *     new_impl.dicts[currentId] = _localimpl_dict_entry(entry.wrgreenlet, duplicate)
*/
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(__pyx_assertions_enabled())) {
    __pyx_t_4 = (__pyx_v_new_impl != __pyx_v_impl);
    if (unlikely(!__pyx_t_4)) {
      __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_AssertionError))), 0, 0, 0);
      __PYX_ERR(0, 535, __pyx_L1_error)
    }
  }
  #else
  if ((1)); else __PYX_ERR(0, 535, __pyx_L1_error)
  #endif

  /* "src/gevent/local.py":536
 *     new_impl = self._local__impl
 *     assert new_impl is not impl
 *     entry = new_impl.dicts[currentId]             # <<<<<<<<<<<<<<
 *     new_impl.dicts[currentId] = _localimpl_dict_entry(entry.wrgreenlet, duplicate)
 * 
*/
  if (unlikely(__pyx_v_new_impl->dicts == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 536, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_new_impl->dicts, __pyx_v_currentId); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_clocal__localimpl_dict_entry))))) __PYX_ERR(0, 536, __pyx_L1_error)
  __pyx_v_entry = ((struct __pyx_obj_6gevent_14_gevent_clocal__localimpl_dict_entry *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "src/gevent/local.py":537
 *     assert new_impl is not impl
 *     entry = new_impl.dicts[currentId]
 *     new_impl.dicts[currentId] = _localimpl_dict_entry(entry.wrgreenlet, duplicate)             # <<<<<<<<<<<<<<
 * 
 * def _local_find_descriptors(self):
*/
  __pyx_t_2 = NULL;
  __pyx_t_3 = 1;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_entry->wrgreenlet, __pyx_v_duplicate};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_clocal__localimpl_dict_entry, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 537, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_1);
  }
  if (unlikely(__pyx_v_new_impl->dicts == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 537, __pyx_L1_error)
  }
  if (unlikely((PyDict_SetItem(__pyx_v_new_impl->dicts, __pyx_v_currentId, ((PyObject *)__pyx_t_1)) < 0))) __PYX_ERR(0, 537, __pyx_L1_error)
  __Pyx_DECREF((PyObject *)__pyx_t_1); __pyx_t_1 = 0;

  /* "src/gevent/local.py":531
 *         return instance
 * 
 * def _local__copy_dict_from(self, impl, duplicate):             # <<<<<<<<<<<<<<
 *     current = getcurrent() # pylint:disable=undefined-variable
 *     currentId = id(current)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("gevent._gevent_clocal._local__copy_dict_from", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_entry);
  __Pyx_XDECREF((PyObject *)__pyx_v_current);
  __Pyx_XDECREF(__pyx_v_currentId);
  __Pyx_XDECREF((PyObject *)__pyx_v_new_impl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/local.py":539
 *     new_impl.dicts[currentId] = _localimpl_dict_entry(entry.wrgreenlet, duplicate)
 * 
 * def _local_find_descriptors(self):             # <<<<<<<<<<<<<<
 *     type_self = type(self)
 *     gets = set()
*/

static PyObject *__pyx_f_6gevent_14_gevent_clocal__local_find_descriptors(struct __pyx_obj_6gevent_14_gevent_clocal_local *__pyx_v_self) {
  PyObject *__pyx_v_mro = 0;
  PyObject *__pyx_v_gets = 0;
  PyObject *__pyx_v_dels = 0;
  PyObject *__pyx_v_set_or_del = 0;
  PyTypeObject *__pyx_v_type_self = 0;
  PyTypeObject *__pyx_v_type_attr = 0;
  PyObject *__pyx_v_sets = 0;
  PyObject *__pyx_v_attr_name = NULL;
  PyObject *__pyx_v_base = NULL;
  PyObject *__pyx_v_bd = NULL;
  PyObject *__pyx_v_attr = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  Py_ssize_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_local_find_descriptors", 0);

  /* "src/gevent/local.py":540
 * 
 * def _local_find_descriptors(self):
 *     type_self = type(self)             # <<<<<<<<<<<<<<
 *     gets = set()
 *     dels = set()
*/
  __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
  __pyx_v_type_self = ((PyTypeObject*)((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));

  /* "src/gevent/local.py":541
 * def _local_find_descriptors(self):
 *     type_self = type(self)
 *     gets = set()             # <<<<<<<<<<<<<<
 *     dels = set()
 *     set_or_del = set()
*/
  __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_gets = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "src/gevent/local.py":542
 *     type_self = type(self)
 *     gets = set()
 *     dels = set()             # <<<<<<<<<<<<<<
 *     set_or_del = set()
 *     sets = set()
*/
  __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 542, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_dels = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "src/gevent/local.py":543
 *     gets = set()
 *     dels = set()
 *     set_or_del = set()             # <<<<<<<<<<<<<<
 *     sets = set()
 *     mro = list(type_self.mro())
*/
  __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_set_or_del = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "src/gevent/local.py":544
 *     dels = set()
 *     set_or_del = set()
 *     sets = set()             # <<<<<<<<<<<<<<
 *     mro = list(type_self.mro())
 * 
*/
  __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_sets = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "src/gevent/local.py":545
 *     set_or_del = set()
 *     sets = set()
 *     mro = list(type_self.mro())             # <<<<<<<<<<<<<<
 * 
 *     for attr_name in dir(type_self):
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_type_self);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_mro, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 545, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_t_2 = __Pyx_PySequence_ListKeepNew(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_mro = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "src/gevent/local.py":547
 *     mro = list(type_self.mro())
 * 
 *     for attr_name in dir(type_self):             # <<<<<<<<<<<<<<
 *         # Conventionally, descriptors when called on a class
 *         # return themself, but not all do. Notable exceptions are
*/
  __pyx_t_2 = PyObject_Dir(((PyObject *)__pyx_v_type_self)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
    __pyx_t_1 = __pyx_t_2; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 547, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 547, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  for (;;) {
    if (likely(!__pyx_t_5)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 547, __pyx_L1_error)
          #endif
          if (__pyx_t_4 >= __pyx_temp) break;
        }
        __pyx_t_2 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_4, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_4;
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 547, __pyx_L1_error)
          #endif
          if (__pyx_t_4 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_4));
        #else
        __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_4);
        #endif
        ++__pyx_t_4;
      }
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 547, __pyx_L1_error)
    } else {
      __pyx_t_2 = __pyx_t_5(__pyx_t_1);
      if (unlikely(!__pyx_t_2)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 547, __pyx_L1_error)
          PyErr_Clear();
        }
        break;
      }
    }
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_XDECREF_SET(__pyx_v_attr_name, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "src/gevent/local.py":553
 *         # return other class attributes. So we can't use getattr, and instead
 *         # walk up the dicts
 *         for base in mro:             # <<<<<<<<<<<<<<
 *             bd = base.__dict__
 *             if attr_name in bd:
*/
    __pyx_t_2 = __pyx_v_mro; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_6 = 0;
    for (;;) {
      {
        Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 553, __pyx_L1_error)
        #endif
        if (__pyx_t_6 >= __pyx_temp) break;
      }
      __pyx_t_7 = __Pyx_PyList_GetItemRefFast(__pyx_t_2, __pyx_t_6, __Pyx_ReferenceSharing_OwnStrongReference);
      ++__pyx_t_6;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 553, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_XDECREF_SET(__pyx_v_base, __pyx_t_7);
      __pyx_t_7 = 0;

      /* "src/gevent/local.py":554
 *         # walk up the dicts
 *         for base in mro:
 *             bd = base.__dict__             # <<<<<<<<<<<<<<
 *             if attr_name in bd:
 *                 attr = bd[attr_name]
*/
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_base, __pyx_mstate_global->__pyx_n_u_dict); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 554, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_XDECREF_SET(__pyx_v_bd, __pyx_t_7);
      __pyx_t_7 = 0;

      /* "src/gevent/local.py":555
 *         for base in mro:
 *             bd = base.__dict__
 *             if attr_name in bd:             # <<<<<<<<<<<<<<
 *                 attr = bd[attr_name]
 *                 break
*/
      __pyx_t_8 = (__Pyx_PySequence_ContainsTF(__pyx_v_attr_name, __pyx_v_bd, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 555, __pyx_L1_error)
      if (__pyx_t_8) {

        /* "src/gevent/local.py":556
 *             bd = base.__dict__
 *             if attr_name in bd:
 *                 attr = bd[attr_name]             # <<<<<<<<<<<<<<
 *                 break
 *         else:
*/
        __pyx_t_7 = __Pyx_PyObject_GetItem(__pyx_v_bd, __pyx_v_attr_name); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 556, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_XDECREF_SET(__pyx_v_attr, __pyx_t_7);
        __pyx_t_7 = 0;

        /* "src/gevent/local.py":557
 *             if attr_name in bd:
 *                 attr = bd[attr_name]
 *                 break             # <<<<<<<<<<<<<<
 *         else:
 *             raise AttributeError(attr_name)
*/
        goto __pyx_L6_break;

        /* "src/gevent/local.py":555
 *         for base in mro:
 *             bd = base.__dict__
 *             if attr_name in bd:             # <<<<<<<<<<<<<<
 *                 attr = bd[attr_name]
 *                 break
*/
      }

      /* "src/gevent/local.py":553
 *         # return other class attributes. So we can't use getattr, and instead
 *         # walk up the dicts
 *         for base in mro:             # <<<<<<<<<<<<<<
 *             bd = base.__dict__
 *             if attr_name in bd:
*/
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    goto __pyx_L8_for_else;
    __pyx_L6_break:;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    goto __pyx_L9_for_end;
    /*else*/ {
      __pyx_L8_for_else:;

      /* "src/gevent/local.py":559
 *                 break
 *         else:
 *             raise AttributeError(attr_name)             # <<<<<<<<<<<<<<
 * 
 *         type_attr = type(attr)
*/
      __pyx_t_7 = NULL;
      __pyx_t_3 = 1;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_v_attr_name};
        __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_AttributeError)), __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 559, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(0, 559, __pyx_L1_error)
    }
    __pyx_L9_for_end:;

    /* "src/gevent/local.py":561
 *             raise AttributeError(attr_name)
 * 
 *         type_attr = type(attr)             # <<<<<<<<<<<<<<
 *         if hasattr(type_attr, '__get__'):
 *             gets.add(attr_name)
*/
    __Pyx_INCREF(((PyObject *)Py_TYPE(__pyx_v_attr)));
    __Pyx_XDECREF_SET(__pyx_v_type_attr, ((PyTypeObject*)((PyObject *)Py_TYPE(__pyx_v_attr))));

    /* "src/gevent/local.py":562
 * 
 *         type_attr = type(attr)
 *         if hasattr(type_attr, '__get__'):             # <<<<<<<<<<<<<<
 *             gets.add(attr_name)
 *         if hasattr(type_attr, '__delete__'):
*/
    __pyx_t_8 = __Pyx_HasAttr(((PyObject *)__pyx_v_type_attr), __pyx_mstate_global->__pyx_n_u_get); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 562, __pyx_L1_error)
    if (__pyx_t_8) {

      /* "src/gevent/local.py":563
 *         type_attr = type(attr)
 *         if hasattr(type_attr, '__get__'):
 *             gets.add(attr_name)             # <<<<<<<<<<<<<<
 *         if hasattr(type_attr, '__delete__'):
 *             dels.add(attr_name)
*/
      __pyx_t_9 = PySet_Add(__pyx_v_gets, __pyx_v_attr_name); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 563, __pyx_L1_error)

      /* "src/gevent/local.py":562
 * 
 *         type_attr = type(attr)
 *         if hasattr(type_attr, '__get__'):             # <<<<<<<<<<<<<<
 *             gets.add(attr_name)
 *         if hasattr(type_attr, '__delete__'):
*/
    }

    /* "src/gevent/local.py":564
 *         if hasattr(type_attr, '__get__'):
 *             gets.add(attr_name)
 *         if hasattr(type_attr, '__delete__'):             # <<<<<<<<<<<<<<
 *             dels.add(attr_name)
 *             set_or_del.add(attr_name)
*/
    __pyx_t_8 = __Pyx_HasAttr(((PyObject *)__pyx_v_type_attr), __pyx_mstate_global->__pyx_n_u_delete); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 564, __pyx_L1_error)
    if (__pyx_t_8) {

      /* "src/gevent/local.py":565
 *             gets.add(attr_name)
 *         if hasattr(type_attr, '__delete__'):
 *             dels.add(attr_name)             # <<<<<<<<<<<<<<
 *             set_or_del.add(attr_name)
 *         if hasattr(type_attr, '__set__'):
*/
      __pyx_t_9 = PySet_Add(__pyx_v_dels, __pyx_v_attr_name); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 565, __pyx_L1_error)

      /* "src/gevent/local.py":566
 *         if hasattr(type_attr, '__delete__'):
 *             dels.add(attr_name)
 *             set_or_del.add(attr_name)             # <<<<<<<<<<<<<<
 *         if hasattr(type_attr, '__set__'):
 *             sets.add(attr_name)
*/
      __pyx_t_9 = PySet_Add(__pyx_v_set_or_del, __pyx_v_attr_name); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 566, __pyx_L1_error)

      /* "src/gevent/local.py":564
 *         if hasattr(type_attr, '__get__'):
 *             gets.add(attr_name)
 *         if hasattr(type_attr, '__delete__'):             # <<<<<<<<<<<<<<
 *             dels.add(attr_name)
 *             set_or_del.add(attr_name)
*/
    }

    /* "src/gevent/local.py":567
 *             dels.add(attr_name)
 *             set_or_del.add(attr_name)
 *         if hasattr(type_attr, '__set__'):             # <<<<<<<<<<<<<<
 *             sets.add(attr_name)
 * 
*/
    __pyx_t_8 = __Pyx_HasAttr(((PyObject *)__pyx_v_type_attr), __pyx_mstate_global->__pyx_n_u_set); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 567, __pyx_L1_error)
    if (__pyx_t_8) {

      /* "src/gevent/local.py":568
 *             set_or_del.add(attr_name)
 *         if hasattr(type_attr, '__set__'):
 *             sets.add(attr_name)             # <<<<<<<<<<<<<<
 * 
 *     return (gets, dels, set_or_del, sets)
*/
      __pyx_t_9 = PySet_Add(__pyx_v_sets, __pyx_v_attr_name); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 568, __pyx_L1_error)

      /* "src/gevent/local.py":567
 *             dels.add(attr_name)
 *             set_or_del.add(attr_name)
 *         if hasattr(type_attr, '__set__'):             # <<<<<<<<<<<<<<
 *             sets.add(attr_name)
 * 
*/
    }

    /* "src/gevent/local.py":547
 *     mro = list(type_self.mro())
 * 
 *     for attr_name in dir(type_self):             # <<<<<<<<<<<<<<
 *         # Conventionally, descriptors when called on a class
 *         # return themself, but not all do. Notable exceptions are
*/
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "src/gevent/local.py":570
 *             sets.add(attr_name)
 * 
 *     return (gets, dels, set_or_del, sets)             # <<<<<<<<<<<<<<
 * 
 * # Cython doesn't let us use __new__, it requires
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 570, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_gets);
  __Pyx_GIVEREF(__pyx_v_gets);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_gets) != (0)) __PYX_ERR(0, 570, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_dels);
  __Pyx_GIVEREF(__pyx_v_dels);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_dels) != (0)) __PYX_ERR(0, 570, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_set_or_del);
  __Pyx_GIVEREF(__pyx_v_set_or_del);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_set_or_del) != (0)) __PYX_ERR(0, 570, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_sets);
  __Pyx_GIVEREF(__pyx_v_sets);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_v_sets) != (0)) __PYX_ERR(0, 570, __pyx_L1_error);
  __pyx_r = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "src/gevent/local.py":539
 *     new_impl.dicts[currentId] = _localimpl_dict_entry(entry.wrgreenlet, duplicate)
 * 
 * def _local_find_descriptors(self):             # <<<<<<<<<<<<<<
 *     type_self = type(self)
 *     gets = set()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("gevent._gevent_clocal._local_find_descriptors", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_mro);
  __Pyx_XDECREF(__pyx_v_gets);
  __Pyx_XDECREF(__pyx_v_dels);
  __Pyx_XDECREF(__pyx_v_set_or_del);
  __Pyx_XDECREF((PyObject *)__pyx_v_type_self);
  __Pyx_XDECREF((PyObject *)__pyx_v_type_attr);
  __Pyx_XDECREF(__pyx_v_sets);
  __Pyx_XDECREF(__pyx_v_attr_name);
  __Pyx_XDECREF(__pyx_v_base);
  __Pyx_XDECREF(__pyx_v_bd);
  __Pyx_XDECREF(__pyx_v_attr);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/local.py":576
 * # (e.g., on PyPy). So we set it at runtime. Cython
 * # will raise an error if we're compiled.
 * def __new__(cls, *args, **kw):             # <<<<<<<<<<<<<<
 *     self = super(local, cls).__new__(cls) # pylint:disable=no-value-for-parameter
 *     # We get the cls in *args for some reason
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_14_gevent_clocal_3__new__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_14_gevent_clocal_2__new__, "__new__(cls, *args, **kw)");
static PyMethodDef __pyx_mdef_6gevent_14_gevent_clocal_3__new__ = {"__new__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6gevent_14_gevent_clocal_3__new__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6gevent_14_gevent_clocal_2__new__};
static PyObject *__pyx_pw_6gevent_14_gevent_clocal_3__new__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_cls = 0;
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_v_kw = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__new__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_kw = PyDict_New(); if (unlikely(!__pyx_v_kw)) return NULL;
  __Pyx_GOTREF(__pyx_v_kw);
  __pyx_v_args = __Pyx_ArgsSlice_FASTCALL(__pyx_args, 1, __pyx_nargs);
  if (unlikely(!__pyx_v_args)) {
    __Pyx_DECREF(__pyx_v_kw); __pyx_v_kw = 0;
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __Pyx_GOTREF(__pyx_v_args);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_cls,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 576, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        default:
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 576, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      const Py_ssize_t used_pos_args = (kwd_pos_args < 1) ? kwd_pos_args : 1;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_kw, values, used_pos_args, __pyx_kwds_len, "__new__", 1) < (0)) __PYX_ERR(0, 576, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__new__", 0, 1, 1, i); __PYX_ERR(0, 576, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs < 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 576, __pyx_L3_error)
    }
    __pyx_v_cls = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__new__", 0, 1, 1, __pyx_nargs); __PYX_ERR(0, 576, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_DECREF(__pyx_v_args); __pyx_v_args = 0;
  __Pyx_DECREF(__pyx_v_kw); __pyx_v_kw = 0;
  __Pyx_AddTraceback("gevent._gevent_clocal.__new__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6gevent_14_gevent_clocal_2__new__(__pyx_self, __pyx_v_cls, __pyx_v_args, __pyx_v_kw);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_DECREF(__pyx_v_kw);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_14_gevent_clocal_2__new__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls, PyObject *__pyx_v_args, PyObject *__pyx_v_kw) {
  PyObject *__pyx_v_self = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__new__", 0);

  /* "src/gevent/local.py":577
 * # will raise an error if we're compiled.
 * def __new__(cls, *args, **kw):
 *     self = super(local, cls).__new__(cls) # pylint:disable=no-value-for-parameter             # <<<<<<<<<<<<<<
 *     # We get the cls in *args for some reason
 *     # too when we do it this way....except on PyPy3, which does
*/
  __pyx_t_4 = NULL;
  __pyx_t_5 = 1;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, ((PyObject *)__pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_clocal_local), __pyx_v_cls};
    __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_super, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 577, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_t_2 = __pyx_t_3;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_cls};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_new, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 577, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_self = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "src/gevent/local.py":581
 *     # too when we do it this way....except on PyPy3, which does
 *     # not *unless* it's wrapped in a classmethod (which it is)
 *     self.__cinit__(*args[1:], **kw)             # <<<<<<<<<<<<<<
 *     return self
 * 
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_cinit); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 581, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyTuple_GetSlice(__pyx_v_args, 1, PY_SSIZE_T_MAX); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 581, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyDict_Copy(__pyx_v_kw); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 581, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 581, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/local.py":582
 *     # not *unless* it's wrapped in a classmethod (which it is)
 *     self.__cinit__(*args[1:], **kw)
 *     return self             # <<<<<<<<<<<<<<
 * 
 * if local.__module__ == 'gevent.local':
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "src/gevent/local.py":576
 * # (e.g., on PyPy). So we set it at runtime. Cython
 * # will raise an error if we're compiled.
 * def __new__(cls, *args, **kw):             # <<<<<<<<<<<<<<
 *     self = super(local, cls).__new__(cls) # pylint:disable=no-value-for-parameter
 *     # We get the cls in *args for some reason
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("gevent._gevent_clocal.__new__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_self);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
/* #### Code section: module_exttypes ### */

static PyObject *__pyx_tp_new_6gevent_14_gevent_clocal__wrefdict(PyTypeObject *t, PyObject *a, PyObject *k) {
  PyObject *o = __Pyx_PyType_GetSlot((&PyDict_Type), tp_new, newfunc)(t, a, k);
  if (unlikely(!o)) return 0;
  return o;
}

static void __pyx_tp_dealloc_6gevent_14_gevent_clocal__wrefdict(PyObject *o) {
  struct __pyx_obj_6gevent_14_gevent_clocal__wrefdict *p = (struct __pyx_obj_6gevent_14_gevent_clocal__wrefdict *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6gevent_14_gevent_clocal__wrefdict) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  __Pyx_TRASHCAN_BEGIN(o, __pyx_tp_dealloc_6gevent_14_gevent_clocal__wrefdict)
  if (p->__weakref__) PyObject_ClearWeakRefs(o);
  PyObject_GC_Track(o);
  __Pyx_PyType_GetSlot((&PyDict_Type), tp_dealloc, destructor)(o);
  __Pyx_TRASHCAN_END
}

static int __pyx_tp_traverse_6gevent_14_gevent_clocal__wrefdict(PyObject *o, visitproc v, void *a) {
  int e;
  {
    traverseproc traverse = __Pyx_PyType_GetSlot((&PyDict_Type), tp_traverse, traverseproc);
    if (!traverse); else { e = traverse(o,v,a); if (e) return e; }
  }
  {
    e = __Pyx_call_type_traverse(o, 0, v, a);
    if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6gevent_14_gevent_clocal__wrefdict(PyObject *o) {
  {
    inquiry clear = __Pyx_PyType_GetSlot((&PyDict_Type), tp_clear, inquiry);
    if (clear) clear(o);
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyMemberDef __pyx_type_6gevent_14_gevent_clocal__wrefdict_members[] = {
  #if !CYTHON_USE_TYPE_SLOTS
  {"__weaklistoffset__", T_PYSSIZET, offsetof(struct __pyx_obj_6gevent_14_gevent_clocal__wrefdict, __weakref__), READONLY, 0},
  #endif
  {0, 0, 0, 0, 0}
};
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x03090000
#if defined(__GNUC__) || defined(__clang__)
#warning "src/gevent/_gevent_clocal.pxd:41:15: : __weakref__ is unsupported in the Limited API when running on Python <3.9."
#elif defined(_MSC_VER)
#pragma message("src/gevent/_gevent_clocal.pxd:41:15: : __weakref__ is unsupported in the Limited API when running on Python <3.9.")
#endif
#endif
static PyType_Slot __pyx_type_6gevent_14_gevent_clocal__wrefdict_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6gevent_14_gevent_clocal__wrefdict},
  {Py_tp_doc, (void *)PyDoc_STR("A dict that can be weak referenced")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6gevent_14_gevent_clocal__wrefdict},
  {Py_tp_clear, (void *)__pyx_tp_clear_6gevent_14_gevent_clocal__wrefdict},
  {Py_tp_new, (void *)__pyx_tp_new_6gevent_14_gevent_clocal__wrefdict},
  {Py_tp_members, (void*)__pyx_type_6gevent_14_gevent_clocal__wrefdict_members},
  {0, 0},
};
static PyType_Spec __pyx_type_6gevent_14_gevent_clocal__wrefdict_spec = {
  "gevent._gevent_clocal._wrefdict",
  sizeof(struct __pyx_obj_6gevent_14_gevent_clocal__wrefdict),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6gevent_14_gevent_clocal__wrefdict_slots,
};
#else

static PyTypeObject __pyx_type_6gevent_14_gevent_clocal__wrefdict = {
  PyVarObject_HEAD_INIT(0, 0)
  "gevent._gevent_clocal.""_wrefdict", /*tp_name*/
  sizeof(struct __pyx_obj_6gevent_14_gevent_clocal__wrefdict), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6gevent_14_gevent_clocal__wrefdict, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("A dict that can be weak referenced"), /*tp_doc*/
  __pyx_tp_traverse_6gevent_14_gevent_clocal__wrefdict, /*tp_traverse*/
  __pyx_tp_clear_6gevent_14_gevent_clocal__wrefdict, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6gevent_14_gevent_clocal__wrefdict, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_6gevent_14_gevent_clocal__greenlet_deleted(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_6gevent_14_gevent_clocal__greenlet_deleted *p;
  PyObject *o;
  o = __Pyx_AllocateExtensionType(t, 1);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6gevent_14_gevent_clocal__greenlet_deleted *)o);
  p->idt = Py_None; Py_INCREF(Py_None);
  p->wrdicts = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6gevent_14_gevent_clocal__greenlet_deleted(PyObject *o) {
  struct __pyx_obj_6gevent_14_gevent_clocal__greenlet_deleted *p = (struct __pyx_obj_6gevent_14_gevent_clocal__greenlet_deleted *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->idt);
  Py_CLEAR(p->wrdicts);
  PyTypeObject *tp = Py_TYPE(o);
  #if CYTHON_USE_TYPE_SLOTS
  (*tp->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  Py_DECREF(tp);
  #endif
}

static int __pyx_tp_traverse_6gevent_14_gevent_clocal__greenlet_deleted(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6gevent_14_gevent_clocal__greenlet_deleted *p = (struct __pyx_obj_6gevent_14_gevent_clocal__greenlet_deleted *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->idt) {
    e = (*v)(p->idt, a); if (e) return e;
  }
  if (p->wrdicts) {
    e = (*v)(p->wrdicts, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6gevent_14_gevent_clocal__greenlet_deleted(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6gevent_14_gevent_clocal__greenlet_deleted *p = (struct __pyx_obj_6gevent_14_gevent_clocal__greenlet_deleted *)o;
  tmp = ((PyObject*)p->idt);
  p->idt = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->wrdicts);
  p->wrdicts = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_6gevent_14_gevent_clocal__greenlet_deleted[] = {
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6gevent_14_gevent_clocal__greenlet_deleted_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6gevent_14_gevent_clocal__greenlet_deleted},
  {Py_tp_call, (void *)__pyx_pw_6gevent_14_gevent_clocal_17_greenlet_deleted_3__call__},
  {Py_tp_doc, (void *)PyDoc_STR("_greenlet_deleted(idt, wrdicts)\n\nA weakref callback for when the greenlet\nis deleted.\n\nIf the greenlet is a `gevent.greenlet.Greenlet` and\nsupplies ``rawlink``, that will be used instead of a\nweakref.")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6gevent_14_gevent_clocal__greenlet_deleted},
  {Py_tp_clear, (void *)__pyx_tp_clear_6gevent_14_gevent_clocal__greenlet_deleted},
  {Py_tp_methods, (void *)__pyx_methods_6gevent_14_gevent_clocal__greenlet_deleted},
  {Py_tp_init, (void *)__pyx_pw_6gevent_14_gevent_clocal_17_greenlet_deleted_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6gevent_14_gevent_clocal__greenlet_deleted},
  {0, 0},
};
static PyType_Spec __pyx_type_6gevent_14_gevent_clocal__greenlet_deleted_spec = {
  "gevent._gevent_clocal._greenlet_deleted",
  sizeof(struct __pyx_obj_6gevent_14_gevent_clocal__greenlet_deleted),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6gevent_14_gevent_clocal__greenlet_deleted_slots,
};
#else

static PyTypeObject __pyx_type_6gevent_14_gevent_clocal__greenlet_deleted = {
  PyVarObject_HEAD_INIT(0, 0)
  "gevent._gevent_clocal.""_greenlet_deleted", /*tp_name*/
  sizeof(struct __pyx_obj_6gevent_14_gevent_clocal__greenlet_deleted), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6gevent_14_gevent_clocal__greenlet_deleted, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  __pyx_pw_6gevent_14_gevent_clocal_17_greenlet_deleted_3__call__, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("_greenlet_deleted(idt, wrdicts)\n\nA weakref callback for when the greenlet\nis deleted.\n\nIf the greenlet is a `gevent.greenlet.Greenlet` and\nsupplies ``rawlink``, that will be used instead of a\nweakref."), /*tp_doc*/
  __pyx_tp_traverse_6gevent_14_gevent_clocal__greenlet_deleted, /*tp_traverse*/
  __pyx_tp_clear_6gevent_14_gevent_clocal__greenlet_deleted, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6gevent_14_gevent_clocal__greenlet_deleted, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6gevent_14_gevent_clocal_17_greenlet_deleted_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6gevent_14_gevent_clocal__greenlet_deleted, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_6gevent_14_gevent_clocal__local_deleted(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_6gevent_14_gevent_clocal__local_deleted *p;
  PyObject *o;
  o = __Pyx_AllocateExtensionType(t, 1);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6gevent_14_gevent_clocal__local_deleted *)o);
  p->key = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->wrthread = Py_None; Py_INCREF(Py_None);
  p->greenlet_deleted = ((struct __pyx_obj_6gevent_14_gevent_clocal__greenlet_deleted *)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6gevent_14_gevent_clocal__local_deleted(PyObject *o) {
  struct __pyx_obj_6gevent_14_gevent_clocal__local_deleted *p = (struct __pyx_obj_6gevent_14_gevent_clocal__local_deleted *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->key);
  Py_CLEAR(p->wrthread);
  Py_CLEAR(p->greenlet_deleted);
  PyTypeObject *tp = Py_TYPE(o);
  #if CYTHON_USE_TYPE_SLOTS
  (*tp->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  Py_DECREF(tp);
  #endif
}

static int __pyx_tp_traverse_6gevent_14_gevent_clocal__local_deleted(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6gevent_14_gevent_clocal__local_deleted *p = (struct __pyx_obj_6gevent_14_gevent_clocal__local_deleted *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->wrthread) {
    e = (*v)(p->wrthread, a); if (e) return e;
  }
  if (p->greenlet_deleted) {
    e = (*v)(((PyObject *)p->greenlet_deleted), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6gevent_14_gevent_clocal__local_deleted(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6gevent_14_gevent_clocal__local_deleted *p = (struct __pyx_obj_6gevent_14_gevent_clocal__local_deleted *)o;
  tmp = ((PyObject*)p->wrthread);
  p->wrthread = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->greenlet_deleted);
  p->greenlet_deleted = ((struct __pyx_obj_6gevent_14_gevent_clocal__greenlet_deleted *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_6gevent_14_gevent_clocal__local_deleted[] = {
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6gevent_14_gevent_clocal__local_deleted_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6gevent_14_gevent_clocal__local_deleted},
  {Py_tp_call, (void *)__pyx_pw_6gevent_14_gevent_clocal_14_local_deleted_3__call__},
  {Py_tp_doc, (void *)PyDoc_STR("_local_deleted(key, wrthread, greenlet_deleted)")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6gevent_14_gevent_clocal__local_deleted},
  {Py_tp_clear, (void *)__pyx_tp_clear_6gevent_14_gevent_clocal__local_deleted},
  {Py_tp_methods, (void *)__pyx_methods_6gevent_14_gevent_clocal__local_deleted},
  {Py_tp_init, (void *)__pyx_pw_6gevent_14_gevent_clocal_14_local_deleted_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6gevent_14_gevent_clocal__local_deleted},
  {0, 0},
};
static PyType_Spec __pyx_type_6gevent_14_gevent_clocal__local_deleted_spec = {
  "gevent._gevent_clocal._local_deleted",
  sizeof(struct __pyx_obj_6gevent_14_gevent_clocal__local_deleted),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6gevent_14_gevent_clocal__local_deleted_slots,
};
#else

static PyTypeObject __pyx_type_6gevent_14_gevent_clocal__local_deleted = {
  PyVarObject_HEAD_INIT(0, 0)
  "gevent._gevent_clocal.""_local_deleted", /*tp_name*/
  sizeof(struct __pyx_obj_6gevent_14_gevent_clocal__local_deleted), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6gevent_14_gevent_clocal__local_deleted, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  __pyx_pw_6gevent_14_gevent_clocal_14_local_deleted_3__call__, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("_local_deleted(key, wrthread, greenlet_deleted)"), /*tp_doc*/
  __pyx_tp_traverse_6gevent_14_gevent_clocal__local_deleted, /*tp_traverse*/
  __pyx_tp_clear_6gevent_14_gevent_clocal__local_deleted, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6gevent_14_gevent_clocal__local_deleted, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6gevent_14_gevent_clocal_14_local_deleted_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6gevent_14_gevent_clocal__local_deleted, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_6gevent_14_gevent_clocal__localimpl(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_6gevent_14_gevent_clocal__localimpl *p;
  PyObject *o;
  o = __Pyx_AllocateExtensionType(t, 1);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6gevent_14_gevent_clocal__localimpl *)o);
  p->key = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->dicts = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->localargs = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->localkwargs = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->localtypeid = ((PyObject*)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6gevent_14_gevent_clocal__localimpl(PyObject *o) {
  struct __pyx_obj_6gevent_14_gevent_clocal__localimpl *p = (struct __pyx_obj_6gevent_14_gevent_clocal__localimpl *)o;
  PyObject_GC_UnTrack(o);
  if (p->__weakref__) PyObject_ClearWeakRefs(o);
  Py_CLEAR(p->key);
  Py_CLEAR(p->dicts);
  Py_CLEAR(p->localargs);
  Py_CLEAR(p->localkwargs);
  Py_CLEAR(p->localtypeid);
  PyTypeObject *tp = Py_TYPE(o);
  #if CYTHON_USE_TYPE_SLOTS
  (*tp->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  Py_DECREF(tp);
  #endif
}

static int __pyx_tp_traverse_6gevent_14_gevent_clocal__localimpl(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6gevent_14_gevent_clocal__localimpl *p = (struct __pyx_obj_6gevent_14_gevent_clocal__localimpl *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->dicts) {
    e = (*v)(p->dicts, a); if (e) return e;
  }
  if (p->localargs) {
    e = (*v)(p->localargs, a); if (e) return e;
  }
  if (p->localkwargs) {
    e = (*v)(p->localkwargs, a); if (e) return e;
  }
  if (p->localtypeid) {
    e = (*v)(p->localtypeid, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6gevent_14_gevent_clocal__localimpl(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6gevent_14_gevent_clocal__localimpl *p = (struct __pyx_obj_6gevent_14_gevent_clocal__localimpl *)o;
  tmp = ((PyObject*)p->dicts);
  p->dicts = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->localargs);
  p->localargs = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->localkwargs);
  p->localkwargs = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->localtypeid);
  p->localtypeid = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_6gevent_14_gevent_clocal__localimpl[] = {
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyMemberDef __pyx_type_6gevent_14_gevent_clocal__localimpl_members[] = {
  #if !CYTHON_USE_TYPE_SLOTS
  {"__weaklistoffset__", T_PYSSIZET, offsetof(struct __pyx_obj_6gevent_14_gevent_clocal__localimpl, __weakref__), READONLY, 0},
  #endif
  {0, 0, 0, 0, 0}
};
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x03090000
#if defined(__GNUC__) || defined(__clang__)
#warning "src/gevent/_gevent_clocal.pxd:65:16: : __weakref__ is unsupported in the Limited API when running on Python <3.9."
#elif defined(_MSC_VER)
#pragma message("src/gevent/_gevent_clocal.pxd:65:16: : __weakref__ is unsupported in the Limited API when running on Python <3.9.")
#endif
#endif
static PyType_Slot __pyx_type_6gevent_14_gevent_clocal__localimpl_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6gevent_14_gevent_clocal__localimpl},
  {Py_tp_doc, (void *)PyDoc_STR("_localimpl(args, kwargs, local_type, id_local)\n\nA class managing thread-local dicts")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6gevent_14_gevent_clocal__localimpl},
  {Py_tp_clear, (void *)__pyx_tp_clear_6gevent_14_gevent_clocal__localimpl},
  {Py_tp_methods, (void *)__pyx_methods_6gevent_14_gevent_clocal__localimpl},
  {Py_tp_init, (void *)__pyx_pw_6gevent_14_gevent_clocal_10_localimpl_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6gevent_14_gevent_clocal__localimpl},
  {Py_tp_members, (void*)__pyx_type_6gevent_14_gevent_clocal__localimpl_members},
  {0, 0},
};
static PyType_Spec __pyx_type_6gevent_14_gevent_clocal__localimpl_spec = {
  "gevent._gevent_clocal._localimpl",
  sizeof(struct __pyx_obj_6gevent_14_gevent_clocal__localimpl),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6gevent_14_gevent_clocal__localimpl_slots,
};
#else

static PyTypeObject __pyx_type_6gevent_14_gevent_clocal__localimpl = {
  PyVarObject_HEAD_INIT(0, 0)
  "gevent._gevent_clocal.""_localimpl", /*tp_name*/
  sizeof(struct __pyx_obj_6gevent_14_gevent_clocal__localimpl), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6gevent_14_gevent_clocal__localimpl, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("_localimpl(args, kwargs, local_type, id_local)\n\nA class managing thread-local dicts"), /*tp_doc*/
  __pyx_tp_traverse_6gevent_14_gevent_clocal__localimpl, /*tp_traverse*/
  __pyx_tp_clear_6gevent_14_gevent_clocal__localimpl, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6gevent_14_gevent_clocal__localimpl, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6gevent_14_gevent_clocal_10_localimpl_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6gevent_14_gevent_clocal__localimpl, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_6gevent_14_gevent_clocal__localimpl_dict_entry(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_6gevent_14_gevent_clocal__localimpl_dict_entry *p;
  PyObject *o;
  o = __Pyx_AllocateExtensionType(t, 1);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6gevent_14_gevent_clocal__localimpl_dict_entry *)o);
  p->wrgreenlet = Py_None; Py_INCREF(Py_None);
  p->localdict = ((PyObject*)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6gevent_14_gevent_clocal__localimpl_dict_entry(PyObject *o) {
  struct __pyx_obj_6gevent_14_gevent_clocal__localimpl_dict_entry *p = (struct __pyx_obj_6gevent_14_gevent_clocal__localimpl_dict_entry *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->wrgreenlet);
  Py_CLEAR(p->localdict);
  PyTypeObject *tp = Py_TYPE(o);
  #if CYTHON_USE_TYPE_SLOTS
  (*tp->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  Py_DECREF(tp);
  #endif
}

static int __pyx_tp_traverse_6gevent_14_gevent_clocal__localimpl_dict_entry(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6gevent_14_gevent_clocal__localimpl_dict_entry *p = (struct __pyx_obj_6gevent_14_gevent_clocal__localimpl_dict_entry *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->wrgreenlet) {
    e = (*v)(p->wrgreenlet, a); if (e) return e;
  }
  if (p->localdict) {
    e = (*v)(p->localdict, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6gevent_14_gevent_clocal__localimpl_dict_entry(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6gevent_14_gevent_clocal__localimpl_dict_entry *p = (struct __pyx_obj_6gevent_14_gevent_clocal__localimpl_dict_entry *)o;
  tmp = ((PyObject*)p->wrgreenlet);
  p->wrgreenlet = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->localdict);
  p->localdict = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_6gevent_14_gevent_clocal__localimpl_dict_entry[] = {
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6gevent_14_gevent_clocal__localimpl_dict_entry_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6gevent_14_gevent_clocal__localimpl_dict_entry},
  {Py_tp_doc, (void *)PyDoc_STR("_localimpl_dict_entry(wrgreenlet, localdict)\n\nThe object that goes in the ``dicts`` of ``_localimpl``\nobject for each thread.")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6gevent_14_gevent_clocal__localimpl_dict_entry},
  {Py_tp_clear, (void *)__pyx_tp_clear_6gevent_14_gevent_clocal__localimpl_dict_entry},
  {Py_tp_methods, (void *)__pyx_methods_6gevent_14_gevent_clocal__localimpl_dict_entry},
  {Py_tp_init, (void *)__pyx_pw_6gevent_14_gevent_clocal_21_localimpl_dict_entry_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6gevent_14_gevent_clocal__localimpl_dict_entry},
  {0, 0},
};
static PyType_Spec __pyx_type_6gevent_14_gevent_clocal__localimpl_dict_entry_spec = {
  "gevent._gevent_clocal._localimpl_dict_entry",
  sizeof(struct __pyx_obj_6gevent_14_gevent_clocal__localimpl_dict_entry),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6gevent_14_gevent_clocal__localimpl_dict_entry_slots,
};
#else

static PyTypeObject __pyx_type_6gevent_14_gevent_clocal__localimpl_dict_entry = {
  PyVarObject_HEAD_INIT(0, 0)
  "gevent._gevent_clocal.""_localimpl_dict_entry", /*tp_name*/
  sizeof(struct __pyx_obj_6gevent_14_gevent_clocal__localimpl_dict_entry), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6gevent_14_gevent_clocal__localimpl_dict_entry, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("_localimpl_dict_entry(wrgreenlet, localdict)\n\nThe object that goes in the ``dicts`` of ``_localimpl``\nobject for each thread."), /*tp_doc*/
  __pyx_tp_traverse_6gevent_14_gevent_clocal__localimpl_dict_entry, /*tp_traverse*/
  __pyx_tp_clear_6gevent_14_gevent_clocal__localimpl_dict_entry, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6gevent_14_gevent_clocal__localimpl_dict_entry, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6gevent_14_gevent_clocal_21_localimpl_dict_entry_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6gevent_14_gevent_clocal__localimpl_dict_entry, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6gevent_14_gevent_clocal_local __pyx_vtable_6gevent_14_gevent_clocal_local;

static PyObject *__pyx_tp_new_6gevent_14_gevent_clocal_local(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6gevent_14_gevent_clocal_local *p;
  PyObject *o;
  o = __Pyx_AllocateExtensionType(t, 0);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6gevent_14_gevent_clocal_local *)o);
  p->__pyx_vtab = __pyx_vtabptr_6gevent_14_gevent_clocal_local;
  p->_local__impl = ((struct __pyx_obj_6gevent_14_gevent_clocal__localimpl *)Py_None); Py_INCREF(Py_None);
  p->_local_type_get_descriptors = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_local_type_set_or_del_descriptors = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_local_type_del_descriptors = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_local_type_set_descriptors = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_local_type_vars = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_local_type = ((PyTypeObject*)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6gevent_14_gevent_clocal_5local_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6gevent_14_gevent_clocal_local(PyObject *o) {
  struct __pyx_obj_6gevent_14_gevent_clocal_local *p = (struct __pyx_obj_6gevent_14_gevent_clocal_local *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6gevent_14_gevent_clocal_local) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->_local__impl);
  Py_CLEAR(p->_local_type_get_descriptors);
  Py_CLEAR(p->_local_type_set_or_del_descriptors);
  Py_CLEAR(p->_local_type_del_descriptors);
  Py_CLEAR(p->_local_type_set_descriptors);
  Py_CLEAR(p->_local_type_vars);
  Py_CLEAR(p->_local_type);
  PyTypeObject *tp = Py_TYPE(o);
  #if CYTHON_USE_TYPE_SLOTS
  (*tp->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  Py_DECREF(tp);
  #endif
}

static int __pyx_tp_traverse_6gevent_14_gevent_clocal_local(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6gevent_14_gevent_clocal_local *p = (struct __pyx_obj_6gevent_14_gevent_clocal_local *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->_local__impl) {
    e = (*v)(((PyObject *)p->_local__impl), a); if (e) return e;
  }
  if (p->_local_type_get_descriptors) {
    e = (*v)(p->_local_type_get_descriptors, a); if (e) return e;
  }
  if (p->_local_type_set_or_del_descriptors) {
    e = (*v)(p->_local_type_set_or_del_descriptors, a); if (e) return e;
  }
  if (p->_local_type_del_descriptors) {
    e = (*v)(p->_local_type_del_descriptors, a); if (e) return e;
  }
  if (p->_local_type_set_descriptors) {
    e = (*v)(p->_local_type_set_descriptors, a); if (e) return e;
  }
  if (p->_local_type_vars) {
    e = (*v)(p->_local_type_vars, a); if (e) return e;
  }
  if (p->_local_type) {
    e = (*v)(((PyObject *)p->_local_type), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6gevent_14_gevent_clocal_local(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6gevent_14_gevent_clocal_local *p = (struct __pyx_obj_6gevent_14_gevent_clocal_local *)o;
  tmp = ((PyObject*)p->_local__impl);
  p->_local__impl = ((struct __pyx_obj_6gevent_14_gevent_clocal__localimpl *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_local_type_get_descriptors);
  p->_local_type_get_descriptors = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_local_type_set_or_del_descriptors);
  p->_local_type_set_or_del_descriptors = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_local_type_del_descriptors);
  p->_local_type_del_descriptors = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_local_type_set_descriptors);
  p->_local_type_set_descriptors = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_local_type_vars);
  p->_local_type_vars = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_local_type);
  p->_local_type = ((PyTypeObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_tp_getattro_6gevent_14_gevent_clocal_local(PyObject *o, PyObject *n) {
  PyObject *v = __pyx_pw_6gevent_14_gevent_clocal_5local_3__getattribute__(o, n);
  return v;
}

static int __pyx_tp_setattro_6gevent_14_gevent_clocal_local(PyObject *o, PyObject *n, PyObject *v) {
  if (v) {
    return __pyx_pw_6gevent_14_gevent_clocal_5local_5__setattr__(o, n, v);
  }
  else {
    return __pyx_pw_6gevent_14_gevent_clocal_5local_7__delattr__(o, n);
  }
}

static PyMethodDef __pyx_methods_6gevent_14_gevent_clocal_local[] = {
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6gevent_14_gevent_clocal_local_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6gevent_14_gevent_clocal_local},
  {Py_tp_getattro, (void *)__pyx_tp_getattro_6gevent_14_gevent_clocal_local},
  {Py_tp_setattro, (void *)__pyx_tp_setattro_6gevent_14_gevent_clocal_local},
  {Py_tp_doc, (void *)PyDoc_STR("\n    An object whose attributes are greenlet-local.\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6gevent_14_gevent_clocal_local},
  {Py_tp_clear, (void *)__pyx_tp_clear_6gevent_14_gevent_clocal_local},
  {Py_tp_methods, (void *)__pyx_methods_6gevent_14_gevent_clocal_local},
  {Py_tp_new, (void *)__pyx_tp_new_6gevent_14_gevent_clocal_local},
  {0, 0},
};
static PyType_Spec __pyx_type_6gevent_14_gevent_clocal_local_spec = {
  "gevent._gevent_clocal.local",
  sizeof(struct __pyx_obj_6gevent_14_gevent_clocal_local),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6gevent_14_gevent_clocal_local_slots,
};
#else

static PyTypeObject __pyx_type_6gevent_14_gevent_clocal_local = {
  PyVarObject_HEAD_INIT(0, 0)
  "gevent._gevent_clocal.""local", /*tp_name*/
  sizeof(struct __pyx_obj_6gevent_14_gevent_clocal_local), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6gevent_14_gevent_clocal_local, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  __pyx_tp_getattro_6gevent_14_gevent_clocal_local, /*tp_getattro*/
  __pyx_tp_setattro_6gevent_14_gevent_clocal_local, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("\n    An object whose attributes are greenlet-local.\n    "), /*tp_doc*/
  __pyx_tp_traverse_6gevent_14_gevent_clocal_local, /*tp_traverse*/
  __pyx_tp_clear_6gevent_14_gevent_clocal_local, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6gevent_14_gevent_clocal_local, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6gevent_14_gevent_clocal_local, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};
/* #### Code section: initfunc_declarations ### */
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitConstants(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_CreateCodeObjects(__pyx_mstatetype *__pyx_mstate); /*proto*/
/* #### Code section: init_module ### */

static int __Pyx_modinit_global_init_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __pyx_v_6gevent_14_gevent_clocal_ref = Py_None; Py_INCREF(Py_None);
  __pyx_v_6gevent_14_gevent_clocal_copy = Py_None; Py_INCREF(Py_None);
  __pyx_v_6gevent_14_gevent_clocal__marker = Py_None; Py_INCREF(Py_None);
  __pyx_v_6gevent_14_gevent_clocal_key_prefix = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_6gevent_14_gevent_clocal__local_attrs = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  {
    __pyx_t_1 = __Pyx_ApiExport_GetApiDict(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_export_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_PyObject_int__local_attrs__marke);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_export_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_export_name = __pyx_export_signature + 20;
    void *const __pyx_export_pointers[] = {(void *)&__pyx_v_6gevent_14_gevent_clocal__local_attrs, (void *)&__pyx_v_6gevent_14_gevent_clocal__marker, (void *)&__pyx_v_6gevent_14_gevent_clocal_copy, (void *)&__pyx_v_6gevent_14_gevent_clocal_key_prefix, (void *)&__pyx_v_6gevent_14_gevent_clocal_ref, (void *)&__pyx_v_6gevent_14_gevent_clocal__PYPY, (void *)&__pyx_v_6gevent_14_gevent_clocal__greenlet_imported, (void *) NULL};
    void *const *__pyx_export_pointer = __pyx_export_pointers;
    const char *__pyx_export_current_signature = __pyx_export_signature;
    while (*__pyx_export_pointer) {
      if (__Pyx_ExportVoidPtr(__pyx_t_1, __pyx_export_name, *__pyx_export_pointer, __pyx_export_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_export_pointer;
      __pyx_export_name = strchr(__pyx_export_name, '\0') + 1;
      __pyx_export_signature = strchr(__pyx_export_signature, '\0') + 1;
      if (*__pyx_export_signature != '\0') __pyx_export_current_signature = __pyx_export_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_function_export_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  {
    __pyx_t_1 = __Pyx_ApiExport_GetApiDict(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_export_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_PyObject_PyGreenlet_int___pyx_sk);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_export_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_export_name = __pyx_export_signature + 348;
    void (*const __pyx_export_pointers[])(void) = {(void (*)(void))&__pyx_f_6gevent_14_gevent_clocal_all_local_dicts_for_greenlet, (void (*)(void))&__pyx_f_6gevent_14_gevent_clocal__localimpl_create_dict, (void (*)(void))&__pyx_f_6gevent_14_gevent_clocal__local_find_descriptors, (void (*)(void))&__pyx_f_6gevent_14_gevent_clocal__local_get_dict, (void (*)(void))&__pyx_f_6gevent_14_gevent_clocal__local__copy_dict_from, (void (*)(void))&__pyx_f_6gevent_14_gevent_clocal__init, (void (*)(void)) NULL};
    void (*const *__pyx_export_pointer)(void) = __pyx_export_pointers;
    const char *__pyx_export_current_signature = __pyx_export_signature;
    while (*__pyx_export_pointer) {
      if (__Pyx_ExportFunction(__pyx_t_1, __pyx_export_name, *__pyx_export_pointer, __pyx_export_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_export_pointer;
      __pyx_export_name = strchr(__pyx_export_name, '\0') + 1;
      __pyx_export_signature = strchr(__pyx_export_signature, '\0') + 1;
      if (*__pyx_export_signature != '\0') __pyx_export_current_signature = __pyx_export_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_init_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  __pyx_t_1 = PyImport_ImportModule("greenlet"); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal_greenlet = __Pyx_ImportType_3_2_4(__pyx_t_1, "greenlet", "greenlet",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyGreenlet),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(PyGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyGreenlet),
  #else
  sizeof(PyGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyGreenlet),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal_greenlet) __PYX_ERR(4, 17, __pyx_L1_error)
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_2 = PyTuple_Pack(1, (PyObject *)(&PyDict_Type)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__wrefdict = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6gevent_14_gevent_clocal__wrefdict_spec, __pyx_t_2);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__wrefdict)) __PYX_ERR(0, 212, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6gevent_14_gevent_clocal__wrefdict_spec, __pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__wrefdict) < (0)) __PYX_ERR(0, 212, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__wrefdict = &__pyx_type_6gevent_14_gevent_clocal__wrefdict;
  #endif
  if (sizeof(struct __pyx_obj_6gevent_14_gevent_clocal__wrefdict) != sizeof(PyDictObject)) {
    if (__Pyx_validate_extern_base((&PyDict_Type)) < (0)) __PYX_ERR(0, 212, __pyx_L1_error)
  }
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_clocal__wrefdict->tp_base = (&PyDict_Type);
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__wrefdict) < (0)) __PYX_ERR(0, 212, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__wrefdict);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__wrefdict->tp_dictoffset && __pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__wrefdict->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__wrefdict->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_wrefdict, (PyObject *) __pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__wrefdict) < (0)) __PYX_ERR(0, 212, __pyx_L1_error)
  #if CYTHON_USE_TYPE_SLOTS
  if (__pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__wrefdict->tp_weaklistoffset == 0) __pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__wrefdict->tp_weaklistoffset = offsetof(struct __pyx_obj_6gevent_14_gevent_clocal__wrefdict, __weakref__);
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__greenlet_deleted = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6gevent_14_gevent_clocal__greenlet_deleted_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__greenlet_deleted)) __PYX_ERR(0, 215, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6gevent_14_gevent_clocal__greenlet_deleted_spec, __pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__greenlet_deleted) < (0)) __PYX_ERR(0, 215, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__greenlet_deleted = &__pyx_type_6gevent_14_gevent_clocal__greenlet_deleted;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__greenlet_deleted) < (0)) __PYX_ERR(0, 215, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__greenlet_deleted);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__greenlet_deleted->tp_dictoffset && __pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__greenlet_deleted->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__greenlet_deleted->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_greenlet_deleted_2, (PyObject *) __pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__greenlet_deleted) < (0)) __PYX_ERR(0, 215, __pyx_L1_error)
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__local_deleted = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6gevent_14_gevent_clocal__local_deleted_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__local_deleted)) __PYX_ERR(0, 235, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6gevent_14_gevent_clocal__local_deleted_spec, __pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__local_deleted) < (0)) __PYX_ERR(0, 235, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__local_deleted = &__pyx_type_6gevent_14_gevent_clocal__local_deleted;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__local_deleted) < (0)) __PYX_ERR(0, 235, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__local_deleted);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__local_deleted->tp_dictoffset && __pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__local_deleted->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__local_deleted->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_local_deleted, (PyObject *) __pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__local_deleted) < (0)) __PYX_ERR(0, 235, __pyx_L1_error)
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__localimpl = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6gevent_14_gevent_clocal__localimpl_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__localimpl)) __PYX_ERR(0, 254, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6gevent_14_gevent_clocal__localimpl_spec, __pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__localimpl) < (0)) __PYX_ERR(0, 254, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__localimpl = &__pyx_type_6gevent_14_gevent_clocal__localimpl;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__localimpl) < (0)) __PYX_ERR(0, 254, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__localimpl);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__localimpl->tp_dictoffset && __pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__localimpl->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__localimpl->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_localimpl, (PyObject *) __pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__localimpl) < (0)) __PYX_ERR(0, 254, __pyx_L1_error)
  #if CYTHON_USE_TYPE_SLOTS
  if (__pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__localimpl->tp_weaklistoffset == 0) __pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__localimpl->tp_weaklistoffset = offsetof(struct __pyx_obj_6gevent_14_gevent_clocal__localimpl, __weakref__);
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__localimpl_dict_entry = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6gevent_14_gevent_clocal__localimpl_dict_entry_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__localimpl_dict_entry)) __PYX_ERR(0, 275, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6gevent_14_gevent_clocal__localimpl_dict_entry_spec, __pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__localimpl_dict_entry) < (0)) __PYX_ERR(0, 275, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__localimpl_dict_entry = &__pyx_type_6gevent_14_gevent_clocal__localimpl_dict_entry;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__localimpl_dict_entry) < (0)) __PYX_ERR(0, 275, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__localimpl_dict_entry);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__localimpl_dict_entry->tp_dictoffset && __pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__localimpl_dict_entry->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__localimpl_dict_entry->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_localimpl_dict_entry, (PyObject *) __pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal__localimpl_dict_entry) < (0)) __PYX_ERR(0, 275, __pyx_L1_error)
  __pyx_vtabptr_6gevent_14_gevent_clocal_local = &__pyx_vtable_6gevent_14_gevent_clocal_local;
  __pyx_vtable_6gevent_14_gevent_clocal_local.__pyx___copy__ = (struct __pyx_obj_6gevent_14_gevent_clocal_local *(*)(struct __pyx_obj_6gevent_14_gevent_clocal_local *, int __pyx_skip_dispatch))__pyx_f_6gevent_14_gevent_clocal_5local___copy__;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal_local = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6gevent_14_gevent_clocal_local_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal_local)) __PYX_ERR(0, 363, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6gevent_14_gevent_clocal_local_spec, __pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal_local) < (0)) __PYX_ERR(0, 363, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal_local = &__pyx_type_6gevent_14_gevent_clocal_local;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal_local) < (0)) __PYX_ERR(0, 363, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal_local);
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal_local, __pyx_vtabptr_6gevent_14_gevent_clocal_local) < (0)) __PYX_ERR(0, 363, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal_local) < (0)) __PYX_ERR(0, 363, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_local, (PyObject *) __pyx_mstate->__pyx_ptype_6gevent_14_gevent_clocal_local) < (0)) __PYX_ERR(0, 363, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __pyx_t_1 = PyImport_ImportModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_7cpython_4type_type = __Pyx_ImportType_3_2_4(__pyx_t_1, __Pyx_BUILTIN_MODULE_NAME, "type",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyTypeObject), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyTypeObject),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  0, 0,
  #else
  sizeof(PyHeapTypeObject), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyHeapTypeObject),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_7cpython_4type_type) __PYX_ERR(5, 9, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("weakref"); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_6gevent_15_gevent_c_ident_ref = __Pyx_ImportType_3_2_4(__pyx_t_1, "weakref", "ref",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyWeakReference), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyWeakReference),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(PyWeakReference), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyWeakReference),
  #else
  sizeof(PyWeakReference), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyWeakReference),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_15_gevent_c_ident_ref) __PYX_ERR(6, 5, __pyx_L1_error)
  __pyx_t_2 = PyImport_ImportModule("gevent._gevent_c_ident"); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 13, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_mstate->__pyx_ptype_6gevent_15_gevent_c_ident_ValuedWeakRef = __Pyx_ImportType_3_2_4(__pyx_t_2, "gevent._gevent_c_ident", "ValuedWeakRef",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_15_gevent_c_ident_ValuedWeakRef), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_15_gevent_c_ident_ValuedWeakRef),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_15_gevent_c_ident_ValuedWeakRef), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_15_gevent_c_ident_ValuedWeakRef),
  #else
  sizeof(struct __pyx_obj_6gevent_15_gevent_c_ident_ValuedWeakRef), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_15_gevent_c_ident_ValuedWeakRef),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_15_gevent_c_ident_ValuedWeakRef) __PYX_ERR(6, 13, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6gevent_15_gevent_c_ident_IdentRegistry = __Pyx_ImportType_3_2_4(__pyx_t_2, "gevent._gevent_c_ident", "IdentRegistry",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_15_gevent_c_ident_IdentRegistry), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_15_gevent_c_ident_IdentRegistry),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_15_gevent_c_ident_IdentRegistry), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_15_gevent_c_ident_IdentRegistry),
  #else
  sizeof(struct __pyx_obj_6gevent_15_gevent_c_ident_IdentRegistry), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_15_gevent_c_ident_IdentRegistry),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_15_gevent_c_ident_IdentRegistry) __PYX_ERR(6, 18, __pyx_L1_error)
  __pyx_vtabptr_6gevent_15_gevent_c_ident_IdentRegistry = (struct __pyx_vtabstruct_6gevent_15_gevent_c_ident_IdentRegistry*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6gevent_15_gevent_c_ident_IdentRegistry); if (unlikely(!__pyx_vtabptr_6gevent_15_gevent_c_ident_IdentRegistry)) __PYX_ERR(6, 18, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyImport_ImportModule("greenlet"); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_mstate->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_greenlet = __Pyx_ImportType_3_2_4(__pyx_t_2, "greenlet", "greenlet",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyGreenlet),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(PyGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyGreenlet),
  #else
  sizeof(PyGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyGreenlet),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_greenlet) __PYX_ERR(1, 12, __pyx_L1_error)
  __pyx_t_1 = PyImport_ImportModule("gevent._gevent_c_greenlet_primitives"); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet = __Pyx_ImportType_3_2_4(__pyx_t_1, "gevent._gevent_c_greenlet_primitives", "TrackedRawGreenlet",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet),
  #else
  sizeof(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet) __PYX_ERR(1, 37, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop = __Pyx_ImportType_3_2_4(__pyx_t_1, "gevent._gevent_c_greenlet_primitives", "SwitchOutGreenletWithLoop",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop),
  #else
  sizeof(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop) __PYX_ERR(1, 40, __pyx_L1_error)
  __pyx_vtabptr_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop = (struct __pyx_vtabstruct_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop); if (unlikely(!__pyx_vtabptr_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop)) __PYX_ERR(1, 40, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("greenlet"); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_6gevent_16_gevent_c_waiter_greenlet = __Pyx_ImportType_3_2_4(__pyx_t_1, "greenlet", "greenlet",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyGreenlet),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(PyGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyGreenlet),
  #else
  sizeof(PyGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyGreenlet),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_16_gevent_c_waiter_greenlet) __PYX_ERR(2, 15, __pyx_L1_error)
  __pyx_t_2 = PyImport_ImportModule("gevent._gevent_c_waiter"); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 33, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_mstate->__pyx_ptype_6gevent_16_gevent_c_waiter_Waiter = __Pyx_ImportType_3_2_4(__pyx_t_2, "gevent._gevent_c_waiter", "Waiter",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_16_gevent_c_waiter_Waiter), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_16_gevent_c_waiter_Waiter),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_16_gevent_c_waiter_Waiter), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_16_gevent_c_waiter_Waiter),
  #else
  sizeof(struct __pyx_obj_6gevent_16_gevent_c_waiter_Waiter), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_16_gevent_c_waiter_Waiter),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_16_gevent_c_waiter_Waiter) __PYX_ERR(2, 33, __pyx_L1_error)
  __pyx_vtabptr_6gevent_16_gevent_c_waiter_Waiter = (struct __pyx_vtabstruct_6gevent_16_gevent_c_waiter_Waiter*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6gevent_16_gevent_c_waiter_Waiter); if (unlikely(!__pyx_vtabptr_6gevent_16_gevent_c_waiter_Waiter)) __PYX_ERR(2, 33, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6gevent_16_gevent_c_waiter_MultipleWaiter = __Pyx_ImportType_3_2_4(__pyx_t_2, "gevent._gevent_c_waiter", "MultipleWaiter",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_16_gevent_c_waiter_MultipleWaiter), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_16_gevent_c_waiter_MultipleWaiter),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_16_gevent_c_waiter_MultipleWaiter), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_16_gevent_c_waiter_MultipleWaiter),
  #else
  sizeof(struct __pyx_obj_6gevent_16_gevent_c_waiter_MultipleWaiter), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_16_gevent_c_waiter_MultipleWaiter),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_16_gevent_c_waiter_MultipleWaiter) __PYX_ERR(2, 45, __pyx_L1_error)
  __pyx_vtabptr_6gevent_16_gevent_c_waiter_MultipleWaiter = (struct __pyx_vtabstruct_6gevent_16_gevent_c_waiter_MultipleWaiter*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6gevent_16_gevent_c_waiter_MultipleWaiter); if (unlikely(!__pyx_vtabptr_6gevent_16_gevent_c_waiter_MultipleWaiter)) __PYX_ERR(2, 45, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyImport_ImportModule("greenlet"); if (unlikely(!__pyx_t_2)) __PYX_ERR(3, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_greenlet = __Pyx_ImportType_3_2_4(__pyx_t_2, "greenlet", "greenlet",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyGreenlet),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(PyGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyGreenlet),
  #else
  sizeof(PyGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyGreenlet),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_greenlet) __PYX_ERR(3, 20, __pyx_L1_error)
  __pyx_t_1 = PyImport_ImportModule("gevent._gevent_cgreenlet"); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 100, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_SpawnedLink = __Pyx_ImportType_3_2_4(__pyx_t_1, "gevent._gevent_cgreenlet", "SpawnedLink",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink),
  #else
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_SpawnedLink) __PYX_ERR(3, 100, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink = __Pyx_ImportType_3_2_4(__pyx_t_1, "gevent._gevent_cgreenlet", "SuccessSpawnedLink",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink),
  #else
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink) __PYX_ERR(3, 104, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_FailureSpawnedLink = __Pyx_ImportType_3_2_4(__pyx_t_1, "gevent._gevent_cgreenlet", "FailureSpawnedLink",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet_FailureSpawnedLink), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_17_gevent_cgreenlet_FailureSpawnedLink),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet_FailureSpawnedLink), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_17_gevent_cgreenlet_FailureSpawnedLink),
  #else
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet_FailureSpawnedLink), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_17_gevent_cgreenlet_FailureSpawnedLink),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_FailureSpawnedLink) __PYX_ERR(3, 108, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet__Frame = __Pyx_ImportType_3_2_4(__pyx_t_1, "gevent._gevent_cgreenlet", "_Frame",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame),
  #else
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet__Frame) __PYX_ERR(3, 112, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet = __Pyx_ImportType_3_2_4(__pyx_t_1, "gevent._gevent_cgreenlet", "Greenlet",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet),
  #else
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet) __PYX_ERR(3, 128, __pyx_L1_error)
  __pyx_vtabptr_6gevent_17_gevent_cgreenlet_Greenlet = (struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet); if (unlikely(!__pyx_vtabptr_6gevent_17_gevent_cgreenlet_Greenlet)) __PYX_ERR(3, 128, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet__dummy_event = __Pyx_ImportType_3_2_4(__pyx_t_1, "gevent._gevent_cgreenlet", "_dummy_event",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event),
  #else
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet__dummy_event) __PYX_ERR(3, 199, __pyx_L1_error)
  __pyx_vtabptr_6gevent_17_gevent_cgreenlet__dummy_event = (struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet__dummy_event*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet__dummy_event); if (unlikely(!__pyx_vtabptr_6gevent_17_gevent_cgreenlet__dummy_event)) __PYX_ERR(3, 199, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_variable_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  {
    __pyx_t_1 = PyImport_ImportModule("gevent._gevent_c_ident"); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_import_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_PyObject_WeakKeyDictionary_heapp);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_import_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_import_name = __pyx_import_signature + 13;
    void **const __pyx_import_pointers[] = {(void **)&__pyx_vp_6gevent_15_gevent_c_ident_WeakKeyDictionary, (void **)&__pyx_vp_6gevent_15_gevent_c_ident_heappop, (void **)&__pyx_vp_6gevent_15_gevent_c_ident_heappush, (void **) NULL};
    void **const *__pyx_import_pointer = __pyx_import_pointers;
    const char *__pyx_import_current_signature = __pyx_import_signature;
    while (*__pyx_import_pointer) {
      if (__Pyx_ImportVoidPtr_3_2_4(__pyx_t_1, __pyx_import_name, *__pyx_import_pointer, __pyx_import_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_import_pointer;
      __pyx_import_name = strchr(__pyx_import_name, '\0') + 1;
      __pyx_import_signature = strchr(__pyx_import_signature, '\0') + 1;
      if (*__pyx_import_signature != '\0') __pyx_import_current_signature = __pyx_import_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  {
    __pyx_t_1 = PyImport_ImportModule("gevent._gevent_c_greenlet_primitives"); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_import_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_PyObject_PyTypeObject_int_Blocki);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_import_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_import_name = __pyx_import_signature + 33;
    void **const __pyx_import_pointers[] = {(void **)&__pyx_vp_6gevent_29_gevent_c_greenlet_primitives_BlockingSwitchOutError, (void **)&__pyx_vp_6gevent_29_gevent_c_greenlet_primitives_get_objects, (void **)&__pyx_vp_6gevent_29_gevent_c_greenlet_primitives_wref, (void **)&__pyx_vp_6gevent_29_gevent_c_greenlet_primitives__buffer, (void **)&__pyx_vp_6gevent_29_gevent_c_greenlet_primitives__memoryview, (void **)&__pyx_vp_6gevent_29_gevent_c_greenlet_primitives__greenlet_imported, (void **) NULL};
    void **const *__pyx_import_pointer = __pyx_import_pointers;
    const char *__pyx_import_current_signature = __pyx_import_signature;
    while (*__pyx_import_pointer) {
      if (__Pyx_ImportVoidPtr_3_2_4(__pyx_t_1, __pyx_import_name, *__pyx_import_pointer, __pyx_import_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_import_pointer;
      __pyx_import_name = strchr(__pyx_import_name, '\0') + 1;
      __pyx_import_signature = strchr(__pyx_import_signature, '\0') + 1;
      if (*__pyx_import_signature != '\0') __pyx_import_current_signature = __pyx_import_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  {
    __pyx_t_1 = PyImport_ImportModule("gevent._gevent_c_hub_local"); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_import_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_PyObject__threadlocal);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_import_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_import_name = __pyx_import_signature + 11;
    void **const __pyx_import_pointers[] = {(void **)&__pyx_vp_6gevent_19_gevent_c_hub_local__threadlocal, (void **) NULL};
    void **const *__pyx_import_pointer = __pyx_import_pointers;
    const char *__pyx_import_current_signature = __pyx_import_signature;
    while (*__pyx_import_pointer) {
      if (__Pyx_ImportVoidPtr_3_2_4(__pyx_t_1, __pyx_import_name, *__pyx_import_pointer, __pyx_import_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_import_pointer;
      __pyx_import_name = strchr(__pyx_import_name, '\0') + 1;
      __pyx_import_signature = strchr(__pyx_import_signature, '\0') + 1;
      if (*__pyx_import_signature != '\0') __pyx_import_current_signature = __pyx_import_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  {
    __pyx_t_1 = PyImport_ImportModule("gevent._gevent_c_waiter"); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_import_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_PyObject_int_ConcurrentObjectUse);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_import_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_import_name = __pyx_import_signature + 17;
    void **const __pyx_import_pointers[] = {(void **)&__pyx_vp_6gevent_16_gevent_c_waiter_ConcurrentObjectUseError, (void **)&__pyx_vp_6gevent_16_gevent_c_waiter__NONE, (void **)&__pyx_vp_6gevent_16_gevent_c_waiter_sys, (void **)&__pyx_vp_6gevent_16_gevent_c_waiter__greenlet_imported, (void **) NULL};
    void **const *__pyx_import_pointer = __pyx_import_pointers;
    const char *__pyx_import_current_signature = __pyx_import_signature;
    while (*__pyx_import_pointer) {
      if (__Pyx_ImportVoidPtr_3_2_4(__pyx_t_1, __pyx_import_name, *__pyx_import_pointer, __pyx_import_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_import_pointer;
      __pyx_import_name = strchr(__pyx_import_name, '\0') + 1;
      __pyx_import_signature = strchr(__pyx_import_signature, '\0') + 1;
      if (*__pyx_import_signature != '\0') __pyx_import_current_signature = __pyx_import_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  {
    __pyx_t_1 = PyImport_ImportModule("gevent._gevent_cgreenlet"); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_import_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_PyObject_int_struct___pyx_obj_6g);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_import_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_import_name = __pyx_import_signature + 92;
    void **const __pyx_import_pointers[] = {(void **)&__pyx_vp_6gevent_17_gevent_cgreenlet_GEVENT_CONFIG, (void **)&__pyx_vp_6gevent_17_gevent_cgreenlet_GreenletExit, (void **)&__pyx_vp_6gevent_17_gevent_cgreenlet_InvalidSwitchError, (void **)&__pyx_vp_6gevent_17_gevent_cgreenlet_Timeout, (void **)&__pyx_vp_6gevent_17_gevent_cgreenlet__greenlet__init__, (void **)&__pyx_vp_6gevent_17_gevent_cgreenlet__spawn_callbacks, (void **)&__pyx_vp_6gevent_17_gevent_cgreenlet__threadlocal, (void **)&__pyx_vp_6gevent_17_gevent_cgreenlet_dump_traceback, (void **)&__pyx_vp_6gevent_17_gevent_cgreenlet_get_hub_class, (void **)&__pyx_vp_6gevent_17_gevent_cgreenlet_iwait, (void **)&__pyx_vp_6gevent_17_gevent_cgreenlet_load_traceback, (void **)&__pyx_vp_6gevent_17_gevent_cgreenlet_reraise, (void **)&__pyx_vp_6gevent_17_gevent_cgreenlet_sys_exc_info, (void **)&__pyx_vp_6gevent_17_gevent_cgreenlet_sys_getframe, (void **)&__pyx_vp_6gevent_17_gevent_cgreenlet_wait, (void **)&__pyx_vp_6gevent_17_gevent_cgreenlet_wref, (void **)&__pyx_vp_6gevent_17_gevent_cgreenlet__PYPY, (void **)&__pyx_vp_6gevent_17_gevent_cgreenlet__greenlet_imported, (void **)&__pyx_vp_6gevent_17_gevent_cgreenlet__cancelled_start_event, (void **)&__pyx_vp_6gevent_17_gevent_cgreenlet__start_completed_event, (void **) NULL};
    void **const *__pyx_import_pointer = __pyx_import_pointers;
    const char *__pyx_import_current_signature = __pyx_import_signature;
    while (*__pyx_import_pointer) {
      if (__Pyx_ImportVoidPtr_3_2_4(__pyx_t_1, __pyx_import_name, *__pyx_import_pointer, __pyx_import_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_import_pointer;
      __pyx_import_name = strchr(__pyx_import_name, '\0') + 1;
      __pyx_import_signature = strchr(__pyx_import_signature, '\0') + 1;
      if (*__pyx_import_signature != '\0') __pyx_import_current_signature = __pyx_import_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_function_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  {
    __pyx_t_1 = PyImport_ImportModule("gevent._gevent_c_hub_local"); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_import_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_struct___pyx_obj_6gevent_29_geve);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_import_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_import_name = __pyx_import_signature + 110;
    void (**const __pyx_import_pointers[])(void) = {(void (**)(void))&__pyx_f_6gevent_19_gevent_c_hub_local_get_hub_noargs, (void (**)(void)) NULL};
    void (**const *__pyx_import_pointer)(void) = __pyx_import_pointers;
    const char *__pyx_import_current_signature = __pyx_import_signature;
    while (*__pyx_import_pointer) {
      if (__Pyx_ImportFunction_3_2_4(__pyx_t_1, __pyx_import_name, *__pyx_import_pointer, __pyx_import_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_import_pointer;
      __pyx_import_name = strchr(__pyx_import_name, '\0') + 1;
      __pyx_import_signature = strchr(__pyx_import_signature, '\0') + 1;
      if (*__pyx_import_signature != '\0') __pyx_import_current_signature = __pyx_import_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec__gevent_clocal(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec__gevent_clocal},
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
  {Py_mod_gil, __Pyx_FREETHREADING_COMPATIBLE},
  #endif
  #if PY_VERSION_HEX >= 0x030C0000 && CYTHON_USE_MODULE_STATE
  {Py_mod_multiple_interpreters, Py_MOD_MULTIPLE_INTERPRETERS_NOT_SUPPORTED},
  #endif
  {0, NULL}
};
#endif

#ifdef __cplusplus
namespace {
  struct PyModuleDef __pyx_moduledef =
  #else
  static struct PyModuleDef __pyx_moduledef =
  #endif
  {
      PyModuleDef_HEAD_INIT,
      "_gevent_clocal",
      __pyx_k_Greenlet_local_objects_This_mod, /* m_doc */
    #if CYTHON_USE_MODULE_STATE
      sizeof(__pyx_mstatetype), /* m_size */
    #else
      (CYTHON_PEP489_MULTI_PHASE_INIT) ? 0 : -1, /* m_size */
    #endif
      __pyx_methods /* m_methods */,
    #if CYTHON_PEP489_MULTI_PHASE_INIT
      __pyx_moduledef_slots, /* m_slots */
    #else
      NULL, /* m_reload */
    #endif
    #if CYTHON_USE_MODULE_STATE
      __pyx_m_traverse, /* m_traverse */
      __pyx_m_clear, /* m_clear */
      NULL /* m_free */
    #else
      NULL, /* m_traverse */
      NULL, /* m_clear */
      NULL /* m_free */
    #endif
  };
  #ifdef __cplusplus
} /* anonymous namespace */
#endif

/* PyModInitFuncType */
#ifndef CYTHON_NO_PYINIT_EXPORT
  #define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#else
  #ifdef __cplusplus
  #define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
  #else
  #define __Pyx_PyMODINIT_FUNC PyObject *
  #endif
#endif

__Pyx_PyMODINIT_FUNC PyInit__gevent_clocal(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit__gevent_clocal(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
/* ModuleCreationPEP489 */
#include "src/gevent/_generated_include/ModuleCreationPEP489_impl_e8e48a7033664eca332c0112edbc6a62057c1d998b2c8eee547bdd9088e6ab4c.h"

static CYTHON_SMALL_CODE int __pyx_pymod_exec__gevent_clocal(PyObject *__pyx_pyinit_module)
#endif
{
  int stringtab_initialized = 0;
  #if CYTHON_USE_MODULE_STATE
  int pystate_addmodule_run = 0;
  #endif
  __pyx_mstatetype *__pyx_mstate = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10[5];
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module '_gevent_clocal' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #else
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_t_1 = __pyx_pyinit_module;
  Py_INCREF(__pyx_t_1);
  #else
  __pyx_t_1 = PyModule_Create(&__pyx_moduledef); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #if CYTHON_USE_MODULE_STATE
  {
    int add_module_result = __Pyx_State_AddModule(__pyx_t_1, &__pyx_moduledef);
    __pyx_t_1 = 0; /* transfer ownership from __pyx_t_1 to "_gevent_clocal" pseudovariable */
    if (unlikely((add_module_result < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    pystate_addmodule_run = 1;
  }
  #else
  __pyx_m = __pyx_t_1;
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
  PyUnstable_Module_SetGIL(__pyx_m, Py_MOD_GIL_USED);
  #endif
  __pyx_mstate = __pyx_mstate_global;
  CYTHON_UNUSED_VAR(__pyx_t_1);
  __pyx_mstate->__pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_mstate->__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_mstate->__pyx_d);
  __pyx_mstate->__pyx_b = __Pyx_PyImport_AddModuleRef(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_mstate->__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_cython_runtime = __Pyx_PyImport_AddModuleRef("cython_runtime"); if (unlikely(!__pyx_mstate->__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_mstate->__pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /* ImportRefnannyAPI */
  #if CYTHON_REFNANNY
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
  if (!__Pyx_RefNanny) {
    PyErr_Clear();
    __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
    if (!__Pyx_RefNanny)
        Py_FatalError("failed to import 'refnanny' module");
  }
  #endif
  
__Pyx_RefNannySetupContext("PyInit__gevent_clocal", 0);
  __Pyx_init_runtime_version();
  if (__Pyx_check_binary_version(__PYX_LIMITED_VERSION_HEX, __Pyx_get_runtime_version(), CYTHON_COMPILING_IN_LIMITED_API) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_mstate->__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_mstate->__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_mstate->__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Library function declarations ---*/
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitConstants(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  stringtab_initialized = 1;
  if (__Pyx_InitGlobals() < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__pyx_module_is_main_gevent___gevent_clocal) {
    if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_name, __pyx_mstate_global->__pyx_n_u_main) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "gevent._gevent_clocal")) {
      if (unlikely((PyDict_SetItemString(modules, "gevent._gevent_clocal", __pyx_m) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_CreateCodeObjects(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code(__pyx_mstate);
  if (unlikely((__Pyx_modinit_variable_export_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely((__Pyx_modinit_function_export_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely((__Pyx_modinit_type_init_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely((__Pyx_modinit_type_import_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely((__Pyx_modinit_variable_import_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely((__Pyx_modinit_function_import_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Execution code ---*/

  /* "src/gevent/local.py":158
 * from __future__ import print_function
 * 
 * from copy import copy             # <<<<<<<<<<<<<<
 * from weakref import ref
 * 
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_copy_2};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_copy_2, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 158, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_copy_2};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 158, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6gevent_14_gevent_clocal_copy);
        __Pyx_DECREF_SET(__pyx_v_6gevent_14_gevent_clocal_copy, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/local.py":159
 * 
 * from copy import copy
 * from weakref import ref             # <<<<<<<<<<<<<<
 * 
 * 
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_ref};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_weakref, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 159, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_ref};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 159, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6gevent_14_gevent_clocal_ref);
        __Pyx_DECREF_SET(__pyx_v_6gevent_14_gevent_clocal_ref, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/local.py":162
 * 
 * 
 * locals()['getcurrent'] = __import__('greenlet').getcurrent             # <<<<<<<<<<<<<<
 * locals()['greenlet_init'] = lambda: None
 * 
*/
  __pyx_t_4 = NULL;
  __pyx_t_5 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_mstate_global->__pyx_n_u_greenlet};
    __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin___import__, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 162, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_getcurrent); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_Globals(); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (unlikely((PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_getcurrent, __pyx_t_4) < 0))) __PYX_ERR(0, 162, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/local.py":163
 * 
 * locals()['getcurrent'] = __import__('greenlet').getcurrent
 * locals()['greenlet_init'] = lambda: None             # <<<<<<<<<<<<<<
 * 
 * __all__ = [
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_14_gevent_clocal_4lambda, 0, __pyx_mstate_global->__pyx_n_u_lambda, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_clocal, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[0])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  __pyx_t_2 = __Pyx_Globals(); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (unlikely((PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_greenlet_init, __pyx_t_4) < 0))) __PYX_ERR(0, 163, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/local.py":165
 * locals()['greenlet_init'] = lambda: None
 * 
 * __all__ = [             # <<<<<<<<<<<<<<
 *     "local",
 * ]
*/
  __pyx_t_4 = __Pyx_PyList_Pack(1, __pyx_mstate_global->__pyx_n_u_local); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_all, __pyx_t_4) < (0)) __PYX_ERR(0, 165, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/local.py":172
 * # We keep it a string for speed but make it unlikely to clash with
 * # a "real" attribute.
 * key_prefix = '_gevent_local_localimpl_'             # <<<<<<<<<<<<<<
 * 
 * # The overall structure is as follows:
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_gevent_local_localimpl);
  __Pyx_XGOTREF(__pyx_v_6gevent_14_gevent_clocal_key_prefix);
  __Pyx_DECREF_SET(__pyx_v_6gevent_14_gevent_clocal_key_prefix, __pyx_mstate_global->__pyx_n_u_gevent_local_localimpl);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_n_u_gevent_local_localimpl);

  /* "src/gevent/local.py":181
 * # That final tuple is actually a localimpl_dict_entry object.
 * 
 * def all_local_dicts_for_greenlet(greenlet):             # <<<<<<<<<<<<<<
 *     """
 *     Internal debug helper for getting the local values associated
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_14_gevent_clocal_1all_local_dicts_for_greenlet, 0, __pyx_mstate_global->__pyx_n_u_all_local_dicts_for_greenlet, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_clocal, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[1])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_all_local_dicts_for_greenlet, __pyx_t_4) < (0)) __PYX_ERR(0, 181, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/local.py":224
 *     weakref.
 *     """
 *     __slots__ = ('idt', 'wrdicts')             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, idt, wrdicts):
*/
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_clocal__greenlet_deleted, __pyx_mstate_global->__pyx_n_u_slots, __pyx_mstate_global->__pyx_tuple[0]) < (0)) __PYX_ERR(0, 224, __pyx_L1_error)

  /* "src/gevent/local.py":236
 * 
 * class _local_deleted(object):
 *     __slots__ = ('key', 'wrthread', 'greenlet_deleted')             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, key, wrthread, greenlet_deleted):
*/
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_clocal__local_deleted, __pyx_mstate_global->__pyx_n_u_slots, __pyx_mstate_global->__pyx_tuple[1]) < (0)) __PYX_ERR(0, 236, __pyx_L1_error)

  /* "src/gevent/local.py":256
 * class _localimpl(object):
 *     """A class managing thread-local dicts"""
 *     __slots__ = ('key', 'dicts',             # <<<<<<<<<<<<<<
 *                  'localargs', 'localkwargs',
 *                  'localtypeid',
*/
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_clocal__localimpl, __pyx_mstate_global->__pyx_n_u_slots, __pyx_mstate_global->__pyx_tuple[2]) < (0)) __PYX_ERR(0, 256, __pyx_L1_error)

  /* "src/gevent/local.py":282
 *     # This is a class, not just a tuple, so that cython can optimize
 *     # attribute access
 *     __slots__ = ('wrgreenlet', 'localdict')             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, wrgreenlet, localdict):
*/
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_clocal__localimpl_dict_entry, __pyx_mstate_global->__pyx_n_u_slots, __pyx_mstate_global->__pyx_tuple[3]) < (0)) __PYX_ERR(0, 282, __pyx_L1_error)

  /* "src/gevent/local.py":333
 * 
 * 
 * _marker = object()             # <<<<<<<<<<<<<<
 * 
 * def _local_get_dict(self):
*/
  __pyx_t_2 = NULL;
  __pyx_t_5 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_object, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 333, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  __Pyx_XGOTREF(__pyx_v_6gevent_14_gevent_clocal__marker);
  __Pyx_DECREF_SET(__pyx_v_6gevent_14_gevent_clocal__marker, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_t_4 = 0;

  /* "src/gevent/local.py":352
 * 
 * _local_attrs = {
 *     '_local__impl',             # <<<<<<<<<<<<<<
 *     '_local_type_get_descriptors',
 *     '_local_type_set_or_del_descriptors',
*/
  __pyx_t_4 = PySet_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 352, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PySet_Add(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_local__impl) < (0)) __PYX_ERR(0, 352, __pyx_L1_error)
  if (PySet_Add(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_local_type_get_descriptors) < (0)) __PYX_ERR(0, 352, __pyx_L1_error)
  if (PySet_Add(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_local_type_set_or_del_descripto) < (0)) __PYX_ERR(0, 352, __pyx_L1_error)
  if (PySet_Add(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_local_type_del_descriptors) < (0)) __PYX_ERR(0, 352, __pyx_L1_error)
  if (PySet_Add(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_local_type_set_descriptors) < (0)) __PYX_ERR(0, 352, __pyx_L1_error)
  if (PySet_Add(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_local_type_2) < (0)) __PYX_ERR(0, 352, __pyx_L1_error)
  if (PySet_Add(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_local_type_vars) < (0)) __PYX_ERR(0, 352, __pyx_L1_error)
  if (PySet_Add(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_class) < (0)) __PYX_ERR(0, 352, __pyx_L1_error)
  if (PySet_Add(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_cinit) < (0)) __PYX_ERR(0, 352, __pyx_L1_error)
  __Pyx_XGOTREF(__pyx_v_6gevent_14_gevent_clocal__local_attrs);
  __Pyx_DECREF_SET(__pyx_v_6gevent_14_gevent_clocal__local_attrs, ((PyObject*)__pyx_t_4));
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_t_4 = 0;

  /* "src/gevent/local.py":367
 *     An object whose attributes are greenlet-local.
 *     """
 *     __slots__ = tuple(_local_attrs - {'__class__', '__cinit__'})             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(self, *args, **kw): # pylint:disable=bad-dunder-name
*/
  __pyx_t_4 = PySet_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 367, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PySet_Add(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_class) < (0)) __PYX_ERR(0, 367, __pyx_L1_error)
  if (PySet_Add(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_cinit) < (0)) __PYX_ERR(0, 367, __pyx_L1_error)
  __pyx_t_2 = PyNumber_Subtract(__pyx_v_6gevent_14_gevent_clocal__local_attrs, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 367, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PySequence_Tuple(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 367, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_clocal_local, __pyx_mstate_global->__pyx_n_u_slots, __pyx_t_4) < (0)) __PYX_ERR(0, 367, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/local.py":519
 *             raise AttributeError(name)
 * 
 *     def __copy__(self):             # <<<<<<<<<<<<<<
 *         impl = self._local__impl
 *         entry = impl.dicts[id(getcurrent())]  # pylint:disable=undefined-variable
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_14_gevent_clocal_5local_9__copy__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_local___copy, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_clocal, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[2])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_clocal_local, __pyx_mstate_global->__pyx_n_u_copy, __pyx_t_4) < (0)) __PYX_ERR(0, 519, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/local.py":576
 * # (e.g., on PyPy). So we set it at runtime. Cython
 * # will raise an error if we're compiled.
 * def __new__(cls, *args, **kw):             # <<<<<<<<<<<<<<
 *     self = super(local, cls).__new__(cls) # pylint:disable=no-value-for-parameter
 *     # We get the cls in *args for some reason
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_14_gevent_clocal_3__new__, 0, __pyx_mstate_global->__pyx_n_u_new, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_clocal, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[3])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 576, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_new, __pyx_t_4) < (0)) __PYX_ERR(0, 576, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/local.py":584
 *     return self
 * 
 * if local.__module__ == 'gevent.local':             # <<<<<<<<<<<<<<
 *     # PyPy2/3 and CPython handle adding a __new__ to the class
 *     # in different ways. In CPython and PyPy3, it must be wrapped with classmethod;
*/
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_clocal_local), __pyx_mstate_global->__pyx_n_u_module); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 584, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_mstate_global->__pyx_kp_u_gevent_local, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 584, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_6) {

    /* "src/gevent/local.py":600
 *     # It's not as direct, but it works.
 *     # So here we're not compiled
 *     local.__new__ = classmethod(__new__)             # <<<<<<<<<<<<<<
 * else: # pragma: no cover
 *     # Make sure we revisit in case of changes to the (accelerator) module names.
*/
    __pyx_t_2 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_new); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 600, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_5 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_7};
      __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_classmethod, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 600, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    }
    if (__Pyx_PyObject_SetAttrStr(((PyObject *)__pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_clocal_local), __pyx_mstate_global->__pyx_n_u_new, __pyx_t_4) < (0)) __PYX_ERR(0, 600, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "src/gevent/local.py":584
 *     return self
 * 
 * if local.__module__ == 'gevent.local':             # <<<<<<<<<<<<<<
 *     # PyPy2/3 and CPython handle adding a __new__ to the class
 *     # in different ways. In CPython and PyPy3, it must be wrapped with classmethod;
*/
    goto __pyx_L2;
  }

  /* "src/gevent/local.py":603
 * else: # pragma: no cover
 *     # Make sure we revisit in case of changes to the (accelerator) module names.
 *     if local.__module__ != 'gevent._gevent_clocal': # pylint:disable=else-if-used             # <<<<<<<<<<<<<<
 *         raise AssertionError("Module names changed (local: %r; __name__: %r); revisit this code" % (
 *             local.__module__, __name__) )
*/
  /*else*/ {
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_clocal_local), __pyx_mstate_global->__pyx_n_u_module); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 603, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_mstate_global->__pyx_kp_u_gevent__gevent_clocal, Py_NE)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 603, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(__pyx_t_6)) {

      /* "src/gevent/local.py":604
 *     # Make sure we revisit in case of changes to the (accelerator) module names.
 *     if local.__module__ != 'gevent._gevent_clocal': # pylint:disable=else-if-used
 *         raise AssertionError("Module names changed (local: %r; __name__: %r); revisit this code" % (             # <<<<<<<<<<<<<<
 *             local.__module__, __name__) )
 * 
*/
      __pyx_t_7 = NULL;

      /* "src/gevent/local.py":605
 *     if local.__module__ != 'gevent._gevent_clocal': # pylint:disable=else-if-used
 *         raise AssertionError("Module names changed (local: %r; __name__: %r); revisit this code" % (
 *             local.__module__, __name__) )             # <<<<<<<<<<<<<<
 * 
 * _init()
*/
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_clocal_local), __pyx_mstate_global->__pyx_n_u_module); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 605, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_8 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_t_2), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 605, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 605, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_9 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_t_2), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 605, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_10[0] = __pyx_mstate_global->__pyx_kp_u_Module_names_changed_local;
      __pyx_t_10[1] = __pyx_t_8;
      __pyx_t_10[2] = __pyx_mstate_global->__pyx_kp_u_name_2;
      __pyx_t_10[3] = __pyx_t_9;
      __pyx_t_10[4] = __pyx_mstate_global->__pyx_kp_u_revisit_this_code;

      /* "src/gevent/local.py":604
 *     # Make sure we revisit in case of changes to the (accelerator) module names.
 *     if local.__module__ != 'gevent._gevent_clocal': # pylint:disable=else-if-used
 *         raise AssertionError("Module names changed (local: %r; __name__: %r); revisit this code" % (             # <<<<<<<<<<<<<<
 *             local.__module__, __name__) )
 * 
*/
      __pyx_t_2 = __Pyx_PyUnicode_Join(__pyx_t_10, 5, 29 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8) + 12 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_9) + 20, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_9));
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 604, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_5 = 1;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_2};
        __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_AssertionError)), __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 604, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
      }
      __Pyx_Raise(__pyx_t_4, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __PYX_ERR(0, 604, __pyx_L1_error)

      /* "src/gevent/local.py":603
 * else: # pragma: no cover
 *     # Make sure we revisit in case of changes to the (accelerator) module names.
 *     if local.__module__ != 'gevent._gevent_clocal': # pylint:disable=else-if-used             # <<<<<<<<<<<<<<
 *         raise AssertionError("Module names changed (local: %r; __name__: %r); revisit this code" % (
 *             local.__module__, __name__) )
*/
    }
  }
  __pyx_L2:;

  /* "src/gevent/local.py":607
 *             local.__module__, __name__) )
 * 
 * _init()             # <<<<<<<<<<<<<<
 * 
 * from gevent._util import import_c_accel
*/
  __pyx_f_6gevent_14_gevent_clocal__init(); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 607, __pyx_L1_error)

  /* "src/gevent/local.py":609
 * _init()
 * 
 * from gevent._util import import_c_accel             # <<<<<<<<<<<<<<
 * import_c_accel(globals(), 'gevent._local')
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_import_c_accel};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_gevent__util, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 609, __pyx_L1_error)
  }
  __pyx_t_4 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_4);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_import_c_accel};
    __pyx_t_3 = 0; {
      __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_4, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 609, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_2) < (0)) __PYX_ERR(0, 609, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/local.py":610
 * 
 * from gevent._util import import_c_accel
 * import_c_accel(globals(), 'gevent._local')             # <<<<<<<<<<<<<<
*/
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_import_c_accel); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 610, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_9 = __Pyx_Globals(); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 610, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_5 = 1;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_t_9, __pyx_mstate_global->__pyx_kp_u_gevent__local};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 610, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/local.py":1
 * # cython: auto_pickle=False,embedsignature=True,always_allow_keywords=False             # <<<<<<<<<<<<<<
 * """
 * Greenlet-local objects.
*/
  __pyx_t_4 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_test, __pyx_t_4) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  if (__pyx_m) {
    if (__pyx_mstate->__pyx_d && stringtab_initialized) {
      __Pyx_AddTraceback("init gevent._gevent_clocal", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    #if !CYTHON_USE_MODULE_STATE
    Py_CLEAR(__pyx_m);
    #else
    Py_DECREF(__pyx_m);
    if (pystate_addmodule_run) {
      PyObject *tp, *value, *tb;
      PyErr_Fetch(&tp, &value, &tb);
      PyState_RemoveModule(&__pyx_moduledef);
      PyErr_Restore(tp, value, tb);
    }
    #endif
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init gevent._gevent_clocal");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #else
  return __pyx_m;
  #endif
}
/* #### Code section: pystring_table ### */
/* #### Code section: cached_builtins ### */

static int __Pyx_InitCachedBuiltins(__pyx_mstatetype *__pyx_mstate) {
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __pyx_builtin___import__ = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_import); if (!__pyx_builtin___import__) __PYX_ERR(0, 162, __pyx_L1_error)
  __pyx_builtin_object = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_object); if (!__pyx_builtin_object) __PYX_ERR(0, 333, __pyx_L1_error)
  __pyx_builtin_classmethod = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_classmethod); if (!__pyx_builtin_classmethod) __PYX_ERR(0, 600, __pyx_L1_error)
  __pyx_builtin_id = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_id); if (!__pyx_builtin_id) __PYX_ERR(0, 194, __pyx_L1_error)
  __pyx_builtin_super = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_super); if (!__pyx_builtin_super) __PYX_ERR(0, 577, __pyx_L1_error)

  /* Cached unbound methods */
  __pyx_mstate->__pyx_umethod_PyDict_Type_get.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_get.method_name = &__pyx_mstate->__pyx_n_u_get_2;
  __pyx_mstate->__pyx_umethod_PyDict_Type_items.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_items.method_name = &__pyx_mstate->__pyx_n_u_items;
  __pyx_mstate->__pyx_umethod_PyDict_Type_pop.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_pop.method_name = &__pyx_mstate->__pyx_n_u_pop;
  __pyx_mstate->__pyx_umethod_PyDict_Type_values.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_values.method_name = &__pyx_mstate->__pyx_n_u_values;
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cached_constants ### */

static int __Pyx_InitCachedConstants(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "src/gevent/local.py":224
 *     weakref.
 *     """
 *     __slots__ = ('idt', 'wrdicts')             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, idt, wrdicts):
*/
  __pyx_mstate_global->__pyx_tuple[0] = PyTuple_Pack(2, __pyx_mstate_global->__pyx_n_u_idt, __pyx_mstate_global->__pyx_n_u_wrdicts); if (unlikely(!__pyx_mstate_global->__pyx_tuple[0])) __PYX_ERR(0, 224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[0]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[0]);

  /* "src/gevent/local.py":236
 * 
 * class _local_deleted(object):
 *     __slots__ = ('key', 'wrthread', 'greenlet_deleted')             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, key, wrthread, greenlet_deleted):
*/
  __pyx_mstate_global->__pyx_tuple[1] = PyTuple_Pack(3, __pyx_mstate_global->__pyx_n_u_key, __pyx_mstate_global->__pyx_n_u_wrthread, __pyx_mstate_global->__pyx_n_u_greenlet_deleted); if (unlikely(!__pyx_mstate_global->__pyx_tuple[1])) __PYX_ERR(0, 236, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[1]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[1]);

  /* "src/gevent/local.py":256
 * class _localimpl(object):
 *     """A class managing thread-local dicts"""
 *     __slots__ = ('key', 'dicts',             # <<<<<<<<<<<<<<
 *                  'localargs', 'localkwargs',
 *                  'localtypeid',
*/
  __pyx_mstate_global->__pyx_tuple[2] = PyTuple_Pack(6, __pyx_mstate_global->__pyx_n_u_key, __pyx_mstate_global->__pyx_n_u_dicts, __pyx_mstate_global->__pyx_n_u_localargs, __pyx_mstate_global->__pyx_n_u_localkwargs, __pyx_mstate_global->__pyx_n_u_localtypeid, __pyx_mstate_global->__pyx_n_u_weakref_2); if (unlikely(!__pyx_mstate_global->__pyx_tuple[2])) __PYX_ERR(0, 256, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[2]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[2]);

  /* "src/gevent/local.py":282
 *     # This is a class, not just a tuple, so that cython can optimize
 *     # attribute access
 *     __slots__ = ('wrgreenlet', 'localdict')             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, wrgreenlet, localdict):
*/
  __pyx_mstate_global->__pyx_tuple[3] = PyTuple_Pack(2, __pyx_mstate_global->__pyx_n_u_wrgreenlet, __pyx_mstate_global->__pyx_n_u_localdict); if (unlikely(!__pyx_mstate_global->__pyx_tuple[3])) __PYX_ERR(0, 282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[3]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[3]);
  #if CYTHON_IMMORTAL_CONSTANTS
  {
    PyObject **table = __pyx_mstate->__pyx_tuple;
    for (Py_ssize_t i=0; i<4; ++i) {
      #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
      #if PY_VERSION_HEX < 0x030E0000
      if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
      #else
      if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
      #endif
      {
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
      }
      #else
      Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
      #endif
    }
  }
  #endif
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}
/* #### Code section: init_constants ### */

static int __Pyx_InitConstants(__pyx_mstatetype *__pyx_mstate) {
  CYTHON_UNUSED_VAR(__pyx_mstate);
  {
    const struct { const unsigned int length: 9; } index[] = {{1},{42},{29},{179},{1},{1},{8},{7},{6},{2},{21},{13},{12},{9},{12},{26},{43},{20},{19},{20},{7},{28},{4},{18},{9},{9},{17},{11},{18},{3},{8},{4},{10},{8},{5},{8},{7},{3},{11},{16},{10},{21},{12},{24},{8},{16},{17},{13},{2},{8},{3},{10},{14},{8},{13},{5},{3},{2},{6},{8},{5},{14},{12},{14},{10},{11},{27},{27},{27},{34},{16},{9},{9},{10},{21},{11},{11},{8},{10},{3},{8},{7},{6},{3},{12},{14},{12},{7},{3},{4},{7},{12},{11},{10},{9},{5},{8},{6},{7},{6},{7},{11},{7},{9},{10},{8},{468},{111},{47},{23},{70},{85},{358},{41},{82},{4},{131},{124}};
    #if (CYTHON_COMPRESS_STRINGS) == 3 && __PYX_LIMITED_VERSION_HEX >= 0x030e0000 /* compression: zstd (1367 bytes) */
const char* const cstring = "(\265/\375`h\nm*\000ZA\244\014>0s\322\001\300\300O\014\005\005\2058BV\301+z\001\211\025\356F\310NI\266\245\334\222\232\010\331IJ)\270\231\217FD\256\353\256\346o\367\3679\312\325\335\375\275\307\334\355\376_\3607V\006\251\000\246\000\270\000\233\236\377\333dl\276\235\266\221\255\231PUm'\236\267S%\371\310\037\3468Nd\206\233\365~\3742\352{K\242\202\204\035\256\013\376\364\354\327F8\261\365e\214;\322\236\275E\356\274\357\324\344\267\307\034\033%\253\026\2454\022\347\251\372\026\373aS\233\026\311\346\354\276\320m\374\035\357\340\331^\334fB\302\244\203\006E\323\342\344w=\337[\005\371w\362\246!\277\346\335\371\212E\373\355|\343\227\231f\002\256\2230C{\314\211\333q\315YZH=9\343\361O9M\224\267\227\261\261\177d\211\342\314mQ\366o\217\206\333\3371e$\021OOl\010\332\t\227\342\361\037\325\236\326)K5\251NrR\005\261\234\252\261W\322j\372\334\317\224\356S\376\324\3239?M\261o#-D\001\362\200<\025{\\\275U!;\267\352\246T\375\367\372\265>8I\r?\362\234\224SU\027\251HU\231_5I\350<n7\354v\276\306V\216\r\335cI\342\357g\216~\307v\252\316\261\237\222S:\022\331.V\276\376\014#\363\344\350\224\221:\204\253\0321\215g\341L\013\226J\243ZM$\036<\270\351\374\244k\357\317\t\r\025\214\262\303[\236#\252\357\372\251\316\013O\005\021\264\223+{J\262\3246>1\205}\263\240\260\027).2*,\324F\006\005\007\312\013\255$\211z:B\207F\207\206\261t\304s\322\212=\3143\327\275r\206\222Q\311(\373\215(Yh\307\251IN\323r\207Us\243l\216\341Y\316\361\230\201\270?\325\224\022K\312&G\021\265Q\306\234M9'\312S*\r\252\301\211\355Y\301x\252l0&\311\031\275\330\221\362/O\307\230\206\014\355\265\374\250I\211\010u\324|g\032:\356w\362~:\265\307\333\307n\034^T\232\014\033T*M\347'\0104U\227A\316\024\334\317c\247\"\345\374<Q\376\252\017\251\215\370\271j\004\331\003\316\231+\343$\245\214\316w\016u\376\364\267\324s*\361\001\310\311\017\312EBK\017\213\206\305\251\320\342W\014\213\002rb1\260D\210\264`\270\006(\270\234ub\255\025\313\001\346\305@\201\222\213\200\305#d\022\"\320\202\3432\000 \204\021y9\271`X\r\254\223\005\"/+\241\003\001X\204 !>x""\360py\340\322\343\332K\002\346e],\270d6\026\010\213\301\004\353)h\300\241\003\030 !.;\256\225\353\3035\341ra\211X\t0/%\326\207\020`^N|\224\264@\270B\256\026\026\005k@H@\000\206\t\262\322r\322\002\343\022\271 X!V\210\020\001\221\227\020\037\223$\035\373\271\357\372\030Bvq\2352\020cig$#\307\302\312\336;y\276\225pA\3156Tgb\256\001\200\375\250q\235C\312\014\321H\222\244P\030\016 \204 f\314\252\003\222\321H\221I&\321\214\004\311IA\n\223\302\276\001\010(`\271\014\027\n?d\253\265\234)\r\311c\216I[\271'\217\346<\335C\013\360\031\305/#\233iC\213\367eF\342\033\365X\025:u\274\022\216I\033\034\3458\250i7c\325\352\n\247Z\211\311L\241x\365\202s\347\207r\317\357\006\342\253J\250a\177\303w|\352\226\303\330Ct\260.\376{\276\360\352\346X\270\264\303K\330\351\351\027\241>\261;QH#>\245\247Z/\001\032\031:\212\214\242\3422bR\224\213v\236\2636s\262Z\367\270\\\227\371\361\343\207J\225\265N\253(\324&=97\034j\277%\321^5\337\313N\262Xk\204\257\213\2135J\252M\007\234a\035\024\270nC\226\322Y\340NV\016\277\345l\021j\372\213\354N\334b\215\317\001\024\331P\267lDj\302\211 \324\210\305]\312\2469t\001\035\034\370\n\202+*^\332\305'\303\036\026sp\323\306Q\036\220\205\242\352\324\3367\213\300b\001\325\343\223`\336\004\272D*%\033\"\244m\230\271\376\022Tt\362?i;\245\026\320\260\220}/\244Z\332J\335\324\341\271\022\272\361.\351\267\336\262\001\332E\033\001\345\"\356\230]\247f\314\014\206s'\203L\262\343.\264\031d\333\261\310z \002\272\211\035\000\032H\025\360\340\321<\362\220\373\003{\240\376\020R\253d\0272h\344d\367\000h6k\021\213\231Sr\262\031\313\254R\023Dd\001!\236\237\007\3113\236\257Mw\307\224\341\321\366\206\356\006\347S\250\006\t\010\275\n( \220\3152\2061K\361\3164<lLL\217R\261\344\332\227m1\366o\317\217\207\025\245@\267\221\223\273\030\301\200\220\345h\227\346S\352x\211\222?R|Z\3022\017$\340\335\313O@\010A\230\353\337\252\263\314\037\014\243\231\t;Nw\341\364Pi\257\262k\n\304\3761\253:$UM\345\017";
    PyObject *data = __Pyx_DecompressString(cstring, 1367, 3);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #elif (CYTHON_COMPRESS_STRINGS) == 2 /* compression: bz2 (1513 bytes) */
const char* const cstring = "BZh91AY&SY<\300\031?\000\000\203\177\373\356\177\377\301\177\367\277\375\277\357\377\240\277\377\377\360@@@@@@@\000\000@@\000@\000P\005\265\255\266\324H(\220\333U\026z\303MT\360@\247\242z\ni\371\024\332\233@G\250\32014\323L\004\320\300FF\232i\3514\304\3314=Pi\244)\344\311\242d'\2450\207\250\311\351\032i\240\001\240\000\0004\0002\000\003 \224\320\223@\232h&\246\t\352jdd\323!\243@\000\000\000\000\006\200i\221\2408\320\321\243A\243@\320\000\000\000\000\310\000\000\000\320\031\000\006\025M\250\000\000\320\000\032\000\000h\000\000\000\000\003\324\000\003L\200\202\204\034\2126\230\252a\215X\016\272\336\014\033$\371\223a\336-\243\363\367\266\005\304\303a\212\216\025\206\036S\312\265\253\247\371\000}P0\016\227\350\006\354\376\271\342\240\364\r\273xv^\276o\367w\220\035R\266\237\365\032\301\014tzW]\007|\220\366X[\035F\266\3000-z'Z\"p\230\276\230)dH\200JR\271\004\222Mm7vi\246\333@\0332\261\345\343\2555\024\363U\037khh\364\031\023d\350\322\223\2054EXV\017\235\327\021\213\035\215\374\350\33322\202P\237\321\232\255\255a\207c\362\245\231\361\353\017\237\234\361\335}\014t\314\366mi\207\371}\357\200*\326\014\237\177\3038\352\266\351.\332\243\031\024|\306u\333\3002\314\0269\356\327\316\303\361L\032\373\334\320\302\013W\030\270\353M\314l^\037\240\267\226h\225{5\240\260\242_\220\242\032\342(\276y\207\235\344\026\304\274\013\357\327\273\\\344\212\303\203]wg\\\360\230\342\n\260\3167xg\356RQ\350OF]\230[\260\206b&z\275\216\304\177M\342a\306\335Q\322\312\256i\310\360\322 \345C0E\315\316\326\351\363X\000mVFJ\254\026\342c\266\206\307\333\024\357'fA}p\302hNi\304\2511\255\334\322=\t\262\333\0214+.I\332\355x\301\270\263\0358 \325\023\211\203 \306\226I*\204:vDS\024\232\353\252YR\261\002g\323L\306\2314\247f/\024\212\245\2169\234j\212!v\2354P\3218J\014-\255*\002\0032*1\272\340\304\264\000\006\331\000f\230\340*5\365\026\366\030\326\203+\263\327A\223\r\262\2741V\331K\204\244\374e\006&0J\255\310$\201\327\276\225\350\364\374\355\306\r\223\232\270v\215\341\260\310H\354\206Y\321\260\313m\r\366\2600\350E""\241\303N\254\355c\007\233\032\2529M\343\364\020\334\326\275\023\034\313\225\215F\346\033\200d\316\002\004\306\214\266I2\357\223\260\234\210\037C\316Z^\334\006\31116;d\215\311\266\361\343mh^<\334M\323\326\325\303\240\347\345\224o\260\347\326U\211\335\342\026\304\305C\375\346/#\221\274\020\007Mo.\234`d\233F1V\030\357#\2114eH\302\202<\254\005fn\222 \027\300\020(\210p=\207\036\205\023~m\350\206\302\252\202C>\372<\211k\023'L\354;\247\035\320\235\207W;\344;\014,x\257\216\277w3\213crx\357\212\016\014\357\214\034\324\241@\353\226\0312I\270ik~\177\260\324\030\242\242crm\214\332h\324F\347~g0\0235N'\306\346\274\356&\035\335\215\204\347\026G\033\333\255C\220H\220\216\337.&\2642w(\260\207\017\007v\321\203\224\370\245\002h,\310\361K+\235\254\032m\027g\001\244\223\273\200\321\277h\301t\364@\t\rLBq\\4T\302\034\034\312\243\254\341\306&!\030&\204\343\270x\016\342\2218\037\302\264i}\372R\204`\001u\251\234V2@V0\206iF\216\016q\177K\226d\274C!\003\246\324@\340u\265\366\351\334Vc\257k\232ut\237\022FVY\026\274j\261\341\232\250j\317\035\264\"\206\305\020X\3337\315\326\347\017iD`\232\020u\023^0[ZV\365\223\324* B\004s\323Wql\321\255\360\220\002\024\002 \263N\3756\370\303\354\201\304hk_\303\252\\\202\tU\201\202\304\016D\252\301\252m\307\231!J_\020\301\232\217@.8\313\200\023\251QKM\026\242\346)\177=\004\260q\235c\263&b\355\276\201C;>\345n{\362\327\310\334:\270\2750\n\004}\207P\034+F0\345t\202_\001\362@\313\254\241-\027\016\212-\004\007\221\t\213\340hQ\305S-\22486\026\273\304\306\264\223\2569)s\212\227\004M^\201_\267Um\240`\270b$\336v\006\t\322\026\016\013Mh\205Dr\222%\332`iu\224n\277@.\313\204\254\311\014:\002\n\270\320#t\322F\262\023\307\211e$g\224\241;\267\205\251\3705E@R\305\216\235\232\035\303\246\250`\355\211{9\211.\363s\020\322\242\205\271\315\352sa\370n\260\241~\204^_j\245\307+\021\304\\\311*$$\332H\250\244B\030\275\022\230\253\362Csz$/\204\243Ta\025f\250\317\230\200\244#\222<\361\n9B\226+\241eZ\200\004>\n\023Xb\203\027dRd\350\252\201L\006P\350\021\003\366\216\025L!\250\262\210\212A""\210\240\31263\"\010\024\226\330\373\341\006\006\206+\335\330\373\374|\200j\030\033@\n\333\213}\020\037\006\235\"8\211/\206\034\374\215\324\"\t=\226\022W\356\030/\203\324\251\212A\224vC\224E\212\242\345\356\332|Y\3703\361\372\356G\021\233\274\362;~y\351b:Q \254d5\231U\204\202\311\326\013\225\353\377\027rE8P\220<\300\031?";
    PyObject *data = __Pyx_DecompressString(cstring, 1513, 2);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #elif (CYTHON_COMPRESS_STRINGS) != 0 /* compression: zlib (1358 bytes) */
const char* const cstring = "x\332\245VK\217\0247\020\356U\026i\002\341\025H\310\t\231\274\026\020,Z\262!\tD\2116\260\300\212\260\017B@\234,\217\273f\306Lw\273\327v\317ls\3428\307>\366q\217{\314\317\231#?\201\237\220*{zf6\202E\"#\215]\256r\225\253>W\225{i#SN\211D\275\022N\351\214\t\323-R\310\234E\nX\246\035\263E\236k\343 ~\254\343\"A\236H\3012\331\023Y\027bv9\321R$\267\331\246v\300\\O8v\267t=4\244,\213!Qm0\302AR2\353\214\222\016\014m\312\330\366\372\366\365\325\237W\231\310bf\340%H<\320\026m\231\010k\321\272\356\260v\241\022\2472\346\312\034\3542\333\350\260R\027,\003<\323i\226\343\276y\005\327\203\214YpD\260%\221\241\343>\036\216\352*\353.\261X\031<D\r\200\264\357\213\304\302\362\357\313\"\2169\356\204XY\321N\0002\032\273\262\013\003D`\231\207\231K\037b\303\234_xZ\331\240\027\337a\234\0238\234\337fL\267)(\326\023\026Ad\302a\364\355\002!Z\372\3164\2629&\3471\202\303\371\022\301f@\304\327u\226\224W\356 =PVQX(\220:\006k\344\215p\372\r\177\372r^r\276]\356\341\377\036\231\330\204=\367\004:\234\213$\t\203\337\346\355[\336\321\206w\r\006\232\200\303\233\266\302\226\231TzYj\243\013D\033,\347RaFp\374ylgD\027\234r\220N\226)\340-\3072A\035\256\020f#$\264\205\354\313\204Lh\362*\214\230\004\340\200\314\204\020\203#\274Sd\222\230hu6\020\"\023\346\024\034\277\222\2051\030\362\221\027\203\376'\215$\304\034\256'\315\223i\314\315<\361*\346\377eL\327\004\202\212U<1\022\243\203h\t\353`:K.\244\004\004y\202\227\262|\n#\001e\373P\366\207\375!\341\374k\"\322v,~\363\306\302\2755\370L|\345\336\317\311]\005_\302\202\362\237\277\233\304}\370\267\322\250\334ic\347E]\037\322;E\366h\021f\310\021v\007\302X\277\244\250<\341ou\206\364\214\362\002\274\014Sz^\000\302\223d\t\221\345\251\300\314\301_\352\033\013\316F7\025\2043\0149\017\225\222\353\234\363\034s\\\212\\\221\214\350\201\243\242\243\325n!\222\240e\304\020\023\262o\240c!\301\032\240xx\230\032\263\266\3112$b\350\210\"\301-\350\026\345$v:@\211\003\213\274\"#S8\025\026\342\201H\n\260C\020d\233\363\031aB:\017qE\324\3204\t44\256G\205\274]n\205j\277zy\273|0\021\262\253\327""\230\312\034\013\221\330\276\312\021-\233\013'{W\2429\r\354\231\205l\266!\026\374\326$\277WV\017\327\000\237\341N\266\017\23743\370\221\306\375H\332\377K\375\032\373\370pf\001\014\264\302G\207\306+\321Q\335-\232\313D\211\027\201\215\2046M\330\274\243\262x>\307\033\276\257\233\271}\241H}*w\214N#_\3543\177\"\202\344)\246\363\214\201\367\032\375\201\312}|v\376\032*\274\322\255\302\255\033\243MD\306CF\333\2102&\342\355\242\323\001\023\361\024Rm\312\201\202a4kI\241\317@|\350\270\347\230z\217\300\367z|\336\204)\243\036\010|\240\3630\027\2667\267\235\207\034\364\241\034\262BN\336\325\331\244\255\006\301\337\026\202\233|sks=\262\245\375\220/\301N\003\025\225\025\252\244\302\3641$\302-\302\016\310s\014T\355E>\334\355\027\333/>lt\356\347\355\277?m~\232\246\315\324&\217\2134-\271g\223\275\007\353\317\3267\237\362\273[\233\3677\036DMY\254\357)\027md\003\352\354\341\222B\350OU\n\330\301\347|\234t\367\210cy\0163N\355\233\2369{\010\333\010\017\315go\240\277\350^\321\016/e\244\206\002OK\264\210\347\266\030\374.\302/\007\202\231\303\236\304c:\332/P\267c\260YE^kx\024n\021\272\223\341\023\204\337\036\334\342{\356B\330\321d!5&\277\177\345<\373\365\302x\361\304\350\307j\241\272P/\326\017\367\327\366w\336\266\242c\237\216\216W_W\367\352\205\372\302\276\337\261\362zm\334:=r\325\312\270u\246Z\254\356\327\227\352\233\365N\375\362`\341M\353\324\010\210\177\336+\234\245u\\]\"\316\271\352\207\252\215v7\017\276=\020\343\326\305Z\324\257\016\276<\330%S\273t\332\353\205\267_E\307N\215v\306\213\237\343\201k\025\022\347\253\207\365\332x\2615\372\004\375:Y?\333GC'F\253\243\335\352D\275\202\222\317N\216[_T;\225 \366\235J\326g=\353Lu\274\376~\177\221\" \301\255\352\\\265\366\206\004\247GE\365\250\266\373\337\220\340\324\250[=\251^\355_<(\376Y{C\201\2757\221n\3762M\244\031\312\271Q\251\242/F\313\247u\334\344\317s\345z\177j\235c\037|o\037o\222 \323\364\360\375\0136^Q\231";
    PyObject *data = __Pyx_DecompressString(cstring, 1358, 1);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #else /* compression: none (2920 bytes) */
const char* const bytes = "'Initialization arguments are not supportedModule names changed (local: Note that Cython is deliberately stricter than PEP-484 and rejects subclasses of builtin types. If you need to pass subclasses then set the 'annotation_typing' directive to False.?.add_notedisableenablegcgevent._gevent_clocalgevent._localgevent.localisenabled; __name__:  object has no attribute '%r object attribute '__dict__' is read-only); revisit this codesrc/gevent/local.py__Pyx_PyDict_NextRef__all__all_local_dicts_for_greenletargsasyncio.coroutines__cinit____class____class_getitem__classmethodcline_in_tracebackcls__copy__copy__delete____dict__dicts__func____get__get__getattr____getattribute__getcurrentgevent._gevent_clocalgevent._util_gevent_local_localimpl_greenletgreenlet_deleted_greenlet_deletedgreenlet_initidid_localidt__import__import_c_accel__init___is_coroutineitemskeykwkwargs<lambda>locallocal.__copy___local__impl_local_deletedlocal_type_local_type_local_type_del_descriptors_local_type_get_descriptors_local_type_set_descriptors_local_type_set_or_del_descriptors_local_type_varslocalargslocaldict_localimpl_localimpl_dict_entrylocalkwargslocaltypeid__main____module__mro__name____new__objectpop__pyx_capi____pyx_vtable____qualname__rawlinkrefself__set____set_name____setattr__setdefault__slots__super__test__unlink_unusedvaluesweakref__weakref__wrdicts_wrefdictwrgreenletwrthreadPyObject *(PyGreenlet *, int __pyx_skip_dispatch)\000PyObject *(struct __pyx_obj_6gevent_14_gevent_clocal__localimpl *, PyGreenlet *, PyObject *)\000PyObject *(struct __pyx_obj_6gevent_14_gevent_clocal_local *)\000\000PyObject *(struct __pyx_obj_6gevent_14_gevent_clocal_local *, struct __pyx_obj_6gevent_14_gevent_clocal__localimpl *, PyObject *)\000void (void)\000all_local_dicts_for_greenlet\000_localimpl_create_dict\000_local_find_descriptors\000_local_get_dict\000_local__copy_dict_from\000_initPyObject *\000\000\000PyTypeObject *\000\000int\000BlockingSwitchOutError\000get_objects\000wref\000_buffer\000_memoryview""\000_greenlet_importedPyObject *\000\000\000WeakKeyDictionary\000heappop\000heappushPyObject *\000_threadlocalPyObject *\000\000\000int\000ConcurrentObjectUseError\000_NONE\000sys\000_greenlet_importedPyObject *\000\000\000\000\000int\000\000_local_attrs\000_marker\000copy\000key_prefix\000ref\000_PYPY\000_greenlet_importedPyObject *\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000int\000\000struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *\000\000GEVENT_CONFIG\000GreenletExit\000InvalidSwitchError\000Timeout\000_greenlet__init__\000_spawn_callbacks\000_threadlocal\000dump_traceback\000get_hub_class\000iwait\000load_traceback\000reraise\000sys_exc_info\000sys_getframe\000wait\000wref\000_PYPY\000_greenlet_imported\000_cancelled_start_event\000_start_completed_event\200\001\330\004\013\2105\220\001\220\027\230\004\230H\240A\240Q\360\010\000\005\t\210\n\220\"\220D\230\001\230\027\240\001\330\004\013\2101\200A\330\010\017\210t\2201\330\010\020\220\004\220F\230!\2302\230Q\230j\250\001\340\010\016\210e\2201\330\010\024\220D\230\001\230\021\340\010\016\210d\220!\2201\330\010\023\2203\220b\230\004\230N\250$\250a\330\010\036\230a\230z\250\026\250q\330\010\017\210q\230H\240A\200\001\360\030\000\005\016\210Q\330\004\022\220\"\220A\220Q\330\004\024\220H\230A\330\004\010\210\003\2105\220\r\230V\2401\330\010\013\2104\210q\220\013\2301\230A\330\014\r\330\010\025\220Q\220a\330\010\013\210;\220c\230\021\330\014\r\330\010\020\220\n\230&\240\004\240A\240Q\330\010\013\2106\220\023\220A\340\014\r\330\010\017\210u\220K\230s\240#\240Q\330\010\016\210g\220R\220z\240\036\250u\260A\340\004\013\2101struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *(int __pyx_skip_dispatch)\000get_hub_noargs";
    PyObject *data = NULL;
    CYTHON_UNUSED_VAR(__Pyx_DecompressString);
    #endif
    PyObject **stringtab = __pyx_mstate->__pyx_string_tab;
    Py_ssize_t pos = 0;
    for (int i = 0; i < 106; i++) {
      Py_ssize_t bytes_length = index[i].length;
      PyObject *string = PyUnicode_DecodeUTF8(bytes + pos, bytes_length, NULL);
      if (likely(string) && i >= 19) PyUnicode_InternInPlace(&string);
      if (unlikely(!string)) {
        Py_XDECREF(data);
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
      stringtab[i] = string;
      pos += bytes_length;
    }
    for (int i = 106; i < 118; i++) {
      Py_ssize_t bytes_length = index[i].length;
      PyObject *string = PyBytes_FromStringAndSize(bytes + pos, bytes_length);
      stringtab[i] = string;
      pos += bytes_length;
      if (unlikely(!string)) {
        Py_XDECREF(data);
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
    }
    Py_XDECREF(data);
    for (Py_ssize_t i = 0; i < 118; i++) {
      if (unlikely(PyObject_Hash(stringtab[i]) == -1)) {
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
    }
    #if CYTHON_IMMORTAL_CONSTANTS
    {
      PyObject **table = stringtab + 106;
      for (Py_ssize_t i=0; i<12; ++i) {
        #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
        #if PY_VERSION_HEX < 0x030E0000
        if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
        #else
        if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
        #endif
        {
          Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
        }
        #else
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
        #endif
      }
    }
    #endif
  }
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: init_codeobjects ### */
typedef struct {
    unsigned int argcount : 1;
    unsigned int num_posonly_args : 1;
    unsigned int num_kwonly_args : 1;
    unsigned int nlocals : 3;
    unsigned int flags : 10;
    unsigned int first_line : 10;
} __Pyx_PyCode_New_function_description;
/* NewCodeObj.proto */
static PyObject* __Pyx_PyCode_New(
        const __Pyx_PyCode_New_function_description descr,
        PyObject * const *varnames,
        PyObject *filename,
        PyObject *funcname,
        PyObject *line_table,
        PyObject *tuple_dedup_map
);


static int __Pyx_CreateCodeObjects(__pyx_mstatetype *__pyx_mstate) {
  PyObject* tuple_dedup_map = PyDict_New();
  if (unlikely(!tuple_dedup_map)) return -1;
  {
    const __Pyx_PyCode_New_function_description descr = {0, 0, 0, 0, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 163};
    PyObject* const varnames[] = {0};
    __pyx_mstate_global->__pyx_codeobj_tab[0] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_local_py, __pyx_mstate->__pyx_n_u_lambda, __pyx_mstate->__pyx_kp_b_iso88591_HA, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[0])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 181};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_greenlet};
    __pyx_mstate_global->__pyx_codeobj_tab[1] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_local_py, __pyx_mstate->__pyx_n_u_all_local_dicts_for_greenlet, __pyx_mstate->__pyx_kp_b_iso88591_Q_AQ_HA_5_V1_4q_1A_Qa_c_AQ_6_A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[1])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 519};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[2] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_local_py, __pyx_mstate->__pyx_n_u_copy, __pyx_mstate->__pyx_kp_b_iso88591_A_t1_F_2Qj_e1_D_d_1_3b_N_a_az_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[2])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS|CO_VARKEYWORDS), 576};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_cls, __pyx_mstate->__pyx_n_u_args, __pyx_mstate->__pyx_n_u_kw, __pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[3] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_local_py, __pyx_mstate->__pyx_n_u_new, __pyx_mstate->__pyx_kp_b_iso88591_5_HAQ_D_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[3])) goto bad;
  }
  Py_DECREF(tuple_dedup_map);
  return 0;
  bad:
  Py_DECREF(tuple_dedup_map);
  return -1;
}
/* #### Code section: init_globals ### */

static int __Pyx_InitGlobals(void) {
  /* PythonCompatibility.init */
  if (likely(__Pyx_init_co_variables() == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* AssertionsEnabled.init */
  if (likely(__Pyx_init_assertions_enabled() == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CommonTypesMetaclass.init */
  if (likely(__pyx_CommonTypesMetaclass_init(__pyx_m) == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CachedMethodType.init */
  #if CYTHON_COMPILING_IN_LIMITED_API
  {
      PyObject *typesModule=NULL;
      typesModule = PyImport_ImportModule("types");
      if (typesModule) {
          __pyx_mstate_global->__Pyx_CachedMethodType = PyObject_GetAttrString(typesModule, "MethodType");
          Py_DECREF(typesModule);
      }
  } // error handling follows
  #endif
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CythonFunctionShared.init */
  if (likely(__pyx_CyFunction_init(__pyx_m) == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cleanup_globals ### */
/* #### Code section: cleanup_module ### */
/* #### Code section: main_method ### */
/* #### Code section: utility_code_pragmas ### */
#ifdef _MSC_VER
#pragma warning( push )
/* Warning 4127: conditional expression is constant
 * Cython uses constant conditional expressions to allow in inline functions to be optimized at
 * compile-time, so this warning is not useful
 */
#pragma warning( disable : 4127 )
#endif



/* #### Code section: utility_code_def ### */

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyErrExceptionMatches (used by PyObjectGetAttrStrNoError) */
#include "src/gevent/_generated_include/PyErrExceptionMatches_impl_7b4f377310190df92a521563db80ecc2f42d95506fc867b739186a972ce9c8f6.h"
/* PyErrFetchRestore (used by PyObjectGetAttrStrNoError) */
#include "src/gevent/_generated_include/PyErrFetchRestore_impl_83072c493b1583a48ff3aad9f8dc7ade3be268831a2ab8ada440fe395cf916ad.h"
/* PyObjectGetAttrStr (used by PyObjectGetAttrStrNoError) */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* PyObjectGetAttrStrNoError (used by GetBuiltinName) */
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
static void __Pyx_PyObject_GetAttrStr_ClearAttributeError(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (likely(__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        __Pyx_PyErr_Clear();
}
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name) {
    PyObject *result;
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    (void) PyObject_GetOptionalAttr(obj, attr_name, &result);
    return result;
#else
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_TYPE_SLOTS
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro == PyObject_GenericGetAttr)) {
        return _PyObject_GenericGetAttrWithDict(obj, attr_name, NULL, 1);
    }
#endif
    result = __Pyx_PyObject_GetAttrStr(obj, attr_name);
    if (unlikely(!result)) {
        __Pyx_PyObject_GetAttrStr_ClearAttributeError();
    }
    return result;
#endif
}

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStrNoError(__pyx_mstate_global->__pyx_b, name);
    if (unlikely(!result) && !PyErr_Occurred()) {
        PyErr_Format(PyExc_NameError,
            "name '%U' is not defined", name);
    }
    return result;
}

/* TupleAndListFromArray (used by fastcall) */
#include "src/gevent/_generated_include/TupleAndListFromArray_impl_d69ed499f68cd42feaee4b5942c18d0f8efd9989393e455f897298c58b9fa8dd.h"
/* BytesEquals (used by UnicodeEquals) */
#include "src/gevent/_generated_include/BytesEquals_impl_d48b3ef06490e9921f32936be4dcafdc3250ac7ef2252e904b8f20e24a665cc0.h"
/* UnicodeEquals (used by fastcall) */
#include "src/gevent/_generated_include/UnicodeEquals_impl_836cabebedcde255d7b2e14d2d3ec8ae093224d9992c111dd33f6f1ba2aecbef.h"
/* fastcall */
#include "src/gevent/_generated_include/fastcall_impl_2d371982e998467e5c3fa3d5d125a44afb3a07b23828be3d6b5d120f6be5ca37.h"
/* ExtTypeTest */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type) {
    __Pyx_TypeName obj_type_name;
    __Pyx_TypeName type_name;
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (likely(__Pyx_TypeCheck(obj, type)))
        return 1;
    obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    type_name = __Pyx_PyType_GetFullyQualifiedName(type);
    PyErr_Format(PyExc_TypeError,
                 "Cannot convert " __Pyx_FMT_TYPENAME " to " __Pyx_FMT_TYPENAME,
                 obj_type_name, type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    __Pyx_DECREF_TypeName(type_name);
    return 0;
}

/* PyObjectCall (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = Py_TYPE(func)->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallMethO (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = __Pyx_CyOrPyCFunction_GET_FUNCTION(func);
    self = __Pyx_CyOrPyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectFastCall */
#include "src/gevent/_generated_include/PyObjectFastCall_impl_49781168209ae59e1c56f88d63362765f980ea90cc34bbbe49d64735688b114b.h"
/* RaiseUnexpectedTypeError */
static int
__Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj)
{
    __Pyx_TypeName obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError, "Expected %s, got " __Pyx_FMT_TYPENAME,
                 expected, obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* IterFinish (used by dict_iter) */
static CYTHON_INLINE int __Pyx_IterFinish(void) {
    PyObject* exc_type;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    exc_type = __Pyx_PyErr_CurrentExceptionType();
    if (unlikely(exc_type)) {
        if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)))
            return -1;
        __Pyx_PyErr_Clear();
        return 0;
    }
    return 0;
}

/* PyObjectCallNoArg (used by PyObjectCallMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
    PyObject *arg[2] = {NULL, NULL};
    return __Pyx_PyObject_FastCall(func, arg + 1, 0 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* PyObjectCallOneArg (used by PyObjectCallMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *args[2] = {NULL, arg};
    return __Pyx_PyObject_FastCall(func, args+1, 1 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* PyObjectGetMethod (used by PyObjectCallMethod0) */
#include "src/gevent/_generated_include/PyObjectGetMethod_impl_e128eb9d3930413c3ed54abc40d4953c55ff9ea67a8c08ac7b5c2fd8494b6c00.h"
/* PyObjectCallMethod0 (used by dict_iter) */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name) {
#if CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000))
    PyObject *args[1] = {obj};
    (void) __Pyx_PyObject_CallOneArg;
    (void) __Pyx_PyObject_CallNoArg;
    return PyObject_VectorcallMethod(method_name, args, 1 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#else
    PyObject *method = NULL, *result = NULL;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_CallOneArg(method, obj);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) goto bad;
    result = __Pyx_PyObject_CallNoArg(method);
    Py_DECREF(method);
bad:
    return result;
#endif
}

/* RaiseNeedMoreValuesToUnpack (used by UnpackTuple2) */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%.1s to unpack",
                 index, (index == 1) ? "" : "s");
}

/* RaiseTooManyValuesToUnpack (used by UnpackItemEndCheck) */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

/* UnpackItemEndCheck (used by UnpackTuple2) */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    }
    return __Pyx_IterFinish();
}

/* RaiseNoneIterError (used by UnpackTupleError) */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
}

/* UnpackTupleError (used by UnpackTuple2) */
static void __Pyx_UnpackTupleError(PyObject *t, Py_ssize_t index) {
    if (t == Py_None) {
      __Pyx_RaiseNoneNotIterableError();
    } else {
      Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(t);
 #if !CYTHON_ASSUME_SAFE_SIZE
      if (unlikely(size < 0)) return;
 #endif
      if (size < index) {
        __Pyx_RaiseNeedMoreValuesError(size);
      } else {
        __Pyx_RaiseTooManyValuesError(index);
      }
    }
}

/* UnpackTuple2 (used by dict_iter) */
#include "src/gevent/_generated_include/UnpackTuple2_impl_2a9fba3d5d02c0857f856a572fabeaf6b2890c41e9ae9233a4ba12e3ba633488.h"
/* dict_iter */
#include "src/gevent/_generated_include/dict_iter_impl_29ea27b89a8b9bec194021fbce5f0da5d4b899d1c47b5cbe1cbe8d300e27d823.h"
/* unicode_tailmatch */
#include "src/gevent/_generated_include/unicode_tailmatch_impl_6103cc63421b2b408ea9223aaeb337a5b73c6075f92cb7f9de21e9c07d839c9f.h"
/* PyObjectCall2Args (used by CallUnboundCMethod1) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2) {
    PyObject *args[3] = {NULL, arg1, arg2};
    return __Pyx_PyObject_FastCall(function, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* UnpackUnboundCMethod (used by CallUnboundCMethod1) */
#include "src/gevent/_generated_include/UnpackUnboundCMethod_impl_73fbc94f885e37a7810c861231fd30d7a9eae7cde8890c6786a4ce1f346a7810.h"
/* CallUnboundCMethod1 */
#include "src/gevent/_generated_include/CallUnboundCMethod1_impl_0820fa80b637dcac9bcf44c709c1dc323f347b99ab227a86488e6c6ecf6c876e.h"
/* CallUnboundCMethod2 */
#include "src/gevent/_generated_include/CallUnboundCMethod2_impl_15aa7f0a5154a4d6051e84dd189b6dc929e7450de4be5cb5e9cc003766aec24d.h"
/* dict_getitem_default */
static PyObject* __Pyx_PyDict_GetItemDefault(PyObject* d, PyObject* key, PyObject* default_value) {
    PyObject* value;
#if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07020000
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (unlikely(PyErr_Occurred()))
            return NULL;
        value = default_value;
    }
    Py_INCREF(value);
    if ((1));
#else
    if (PyBytes_CheckExact(key) || PyUnicode_CheckExact(key) || PyLong_CheckExact(key)) {
        value = PyDict_GetItem(d, key);
        if (unlikely(!value)) {
            value = default_value;
        }
        Py_INCREF(value);
    }
#endif
    else {
        if (default_value == Py_None)
            value = __Pyx_CallUnboundCMethod1(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_get, d, key);
        else
            value = __Pyx_CallUnboundCMethod2(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_get, d, key, default_value);
    }
    return value;
}

/* RaiseException */
#include "src/gevent/_generated_include/RaiseException_impl_5214b4470ab1cce407ca930811cfafb701053719a58763807254160af0a39f69.h"
/* ArgTypeTestFunc (used by ArgTypeTest) */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact)
{
    __Pyx_TypeName type_name;
    __Pyx_TypeName obj_type_name;
    PyObject *extra_info = __pyx_mstate_global->__pyx_empty_unicode;
    int from_annotation_subclass = 0;
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    else if (!exact) {
        if (likely(__Pyx_TypeCheck(obj, type))) return 1;
    } else if (exact == 2) {
        if (__Pyx_TypeCheck(obj, type)) {
            from_annotation_subclass = 1;
            extra_info = __pyx_mstate_global->__pyx_kp_u_Note_that_Cython_is_deliberately;
        }
    }
    type_name = __Pyx_PyType_GetFullyQualifiedName(type);
    obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "Argument '%.200s' has incorrect type (expected " __Pyx_FMT_TYPENAME
        ", got " __Pyx_FMT_TYPENAME ")"
#if __PYX_LIMITED_VERSION_HEX < 0x030C0000
        "%s%U"
#endif
        , name, type_name, obj_type_name
#if __PYX_LIMITED_VERSION_HEX < 0x030C0000
        , (from_annotation_subclass ? ". " : ""), extra_info
#endif
        );
#if __PYX_LIMITED_VERSION_HEX >= 0x030C0000
    if (exact == 2 && from_annotation_subclass) {
        PyObject *res;
        PyObject *vargs[2];
        vargs[0] = PyErr_GetRaisedException();
        vargs[1] = extra_info;
        res = PyObject_VectorcallMethod(__pyx_mstate_global->__pyx_kp_u_add_note, vargs, 2, NULL);
        Py_XDECREF(res);
        PyErr_SetRaisedException(vargs[0]);
    }
#endif
    __Pyx_DECREF_TypeName(type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* CallUnboundCMethod0 */
#include "src/gevent/_generated_include/CallUnboundCMethod0_impl_506503ba83409bc78d50e6c2a64d54ddd95a836cba396a015c59c17bbf915db5.h"
/* py_dict_items (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Items(PyObject* d) {
    return __Pyx_CallUnboundCMethod0(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_items, d);
}

/* py_dict_values (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Values(PyObject* d) {
    return __Pyx_CallUnboundCMethod0(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_values, d);
}

/* OwnedDictNext (used by ParseKeywordsImpl) */
#if CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, PyObject **ppos, PyObject **pkey, PyObject **pvalue) {
    PyObject *next = NULL;
    if (!*ppos) {
        if (pvalue) {
            PyObject *dictview = pkey ? __Pyx_PyDict_Items(p) : __Pyx_PyDict_Values(p);
            if (unlikely(!dictview)) goto bad;
            *ppos = PyObject_GetIter(dictview);
            Py_DECREF(dictview);
        } else {
            *ppos = PyObject_GetIter(p);
        }
        if (unlikely(!*ppos)) goto bad;
    }
    next = PyIter_Next(*ppos);
    if (!next) {
        if (PyErr_Occurred()) goto bad;
        return 0;
    }
    if (pkey && pvalue) {
        *pkey = __Pyx_PySequence_ITEM(next, 0);
        if (unlikely(*pkey)) goto bad;
        *pvalue = __Pyx_PySequence_ITEM(next, 1);
        if (unlikely(*pvalue)) goto bad;
        Py_DECREF(next);
    } else if (pkey) {
        *pkey = next;
    } else {
        assert(pvalue);
        *pvalue = next;
    }
    return 1;
  bad:
    Py_XDECREF(next);
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d0000
    PyErr_FormatUnraisable("Exception ignored in __Pyx_PyDict_NextRef");
#else
    PyErr_WriteUnraisable(__pyx_mstate_global->__pyx_n_u_Pyx_PyDict_NextRef);
#endif
    if (pkey) *pkey = NULL;
    if (pvalue) *pvalue = NULL;
    return 0;
}
#else // !CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, Py_ssize_t *ppos, PyObject **pkey, PyObject **pvalue) {
    int result = PyDict_Next(p, ppos, pkey, pvalue);
    if (likely(result == 1)) {
        if (pkey) Py_INCREF(*pkey);
        if (pvalue) Py_INCREF(*pvalue);
    }
    return result;
}
#endif

/* RaiseDoubleKeywords (used by ParseKeywordsImpl) */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
}

/* ParseKeywordsImpl (used by ParseKeywords) */
static int __Pyx_ValidateDuplicatePosArgs(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    const char* function_name)
{
    PyObject ** const *name = argnames;
    while (name != first_kw_arg) {
        PyObject *key = **name;
        int found = PyDict_Contains(kwds, key);
        if (unlikely(found)) {
            if (found == 1) __Pyx_RaiseDoubleKeywordsError(function_name, key);
            goto bad;
        }
        name++;
    }
    return 0;
bad:
    return -1;
}
#if CYTHON_USE_UNICODE_INTERNALS
static CYTHON_INLINE int __Pyx_UnicodeKeywordsEqual(PyObject *s1, PyObject *s2) {
    int kind;
    Py_ssize_t len = PyUnicode_GET_LENGTH(s1);
    if (len != PyUnicode_GET_LENGTH(s2)) return 0;
    kind = PyUnicode_KIND(s1);
    if (kind != PyUnicode_KIND(s2)) return 0;
    const void *data1 = PyUnicode_DATA(s1);
    const void *data2 = PyUnicode_DATA(s2);
    return (memcmp(data1, data2, (size_t) len * (size_t) kind) == 0);
}
#endif
static int __Pyx_MatchKeywordArg_str(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    PyObject ** const *name;
    #if CYTHON_USE_UNICODE_INTERNALS
    Py_hash_t key_hash = ((PyASCIIObject*)key)->hash;
    if (unlikely(key_hash == -1)) {
        key_hash = PyObject_Hash(key);
        if (unlikely(key_hash == -1))
            goto bad;
    }
    #endif
    name = first_kw_arg;
    while (*name) {
        PyObject *name_str = **name;
        #if CYTHON_USE_UNICODE_INTERNALS
        if (key_hash == ((PyASCIIObject*)name_str)->hash && __Pyx_UnicodeKeywordsEqual(name_str, key)) {
            *index_found = (size_t) (name - argnames);
            return 1;
        }
        #else
        #if CYTHON_ASSUME_SAFE_SIZE
        if (PyUnicode_GET_LENGTH(name_str) == PyUnicode_GET_LENGTH(key))
        #endif
        {
            int cmp = PyUnicode_Compare(name_str, key);
            if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
            if (cmp == 0) {
                *index_found = (size_t) (name - argnames);
                return 1;
            }
        }
        #endif
        name++;
    }
    name = argnames;
    while (name != first_kw_arg) {
        PyObject *name_str = **name;
        #if CYTHON_USE_UNICODE_INTERNALS
        if (unlikely(key_hash == ((PyASCIIObject*)name_str)->hash)) {
            if (__Pyx_UnicodeKeywordsEqual(name_str, key))
                goto arg_passed_twice;
        }
        #else
        #if CYTHON_ASSUME_SAFE_SIZE
        if (PyUnicode_GET_LENGTH(name_str) == PyUnicode_GET_LENGTH(key))
        #endif
        {
            if (unlikely(name_str == key)) goto arg_passed_twice;
            int cmp = PyUnicode_Compare(name_str, key);
            if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
            if (cmp == 0) goto arg_passed_twice;
        }
        #endif
        name++;
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
bad:
    return -1;
}
static int __Pyx_MatchKeywordArg_nostr(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    PyObject ** const *name;
    if (unlikely(!PyUnicode_Check(key))) goto invalid_keyword_type;
    name = first_kw_arg;
    while (*name) {
        int cmp = PyObject_RichCompareBool(**name, key, Py_EQ);
        if (cmp == 1) {
            *index_found = (size_t) (name - argnames);
            return 1;
        }
        if (unlikely(cmp == -1)) goto bad;
        name++;
    }
    name = argnames;
    while (name != first_kw_arg) {
        int cmp = PyObject_RichCompareBool(**name, key, Py_EQ);
        if (unlikely(cmp != 0)) {
            if (cmp == 1) goto arg_passed_twice;
            else goto bad;
        }
        name++;
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
bad:
    return -1;
}
static CYTHON_INLINE int __Pyx_MatchKeywordArg(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    return likely(PyUnicode_CheckExact(key)) ?
        __Pyx_MatchKeywordArg_str(key, argnames, first_kw_arg, index_found, function_name) :
        __Pyx_MatchKeywordArg_nostr(key, argnames, first_kw_arg, index_found, function_name);
}
static void __Pyx_RejectUnknownKeyword(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    const char *function_name)
{
    #if CYTHON_AVOID_BORROWED_REFS
    PyObject *pos = NULL;
    #else
    Py_ssize_t pos = 0;
    #endif
    PyObject *key = NULL;
    __Pyx_BEGIN_CRITICAL_SECTION(kwds);
    while (
        #if CYTHON_AVOID_BORROWED_REFS
        __Pyx_PyDict_NextRef(kwds, &pos, &key, NULL)
        #else
        PyDict_Next(kwds, &pos, &key, NULL)
        #endif
    ) {
        PyObject** const *name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (!*name) {
            size_t index_found = 0;
            int cmp = __Pyx_MatchKeywordArg(key, argnames, first_kw_arg, &index_found, function_name);
            if (cmp != 1) {
                if (cmp == 0) {
                    PyErr_Format(PyExc_TypeError,
                        "%s() got an unexpected keyword argument '%U'",
                        function_name, key);
                }
                #if CYTHON_AVOID_BORROWED_REFS
                Py_DECREF(key);
                #endif
                break;
            }
        }
        #if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(key);
        #endif
    }
    __Pyx_END_CRITICAL_SECTION();
    #if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(pos);
    #endif
    assert(PyErr_Occurred());
}
static int __Pyx_ParseKeywordDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    PyObject** const *name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    Py_ssize_t extracted = 0;
#if !CYTHON_COMPILING_IN_PYPY || defined(PyArg_ValidateKeywordArguments)
    if (unlikely(!PyArg_ValidateKeywordArguments(kwds))) return -1;
#endif
    name = first_kw_arg;
    while (*name && num_kwargs > extracted) {
        PyObject * key = **name;
        PyObject *value;
        int found = 0;
        #if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
        found = PyDict_GetItemRef(kwds, key, &value);
        #else
        value = PyDict_GetItemWithError(kwds, key);
        if (value) {
            Py_INCREF(value);
            found = 1;
        } else {
            if (unlikely(PyErr_Occurred())) goto bad;
        }
        #endif
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
            extracted++;
        }
        name++;
    }
    if (num_kwargs > extracted) {
        if (ignore_unknown_kwargs) {
            if (unlikely(__Pyx_ValidateDuplicatePosArgs(kwds, argnames, first_kw_arg, function_name) == -1))
                goto bad;
        } else {
            __Pyx_RejectUnknownKeyword(kwds, argnames, first_kw_arg, function_name);
            goto bad;
        }
    }
    return 0;
bad:
    return -1;
}
static int __Pyx_ParseKeywordDictToDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject** const *name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    Py_ssize_t len;
#if !CYTHON_COMPILING_IN_PYPY || defined(PyArg_ValidateKeywordArguments)
    if (unlikely(!PyArg_ValidateKeywordArguments(kwds))) return -1;
#endif
    if (PyDict_Update(kwds2, kwds) < 0) goto bad;
    name = first_kw_arg;
    while (*name) {
        PyObject *key = **name;
        PyObject *value;
#if !CYTHON_COMPILING_IN_LIMITED_API && (PY_VERSION_HEX >= 0x030d00A2 || defined(PyDict_Pop))
        int found = PyDict_Pop(kwds2, key, &value);
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
        }
#elif __PYX_LIMITED_VERSION_HEX >= 0x030d0000
        int found = PyDict_GetItemRef(kwds2, key, &value);
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
            if (unlikely(PyDict_DelItem(kwds2, key) < 0)) goto bad;
        }
#else
    #if CYTHON_COMPILING_IN_CPYTHON
        value = _PyDict_Pop(kwds2, key, kwds2);
    #else
        value = __Pyx_CallUnboundCMethod2(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_pop, kwds2, key, kwds2);
    #endif
        if (value == kwds2) {
            Py_DECREF(value);
        } else {
            if (unlikely(!value)) goto bad;
            values[name-argnames] = value;
        }
#endif
        name++;
    }
    len = PyDict_Size(kwds2);
    if (len > 0) {
        return __Pyx_ValidateDuplicatePosArgs(kwds, argnames, first_kw_arg, function_name);
    } else if (unlikely(len == -1)) {
        goto bad;
    }
    return 0;
bad:
    return -1;
}
static int __Pyx_ParseKeywordsTuple(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    PyObject *key = NULL;
    PyObject** const * name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    for (Py_ssize_t pos = 0; pos < num_kwargs; pos++) {
#if CYTHON_AVOID_BORROWED_REFS
        key = __Pyx_PySequence_ITEM(kwds, pos);
#else
        key = __Pyx_PyTuple_GET_ITEM(kwds, pos);
#endif
#if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(!key)) goto bad;
#endif
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            PyObject *value = kwvalues[pos];
            values[name-argnames] = __Pyx_NewRef(value);
        } else {
            size_t index_found = 0;
            int cmp = __Pyx_MatchKeywordArg(key, argnames, first_kw_arg, &index_found, function_name);
            if (cmp == 1) {
                PyObject *value = kwvalues[pos];
                values[index_found] = __Pyx_NewRef(value);
            } else {
                if (unlikely(cmp == -1)) goto bad;
                if (kwds2) {
                    PyObject *value = kwvalues[pos];
                    if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
                } else if (!ignore_unknown_kwargs) {
                    goto invalid_keyword;
                }
            }
        }
        #if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(key);
        key = NULL;
        #endif
    }
    return 0;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    goto bad;
bad:
    #if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(key);
    #endif
    return -1;
}

/* ParseKeywords */
static int __Pyx_ParseKeywords(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    if (CYTHON_METH_FASTCALL && likely(PyTuple_Check(kwds)))
        return __Pyx_ParseKeywordsTuple(kwds, kwvalues, argnames, kwds2, values, num_pos_args, num_kwargs, function_name, ignore_unknown_kwargs);
    else if (kwds2)
        return __Pyx_ParseKeywordDictToDict(kwds, argnames, kwds2, values, num_pos_args, function_name);
    else
        return __Pyx_ParseKeywordDict(kwds, argnames, values, num_pos_args, num_kwargs, function_name, ignore_unknown_kwargs);
}

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* PyObjectFastCallMethod */
#if !CYTHON_VECTORCALL || PY_VERSION_HEX < 0x03090000
static PyObject *__Pyx_PyObject_FastCallMethod(PyObject *name, PyObject *const *args, size_t nargsf) {
    PyObject *result;
    PyObject *attr = PyObject_GetAttr(args[0], name);
    if (unlikely(!attr))
        return NULL;
    result = __Pyx_PyObject_FastCall(attr, args+1, nargsf - 1);
    Py_DECREF(attr);
    return result;
}
#endif

/* GetTopmostException (used by SaveResetException) */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem *
__Pyx_PyErr_GetTopmostException(PyThreadState *tstate)
{
    _PyErr_StackItem *exc_info = tstate->exc_info;
    while ((exc_info->exc_value == NULL || exc_info->exc_value == Py_None) &&
           exc_info->previous_item != NULL)
    {
        exc_info = exc_info->previous_item;
    }
    return exc_info;
}
#endif

/* SaveResetException */
#include "src/gevent/_generated_include/SaveResetException_impl_b3e76ed9bc3819093e52b1558c2bbad485040cdc5a28b71844e50bfc92f51cf0.h"
/* GetAttr3 */
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
static PyObject *__Pyx_GetAttr3Default(PyObject *d) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (unlikely(!__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        return NULL;
    __Pyx_PyErr_Clear();
    Py_INCREF(d);
    return d;
}
#endif
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *o, PyObject *n, PyObject *d) {
    PyObject *r;
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    int res = PyObject_GetOptionalAttr(o, n, &r);
    return (res != 0) ? r : __Pyx_NewRef(d);
#else
  #if CYTHON_USE_TYPE_SLOTS
    if (likely(PyUnicode_Check(n))) {
        r = __Pyx_PyObject_GetAttrStrNoError(o, n);
        if (unlikely(!r) && likely(!PyErr_Occurred())) {
            r = __Pyx_NewRef(d);
        }
        return r;
    }
  #endif
    r = PyObject_GetAttr(o, n);
    return (likely(r)) ? r : __Pyx_GetAttr3Default(d);
#endif
}

/* DictGetItem */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key) {
    PyObject *value;
    if (unlikely(__Pyx_PyDict_GetItemRef(d, key, &value) == 0)) { // no value, no error
        if (unlikely(PyTuple_Check(key))) {
            PyObject* args = PyTuple_Pack(1, key);
            if (likely(args)) {
                PyErr_SetObject(PyExc_KeyError, args);
                Py_DECREF(args);
            }
        } else {
            PyErr_SetObject(PyExc_KeyError, key);
        }
    }
    return value;
}
#endif

/* GetException */
#include "src/gevent/_generated_include/GetException_impl_36bcd44414c3b1ebf6a1c0f320ee2c6e2baced19353f70d825d0fd0338e3c175.h"
/* KeywordStringCheck */
#include "src/gevent/_generated_include/KeywordStringCheck_impl_ab906f68bdf90466d372bd85a39d7cf8593483145096621667739080797c0f42.h"
/* pyfrozenset_new (used by PySetContains) */
#include "src/gevent/_generated_include/pyfrozenset_new_impl_6d0cc855b17b4f36fd34ea40b1c34574f76580b50d8a268289346dd0eb4aafb2.h"
/* PySetContains */
static int __Pyx_PySet_ContainsUnhashable(PyObject *set, PyObject *key) {
    int result = -1;
    if (PySet_Check(key) && PyErr_ExceptionMatches(PyExc_TypeError)) {
        PyObject *tmpkey;
        PyErr_Clear();
        tmpkey = __Pyx_PyFrozenSet_New(key);
        if (tmpkey != NULL) {
            result = PySet_Contains(set, tmpkey);
            Py_DECREF(tmpkey);
        }
    }
    return result;
}
static CYTHON_INLINE int __Pyx_PySet_ContainsTF(PyObject* key, PyObject* set, int eq) {
    int result = PySet_Contains(set, key);
    if (unlikely(result < 0)) {
        result = __Pyx_PySet_ContainsUnhashable(set, key);
    }
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* GetAttr */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *o, PyObject *n) {
#if CYTHON_USE_TYPE_SLOTS
    if (likely(PyUnicode_Check(n)))
        return __Pyx_PyObject_GetAttrStr(o, n);
#endif
    return PyObject_GetAttr(o, n);
}

/* GetItemInt */
#include "src/gevent/_generated_include/GetItemInt_impl_057d6f270e739b86c6eeceee664d75d3caab665a9ec308b52b1fc08c260ccd28.h"
/* ObjectGetItem */
#if CYTHON_USE_TYPE_SLOTS
static PyObject *__Pyx_PyObject_GetIndex(PyObject *obj, PyObject *index) {
    PyObject *runerr = NULL;
    Py_ssize_t key_value;
    key_value = __Pyx_PyIndex_AsSsize_t(index);
    if (likely(key_value != -1 || !(runerr = PyErr_Occurred()))) {
        return __Pyx_GetItemInt_Fast(obj, key_value, 0, 1, 1, 1);
    }
    if (PyErr_GivenExceptionMatches(runerr, PyExc_OverflowError)) {
        __Pyx_TypeName index_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(index));
        PyErr_Clear();
        PyErr_Format(PyExc_IndexError,
            "cannot fit '" __Pyx_FMT_TYPENAME "' into an index-sized integer", index_type_name);
        __Pyx_DECREF_TypeName(index_type_name);
    }
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem_Slow(PyObject *obj, PyObject *key) {
    __Pyx_TypeName obj_type_name;
    if (likely(PyType_Check(obj))) {
        PyObject *meth = __Pyx_PyObject_GetAttrStrNoError(obj, __pyx_mstate_global->__pyx_n_u_class_getitem);
        if (!meth) {
            PyErr_Clear();
        } else {
            PyObject *result = __Pyx_PyObject_CallOneArg(meth, key);
            Py_DECREF(meth);
            return result;
        }
    }
    obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "'" __Pyx_FMT_TYPENAME "' object is not subscriptable", obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject *key) {
    PyTypeObject *tp = Py_TYPE(obj);
    PyMappingMethods *mm = tp->tp_as_mapping;
    PySequenceMethods *sm = tp->tp_as_sequence;
    if (likely(mm && mm->mp_subscript)) {
        return mm->mp_subscript(obj, key);
    }
    if (likely(sm && sm->sq_item)) {
        return __Pyx_PyObject_GetIndex(obj, key);
    }
    return __Pyx_PyObject_GetItem_Slow(obj, key);
}
#endif

/* HasAttr */
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *o, PyObject *n) {
    PyObject *r;
    if (unlikely(!PyUnicode_Check(n))) {
        PyErr_SetString(PyExc_TypeError,
                        "hasattr(): attribute name must be string");
        return -1;
    }
    r = __Pyx_PyObject_GetAttrStrNoError(o, n);
    if (!r) {
        return (unlikely(PyErr_Occurred())) ? -1 : 0;
    } else {
        Py_DECREF(r);
        return 1;
    }
}
#endif

/* PyObjectFormatAndDecref */
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatSimpleAndDecref(PyObject* s, PyObject* f) {
    if (unlikely(!s)) return NULL;
    if (likely(PyUnicode_CheckExact(s))) return s;
    return __Pyx_PyObject_FormatAndDecref(s, f);
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatAndDecref(PyObject* s, PyObject* f) {
    PyObject *result;
    if (unlikely(!s)) return NULL;
    result = PyObject_Format(s, f);
    Py_DECREF(s);
    return result;
}

/* JoinPyUnicode */
#include "src/gevent/_generated_include/JoinPyUnicode_impl_199e5554049cf0e6f79c238bd653d59e48f3389f2b94c2dd9cad4227096f0038.h"
/* PyDictVersioning */
#include "src/gevent/_generated_include/PyDictVersioning_impl_f179ad268abce9726a76569141f76d5dcd0550225ef9a9e9f73d478d7be0c345.h"
/* SliceTupleAndList */
#include "src/gevent/_generated_include/SliceTupleAndList_impl_3649de67df9cb91fc9f42395dbd0c1b1589e35fe22929fe9e0834046b8c389cb.h"
/* CallTypeTraverse */
#if !CYTHON_USE_TYPE_SPECS || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x03090000)
#else
static int __Pyx_call_type_traverse(PyObject *o, int always_call, visitproc visit, void *arg) {
    #if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x03090000
    if (__Pyx_get_runtime_version() < 0x03090000) return 0;
    #endif
    if (!always_call) {
        PyTypeObject *base = __Pyx_PyObject_GetSlot(o, tp_base, PyTypeObject*);
        unsigned long flags = PyType_GetFlags(base);
        if (flags & Py_TPFLAGS_HEAPTYPE) {
            return 0;
        }
    }
    Py_VISIT((PyObject*)Py_TYPE(o));
    return 0;
}
#endif

/* AllocateExtensionType */
static PyObject *__Pyx_AllocateExtensionType(PyTypeObject *t, int is_final) {
    if (is_final || likely(!__Pyx_PyType_HasFeature(t, Py_TPFLAGS_IS_ABSTRACT))) {
        allocfunc alloc_func = __Pyx_PyType_GetSlot(t, tp_alloc, allocfunc);
        return alloc_func(t, 0);
    } else {
        newfunc tp_new = __Pyx_PyType_TryGetSlot(&PyBaseObject_Type, tp_new, newfunc);
    #if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
        if (!tp_new) {
            PyObject *new_str = PyUnicode_FromString("__new__");
            if (likely(new_str)) {
                PyObject *o = PyObject_CallMethodObjArgs((PyObject *)&PyBaseObject_Type, new_str, t, NULL);
                Py_DECREF(new_str);
                return o;
            } else
                return NULL;
        } else
    #endif
        return tp_new(t, __pyx_mstate_global->__pyx_empty_tuple, 0);
    }
}

/* VoidPtrExport */
static int __Pyx_ExportVoidPtr(PyObject *api_dict, const char *name, void *p, const char *sig) {
    PyObject *cobj;
    cobj = PyCapsule_New(p, sig, 0);
    if (!cobj)
        goto bad;
    if (PyDict_SetItemString(api_dict, name, cobj) < 0)
        goto bad;
    Py_DECREF(cobj);
    return 0;
bad:
    Py_XDECREF(cobj);
    return -1;
}

/* GetApiDict */
static PyObject *__Pyx_ApiExport_GetApiDict(void) {
    PyObject *d;
    if (__Pyx_PyDict_GetItemRef(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_pyx_capi, &d) == -1)
        return NULL;
    if (!d) {
        d = PyDict_New();
        if (!d)
            goto bad;
        if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_pyx_capi, d) < 0)
            goto bad;
    }
    return d;
bad:
    Py_XDECREF(d);
    return NULL;
}

/* FunctionExport */
static int __Pyx_ExportFunction(PyObject *api_dict, const char *name, void (*f)(void), const char *sig) {
    PyObject *cobj;
    union {
        void (*fp)(void);
        void *p;
    } tmp;
    tmp.fp = f;
    cobj = PyCapsule_New(tmp.p, sig, 0);
    if (!cobj)
        goto bad;
    if (PyDict_SetItemString(api_dict, name, cobj) < 0)
        goto bad;
    Py_DECREF(cobj);
    return 0;
bad:
    Py_XDECREF(cobj);
    return -1;
}

/* TypeImport */
#include "src/gevent/_generated_include/TypeImport_impl_e30d056ae329ba5e94fee4709e4266a267c585bd5c229f7cd6121597afbfaa4e.h"
/* LimitedApiGetTypeDict (used by SetItemOnTypeDict) */
#include "src/gevent/_generated_include/LimitedApiGetTypeDict_impl_fd5385b0b7d81c54e35b8e8be86f2a48fa376c140ad1a251d94cb50d5e2fb049.h"
/* SetItemOnTypeDict (used by FixUpExtensionType) */
static int __Pyx__SetItemOnTypeDict(PyTypeObject *tp, PyObject *k, PyObject *v) {
    int result;
    PyObject *tp_dict;
#if CYTHON_COMPILING_IN_LIMITED_API
    tp_dict = __Pyx_GetTypeDict(tp);
    if (unlikely(!tp_dict)) return -1;
#else
    tp_dict = tp->tp_dict;
#endif
    result = PyDict_SetItem(tp_dict, k, v);
    if (likely(!result)) {
        PyType_Modified(tp);
        if (unlikely(PyObject_HasAttr(v, __pyx_mstate_global->__pyx_n_u_set_name))) {
            PyObject *setNameResult = PyObject_CallMethodObjArgs(v, __pyx_mstate_global->__pyx_n_u_set_name,  (PyObject *) tp, k, NULL);
            if (!setNameResult) return -1;
            Py_DECREF(setNameResult);
        }
    }
    return result;
}

/* FixUpExtensionType */
#include "src/gevent/_generated_include/FixUpExtensionType_impl_968625585c074793d4236a363113043104c99af679f80b0b7d0ea5e03b43f419.h"
/* FormatTypeName (used by ValidateExternBase) */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030d0000
static __Pyx_TypeName
__Pyx_PyType_GetFullyQualifiedName(PyTypeObject* tp)
{
    PyObject *module = NULL, *name = NULL, *result = NULL;
    #if __PYX_LIMITED_VERSION_HEX < 0x030b0000
    name = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_mstate_global->__pyx_n_u_qualname);
    #else
    name = PyType_GetQualName(tp);
    #endif
    if (unlikely(name == NULL) || unlikely(!PyUnicode_Check(name))) goto bad;
    module = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_mstate_global->__pyx_n_u_module);
    if (unlikely(module == NULL) || unlikely(!PyUnicode_Check(module))) goto bad;
    if (PyUnicode_CompareWithASCIIString(module, "builtins") == 0) {
        result = name;
        name = NULL;
        goto done;
    }
    result = PyUnicode_FromFormat("%U.%U", module, name);
    if (unlikely(result == NULL)) goto bad;
  done:
    Py_XDECREF(name);
    Py_XDECREF(module);
    return result;
  bad:
    PyErr_Clear();
    if (name) {
        result = name;
        name = NULL;
    } else {
        result = __Pyx_NewRef(__pyx_mstate_global->__pyx_kp_u__2);
    }
    goto done;
}
#endif

/* ValidateExternBase */
static int __Pyx_validate_extern_base(PyTypeObject *base) {
    Py_ssize_t itemsize;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_itemsize;
#endif
#if !CYTHON_COMPILING_IN_LIMITED_API
    itemsize = ((PyTypeObject *)base)->tp_itemsize;
#else
    py_itemsize = PyObject_GetAttrString((PyObject*)base, "__itemsize__");
    if (!py_itemsize)
        return -1;
    itemsize = PyLong_AsSsize_t(py_itemsize);
    Py_DECREF(py_itemsize);
    py_itemsize = 0;
    if (itemsize == (Py_ssize_t)-1 && PyErr_Occurred())
        return -1;
#endif
    if (itemsize) {
        __Pyx_TypeName b_name = __Pyx_PyType_GetFullyQualifiedName(base);
        PyErr_Format(PyExc_TypeError,
                "inheritance from PyVarObject types like '" __Pyx_FMT_TYPENAME "' not currently supported", b_name);
        __Pyx_DECREF_TypeName(b_name);
        return -1;
    }
    return 0;
}

/* ValidateBasesTuple (used by PyType_Ready) */
#include "src/gevent/_generated_include/ValidateBasesTuple_impl_3b9fdcb5e55f23d97a6405040c32f85cd06688a92f7d1964c3b28bc807f560c9.h"
/* PyType_Ready */
CYTHON_UNUSED static int __Pyx_PyType_HasMultipleInheritance(PyTypeObject *t) {
    while (t) {
        PyObject *bases = __Pyx_PyType_GetSlot(t, tp_bases, PyObject*);
        if (bases) {
            return 1;
        }
        t = __Pyx_PyType_GetSlot(t, tp_base, PyTypeObject*);
    }
    return 0;
}
static int __Pyx_PyType_Ready(PyTypeObject *t) {
#if CYTHON_USE_TYPE_SPECS || !CYTHON_COMPILING_IN_CPYTHON || defined(PYSTON_MAJOR_VERSION)
    (void)__Pyx_PyObject_CallMethod0;
#if CYTHON_USE_TYPE_SPECS
    (void)__Pyx_validate_bases_tuple;
#endif
    return PyType_Ready(t);
#else
    int r;
    if (!__Pyx_PyType_HasMultipleInheritance(t)) {
        return PyType_Ready(t);
    }
    PyObject *bases = __Pyx_PyType_GetSlot(t, tp_bases, PyObject*);
    if (bases && unlikely(__Pyx_validate_bases_tuple(t->tp_name, t->tp_dictoffset, bases) == -1))
        return -1;
#if !defined(PYSTON_MAJOR_VERSION)
    {
        int gc_was_enabled;
    #if PY_VERSION_HEX >= 0x030A00b1
        gc_was_enabled = PyGC_Disable();
        (void)__Pyx_PyObject_CallMethod0;
    #else
        PyObject *ret, *py_status;
        PyObject *gc = NULL;
        #if (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM+0 >= 0x07030400) &&\
                !CYTHON_COMPILING_IN_GRAAL
        gc = PyImport_GetModule(__pyx_mstate_global->__pyx_kp_u_gc);
        #endif
        if (unlikely(!gc)) gc = PyImport_Import(__pyx_mstate_global->__pyx_kp_u_gc);
        if (unlikely(!gc)) return -1;
        py_status = __Pyx_PyObject_CallMethod0(gc, __pyx_mstate_global->__pyx_kp_u_isenabled);
        if (unlikely(!py_status)) {
            Py_DECREF(gc);
            return -1;
        }
        gc_was_enabled = __Pyx_PyObject_IsTrue(py_status);
        Py_DECREF(py_status);
        if (gc_was_enabled > 0) {
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_mstate_global->__pyx_kp_u_disable);
            if (unlikely(!ret)) {
                Py_DECREF(gc);
                return -1;
            }
            Py_DECREF(ret);
        } else if (unlikely(gc_was_enabled == -1)) {
            Py_DECREF(gc);
            return -1;
        }
    #endif
        t->tp_flags |= Py_TPFLAGS_HEAPTYPE;
#if PY_VERSION_HEX >= 0x030A0000
        t->tp_flags |= Py_TPFLAGS_IMMUTABLETYPE;
#endif
#else
        (void)__Pyx_PyObject_CallMethod0;
#endif
    r = PyType_Ready(t);
#if !defined(PYSTON_MAJOR_VERSION)
        t->tp_flags &= ~Py_TPFLAGS_HEAPTYPE;
    #if PY_VERSION_HEX >= 0x030A00b1
        if (gc_was_enabled)
            PyGC_Enable();
    #else
        if (gc_was_enabled) {
            PyObject *tp, *v, *tb;
            PyErr_Fetch(&tp, &v, &tb);
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_mstate_global->__pyx_kp_u_enable);
            if (likely(ret || r == -1)) {
                Py_XDECREF(ret);
                PyErr_Restore(tp, v, tb);
            } else {
                Py_XDECREF(tp);
                Py_XDECREF(v);
                Py_XDECREF(tb);
                r = -1;
            }
        }
        Py_DECREF(gc);
    #endif
    }
#endif
    return r;
#endif
}

/* SetVTable */
static int __Pyx_SetVtable(PyTypeObject *type, void *vtable) {
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
    if (unlikely(!ob))
        goto bad;
#if CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(PyObject_SetAttr((PyObject *) type, __pyx_mstate_global->__pyx_n_u_pyx_vtable, ob) < 0))
#else
    if (unlikely(PyDict_SetItem(type->tp_dict, __pyx_mstate_global->__pyx_n_u_pyx_vtable, ob) < 0))
#endif
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

/* GetVTable (used by MergeVTables) */
static void* __Pyx_GetVtable(PyTypeObject *type) {
    void* ptr;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *ob = PyObject_GetAttr((PyObject *)type, __pyx_mstate_global->__pyx_n_u_pyx_vtable);
#else
    PyObject *ob = PyObject_GetItem(type->tp_dict, __pyx_mstate_global->__pyx_n_u_pyx_vtable);
#endif
    if (!ob)
        goto bad;
    ptr = PyCapsule_GetPointer(ob, 0);
    if (!ptr && !PyErr_Occurred())
        PyErr_SetString(PyExc_RuntimeError, "invalid vtable found for imported type");
    Py_DECREF(ob);
    return ptr;
bad:
    Py_XDECREF(ob);
    return NULL;
}

/* MergeVTables */
#include "src/gevent/_generated_include/MergeVTables_impl_cc0b823a0ed067bdca31ab6afca82ec940b10d68e9ecebbaec0a3d49b6244e8c.h"
/* PxdImportShared (used by VoidPtrImport) */
#include "src/gevent/_generated_include/PxdImportShared_impl_df92e4b607edac2b8480e2c8668970e8115d694234fa83cf1c26cb7dc602ab00.h"
/* VoidPtrImport */
#ifndef __PYX_HAVE_RT_ImportVoidPtr_3_2_4
#define __PYX_HAVE_RT_ImportVoidPtr_3_2_4
static int __Pyx_ImportVoidPtr_3_2_4(PyObject *module, const char *name, void **p, const char *sig) {
    return __Pyx_ImportFromPxd_3_2_4(module, name, p, sig, "variable");
}
#endif

/* FunctionImport */
#ifndef __PYX_HAVE_RT_ImportFunction_3_2_4
#define __PYX_HAVE_RT_ImportFunction_3_2_4
static int __Pyx_ImportFunction_3_2_4(PyObject *module, const char *funcname, void (**f)(void), const char *sig) {
    union {
        void (*fp)(void);
        void *p;
    } tmp;
    int result = __Pyx_ImportFromPxd_3_2_4(module, funcname, &tmp.p, sig, "function");
    if (result == 0) {
        *f = tmp.fp;
    }
    return result;
}
#endif

/* ImportImpl (used by Import) */
#include "src/gevent/_generated_include/ImportImpl_impl_54add44d3961eb3adfb567f9d1292a4ce092acafbf7b2d11f026c8e90ea281d3.h"
/* Import */
static PyObject *__Pyx_Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, int level) {
    return __Pyx__Import(name, imported_names, len_imported_names, qualname, __pyx_mstate_global->__pyx_d, level);
}

/* ImportFrom */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        const char* module_name_str = 0;
        PyObject* module_name = 0;
        PyObject* module_dot = 0;
        PyObject* full_name = 0;
        PyErr_Clear();
        module_name_str = PyModule_GetName(module);
        if (unlikely(!module_name_str)) { goto modbad; }
        module_name = PyUnicode_FromString(module_name_str);
        if (unlikely(!module_name)) { goto modbad; }
        module_dot = PyUnicode_Concat(module_name, __pyx_mstate_global->__pyx_kp_u__3);
        if (unlikely(!module_dot)) { goto modbad; }
        full_name = PyUnicode_Concat(module_dot, name);
        if (unlikely(!full_name)) { goto modbad; }
        #if (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM  < 0x07030400) ||\
                CYTHON_COMPILING_IN_GRAAL
        {
            PyObject *modules = PyImport_GetModuleDict();
            if (unlikely(!modules))
                goto modbad;
            value = PyObject_GetItem(modules, full_name);
        }
        #else
        value = PyImport_GetModule(full_name);
        #endif
      modbad:
        Py_XDECREF(full_name);
        Py_XDECREF(module_dot);
        Py_XDECREF(module_name);
    }
    if (unlikely(!value)) {
        PyErr_Format(PyExc_ImportError, "cannot import name %S", name);
    }
    return value;
}

/* dict_setdefault (used by FetchCommonType) */
static CYTHON_INLINE PyObject *__Pyx_PyDict_SetDefault(PyObject *d, PyObject *key, PyObject *default_value) {
    PyObject* value;
#if __PYX_LIMITED_VERSION_HEX >= 0x030F0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4)
    PyDict_SetDefaultRef(d, key, default_value, &value);
#elif CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX >= 0x030C0000
    PyObject *args[] = {d, key, default_value};
    value = PyObject_VectorcallMethod(__pyx_mstate_global->__pyx_n_u_setdefault, args, 3 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#elif CYTHON_COMPILING_IN_LIMITED_API
    value = PyObject_CallMethodObjArgs(d, __pyx_mstate_global->__pyx_n_u_setdefault, key, default_value, NULL);
#else
    value = PyDict_SetDefault(d, key, default_value);
    if (unlikely(!value)) return NULL;
    Py_INCREF(value);
#endif
    return value;
}

/* AddModuleRef (used by FetchSharedCythonModule) */
#include "src/gevent/_generated_include/AddModuleRef_impl_59efe7a55c2d1acdb632a2a6953f1ce31c634c9f98f262a8d338db6996845385.h"
/* FetchSharedCythonModule (used by FetchCommonType) */
static PyObject *__Pyx_FetchSharedCythonABIModule(void) {
    return __Pyx_PyImport_AddModuleRef(__PYX_ABI_MODULE_NAME);
}

/* FetchCommonType (used by CommonTypesMetaclass) */
#include "src/gevent/_generated_include/FetchCommonType_impl_8ddf5d6e0d45314935e4d87502d7fa32ec8f3d50d91ca9715a35d7f0fc2dda28.h"
/* CommonTypesMetaclass (used by CythonFunctionShared) */
#include "src/gevent/_generated_include/CommonTypesMetaclass_impl_5345023feb7cb35c8a99997be95973c1bfc904b959ef880ae7125f77d296af2b.h"
/* PyMethodNew (used by CythonFunctionShared) */
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    PyObject *result;
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    #if __PYX_LIMITED_VERSION_HEX >= 0x030C0000
    {
        PyObject *args[] = {func, self};
        result = PyObject_Vectorcall(__pyx_mstate_global->__Pyx_CachedMethodType, args, 2, NULL);
    }
    #else
    result = PyObject_CallFunctionObjArgs(__pyx_mstate_global->__Pyx_CachedMethodType, func, self, NULL);
    #endif
    return result;
}
#else
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    return PyMethod_New(func, self);
}
#endif

/* PyVectorcallFastCallDict (used by CythonFunctionShared) */
#include "src/gevent/_generated_include/PyVectorcallFastCallDict_impl_3616dfa798c1c336b0933a7ec9d88cb291d491f6315b48f846f69828df4619eb.h"
/* CythonFunctionShared (used by CythonFunction) */
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunctionNoMethod(PyObject *func, void (*cfunc)(void)) {
    if (__Pyx_CyFunction_Check(func)) {
        return PyCFunction_GetFunction(((__pyx_CyFunctionObject*)func)->func) == (PyCFunction) cfunc;
    } else if (PyCFunction_Check(func)) {
        return PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void (*cfunc)(void)) {
    if ((PyObject*)Py_TYPE(func) == __pyx_mstate_global->__Pyx_CachedMethodType) {
        int result;
        PyObject *newFunc = PyObject_GetAttr(func, __pyx_mstate_global->__pyx_n_u_func);
        if (unlikely(!newFunc)) {
            PyErr_Clear(); // It's only an optimization, so don't throw an error
            return 0;
        }
        result = __Pyx__IsSameCyOrCFunctionNoMethod(newFunc, cfunc);
        Py_DECREF(newFunc);
        return result;
    }
    return __Pyx__IsSameCyOrCFunctionNoMethod(func, cfunc);
}
#else
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void (*cfunc)(void)) {
    if (PyMethod_Check(func)) {
        func = PyMethod_GET_FUNCTION(func);
    }
    return __Pyx_CyOrPyCFunction_Check(func) && __Pyx_CyOrPyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
}
#endif
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj) {
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    __Pyx_Py_XDECREF_SET(
        __Pyx_CyFunction_GetClassObj(f),
            ((classobj) ? __Pyx_NewRef(classobj) : NULL));
#else
    __Pyx_Py_XDECREF_SET(
        ((PyCMethodObject *) (f))->mm_class,
        (PyTypeObject*)((classobj) ? __Pyx_NewRef(classobj) : NULL));
#endif
}
static PyObject *
__Pyx_CyFunction_get_doc_locked(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_doc == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_doc = PyObject_GetAttrString(op->func, "__doc__");
        if (unlikely(!op->func_doc)) return NULL;
#else
        if (((PyCFunctionObject*)op)->m_ml->ml_doc) {
            op->func_doc = PyUnicode_FromString(((PyCFunctionObject*)op)->m_ml->ml_doc);
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
#endif
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, void *closure) {
    PyObject *result;
    CYTHON_UNUSED_VAR(closure);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_doc_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (value == NULL) {
        value = Py_None;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_doc, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name_locked(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_name == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_name = PyObject_GetAttrString(op->func, "__name__");
#else
        op->func_name = PyUnicode_InternFromString(((PyCFunctionObject*)op)->m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op, void *context)
{
    PyObject *result = NULL;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_name_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_name, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    PyObject *result;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    Py_INCREF(op->func_qualname);
    result = op->func_qualname;
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_qualname, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
#endif
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(op);
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op, void *context)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    int result = 0;
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    #else
    op->defaults_tuple = __Pyx_PySequence_ITEM(res, 0);
    if (unlikely(!op->defaults_tuple)) result = -1;
    else {
        op->defaults_kwdict = __Pyx_PySequence_ITEM(res, 1);
        if (unlikely(!op->defaults_kwdict)) result = -1;
    }
    #endif
    Py_DECREF(res);
    return result;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyTuple_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__defaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->defaults_tuple, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_tuple;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = NULL;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_defaults_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__kwdefaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->defaults_kwdict, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_kwdict;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_kwdefaults_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value || value == Py_None) {
        value = NULL;
    } else if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_annotations, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->func_annotations;
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op, void *context) {
    PyObject *result;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_annotations_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static PyObject *
__Pyx_CyFunction_get_is_coroutine_value(__pyx_CyFunctionObject *op) {
    int is_coroutine = op->flags & __Pyx_CYFUNCTION_COROUTINE;
    if (is_coroutine) {
        PyObject *is_coroutine_value, *module, *fromlist, *marker = __pyx_mstate_global->__pyx_n_u_is_coroutine;
        fromlist = PyList_New(1);
        if (unlikely(!fromlist)) return NULL;
        Py_INCREF(marker);
#if CYTHON_ASSUME_SAFE_MACROS
        PyList_SET_ITEM(fromlist, 0, marker);
#else
        if (unlikely(PyList_SetItem(fromlist, 0, marker) < 0)) {
            Py_DECREF(marker);
            Py_DECREF(fromlist);
            return NULL;
        }
#endif
        module = PyImport_ImportModuleLevelObject(__pyx_mstate_global->__pyx_n_u_asyncio_coroutines, NULL, NULL, fromlist, 0);
        Py_DECREF(fromlist);
        if (unlikely(!module)) goto ignore;
        is_coroutine_value = __Pyx_PyObject_GetAttrStr(module, marker);
        Py_DECREF(module);
        if (likely(is_coroutine_value)) {
            return is_coroutine_value;
        }
ignore:
        PyErr_Clear();
    }
    return __Pyx_PyBool_FromLong(is_coroutine);
}
static PyObject *
__Pyx_CyFunction_get_is_coroutine(__pyx_CyFunctionObject *op, void *context) {
    PyObject *result;
    CYTHON_UNUSED_VAR(context);
    if (op->func_is_coroutine) {
        return __Pyx_NewRef(op->func_is_coroutine);
    }
    result = __Pyx_CyFunction_get_is_coroutine_value(op);
    if (unlikely(!result))
        return NULL;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    if (op->func_is_coroutine) {
        Py_DECREF(result);
        result = __Pyx_NewRef(op->func_is_coroutine);
    } else {
        op->func_is_coroutine = __Pyx_NewRef(result);
    }
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static void __Pyx_CyFunction_raise_argument_count_error(__pyx_CyFunctionObject *func, const char* message, Py_ssize_t size) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_name = __Pyx_CyFunction_get_name(func, NULL);
    if (!py_name) return;
    PyErr_Format(PyExc_TypeError,
        "%.200S() %s (%" CYTHON_FORMAT_SSIZE_T "d given)",
        py_name, message, size);
    Py_DECREF(py_name);
#else
    const char* name = ((PyCFunctionObject*)func)->m_ml->ml_name;
    PyErr_Format(PyExc_TypeError,
        "%.200s() %s (%" CYTHON_FORMAT_SSIZE_T "d given)",
        name, message, size);
#endif
}
static void __Pyx_CyFunction_raise_type_error(__pyx_CyFunctionObject *func, const char* message) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_name = __Pyx_CyFunction_get_name(func, NULL);
    if (!py_name) return;
    PyErr_Format(PyExc_TypeError,
        "%.200S() %s",
        py_name, message);
    Py_DECREF(py_name);
#else
    const char* name = ((PyCFunctionObject*)func)->m_ml->ml_name;
    PyErr_Format(PyExc_TypeError,
        "%.200s() %s",
        name, message);
#endif
}
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *
__Pyx_CyFunction_get_module(__pyx_CyFunctionObject *op, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_GetAttrString(op->func, "__module__");
}
static int
__Pyx_CyFunction_set_module(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_SetAttrString(op->func, "__module__", value);
}
#endif
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {"func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {"__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {"func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {"__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {"__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
    {"func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)PyObject_GenericSetDict, 0, 0},
    {"__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)PyObject_GenericSetDict, 0, 0},
#else
    {"func_dict", (getter)PyObject_GenericGetDict, (setter)PyObject_GenericSetDict, 0, 0},
    {"__dict__", (getter)PyObject_GenericGetDict, (setter)PyObject_GenericSetDict, 0, 0},
#endif
    {"func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {"__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {"func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {"__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {"func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {"__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {"func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {"__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {"__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {"__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {"_is_coroutine", (getter)__Pyx_CyFunction_get_is_coroutine, 0, 0, 0},
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__module__", (getter)__Pyx_CyFunction_get_module, (setter)__Pyx_CyFunction_set_module, 0, 0},
#endif
    {0, 0, 0, 0, 0}
};
static PyMemberDef __pyx_CyFunction_members[] = {
#if !CYTHON_COMPILING_IN_LIMITED_API
    {"__module__", T_OBJECT, offsetof(PyCFunctionObject, m_module), 0, 0},
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    {"__dictoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_dict), READONLY, 0},
#endif
#if CYTHON_METH_FASTCALL
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__vectorcalloffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_vectorcall), READONLY, 0},
#else
    {"__vectorcalloffset__", T_PYSSIZET, offsetof(PyCFunctionObject, vectorcall), READONLY, 0},
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__weaklistoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_weakreflist), READONLY, 0},
#else
    {"__weaklistoffset__", T_PYSSIZET, offsetof(PyCFunctionObject, m_weakreflist), READONLY, 0},
#endif
#endif
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, PyObject *args)
{
    PyObject *result = NULL;
    CYTHON_UNUSED_VAR(args);
    __Pyx_BEGIN_CRITICAL_SECTION(m);
    Py_INCREF(m->func_qualname);
    result = m->func_qualname;
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {"__reduce__", (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
#if CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func_weakreflist)
#else
#define __Pyx_CyFunction_weakreflist(cyfunc) (((PyCFunctionObject*)cyfunc)->m_weakreflist)
#endif
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject *op, PyMethodDef *ml, int flags, PyObject* qualname,
                                       PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
#if !CYTHON_COMPILING_IN_LIMITED_API
    PyCFunctionObject *cf = (PyCFunctionObject*) op;
#endif
    if (unlikely(op == NULL))
        return NULL;
#if CYTHON_COMPILING_IN_LIMITED_API
    op->func = PyCFunction_NewEx(ml, (PyObject*)op, module);
    if (unlikely(!op->func)) return NULL;
#endif
    op->flags = flags;
    __Pyx_CyFunction_weakreflist(op) = NULL;
#if !CYTHON_COMPILING_IN_LIMITED_API
    cf->m_ml = ml;
    cf->m_self = (PyObject *) op;
#endif
    Py_XINCREF(closure);
    op->func_closure = closure;
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_XINCREF(module);
    cf->m_module = module;
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    op->func_dict = NULL;
#endif
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    op->func_classobj = NULL;
#else
    ((PyCMethodObject*)op)->mm_class = NULL;
#endif
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    op->func_is_coroutine = NULL;
#if CYTHON_METH_FASTCALL
    switch (ml->ml_flags & (METH_VARARGS | METH_FASTCALL | METH_NOARGS | METH_O | METH_KEYWORDS | METH_METHOD)) {
    case METH_NOARGS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_NOARGS;
        break;
    case METH_O:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_O;
        break;
    case METH_METHOD | METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD;
        break;
    case METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS;
        break;
    case METH_VARARGS | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = NULL;
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        Py_DECREF(op);
        return NULL;
    }
#endif
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_CLEAR(m->func);
#else
    Py_CLEAR(((PyCFunctionObject*)m)->m_module);
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    Py_CLEAR(m->func_dict);
#elif PY_VERSION_HEX < 0x030d0000
    _PyObject_ClearManagedDict((PyObject*)m);
#else
    PyObject_ClearManagedDict((PyObject*)m);
#endif
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
#if PY_VERSION_HEX < 0x030900B1
    Py_CLEAR(__Pyx_CyFunction_GetClassObj(m));
#else
    {
        PyObject *cls = (PyObject*) ((PyCMethodObject *) (m))->mm_class;
        ((PyCMethodObject *) (m))->mm_class = NULL;
        Py_XDECREF(cls);
    }
#endif
#endif
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    Py_CLEAR(m->func_is_coroutine);
    Py_CLEAR(m->defaults);
    return 0;
}
static void __Pyx__CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    if (__Pyx_CyFunction_weakreflist(m) != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    __Pyx_PyHeapTypeObject_GC_Del(m);
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    __Pyx__CyFunction_dealloc(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    {
        int e = __Pyx_call_type_traverse((PyObject*)m, 1, visit, arg);
        if (e) return e;
    }
    Py_VISIT(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(m->func);
#else
    Py_VISIT(((PyCFunctionObject*)m)->m_module);
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(m->func_dict);
#else
    {
        int e =
#if PY_VERSION_HEX < 0x030d0000
            _PyObject_VisitManagedDict
#else
            PyObject_VisitManagedDict
#endif
                ((PyObject*)m, visit, arg);
        if (e != 0) return e;
    }
#endif
    __Pyx_VISIT_CONST(m->func_name);
    __Pyx_VISIT_CONST(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    __Pyx_VISIT_CONST(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(__Pyx_CyFunction_GetClassObj(m));
#endif
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    Py_VISIT(m->func_is_coroutine);
    Py_VISIT(m->defaults);
    return 0;
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
    PyObject *repr;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    repr = PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
    __Pyx_END_CRITICAL_SECTION();
    return repr;
}
static PyObject * __Pyx_CyFunction_CallMethod(PyObject *func, PyObject *self, PyObject *arg, PyObject *kw) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *f = ((__pyx_CyFunctionObject*)func)->func;
    PyCFunction meth;
    int flags;
    meth = PyCFunction_GetFunction(f);
    if (unlikely(!meth)) return NULL;
    flags = PyCFunction_GetFlags(f);
    if (unlikely(flags < 0)) return NULL;
#else
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = f->m_ml->ml_meth;
    int flags = f->m_ml->ml_flags;
#endif
    Py_ssize_t size;
    switch (flags & (METH_VARARGS | METH_KEYWORDS | METH_NOARGS | METH_O)) {
    case METH_VARARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0))
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)(void(*)(void))meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_SIZE
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 0))
                return (*meth)(self, NULL);
            __Pyx_CyFunction_raise_argument_count_error(
                (__pyx_CyFunctionObject*)func,
                "takes no arguments", size);
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_SIZE
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 1)) {
                PyObject *result, *arg0;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                arg0 = PyTuple_GET_ITEM(arg, 0);
                #else
                arg0 = __Pyx_PySequence_ITEM(arg, 0); if (unlikely(!arg0)) return NULL;
                #endif
                result = (*meth)(self, arg0);
                #if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
                Py_DECREF(arg0);
                #endif
                return result;
            }
            __Pyx_CyFunction_raise_argument_count_error(
                (__pyx_CyFunctionObject*)func,
                "takes exactly one argument", size);
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        return NULL;
    }
    __Pyx_CyFunction_raise_type_error(
        (__pyx_CyFunctionObject*)func, "takes no keyword arguments");
    return NULL;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *self, *result;
#if CYTHON_COMPILING_IN_LIMITED_API
    self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)func)->func);
    if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
    self = ((PyCFunctionObject*)func)->m_self;
#endif
    result = __Pyx_CyFunction_CallMethod(func, self, arg, kw);
    return result;
}
static PyObject *__Pyx_CyFunction_CallAsMethod(PyObject *func, PyObject *args, PyObject *kw) {
    PyObject *result;
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
     __pyx_vectorcallfunc vc = __Pyx_CyFunction_func_vectorcall(cyfunc);
    if (vc) {
#if CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE
        return __Pyx_PyVectorcall_FastCallDict(func, vc, &PyTuple_GET_ITEM(args, 0), (size_t)PyTuple_GET_SIZE(args), kw);
#else
        (void) &__Pyx_PyVectorcall_FastCallDict;
        return PyVectorcall_Call(func, args, kw);
#endif
    }
#endif
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        Py_ssize_t argc;
        PyObject *new_args;
        PyObject *self;
#if CYTHON_ASSUME_SAFE_SIZE
        argc = PyTuple_GET_SIZE(args);
#else
        argc = PyTuple_Size(args);
        if (unlikely(argc < 0)) return NULL;
#endif
        new_args = PyTuple_GetSlice(args, 1, argc);
        if (unlikely(!new_args))
            return NULL;
        self = PyTuple_GetItem(args, 0);
        if (unlikely(!self)) {
            Py_DECREF(new_args);
            PyErr_Format(PyExc_TypeError,
                         "unbound method %.200S() needs an argument",
                         cyfunc->func_qualname);
            return NULL;
        }
        result = __Pyx_CyFunction_CallMethod(func, self, new_args, kw);
        Py_DECREF(new_args);
    } else {
        result = __Pyx_CyFunction_Call(func, args, kw);
    }
    return result;
}
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
static CYTHON_INLINE int __Pyx_CyFunction_Vectorcall_CheckArgs(__pyx_CyFunctionObject *cyfunc, Py_ssize_t nargs, PyObject *kwnames)
{
    int ret = 0;
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        if (unlikely(nargs < 1)) {
            __Pyx_CyFunction_raise_type_error(
                cyfunc, "needs an argument");
            return -1;
        }
        ret = 1;
    }
    if (unlikely(kwnames) && unlikely(__Pyx_PyTuple_GET_SIZE(kwnames))) {
        __Pyx_CyFunction_raise_type_error(
            cyfunc, "takes no keyword arguments");
        return -1;
    }
    return ret;
}
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 0)) {
        __Pyx_CyFunction_raise_argument_count_error(
            cyfunc, "takes no arguments", nargs);
        return NULL;
    }
    return meth(self, NULL);
}
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 1)) {
        __Pyx_CyFunction_raise_argument_count_error(
            cyfunc, "takes exactly one argument", nargs);
        return NULL;
    }
    return meth(self, args[0]);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    return ((__Pyx_PyCFunctionFastWithKeywords)(void(*)(void))meth)(self, args, nargs, kwnames);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyTypeObject *cls = (PyTypeObject *) __Pyx_CyFunction_GetClassObj(cyfunc);
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    #if PY_VERSION_HEX < 0x030e00A6
    size_t nargs_value = (size_t) nargs;
    #else
    Py_ssize_t nargs_value = nargs;
    #endif
    return ((__Pyx_PyCMethod)(void(*)(void))meth)(self, cls, args, nargs_value, kwnames);
}
#endif
static PyType_Slot __pyx_CyFunctionType_slots[] = {
    {Py_tp_dealloc, (void *)__Pyx_CyFunction_dealloc},
    {Py_tp_repr, (void *)__Pyx_CyFunction_repr},
    {Py_tp_call, (void *)__Pyx_CyFunction_CallAsMethod},
    {Py_tp_traverse, (void *)__Pyx_CyFunction_traverse},
    {Py_tp_clear, (void *)__Pyx_CyFunction_clear},
    {Py_tp_methods, (void *)__pyx_CyFunction_methods},
    {Py_tp_members, (void *)__pyx_CyFunction_members},
    {Py_tp_getset, (void *)__pyx_CyFunction_getsets},
    {Py_tp_descr_get, (void *)__Pyx_PyMethod_New},
    {0, 0},
};
static PyType_Spec __pyx_CyFunctionType_spec = {
    __PYX_TYPE_MODULE_PREFIX "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
#ifdef Py_TPFLAGS_METHOD_DESCRIPTOR
    Py_TPFLAGS_METHOD_DESCRIPTOR |
#endif
#if CYTHON_METH_FASTCALL
#if defined(Py_TPFLAGS_HAVE_VECTORCALL)
    Py_TPFLAGS_HAVE_VECTORCALL |
#elif defined(_Py_TPFLAGS_HAVE_VECTORCALL)
    _Py_TPFLAGS_HAVE_VECTORCALL |
#endif
#endif // CYTHON_METH_FASTCALL
#if PY_VERSION_HEX >= 0x030C0000 && !CYTHON_COMPILING_IN_LIMITED_API
    Py_TPFLAGS_MANAGED_DICT |
#endif
    Py_TPFLAGS_IMMUTABLETYPE | Py_TPFLAGS_DISALLOW_INSTANTIATION |
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    __pyx_CyFunctionType_slots
};
static int __pyx_CyFunction_init(PyObject *module) {
    __pyx_mstatetype *mstate = __Pyx_PyModule_GetState(module);
    mstate->__pyx_CyFunctionType = __Pyx_FetchCommonTypeFromSpec(
        mstate->__pyx_CommonTypesMetaclassType, module, &__pyx_CyFunctionType_spec, NULL);
    if (unlikely(mstate->__pyx_CyFunctionType == NULL)) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_InitDefaults(PyObject *func, PyTypeObject *defaults_type) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyObject_CallObject((PyObject*)defaults_type, NULL); // _PyObject_New(defaults_type);
    if (unlikely(!m->defaults))
        return NULL;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

/* CythonFunction */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    PyObject *op = __Pyx_CyFunction_Init(
        PyObject_GC_New(__pyx_CyFunctionObject, __pyx_mstate_global->__pyx_CyFunctionType),
        ml, flags, qualname, closure, module, globals, code
    );
    if (likely(op)) {
        PyObject_GC_Track(op);
    }
    return op;
}

/* ListPack */
static PyObject *__Pyx_PyList_Pack(Py_ssize_t n, ...) {
    va_list va;
    PyObject *l = PyList_New(n);
    va_start(va, n);
    if (unlikely(!l)) goto end;
    for (Py_ssize_t i=0; i<n; ++i) {
        PyObject *arg = va_arg(va, PyObject*);
        Py_INCREF(arg);
        if (__Pyx_PyList_SET_ITEM(l, i, arg) != (0)) {
            Py_CLEAR(l);
            goto end;
        }
    }
    end:
    va_end(va);
    return l;
}

/* GetModuleGlobalName */
#include "src/gevent/_generated_include/GetModuleGlobalName_impl_b2394fa294c641220c991c48f5c953347ba392e1233755a6228b28d5e679fef0.h"
/* PyObjectSetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
    return PyObject_SetAttr(obj, attr_name, value);
}
#endif

/* Globals */
static PyObject* __Pyx_Globals(void) {
    return __Pyx_NewRef(__pyx_mstate_global->__pyx_d);
}

/* CLineInTraceback (used by AddTraceback) */
#if CYTHON_CLINE_IN_TRACEBACK && CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
#define __Pyx_PyProbablyModule_GetDict(o) __Pyx_XNewRef(PyModule_GetDict(o))
#elif !CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyProbablyModule_GetDict(o) PyObject_GenericGetDict(o, NULL);
#else
PyObject* __Pyx_PyProbablyModule_GetDict(PyObject *o) {
    PyObject **dict_ptr = _PyObject_GetDictPtr(o);
    return dict_ptr ? __Pyx_XNewRef(*dict_ptr) : NULL;
}
#endif
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line) {
    PyObject *use_cline = NULL;
    PyObject *ptype, *pvalue, *ptraceback;
    PyObject *cython_runtime_dict;
    CYTHON_MAYBE_UNUSED_VAR(tstate);
    if (unlikely(!__pyx_mstate_global->__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
    cython_runtime_dict = __Pyx_PyProbablyModule_GetDict(__pyx_mstate_global->__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, cython_runtime_dict,
            __Pyx_PyDict_SetDefault(cython_runtime_dict, __pyx_mstate_global->__pyx_n_u_cline_in_traceback, Py_False))
    }
    if (use_cline == NULL || use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    Py_XDECREF(use_cline);
    Py_XDECREF(cython_runtime_dict);
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache (used by AddTraceback) */
#include "src/gevent/_generated_include/CodeObjectCache_impl_ffc81bf87e547a82e6009d64a2466eb1a5f6677afcbab3333a029ea24e45c012.h"
/* AddTraceback */
#include "src/gevent/_generated_include/AddTraceback_impl_5c53b964023228d90bdfcfa91919f5c3c484446268d5ef056f29421d654f5af4.h"
/* PyObjectVectorCallKwBuilder (used by CIntToPy) */
#include "src/gevent/_generated_include/PyObjectVectorCallKwBuilder_impl_fd859cdb6cbc3b35f6b10f5733f06af41f621c00f218f3658f8b944bf821c5f8.h"
/* CIntToPy */
#include "src/gevent/_generated_include/CIntToPy_impl_3a4503f42bed1a339a5a77cabbacbe22d845586eaf8fe2b8bf391ccbe75ae64a.h"
/* CIntFromPyVerify (used by CIntFromPy) */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntFromPy */
#include "src/gevent/_generated_include/CIntFromPy_impl_b91de55768d50878c1454209403f531c1ef9ecfc0f5cfff0eb0b925c62c994e2.h"
/* CIntFromPy */
#include "src/gevent/_generated_include/CIntFromPy_impl_ceb8d340f976d387a193f777f2c34549caaafc1e59b58b253b09ec2b16efbddf.h"
/* FastTypeChecks */
#include "src/gevent/_generated_include/FastTypeChecks_impl_f9d18941833a215bcf3276e2b6a57d81e032bd85ed1fb021b834da49989898c9.h"
/* GetRuntimeVersion */
#if __PYX_LIMITED_VERSION_HEX < 0x030b0000
void __Pyx_init_runtime_version(void) {
    if (__Pyx_cached_runtime_version == 0) {
        const char* rt_version = Py_GetVersion();
        unsigned long version = 0;
        unsigned long factor = 0x01000000UL;
        unsigned int digit = 0;
        int i = 0;
        while (factor) {
            while ('0' <= rt_version[i] && rt_version[i] <= '9') {
                digit = digit * 10 + (unsigned int) (rt_version[i] - '0');
                ++i;
            }
            version += factor * digit;
            if (rt_version[i] != '.')
                break;
            digit = 0;
            factor >>= 8;
            ++i;
        }
        __Pyx_cached_runtime_version = version;
    }
}
#endif
static unsigned long __Pyx_get_runtime_version(void) {
#if __PYX_LIMITED_VERSION_HEX >= 0x030b0000
    return Py_Version & ~0xFFUL;
#else
    return __Pyx_cached_runtime_version;
#endif
}

/* CheckBinaryVersion */
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer) {
    const unsigned long MAJOR_MINOR = 0xFFFF0000UL;
    if ((rt_version & MAJOR_MINOR) == (ct_version & MAJOR_MINOR))
        return 0;
    if (likely(allow_newer && (rt_version & MAJOR_MINOR) > (ct_version & MAJOR_MINOR)))
        return 1;
    {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compile time Python version %d.%d "
                      "of module '%.100s' "
                      "%s "
                      "runtime version %d.%d",
                       (int) (ct_version >> 24), (int) ((ct_version >> 16) & 0xFF),
                       __Pyx_MODULE_NAME,
                       (allow_newer) ? "was newer than" : "does not match",
                       (int) (rt_version >> 24), (int) ((rt_version >> 16) & 0xFF)
       );
        return PyErr_WarnEx(NULL, message, 1);
    }
}

/* NewCodeObj */
#include "src/gevent/_generated_include/NewCodeObj_impl_a437ae594518b78f515ea800eae13a23abf85c5a9a57d6d2c88c6b9b215ff54c.h"
/* DecompressString */
#include "src/gevent/_generated_include/DecompressString_impl_08916ce6b33dc899db1820b9329c4da53ddc4f977613e2296edf3d94850c4279.h"
#include <string.h>
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s) {
    size_t len = strlen(s);
    if (unlikely(len > (size_t) PY_SSIZE_T_MAX)) {
        PyErr_SetString(PyExc_OverflowError, "byte string is too long");
        return -1;
    }
    return (Py_ssize_t) len;
}
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return __Pyx_PyUnicode_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return PyByteArray_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if CYTHON_COMPILING_IN_LIMITED_API
    {
        const char* result;
        Py_ssize_t unicode_length;
        CYTHON_MAYBE_UNUSED_VAR(unicode_length); // only for __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        #if __PYX_LIMITED_VERSION_HEX < 0x030A0000
        if (unlikely(PyArg_Parse(o, "s#", &result, length) < 0)) return NULL;
        #else
        result = PyUnicode_AsUTF8AndSize(o, length);
        #endif
        #if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        unicode_length = PyUnicode_GetLength(o);
        if (unlikely(unicode_length < 0)) return NULL;
        if (unlikely(unicode_length != *length)) {
            PyUnicode_AsASCIIString(o);
            return NULL;
        }
        #endif
        return result;
    }
#else
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
#endif
}
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
    if (PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
    if (PyByteArray_Check(o)) {
#if (CYTHON_ASSUME_SAFE_SIZE && CYTHON_ASSUME_SAFE_MACROS) || (CYTHON_COMPILING_IN_PYPY && (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE)))
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
#else
        *length = PyByteArray_Size(o);
        if (*length == -1) return NULL;
        return PyByteArray_AsString(o);
#endif
    } else
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_LongWrongResultType(PyObject* result) {
    __Pyx_TypeName result_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(result));
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ").  "
                "The ability to return an instance of a strict subclass of int is deprecated, "
                "and may be removed in a future version of Python.",
                result_type_name)) {
            __Pyx_DECREF_TypeName(result_type_name);
            Py_DECREF(result);
            return NULL;
        }
        __Pyx_DECREF_TypeName(result_type_name);
        return result;
    }
    PyErr_Format(PyExc_TypeError,
                 "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ")",
                 result_type_name);
    __Pyx_DECREF_TypeName(result_type_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Long(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  PyObject *res = NULL;
  if (likely(PyLong_Check(x)))
      return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  if (likely(m && m->nb_int)) {
      res = m->nb_int(x);
  }
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
      res = PyNumber_Long(x);
  }
#endif
  if (likely(res)) {
      if (unlikely(!PyLong_CheckExact(res))) {
          return __Pyx_PyNumber_LongWrongResultType(res);
      }
  }
  else if (!PyErr_Occurred()) {
      PyErr_SetString(PyExc_TypeError,
                      "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(__Pyx_PyLong_IsCompact(b))) {
        return __Pyx_PyLong_CompactValue(b);
    } else {
      const digit* digits = __Pyx_PyLong_Digits(b);
      const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(b);
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyLong_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject* o) {
  if (sizeof(Py_hash_t) == sizeof(Py_ssize_t)) {
    return (Py_hash_t) __Pyx_PyIndex_AsSsize_t(o);
  } else {
    Py_ssize_t ival;
    PyObject *x;
    x = PyNumber_Index(o);
    if (!x) return -1;
    ival = PyLong_AsLong(x);
    Py_DECREF(x);
    return ival;
  }
}
static CYTHON_INLINE PyObject *__Pyx_Owned_Py_None(int b) {
    CYTHON_UNUSED_VAR(b);
    return __Pyx_NewRef(Py_None);
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return __Pyx_NewRef(b ? Py_True: Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyLong_FromSize_t(size_t ival) {
    return PyLong_FromSize_t(ival);
}


/* MultiPhaseInitModuleState */
#include "src/gevent/_generated_include/MultiPhaseInitModuleState_impl_41d512917574f55c289a94dba0e3ef9c60f8de37a71dd41f0dd086494a351cae.h"
/* #### Code section: utility_code_pragmas_end ### */
#ifdef _MSC_VER
#pragma warning( pop )
#endif



/* #### Code section: end ### */
#endif /* Py_PYTHON_H */
