/* Generated by Cython 3.2.4 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "define_macros": [
            [
                "CYTHON_FAST_THREAD_STATE",
                "0"
            ]
        ],
        "depends": [
            "src/gevent/_gevent_c_imap.pxd"
        ],
        "include_dirs": [
            "/usr/include/python3.14",
            "/usr/include/python3.14",
            "/build/python-gevent/src/python-gevent/deps"
        ],
        "name": "gevent._gevent_c_imap",
        "sources": [
            "src/gevent/_imap.py"
        ]
    },
    "module_name": "gevent._gevent_c_imap"
}
END: Cython Metadata */

#ifndef PY_SSIZE_T_CLEAN
#define PY_SSIZE_T_CLEAN
#endif /* PY_SSIZE_T_CLEAN */
/* InitLimitedAPI */
#if defined(Py_LIMITED_API)
  #if !defined(CYTHON_LIMITED_API)
  #define CYTHON_LIMITED_API 1
  #endif
#elif defined(CYTHON_LIMITED_API)
  #ifdef _MSC_VER
  #pragma message ("Limited API usage is enabled with 'CYTHON_LIMITED_API' but 'Py_LIMITED_API' does not define a Python target version. Consider setting 'Py_LIMITED_API' instead.")
  #else
  #warning Limited API usage is enabled with 'CYTHON_LIMITED_API' but 'Py_LIMITED_API' does not define a Python target version. Consider setting 'Py_LIMITED_API' instead.
  #endif
#endif

#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x03080000
    #error Cython requires Python 3.8+.
#else
#define __PYX_ABI_VERSION "3_2_4"
#define CYTHON_HEX_VERSION 0x030204F0
#define CYTHON_FUTURE_DIVISION 1
/* CModulePreamble */
#include "src/gevent/_generated_include/CModulePreamble_impl_67ff8da3bafbaee898fb2680a081f9cf07617f9b80d936bf5254c02966774c38.h"
/* CInitCode */
#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

/* PythonCompatibility */
#include "src/gevent/_generated_include/PythonCompatibility_impl_9f6bc6a154e6d1f4d1d9250f48a0e6d407560d70233eabffbe0fccfe1f684e75.h"
/* MathInitCode */
#if defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)
  #ifndef _USE_MATH_DEFINES
    #define _USE_MATH_DEFINES
  #endif
#endif
#include <math.h>
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#ifndef CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#define CYTHON_CLINE_IN_TRACEBACK_RUNTIME 0
#endif
#ifndef CYTHON_CLINE_IN_TRACEBACK
#define CYTHON_CLINE_IN_TRACEBACK CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#endif
#if CYTHON_CLINE_IN_TRACEBACK
#define __PYX_MARK_ERR_POS(f_index, lineno)  { __pyx_filename = __pyx_f[f_index]; (void) __pyx_filename; __pyx_lineno = lineno; (void) __pyx_lineno; __pyx_clineno = __LINE__; (void) __pyx_clineno; }
#else
#define __PYX_MARK_ERR_POS(f_index, lineno)  { __pyx_filename = __pyx_f[f_index]; (void) __pyx_filename; __pyx_lineno = lineno; (void) __pyx_lineno; (void) __pyx_clineno; }
#endif
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifdef CYTHON_EXTERN_C
    #undef __PYX_EXTERN_C
    #define __PYX_EXTERN_C CYTHON_EXTERN_C
#elif defined(__PYX_EXTERN_C)
    #ifdef _MSC_VER
    #pragma message ("Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.")
    #else
    #warning Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.
    #endif
#else
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__gevent___gevent_c_imap
#define __PYX_HAVE_API__gevent___gevent_c_imap
/* Early includes */
#include <string.h>
#include <stdio.h>
#include "greenlet/greenlet.h"
#include "_compat.h"
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

#ifdef CYTHON_FREETHREADING_COMPATIBLE
#if CYTHON_FREETHREADING_COMPATIBLE
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_NOT_USED
#else
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_USED
#endif
#else
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_USED
#endif
#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s);
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char*);
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyByteArray_AsString(s) PyByteArray_AS_STRING(s)
#else
    #define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AsString(s))
    #define __Pyx_PyByteArray_AsString(s) PyByteArray_AsString(s)
#endif
#define __Pyx_PyObject_AsWritableString(s)    ((char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
#define __Pyx_PyUnicode_FromOrdinal(o)       PyUnicode_FromOrdinal((int)o)
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
static CYTHON_INLINE PyObject *__Pyx_NewRef(PyObject *obj) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030a0000 || defined(Py_NewRef)
    return Py_NewRef(obj);
#else
    Py_INCREF(obj);
    return obj;
#endif
}
static CYTHON_INLINE PyObject *__Pyx_XNewRef(PyObject *obj) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030a0000 || defined(Py_XNewRef)
    return Py_XNewRef(obj);
#else
    Py_XINCREF(obj);
    return obj;
#endif
}
static CYTHON_INLINE PyObject *__Pyx_Owned_Py_None(int b);
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Long(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyLong_FromSize_t(size_t);
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject*);
#if CYTHON_ASSUME_SAFE_MACROS
#define __Pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#define __Pyx_PyFloat_AS_DOUBLE(x) PyFloat_AS_DOUBLE(x)
#else
#define __Pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#define __Pyx_PyFloat_AS_DOUBLE(x) PyFloat_AsDouble(x)
#endif
#define __Pyx_PyFloat_AsFloat(x) ((float) __Pyx_PyFloat_AsDouble(x))
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_VERSION_HEX >= 0x030C00A7
  #ifndef _PyLong_SIGN_MASK
    #define _PyLong_SIGN_MASK 3
  #endif
  #ifndef _PyLong_NON_SIZE_BITS
    #define _PyLong_NON_SIZE_BITS 3
  #endif
  #define __Pyx_PyLong_Sign(x)  (((PyLongObject*)x)->long_value.lv_tag & _PyLong_SIGN_MASK)
  #define __Pyx_PyLong_IsNeg(x)  ((__Pyx_PyLong_Sign(x) & 2) != 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (!__Pyx_PyLong_IsNeg(x))
  #define __Pyx_PyLong_IsZero(x)  (__Pyx_PyLong_Sign(x) & 1)
  #define __Pyx_PyLong_IsPos(x)  (__Pyx_PyLong_Sign(x) == 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  (__Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  ((Py_ssize_t) (((PyLongObject*)x)->long_value.lv_tag >> _PyLong_NON_SIZE_BITS))
  #define __Pyx_PyLong_SignedDigitCount(x)\
        ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * __Pyx_PyLong_DigitCount(x))
  #if defined(PyUnstable_Long_IsCompact) && defined(PyUnstable_Long_CompactValue)
    #define __Pyx_PyLong_IsCompact(x)     PyUnstable_Long_IsCompact((PyLongObject*) x)
    #define __Pyx_PyLong_CompactValue(x)  PyUnstable_Long_CompactValue((PyLongObject*) x)
  #else
    #define __Pyx_PyLong_IsCompact(x)     (((PyLongObject*)x)->long_value.lv_tag < (2 << _PyLong_NON_SIZE_BITS))
    #define __Pyx_PyLong_CompactValue(x)  ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * (Py_ssize_t) __Pyx_PyLong_Digits(x)[0])
  #endif
  typedef Py_ssize_t  __Pyx_compact_pylong;
  typedef size_t  __Pyx_compact_upylong;
  #else
  #define __Pyx_PyLong_IsNeg(x)  (Py_SIZE(x) < 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (Py_SIZE(x) >= 0)
  #define __Pyx_PyLong_IsZero(x)  (Py_SIZE(x) == 0)
  #define __Pyx_PyLong_IsPos(x)  (Py_SIZE(x) > 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  ((Py_SIZE(x) == 0) ? 0 : __Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  __Pyx_sst_abs(Py_SIZE(x))
  #define __Pyx_PyLong_SignedDigitCount(x)  Py_SIZE(x)
  #define __Pyx_PyLong_IsCompact(x)  (Py_SIZE(x) == 0 || Py_SIZE(x) == 1 || Py_SIZE(x) == -1)
  #define __Pyx_PyLong_CompactValue(x)\
        ((Py_SIZE(x) == 0) ? (sdigit) 0 : ((Py_SIZE(x) < 0) ? -(sdigit)__Pyx_PyLong_Digits(x)[0] : (sdigit)__Pyx_PyLong_Digits(x)[0]))
  typedef sdigit  __Pyx_compact_pylong;
  typedef digit  __Pyx_compact_upylong;
  #endif
  #if PY_VERSION_HEX >= 0x030C00A5
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->long_value.ob_digit)
  #else
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->ob_digit)
  #endif
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#elif __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeASCII(c_str, size, NULL)
#else
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
/* PretendToInitialize */
#ifdef __cplusplus
#if __cplusplus > 201103L
#include <type_traits>
#endif
template <typename T>
static void __Pyx_pretend_to_initialize(T* ptr) {
#if __cplusplus > 201103L
    if ((std::is_trivially_default_constructible<T>::value))
#endif
        *ptr = T();
    (void)ptr;
}
#else
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }
#endif


#if !CYTHON_USE_MODULE_STATE
static PyObject *__pyx_m = NULL;
#endif
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * const __pyx_cfilenm = __FILE__;
static const char *__pyx_filename;

/* #### Code section: filename_table ### */

static const char* const __pyx_f[] = {
  "src/gevent/_imap.py",
  "src/gevent/_gevent_c_greenlet_primitives.pxd",
  "src/gevent/_gevent_c_waiter.pxd",
  "src/gevent/_gevent_cgreenlet.pxd",
  "src/gevent/_gevent_c_abstract_linkable.pxd",
  "src/gevent/_gevent_cqueue.pxd",
  "src/gevent/_gevent_c_imap.pxd",
  "cpython/type.pxd",
  "src/gevent/_gevent_c_ident.pxd",
  "src/gevent/_gevent_c_semaphore.pxd",
  "src/gevent/_gevent_cevent.pxd",
};
/* #### Code section: utility_code_proto_before_types ### */
/* Atomics.proto (used by UnpackUnboundCMethod) */
#include "src/gevent/_generated_include/Atomics_proto_3c6d386cad499e8bf66734864569013c6cb59adf2353bb94c6c6798eea3c07cc.h"
/* CriticalSectionsDefinition.proto (used by CriticalSections) */
#if !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyCriticalSection void*
#define __Pyx_PyCriticalSection2 void*
#define __Pyx_PyCriticalSection_End(cs)
#define __Pyx_PyCriticalSection2_End(cs)
#else
#define __Pyx_PyCriticalSection PyCriticalSection
#define __Pyx_PyCriticalSection2 PyCriticalSection2
#define __Pyx_PyCriticalSection_End PyCriticalSection_End
#define __Pyx_PyCriticalSection2_End PyCriticalSection2_End
#endif

/* CriticalSections.proto (used by ParseKeywordsImpl) */
#if !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyCriticalSection_Begin(cs, arg) (void)(cs)
#define __Pyx_PyCriticalSection2_Begin(cs, arg1, arg2) (void)(cs)
#else
#define __Pyx_PyCriticalSection_Begin PyCriticalSection_Begin
#define __Pyx_PyCriticalSection2_Begin PyCriticalSection2_Begin
#endif
#if PY_VERSION_HEX < 0x030d0000 || CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_BEGIN_CRITICAL_SECTION(o) {
#define __Pyx_END_CRITICAL_SECTION() }
#else
#define __Pyx_BEGIN_CRITICAL_SECTION Py_BEGIN_CRITICAL_SECTION
#define __Pyx_END_CRITICAL_SECTION Py_END_CRITICAL_SECTION
#endif

/* IncludeStructmemberH.proto (used by FixUpExtensionType) */
#include <structmember.h>

/* #### Code section: numeric_typedefs ### */
/* #### Code section: complex_type_declarations ### */
/* #### Code section: type_declarations ### */

/*--- Type declarations ---*/
struct __pyx_obj_6gevent_15_gevent_c_ident_ValuedWeakRef;
struct __pyx_obj_6gevent_15_gevent_c_ident_IdentRegistry;
struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet;
struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop;
struct __pyx_obj_6gevent_16_gevent_c_waiter_Waiter;
struct __pyx_obj_6gevent_16_gevent_c_waiter_MultipleWaiter;
struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink;
struct __pyx_obj_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink;
struct __pyx_obj_6gevent_17_gevent_cgreenlet_FailureSpawnedLink;
struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame;
struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet;
struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event;
struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable__FakeNotifier;
struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable;
struct __pyx_obj_6gevent_19_gevent_c_semaphore__LockReleaseLink;
struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore;
struct __pyx_obj_6gevent_19_gevent_c_semaphore_BoundedSemaphore;
struct __pyx_obj_6gevent_14_gevent_cevent_Event;
struct __pyx_obj_6gevent_14_gevent_cevent_AsyncResult;
struct __pyx_obj_6gevent_14_gevent_cqueue_SimpleQueue;
struct __pyx_obj_6gevent_14_gevent_cqueue_Queue;
struct __pyx_obj_6gevent_14_gevent_cqueue_ItemWaiter;
struct __pyx_obj_6gevent_14_gevent_cqueue_UnboundQueue;
struct __pyx_obj_6gevent_14_gevent_cqueue_PriorityQueue;
struct __pyx_obj_6gevent_14_gevent_cqueue_LifoQueue;
struct __pyx_obj_6gevent_14_gevent_cqueue_Channel;
struct __pyx_obj_6gevent_14_gevent_c_imap_Failure;
struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered;
struct __pyx_obj_6gevent_14_gevent_c_imap_IMap;
struct __pyx_opt_args_6gevent_17_gevent_cgreenlet_8Greenlet_join;
struct __pyx_opt_args_6gevent_17_gevent_cgreenlet_8Greenlet_kill;
struct __pyx_opt_args_6gevent_17_gevent_cgreenlet_joinall;

/* "gevent/_gevent_cgreenlet.pxd":72
 *         _greenlet_imported = True
 * 
 * ctypedef object CodeType             # <<<<<<<<<<<<<<
 * ctypedef object FrameType
 * 
*/
typedef PyObject *__pyx_t_6gevent_17_gevent_cgreenlet_CodeType;

/* "gevent/_gevent_cgreenlet.pxd":73
 * 
 * ctypedef object CodeType
 * ctypedef object FrameType             # <<<<<<<<<<<<<<
 * 
 * cdef extern from "_compat.h":
*/
typedef PyObject *__pyx_t_6gevent_17_gevent_cgreenlet_FrameType;

/* "gevent/_gevent_cgreenlet.pxd":144
 * 
 *     cpdef bint has_links(self)
 *     cpdef join(self, timeout=*)             # <<<<<<<<<<<<<<
 *     cpdef kill(self, exception=*, block=*, timeout=*)
 *     cpdef bint ready(self)
*/
struct __pyx_opt_args_6gevent_17_gevent_cgreenlet_8Greenlet_join {
  int __pyx_n;
  PyObject *timeout;
};

/* "gevent/_gevent_cgreenlet.pxd":145
 *     cpdef bint has_links(self)
 *     cpdef join(self, timeout=*)
 *     cpdef kill(self, exception=*, block=*, timeout=*)             # <<<<<<<<<<<<<<
 *     cpdef bint ready(self)
 *     cpdef bint successful(self)
*/
struct __pyx_opt_args_6gevent_17_gevent_cgreenlet_8Greenlet_kill {
  int __pyx_n;
  PyObject *exception;
  PyObject *block;
  PyObject *timeout;
};

/* "gevent/_gevent_cgreenlet.pxd":219
 * 
 * @cython.locals(done=list)
 * cpdef joinall(greenlets, timeout=*, raise_error=*, count=*)             # <<<<<<<<<<<<<<
 * 
 * cdef set _spawn_callbacks
*/
struct __pyx_opt_args_6gevent_17_gevent_cgreenlet_joinall {
  int __pyx_n;
  PyObject *timeout;
  PyObject *raise_error;
  PyObject *count;
};
struct __pyx_opt_args_6gevent_27_gevent_c_abstract_linkable_16AbstractLinkable__wait_core;
struct __pyx_opt_args_6gevent_27_gevent_c_abstract_linkable_16AbstractLinkable__wait;

/* "gevent/_gevent_c_abstract_linkable.pxd":79
 *    cpdef _acquire_lock_for_switch_in(self)
 * 
 *    cdef _wait_core(self, timeout, catch=*)             # <<<<<<<<<<<<<<
 *    cdef _wait_return_value(self, bint waited, bint wait_success)
 *    cdef _wait(self, timeout=*)
*/
struct __pyx_opt_args_6gevent_27_gevent_c_abstract_linkable_16AbstractLinkable__wait_core {
  int __pyx_n;
  PyObject *__pyx_catch;
};

/* "gevent/_gevent_c_abstract_linkable.pxd":81
 *    cdef _wait_core(self, timeout, catch=*)
 *    cdef _wait_return_value(self, bint waited, bint wait_success)
 *    cdef _wait(self, timeout=*)             # <<<<<<<<<<<<<<
 * 
 *    # Unreleated utilities
*/
struct __pyx_opt_args_6gevent_27_gevent_c_abstract_linkable_16AbstractLinkable__wait {
  int __pyx_n;
  PyObject *timeout;
};
struct __pyx_opt_args_6gevent_19_gevent_c_semaphore_9Semaphore_wait;
struct __pyx_opt_args_6gevent_19_gevent_c_semaphore_9Semaphore_acquire;

/* "gevent/_gevent_c_semaphore.pxd":40
 *     # threadpool uses it
 *     cpdef _start_notify(self)
 *     cpdef int wait(self, object timeout=*) except -1000             # <<<<<<<<<<<<<<
 *     @cython.locals(
 *         success=bint,
*/
struct __pyx_opt_args_6gevent_19_gevent_c_semaphore_9Semaphore_wait {
  int __pyx_n;
  PyObject *timeout;
};

/* "gevent/_gevent_c_semaphore.pxd":47
 *         args=tuple,
 *     )
 *     cpdef bint acquire(self, bint blocking=*, object timeout=*) except -1000             # <<<<<<<<<<<<<<
 *     cpdef __enter__(self)
 *     cpdef __exit__(self, object t, object v, object tb)
*/
struct __pyx_opt_args_6gevent_19_gevent_c_semaphore_9Semaphore_acquire {
  int __pyx_n;
  int blocking;
  PyObject *timeout;
};
struct __pyx_opt_args_6gevent_14_gevent_cevent_11AsyncResult_get;
struct __pyx_opt_args_6gevent_14_gevent_cevent_11AsyncResult_wait;

/* "gevent/_gevent_cevent.pxd":23
 *     cdef public int _imap_task_index
 * 
 *     cpdef get(self, block=*, timeout=*)             # <<<<<<<<<<<<<<
 *     cpdef bint successful(self)
 * 
*/
struct __pyx_opt_args_6gevent_14_gevent_cevent_11AsyncResult_get {
  int __pyx_n;
  PyObject *block;
  PyObject *timeout;
};

/* "gevent/_gevent_cevent.pxd":26
 *     cpdef bint successful(self)
 * 
 *     cpdef wait(self, timeout=*)             # <<<<<<<<<<<<<<
 *     cpdef bint done(self)
 * 
*/
struct __pyx_opt_args_6gevent_14_gevent_cevent_11AsyncResult_wait {
  int __pyx_n;
  PyObject *timeout;
};
struct __pyx_opt_args_6gevent_14_gevent_cqueue_11SimpleQueue__create_queue;
struct __pyx_opt_args_6gevent_14_gevent_cqueue_11SimpleQueue_put;
struct __pyx_opt_args_6gevent_14_gevent_cqueue_11SimpleQueue_get;
struct __pyx_opt_args_6gevent_14_gevent_cqueue_11SimpleQueue_peek;
struct __pyx_opt_args_6gevent_14_gevent_cqueue_5Queue_shutdown;
struct __pyx_opt_args_6gevent_14_gevent_cqueue_7Channel_get;

/* "gevent/_gevent_cqueue.pxd":67
 *     cpdef bint empty(self)
 *     cpdef bint full(self)
 *     cpdef _create_queue(self, items=*)             # <<<<<<<<<<<<<<
 * 
 *     cpdef put(self, item, block=*, timeout=*)
*/
struct __pyx_opt_args_6gevent_14_gevent_cqueue_11SimpleQueue__create_queue {
  int __pyx_n;
  PyObject *items;
};

/* "gevent/_gevent_cqueue.pxd":69
 *     cpdef _create_queue(self, items=*)
 * 
 *     cpdef put(self, item, block=*, timeout=*)             # <<<<<<<<<<<<<<
 *     cpdef put_nowait(self, item)
 * 
*/
struct __pyx_opt_args_6gevent_14_gevent_cqueue_11SimpleQueue_put {
  int __pyx_n;
  PyObject *block;
  PyObject *timeout;
};

/* "gevent/_gevent_cqueue.pxd":74
 *     cdef __get_or_peek(self, method, block, timeout)
 * 
 *     cpdef get(self, block=*, timeout=*)             # <<<<<<<<<<<<<<
 *     cpdef get_nowait(self)
 *     cpdef peek(self, block=*, timeout=*)
*/
struct __pyx_opt_args_6gevent_14_gevent_cqueue_11SimpleQueue_get {
  int __pyx_n;
  PyObject *block;
  PyObject *timeout;
};

/* "gevent/_gevent_cqueue.pxd":76
 *     cpdef get(self, block=*, timeout=*)
 *     cpdef get_nowait(self)
 *     cpdef peek(self, block=*, timeout=*)             # <<<<<<<<<<<<<<
 *     cpdef peek_nowait(self)
 * 
*/
struct __pyx_opt_args_6gevent_14_gevent_cqueue_11SimpleQueue_peek {
  int __pyx_n;
  PyObject *block;
  PyObject *timeout;
};

/* "gevent/_gevent_cqueue.pxd":89
 * 
 * 
 *     cpdef shutdown(self, immediate=*)             # <<<<<<<<<<<<<<
 *     cdef _drain_for_immediate_shutdown(self)
 * 
*/
struct __pyx_opt_args_6gevent_14_gevent_cqueue_5Queue_shutdown {
  int __pyx_n;
  PyObject *immediate;
};

/* "gevent/_gevent_cqueue.pxd":116
 *     cdef _event_unlock
 * 
 *     cpdef get(self, block=*, timeout=*)             # <<<<<<<<<<<<<<
 *     cpdef get_nowait(self)
 * 
*/
struct __pyx_opt_args_6gevent_14_gevent_cqueue_7Channel_get {
  int __pyx_n;
  PyObject *block;
  PyObject *timeout;
};

/* "gevent/_gevent_c_ident.pxd":13
 * cdef type ref
 * 
 * @cython.internal             # <<<<<<<<<<<<<<
 * @cython.final
 * cdef class ValuedWeakRef(ref):
*/
struct __pyx_obj_6gevent_15_gevent_c_ident_ValuedWeakRef {
  PyWeakReference __pyx_base;
  PyObject *value;
};


/* "gevent/_gevent_c_ident.pxd":18
 *     cdef object value
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class IdentRegistry:
 *     cdef object _registry
*/
struct __pyx_obj_6gevent_15_gevent_c_ident_IdentRegistry {
  PyObject_HEAD
  struct __pyx_vtabstruct_6gevent_15_gevent_c_ident_IdentRegistry *__pyx_vtab;
  PyObject *_registry;
  PyObject *_available_idents;
};


/* "gevent/_gevent_c_greenlet_primitives.pxd":37
 *     return PyGreenlet_Switch(self, NULL, NULL)
 * 
 * cdef class TrackedRawGreenlet(greenlet):             # <<<<<<<<<<<<<<
 *     pass
 * 
*/
struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet {
  PyGreenlet __pyx_base;
};


/* "gevent/_gevent_c_greenlet_primitives.pxd":40
 *     pass
 * 
 * cdef class SwitchOutGreenletWithLoop(TrackedRawGreenlet):             # <<<<<<<<<<<<<<
 *     cdef public loop
 * 
*/
struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop {
  struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet __pyx_base;
  struct __pyx_vtabstruct_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *__pyx_vtab;
  PyObject *loop;
};


/* "gevent/_gevent_c_waiter.pxd":33
 *         _greenlet_imported = True
 * 
 * cdef class Waiter:             # <<<<<<<<<<<<<<
 *     cdef readonly SwitchOutGreenletWithLoop hub
 *     cdef readonly greenlet greenlet
*/
struct __pyx_obj_6gevent_16_gevent_c_waiter_Waiter {
  PyObject_HEAD
  struct __pyx_vtabstruct_6gevent_16_gevent_c_waiter_Waiter *__pyx_vtab;
  struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *hub;
  PyGreenlet *greenlet;
  PyObject *value;
  PyObject *_exception;
};


/* "gevent/_gevent_c_waiter.pxd":45
 *     #cpdef switch(self, value)
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * @cython.internal
 * cdef class MultipleWaiter(Waiter):
*/
struct __pyx_obj_6gevent_16_gevent_c_waiter_MultipleWaiter {
  struct __pyx_obj_6gevent_16_gevent_c_waiter_Waiter __pyx_base;
  PyObject *_values;
};


/* "gevent/_gevent_cgreenlet.pxd":100
 * cdef void _init()
 * 
 * cdef class SpawnedLink:             # <<<<<<<<<<<<<<
 *     cdef public object callback
 * 
*/
struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink {
  PyObject_HEAD
  PyObject *callback;
};


/* "gevent/_gevent_cgreenlet.pxd":104
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class SuccessSpawnedLink(SpawnedLink):
 *     pass
*/
struct __pyx_obj_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink {
  struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink __pyx_base;
};


/* "gevent/_gevent_cgreenlet.pxd":108
 *     pass
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class FailureSpawnedLink(SpawnedLink):
 *     pass
*/
struct __pyx_obj_6gevent_17_gevent_cgreenlet_FailureSpawnedLink {
  struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink __pyx_base;
};


/* "gevent/_gevent_cgreenlet.pxd":112
 *     pass
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * @cython.internal
 * @cython.freelist(1000)
*/
struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame {
  PyObject_HEAD
  __pyx_t_6gevent_17_gevent_cgreenlet_CodeType f_code;
  int f_lineno;
  struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *f_back;
};


/* "gevent/_gevent_cgreenlet.pxd":128
 * cdef _Frame _extract_stack(int limit)
 * 
 * cdef class Greenlet(greenlet):             # <<<<<<<<<<<<<<
 *     cdef readonly object value
 *     cdef readonly tuple args
*/
struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet {
  PyGreenlet __pyx_base;
  struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_vtab;
  PyObject *value;
  PyObject *args;
  PyObject *kwargs;
  PyObject *spawning_greenlet;
  struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *spawning_stack;
  PyObject *spawn_tree_locals;
  PyObject *_links;
  PyObject *_exc_info;
  PyObject *_notifier;
  PyObject *_start_event;
  PyObject *_formatted_info;
  PyObject *_ident;
};


/* "gevent/_gevent_cgreenlet.pxd":199
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * @cython.internal
 * cdef class _dummy_event:
*/
struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event {
  PyObject_HEAD
  struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet__dummy_event *__pyx_vtab;
  int pending;
  int active;
};


/* "gevent/_gevent_c_abstract_linkable.pxd":38
 * cdef dict get_roots_and_hubs()
 * 
 * cdef class _FakeNotifier(object):             # <<<<<<<<<<<<<<
 *     cdef bint pending
 * 
*/
struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable__FakeNotifier {
  PyObject_HEAD
  int pending;
};


/* "gevent/_gevent_c_abstract_linkable.pxd":41
 *     cdef bint pending
 * 
 * cdef class AbstractLinkable(object):             # <<<<<<<<<<<<<<
 *    # We declare the __weakref__ here in the base (even though
 *    # that's not really what we want) as a workaround for a Cython
*/
struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable {
  PyObject_HEAD
  struct __pyx_vtabstruct_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *__pyx_vtab;
  PyObject *__weakref__;
  struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *hub;
  PyObject *_notifier;
  PyObject *_links;
  int _notify_all;
};


/* "gevent/_gevent_c_semaphore.pxd":18
 * cdef _MULTI
 * 
 * cdef class _LockReleaseLink(object):             # <<<<<<<<<<<<<<
 *     cdef object lock
 * 
*/
struct __pyx_obj_6gevent_19_gevent_c_semaphore__LockReleaseLink {
  PyObject_HEAD
  PyObject *lock;
};


/* "gevent/_gevent_c_semaphore.pxd":22
 * 
 * 
 * cdef class Semaphore(AbstractLinkable):             # <<<<<<<<<<<<<<
 *     cdef public int counter
 *     # On Python 3, thread.get_ident() returns a ``unsigned long``; on
*/
struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore {
  struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable __pyx_base;
  int counter;
  PyObject *_multithreaded;
};


/* "gevent/_gevent_c_semaphore.pxd":67
 *     cdef bint __spin_on_native_lock(self, thread_lock, timeout)
 * 
 * cdef class BoundedSemaphore(Semaphore):             # <<<<<<<<<<<<<<
 *     cdef readonly int _initial_value
 * 
*/
struct __pyx_obj_6gevent_19_gevent_c_semaphore_BoundedSemaphore {
  struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore __pyx_base;
  int _initial_value;
};


/* "gevent/_gevent_cevent.pxd":13
 * cdef Timeout
 * 
 * cdef class Event(AbstractLinkable):             # <<<<<<<<<<<<<<
 *    cdef bint _flag
 * 
*/
struct __pyx_obj_6gevent_14_gevent_cevent_Event {
  struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable __pyx_base;
  int _flag;
};


/* "gevent/_gevent_cevent.pxd":16
 *    cdef bint _flag
 * 
 * cdef class AsyncResult(AbstractLinkable):             # <<<<<<<<<<<<<<
 *     cdef readonly _value
 *     cdef readonly tuple _exc_info
*/
struct __pyx_obj_6gevent_14_gevent_cevent_AsyncResult {
  struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable __pyx_base;
  PyObject *_value;
  PyObject *_exc_info;
  int _imap_task_index;
};


/* "gevent/_gevent_cqueue.pxd":39
 * cdef _safe_remove(deq, item)
 * 
 * cdef class SimpleQueue:             # <<<<<<<<<<<<<<
 *     cdef __weakref__
 *     cdef readonly hub
*/
struct __pyx_obj_6gevent_14_gevent_cqueue_SimpleQueue {
  PyObject_HEAD
  struct __pyx_vtabstruct_6gevent_14_gevent_cqueue_SimpleQueue *__pyx_vtab;
  PyObject *__weakref__;
  PyObject *hub;
  PyObject *queue;
  int is_shutdown;
  PyObject *getters;
  PyObject *putters;
  PyObject *_event_unlock;
  Py_ssize_t _maxsize;
};


/* "gevent/_gevent_cqueue.pxd":83
 * 
 * 
 * cdef class Queue(SimpleQueue):             # <<<<<<<<<<<<<<
 *     cdef Event _cond
 *     cdef readonly int unfinished_tasks
*/
struct __pyx_obj_6gevent_14_gevent_cqueue_Queue {
  struct __pyx_obj_6gevent_14_gevent_cqueue_SimpleQueue __pyx_base;
  struct __pyx_obj_6gevent_14_gevent_cevent_Event *_cond;
  int unfinished_tasks;
};


/* "gevent/_gevent_cqueue.pxd":93
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * @cython.internal
 * cdef class ItemWaiter(Waiter):
*/
struct __pyx_obj_6gevent_14_gevent_cqueue_ItemWaiter {
  struct __pyx_obj_6gevent_16_gevent_c_waiter_Waiter __pyx_base;
  PyObject *item;
  struct __pyx_obj_6gevent_14_gevent_cqueue_SimpleQueue *queue;
};


/* "gevent/_gevent_cqueue.pxd":100
 * 
 * 
 * cdef class UnboundQueue(Queue):             # <<<<<<<<<<<<<<
 *     pass
 * 
*/
struct __pyx_obj_6gevent_14_gevent_cqueue_UnboundQueue {
  struct __pyx_obj_6gevent_14_gevent_cqueue_Queue __pyx_base;
};


/* "gevent/_gevent_cqueue.pxd":103
 *     pass
 * 
 * cdef class PriorityQueue(Queue):             # <<<<<<<<<<<<<<
 *     pass
 * 
*/
struct __pyx_obj_6gevent_14_gevent_cqueue_PriorityQueue {
  struct __pyx_obj_6gevent_14_gevent_cqueue_Queue __pyx_base;
};


/* "gevent/_gevent_cqueue.pxd":106
 *     pass
 * 
 * cdef class LifoQueue(Queue):             # <<<<<<<<<<<<<<
 *     pass
 * 
*/
struct __pyx_obj_6gevent_14_gevent_cqueue_LifoQueue {
  struct __pyx_obj_6gevent_14_gevent_cqueue_Queue __pyx_base;
};


/* "gevent/_gevent_cqueue.pxd":109
 *     pass
 * 
 * cdef class Channel:             # <<<<<<<<<<<<<<
 *     cdef __weakref__
 *     cdef readonly getters
*/
struct __pyx_obj_6gevent_14_gevent_cqueue_Channel {
  PyObject_HEAD
  struct __pyx_vtabstruct_6gevent_14_gevent_cqueue_Channel *__pyx_vtab;
  PyObject *__weakref__;
  PyObject *getters;
  PyObject *putters;
  PyObject *hub;
  PyObject *_event_unlock;
};


/* "gevent/_gevent_c_imap.pxd":6
 * from gevent._gevent_cqueue cimport UnboundQueue
 * 
 * @cython.freelist(100)             # <<<<<<<<<<<<<<
 * @cython.internal
 * @cython.final
*/
struct __pyx_obj_6gevent_14_gevent_c_imap_Failure {
  PyObject_HEAD
  PyObject *exc;
  PyObject *raise_exception;
};


/* "gevent/_gevent_c_imap.pxd":15
 * cdef inline _raise_exc(Failure failure)
 * 
 * cdef class IMapUnordered(Greenlet):             # <<<<<<<<<<<<<<
 *     cdef bint _zipped
 *     cdef func
*/
struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered {
  struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet __pyx_base;
  int _zipped;
  PyObject *func;
  PyObject *iterable;
  PyObject *spawn;
  struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *_result_semaphore;
  int _outstanding_tasks;
  int _max_index;
  struct __pyx_obj_6gevent_14_gevent_cqueue_UnboundQueue *queue;
  int finished;
};


/* "gevent/_gevent_c_imap.pxd":40
 *     cdef _iqueue_value_for_self_failure(self, exception)
 * 
 * cdef class IMap(IMapUnordered):             # <<<<<<<<<<<<<<
 *     cdef int index
 *     cdef dict _results
*/
struct __pyx_obj_6gevent_14_gevent_c_imap_IMap {
  struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered __pyx_base;
  int index;
  PyObject *_results;
};



/* "gevent/_gevent_c_ident.pxd":18
 *     cdef object value
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class IdentRegistry:
 *     cdef object _registry
*/

struct __pyx_vtabstruct_6gevent_15_gevent_c_ident_IdentRegistry {
  PyObject *(*get_ident)(struct __pyx_obj_6gevent_15_gevent_c_ident_IdentRegistry *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*_return_ident)(struct __pyx_obj_6gevent_15_gevent_c_ident_IdentRegistry *, struct __pyx_obj_6gevent_15_gevent_c_ident_ValuedWeakRef *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6gevent_15_gevent_c_ident_IdentRegistry *__pyx_vtabptr_6gevent_15_gevent_c_ident_IdentRegistry;


/* "gevent/_gevent_c_greenlet_primitives.pxd":40
 *     pass
 * 
 * cdef class SwitchOutGreenletWithLoop(TrackedRawGreenlet):             # <<<<<<<<<<<<<<
 *     cdef public loop
 * 
*/

struct __pyx_vtabstruct_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop {
  PyObject *(*__pyx_switch)(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *, int __pyx_skip_dispatch);
  PyObject *(*switch_out)(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *__pyx_vtabptr_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop;


/* "gevent/_gevent_c_waiter.pxd":33
 *         _greenlet_imported = True
 * 
 * cdef class Waiter:             # <<<<<<<<<<<<<<
 *     cdef readonly SwitchOutGreenletWithLoop hub
 *     cdef readonly greenlet greenlet
*/

struct __pyx_vtabstruct_6gevent_16_gevent_c_waiter_Waiter {
  PyObject *(*get)(struct __pyx_obj_6gevent_16_gevent_c_waiter_Waiter *, int __pyx_skip_dispatch);
  PyObject *(*clear)(struct __pyx_obj_6gevent_16_gevent_c_waiter_Waiter *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6gevent_16_gevent_c_waiter_Waiter *__pyx_vtabptr_6gevent_16_gevent_c_waiter_Waiter;


/* "gevent/_gevent_c_waiter.pxd":45
 *     #cpdef switch(self, value)
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * @cython.internal
 * cdef class MultipleWaiter(Waiter):
*/

struct __pyx_vtabstruct_6gevent_16_gevent_c_waiter_MultipleWaiter {
  struct __pyx_vtabstruct_6gevent_16_gevent_c_waiter_Waiter __pyx_base;
};
static struct __pyx_vtabstruct_6gevent_16_gevent_c_waiter_MultipleWaiter *__pyx_vtabptr_6gevent_16_gevent_c_waiter_MultipleWaiter;


/* "gevent/_gevent_cgreenlet.pxd":128
 * cdef _Frame _extract_stack(int limit)
 * 
 * cdef class Greenlet(greenlet):             # <<<<<<<<<<<<<<
 *     cdef readonly object value
 *     cdef readonly tuple args
*/

struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet {
  int (*has_links)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, int __pyx_skip_dispatch);
  PyObject *(*join)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, int __pyx_skip_dispatch, struct __pyx_opt_args_6gevent_17_gevent_cgreenlet_8Greenlet_join *__pyx_optional_args);
  PyObject *(*kill)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, int __pyx_skip_dispatch, struct __pyx_opt_args_6gevent_17_gevent_cgreenlet_8Greenlet_kill *__pyx_optional_args);
  int (*ready)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, int __pyx_skip_dispatch);
  int (*successful)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, int __pyx_skip_dispatch);
  PyObject *(*rawlink)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*_formatinfo)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, int __pyx_skip_dispatch);
  int (*_maybe_kill_before_start)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*_get_minimal_ident)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *);
  int (*_Greenlet__started_but_aborted)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *);
  int (*_Greenlet__start_cancelled_by_kill)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *);
  int (*_Greenlet__start_pending)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *);
  int (*_Greenlet__never_started_or_killed)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *);
  int (*_Greenlet__start_completed)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *);
  PyObject *(*_Greenlet__handle_death_before_start)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, PyObject *);
  void (*_Greenlet__free)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *);
  PyObject *(*_Greenlet__cancel_start)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *);
  PyObject *(*_Greenlet__report_result)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, PyObject *);
  PyObject *(*_Greenlet__report_error)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, PyObject *);
  PyObject *(*_notify_links)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_vtabptr_6gevent_17_gevent_cgreenlet_Greenlet;


/* "gevent/_gevent_cgreenlet.pxd":199
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * @cython.internal
 * cdef class _dummy_event:
*/

struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet__dummy_event {
  PyObject *(*stop)(struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *, int __pyx_skip_dispatch);
  PyObject *(*start)(struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*close)(struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet__dummy_event *__pyx_vtabptr_6gevent_17_gevent_cgreenlet__dummy_event;


/* "gevent/_gevent_c_abstract_linkable.pxd":41
 *     cdef bint pending
 * 
 * cdef class AbstractLinkable(object):             # <<<<<<<<<<<<<<
 *    # We declare the __weakref__ here in the base (even though
 *    # that's not really what we want) as a workaround for a Cython
*/

struct __pyx_vtabstruct_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable {
  PyObject *(*linkcount)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *, int __pyx_skip_dispatch);
  PyObject *(*rawlink)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *, PyObject *, int __pyx_skip_dispatch);
  int (*ready)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *, int __pyx_skip_dispatch);
  PyObject *(*unlink)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*_check_and_notify)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *);
  struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *(*_capture_hub)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *, int);
  PyObject *(*_AbstractLinkable__wait_to_be_notified)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *, int);
  void (*_quiet_unlink_all)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *, PyObject *);
  int (*_switch_to_hub)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *, PyObject *);
  PyObject *(*_notify_link_list)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *, PyObject *);
  PyObject *(*_notify_links)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*_handle_unswitched_notifications)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *, PyObject *);
  PyObject *(*_AbstractLinkable__print_unswitched_warning)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *, PyObject *, int);
  PyObject *(*_drop_lock_for_switch_out)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *, int __pyx_skip_dispatch);
  PyObject *(*_acquire_lock_for_switch_in)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *, int __pyx_skip_dispatch);
  PyObject *(*_wait_core)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *, PyObject *, struct __pyx_opt_args_6gevent_27_gevent_c_abstract_linkable_16AbstractLinkable__wait_core *__pyx_optional_args);
  PyObject *(*_wait_return_value)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *, int, int);
  PyObject *(*_wait)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *, struct __pyx_opt_args_6gevent_27_gevent_c_abstract_linkable_16AbstractLinkable__wait *__pyx_optional_args);
  PyObject *(*_allocate_lock)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *);
  PyGreenlet *(*_getcurrent)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *);
  PyObject *(*_get_thread_ident)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *);
};
static struct __pyx_vtabstruct_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *__pyx_vtabptr_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable;


/* "gevent/_gevent_c_semaphore.pxd":22
 * 
 * 
 * cdef class Semaphore(AbstractLinkable):             # <<<<<<<<<<<<<<
 *     cdef public int counter
 *     # On Python 3, thread.get_ident() returns a ``unsigned long``; on
*/

struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore {
  struct __pyx_vtabstruct_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable __pyx_base;
  int (*locked)(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *, int __pyx_skip_dispatch);
  int (*release)(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *, int __pyx_skip_dispatch);
  PyObject *(*_start_notify)(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *, int __pyx_skip_dispatch);
  int (*wait)(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *, int __pyx_skip_dispatch, struct __pyx_opt_args_6gevent_19_gevent_c_semaphore_9Semaphore_wait *__pyx_optional_args);
  int (*acquire)(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *, int __pyx_skip_dispatch, struct __pyx_opt_args_6gevent_19_gevent_c_semaphore_9Semaphore_acquire *__pyx_optional_args);
  PyObject *(*__pyx___enter__)(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *, int __pyx_skip_dispatch);
  PyObject *(*__pyx___exit__)(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *, PyObject *, PyObject *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*_Semaphore__acquire_from_other_thread)(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *, PyObject *, int, PyObject *);
  PyObject *(*_Semaphore__acquire_from_other_thread_cb)(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *, PyObject *, int, PyObject *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*_Semaphore__add_link)(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *, PyObject *);
  PyObject *(*_Semaphore__acquire_using_two_hubs)(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *, struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *, PyObject *, PyObject *);
  PyObject *(*_Semaphore__acquire_using_other_hub)(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *, struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *, PyObject *);
  int (*_Semaphore__acquire_without_hubs)(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *, PyObject *);
  int (*_Semaphore__spin_on_native_lock)(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *, PyObject *, PyObject *);
};
static struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_vtabptr_6gevent_19_gevent_c_semaphore_Semaphore;


/* "gevent/_gevent_c_semaphore.pxd":67
 *     cdef bint __spin_on_native_lock(self, thread_lock, timeout)
 * 
 * cdef class BoundedSemaphore(Semaphore):             # <<<<<<<<<<<<<<
 *     cdef readonly int _initial_value
 * 
*/

struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_BoundedSemaphore {
  struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore __pyx_base;
};
static struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_BoundedSemaphore *__pyx_vtabptr_6gevent_19_gevent_c_semaphore_BoundedSemaphore;


/* "gevent/_gevent_cevent.pxd":13
 * cdef Timeout
 * 
 * cdef class Event(AbstractLinkable):             # <<<<<<<<<<<<<<
 *    cdef bint _flag
 * 
*/

struct __pyx_vtabstruct_6gevent_14_gevent_cevent_Event {
  struct __pyx_vtabstruct_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable __pyx_base;
};
static struct __pyx_vtabstruct_6gevent_14_gevent_cevent_Event *__pyx_vtabptr_6gevent_14_gevent_cevent_Event;


/* "gevent/_gevent_cevent.pxd":16
 *    cdef bint _flag
 * 
 * cdef class AsyncResult(AbstractLinkable):             # <<<<<<<<<<<<<<
 *     cdef readonly _value
 *     cdef readonly tuple _exc_info
*/

struct __pyx_vtabstruct_6gevent_14_gevent_cevent_AsyncResult {
  struct __pyx_vtabstruct_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable __pyx_base;
  PyObject *(*get)(struct __pyx_obj_6gevent_14_gevent_cevent_AsyncResult *, int __pyx_skip_dispatch, struct __pyx_opt_args_6gevent_14_gevent_cevent_11AsyncResult_get *__pyx_optional_args);
  int (*successful)(struct __pyx_obj_6gevent_14_gevent_cevent_AsyncResult *, int __pyx_skip_dispatch);
  PyObject *(*wait)(struct __pyx_obj_6gevent_14_gevent_cevent_AsyncResult *, int __pyx_skip_dispatch, struct __pyx_opt_args_6gevent_14_gevent_cevent_11AsyncResult_wait *__pyx_optional_args);
  int (*done)(struct __pyx_obj_6gevent_14_gevent_cevent_AsyncResult *, int __pyx_skip_dispatch);
  int (*cancel)(struct __pyx_obj_6gevent_14_gevent_cevent_AsyncResult *, int __pyx_skip_dispatch);
  int (*cancelled)(struct __pyx_obj_6gevent_14_gevent_cevent_AsyncResult *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6gevent_14_gevent_cevent_AsyncResult *__pyx_vtabptr_6gevent_14_gevent_cevent_AsyncResult;


/* "gevent/_gevent_cqueue.pxd":39
 * cdef _safe_remove(deq, item)
 * 
 * cdef class SimpleQueue:             # <<<<<<<<<<<<<<
 *     cdef __weakref__
 *     cdef readonly hub
*/

struct __pyx_vtabstruct_6gevent_14_gevent_cqueue_SimpleQueue {
  PyObject *(*_get)(struct __pyx_obj_6gevent_14_gevent_cqueue_SimpleQueue *, int __pyx_skip_dispatch);
  PyObject *(*_put)(struct __pyx_obj_6gevent_14_gevent_cqueue_SimpleQueue *, PyObject *, int __pyx_skip_dispatch);
  Py_ssize_t (*_qsize)(struct __pyx_obj_6gevent_14_gevent_cqueue_SimpleQueue *, int __pyx_skip_dispatch);
  PyObject *(*_peek)(struct __pyx_obj_6gevent_14_gevent_cqueue_SimpleQueue *, int __pyx_skip_dispatch);
  Py_ssize_t (*qsize)(struct __pyx_obj_6gevent_14_gevent_cqueue_SimpleQueue *, int __pyx_skip_dispatch);
  int (*empty)(struct __pyx_obj_6gevent_14_gevent_cqueue_SimpleQueue *, int __pyx_skip_dispatch);
  int (*full)(struct __pyx_obj_6gevent_14_gevent_cqueue_SimpleQueue *, int __pyx_skip_dispatch);
  PyObject *(*_create_queue)(struct __pyx_obj_6gevent_14_gevent_cqueue_SimpleQueue *, int __pyx_skip_dispatch, struct __pyx_opt_args_6gevent_14_gevent_cqueue_11SimpleQueue__create_queue *__pyx_optional_args);
  PyObject *(*put)(struct __pyx_obj_6gevent_14_gevent_cqueue_SimpleQueue *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_6gevent_14_gevent_cqueue_11SimpleQueue_put *__pyx_optional_args);
  PyObject *(*put_nowait)(struct __pyx_obj_6gevent_14_gevent_cqueue_SimpleQueue *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*_SimpleQueue__get_or_peek)(struct __pyx_obj_6gevent_14_gevent_cqueue_SimpleQueue *, PyObject *, PyObject *, PyObject *);
  PyObject *(*get)(struct __pyx_obj_6gevent_14_gevent_cqueue_SimpleQueue *, int __pyx_skip_dispatch, struct __pyx_opt_args_6gevent_14_gevent_cqueue_11SimpleQueue_get *__pyx_optional_args);
  PyObject *(*get_nowait)(struct __pyx_obj_6gevent_14_gevent_cqueue_SimpleQueue *, int __pyx_skip_dispatch);
  PyObject *(*peek)(struct __pyx_obj_6gevent_14_gevent_cqueue_SimpleQueue *, int __pyx_skip_dispatch, struct __pyx_opt_args_6gevent_14_gevent_cqueue_11SimpleQueue_peek *__pyx_optional_args);
  PyObject *(*peek_nowait)(struct __pyx_obj_6gevent_14_gevent_cqueue_SimpleQueue *, int __pyx_skip_dispatch);
  PyObject *(*_schedule_unlock)(struct __pyx_obj_6gevent_14_gevent_cqueue_SimpleQueue *);
};
static struct __pyx_vtabstruct_6gevent_14_gevent_cqueue_SimpleQueue *__pyx_vtabptr_6gevent_14_gevent_cqueue_SimpleQueue;


/* "gevent/_gevent_cqueue.pxd":83
 * 
 * 
 * cdef class Queue(SimpleQueue):             # <<<<<<<<<<<<<<
 *     cdef Event _cond
 *     cdef readonly int unfinished_tasks
*/

struct __pyx_vtabstruct_6gevent_14_gevent_cqueue_Queue {
  struct __pyx_vtabstruct_6gevent_14_gevent_cqueue_SimpleQueue __pyx_base;
  PyObject *(*_did_put_task)(struct __pyx_obj_6gevent_14_gevent_cqueue_Queue *);
  PyObject *(*shutdown)(struct __pyx_obj_6gevent_14_gevent_cqueue_Queue *, int __pyx_skip_dispatch, struct __pyx_opt_args_6gevent_14_gevent_cqueue_5Queue_shutdown *__pyx_optional_args);
  PyObject *(*_drain_for_immediate_shutdown)(struct __pyx_obj_6gevent_14_gevent_cqueue_Queue *);
};
static struct __pyx_vtabstruct_6gevent_14_gevent_cqueue_Queue *__pyx_vtabptr_6gevent_14_gevent_cqueue_Queue;


/* "gevent/_gevent_cqueue.pxd":93
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * @cython.internal
 * cdef class ItemWaiter(Waiter):
*/

struct __pyx_vtabstruct_6gevent_14_gevent_cqueue_ItemWaiter {
  struct __pyx_vtabstruct_6gevent_16_gevent_c_waiter_Waiter __pyx_base;
};
static struct __pyx_vtabstruct_6gevent_14_gevent_cqueue_ItemWaiter *__pyx_vtabptr_6gevent_14_gevent_cqueue_ItemWaiter;


/* "gevent/_gevent_cqueue.pxd":100
 * 
 * 
 * cdef class UnboundQueue(Queue):             # <<<<<<<<<<<<<<
 *     pass
 * 
*/

struct __pyx_vtabstruct_6gevent_14_gevent_cqueue_UnboundQueue {
  struct __pyx_vtabstruct_6gevent_14_gevent_cqueue_Queue __pyx_base;
};
static struct __pyx_vtabstruct_6gevent_14_gevent_cqueue_UnboundQueue *__pyx_vtabptr_6gevent_14_gevent_cqueue_UnboundQueue;


/* "gevent/_gevent_cqueue.pxd":103
 *     pass
 * 
 * cdef class PriorityQueue(Queue):             # <<<<<<<<<<<<<<
 *     pass
 * 
*/

struct __pyx_vtabstruct_6gevent_14_gevent_cqueue_PriorityQueue {
  struct __pyx_vtabstruct_6gevent_14_gevent_cqueue_Queue __pyx_base;
};
static struct __pyx_vtabstruct_6gevent_14_gevent_cqueue_PriorityQueue *__pyx_vtabptr_6gevent_14_gevent_cqueue_PriorityQueue;


/* "gevent/_gevent_cqueue.pxd":106
 *     pass
 * 
 * cdef class LifoQueue(Queue):             # <<<<<<<<<<<<<<
 *     pass
 * 
*/

struct __pyx_vtabstruct_6gevent_14_gevent_cqueue_LifoQueue {
  struct __pyx_vtabstruct_6gevent_14_gevent_cqueue_Queue __pyx_base;
};
static struct __pyx_vtabstruct_6gevent_14_gevent_cqueue_LifoQueue *__pyx_vtabptr_6gevent_14_gevent_cqueue_LifoQueue;


/* "gevent/_gevent_cqueue.pxd":109
 *     pass
 * 
 * cdef class Channel:             # <<<<<<<<<<<<<<
 *     cdef __weakref__
 *     cdef readonly getters
*/

struct __pyx_vtabstruct_6gevent_14_gevent_cqueue_Channel {
  PyObject *(*get)(struct __pyx_obj_6gevent_14_gevent_cqueue_Channel *, int __pyx_skip_dispatch, struct __pyx_opt_args_6gevent_14_gevent_cqueue_7Channel_get *__pyx_optional_args);
  PyObject *(*get_nowait)(struct __pyx_obj_6gevent_14_gevent_cqueue_Channel *, int __pyx_skip_dispatch);
  PyObject *(*_schedule_unlock)(struct __pyx_obj_6gevent_14_gevent_cqueue_Channel *);
};
static struct __pyx_vtabstruct_6gevent_14_gevent_cqueue_Channel *__pyx_vtabptr_6gevent_14_gevent_cqueue_Channel;


/* "src/gevent/_imap.py":43
 *         raise failure.exc
 * 
 * class IMapUnordered(Greenlet): # pylint:disable=undefined-variable             # <<<<<<<<<<<<<<
 *     """
 *     At iterator of map results.
*/

struct __pyx_vtabstruct_6gevent_14_gevent_c_imap_IMapUnordered {
  struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet __pyx_base;
  PyObject *(*_inext)(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *);
  PyObject *(*_ispawn)(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *, PyObject *, PyObject *, int);
  PyObject *(*_on_result)(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*_on_finish)(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *, PyObject *);
  PyObject *(*_iqueue_value_for_success)(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *, PyObject *);
  PyObject *(*_iqueue_value_for_failure)(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *, PyObject *);
  PyObject *(*_iqueue_value_for_self_finished)(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *);
  PyObject *(*_iqueue_value_for_self_failure)(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *, PyObject *);
};
static struct __pyx_vtabstruct_6gevent_14_gevent_c_imap_IMapUnordered *__pyx_vtabptr_6gevent_14_gevent_c_imap_IMapUnordered;


/* "src/gevent/_imap.py":187
 * 
 * 
 * class IMap(IMapUnordered):             # <<<<<<<<<<<<<<
 *     # A specialization of IMapUnordered that returns items
 *     # in the order in which they were generated, not
*/

struct __pyx_vtabstruct_6gevent_14_gevent_c_imap_IMap {
  struct __pyx_vtabstruct_6gevent_14_gevent_c_imap_IMapUnordered __pyx_base;
};
static struct __pyx_vtabstruct_6gevent_14_gevent_c_imap_IMap *__pyx_vtabptr_6gevent_14_gevent_c_imap_IMap;
/* #### Code section: utility_code_proto ### */

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#include "src/gevent/_generated_include/Refnanny_proto_00d2ab1aa529311d487a88a16574063b4d3b8ffa11a25109d76165964b208920.h"
/* PyErrExceptionMatches.proto (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* PyThreadStateGet.proto (used by PyErrFetchRestore) */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#if PY_VERSION_HEX >= 0x030C00A6
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->current_exception != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->current_exception ? (PyObject*) Py_TYPE(__pyx_tstate->current_exception) : (PyObject*) NULL)
#else
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->curexc_type != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->curexc_type)
#endif
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  (PyErr_Occurred() != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto (used by PyObjectGetAttrStrNoError) */
#include "src/gevent/_generated_include/PyErrFetchRestore_proto_b219ba96ee79f73e7240a9715dc835e7e817ccd9f4f99ab4145b09780817bd8a.h"
/* PyObjectGetAttrStr.proto (used by PyObjectGetAttrStrNoError) */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* PyObjectGetAttrStrNoError.proto (used by GetBuiltinName) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name);

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* ExtTypeTest.proto */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type);

/* TupleAndListFromArray.proto (used by fastcall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n);
#endif
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject* __Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n);
#endif

/* IncludeStringH.proto (used by BytesEquals) */
#include <string.h>

/* BytesEquals.proto (used by UnicodeEquals) */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto (used by fastcall) */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* fastcall.proto */
#include "src/gevent/_generated_include/fastcall_proto_66690a1464eb22fa574c56237a11be9953f14c69fdee2df9c4141aa9c5e2a76d.h"
/* py_dict_items.proto (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Items(PyObject* d);

/* CallCFunction.proto (used by CallUnboundCMethod0) */
#define __Pyx_CallCFunction(cfunc, self, args)\
    ((PyCFunction)(void(*)(void))(cfunc)->func)(self, args)
#define __Pyx_CallCFunctionWithKeywords(cfunc, self, args, kwargs)\
    ((PyCFunctionWithKeywords)(void(*)(void))(cfunc)->func)(self, args, kwargs)
#define __Pyx_CallCFunctionFast(cfunc, self, args, nargs)\
    ((__Pyx_PyCFunctionFast)(void(*)(void))(PyCFunction)(cfunc)->func)(self, args, nargs)
#define __Pyx_CallCFunctionFastWithKeywords(cfunc, self, args, nargs, kwnames)\
    ((__Pyx_PyCFunctionFastWithKeywords)(void(*)(void))(PyCFunction)(cfunc)->func)(self, args, nargs, kwnames)

/* PyObjectCall.proto (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyObjectCallMethO.proto (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectFastCall.proto (used by PyObjectCallOneArg) */
#define __Pyx_PyObject_FastCall(func, args, nargs)  __Pyx_PyObject_FastCallDict(func, args, (size_t)(nargs), NULL)
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject * const*args, size_t nargs, PyObject *kwargs);

/* PyObjectCallOneArg.proto (used by CallUnboundCMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* UnpackUnboundCMethod.proto (used by CallUnboundCMethod0) */
typedef struct {
    PyObject *type;
    PyObject **method_name;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && CYTHON_ATOMICS
    __pyx_atomic_int_type initialized;
#endif
    PyCFunction func;
    PyObject *method;
    int flag;
} __Pyx_CachedCFunction;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
static CYTHON_INLINE int __Pyx_CachedCFunction_GetAndSetInitializing(__Pyx_CachedCFunction *cfunc) {
#if !CYTHON_ATOMICS
    return 1;
#else
    __pyx_nonatomic_int_type expected = 0;
    if (__pyx_atomic_int_cmp_exchange(&cfunc->initialized, &expected, 1)) {
        return 0;
    }
    return expected;
#endif
}
static CYTHON_INLINE void __Pyx_CachedCFunction_SetFinishedInitializing(__Pyx_CachedCFunction *cfunc) {
#if CYTHON_ATOMICS
    __pyx_atomic_store(&cfunc->initialized, 2);
#endif
}
#else
#define __Pyx_CachedCFunction_GetAndSetInitializing(cfunc) 2
#define __Pyx_CachedCFunction_SetFinishedInitializing(cfunc)
#endif

/* CallUnboundCMethod0.proto */
CYTHON_UNUSED
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#else
#define __Pyx_CallUnboundCMethod0(cfunc, self)  __Pyx__CallUnboundCMethod0(cfunc, self)
#endif

/* py_dict_values.proto (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Values(PyObject* d);

/* OwnedDictNext.proto (used by ParseKeywordsImpl) */
#if CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, PyObject **ppos, PyObject **pkey, PyObject **pvalue);
#else
CYTHON_INLINE
static int __Pyx_PyDict_NextRef(PyObject *p, Py_ssize_t *ppos, PyObject **pkey, PyObject **pvalue);
#endif

/* RaiseDoubleKeywords.proto (used by ParseKeywordsImpl) */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywordsImpl.export */
static int __Pyx_ParseKeywordsTuple(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);
static int __Pyx_ParseKeywordDictToDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name
);
static int __Pyx_ParseKeywordDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);

/* CallUnboundCMethod2.proto */
CYTHON_UNUSED
static PyObject* __Pyx__CallUnboundCMethod2(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg1, PyObject* arg2);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject *__Pyx_CallUnboundCMethod2(__Pyx_CachedCFunction *cfunc, PyObject *self, PyObject *arg1, PyObject *arg2);
#else
#define __Pyx_CallUnboundCMethod2(cfunc, self, arg1, arg2)  __Pyx__CallUnboundCMethod2(cfunc, self, arg1, arg2)
#endif

/* ParseKeywords.proto */
static CYTHON_INLINE int __Pyx_ParseKeywords(
    PyObject *kwds, PyObject *const *kwvalues, PyObject ** const argnames[],
    PyObject *kwds2, PyObject *values[],
    Py_ssize_t num_pos_args, Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* RaiseException.export */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* PyObjectFastCallMethod.proto */
#if CYTHON_VECTORCALL && PY_VERSION_HEX >= 0x03090000
#define __Pyx_PyObject_FastCallMethod(name, args, nargsf) PyObject_VectorcallMethod(name, args, nargsf, NULL)
#else
static PyObject *__Pyx_PyObject_FastCallMethod(PyObject *name, PyObject *const *args, size_t nargsf);
#endif

/* PyObjectDelAttr.proto (used by PyObjectSetAttrStr) */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030d0000
#define __Pyx_PyObject_DelAttr(o, n) PyObject_SetAttr(o, n, NULL)
#else
#define __Pyx_PyObject_DelAttr(o, n) PyObject_DelAttr(o, n)
#endif

/* PyObjectSetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o, n, NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value);
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   __Pyx_PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

/* GetTopmostException.proto (used by SaveResetException) */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem * __Pyx_PyErr_GetTopmostException(PyThreadState *tstate);
#endif

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* GetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_GetException(type, value, tb)  __Pyx__GetException(__pyx_tstate, type, value, tb)
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* SwapException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSwap(type, value, tb)  __Pyx__ExceptionSwap(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* PyDictVersioning.proto */
#include "src/gevent/_generated_include/PyDictVersioning_proto_fc9ab32633f390bb88d05edfc7599e60bc4df8ea122afe432e3adec504912045.h"
/* GetAttr.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *, PyObject *);

/* PyStopIteration_Check.proto */
#define __Pyx_PyExc_StopIteration_Check(obj)  __Pyx_TypeCheck(obj, PyExc_StopIteration)

/* KeywordStringCheck.proto */
static CYTHON_INLINE int __Pyx_CheckKeywordStrings(const char* function_name, PyObject *kw);

/* py_dict_pop.proto */
static CYTHON_INLINE PyObject *__Pyx_PyDict_Pop(PyObject *d, PyObject *key, PyObject *default_value);

/* PyObjectCall2Args.proto (used by CallUnboundCMethod1) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2);

/* CallUnboundCMethod1.proto */
CYTHON_UNUSED
static PyObject* __Pyx__CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#else
#define __Pyx_CallUnboundCMethod1(cfunc, self, arg)  __Pyx__CallUnboundCMethod1(cfunc, self, arg)
#endif

/* PyKeyError_Check.proto */
#define __Pyx_PyExc_KeyError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_KeyError)

/* RaiseTooManyValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

/* RaiseNeedMoreValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

/* IterFinish.proto */
static CYTHON_INLINE int __Pyx_IterFinish(void);

/* UnpackItemEndCheck.proto */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected);

/* RaiseUnboundLocalError.proto */
static void __Pyx_RaiseUnboundLocalError(const char *varname);

/* AllocateExtensionType.proto */
static PyObject *__Pyx_AllocateExtensionType(PyTypeObject *t, int is_final);

/* CallTypeTraverse.proto */
#if !CYTHON_USE_TYPE_SPECS || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x03090000)
#define __Pyx_call_type_traverse(o, always_call, visit, arg) 0
#else
static int __Pyx_call_type_traverse(PyObject *o, int always_call, visitproc visit, void *arg);
#endif

/* CallNextTpDealloc.proto */
static void __Pyx_call_next_tp_dealloc(PyObject* obj, destructor current_tp_dealloc);

/* CallNextTpTraverse.proto */
static int __Pyx_call_next_tp_traverse(PyObject* obj, visitproc v, void *a, traverseproc current_tp_traverse);

/* CallNextTpClear.proto */
static void __Pyx_call_next_tp_clear(PyObject* obj, inquiry current_tp_clear);

/* FunctionExport.proto */
static int __Pyx_ExportFunction(PyObject *api_dict, const char *name, void (*f)(void), const char *sig);

/* GetApiDict.proto */
static PyObject *__Pyx_ApiExport_GetApiDict(void);

/* LimitedApiGetTypeDict.proto (used by SetItemOnTypeDict) */
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_GetTypeDict(PyTypeObject *tp);
#endif

/* SetItemOnTypeDict.proto (used by FixUpExtensionType) */
static int __Pyx__SetItemOnTypeDict(PyTypeObject *tp, PyObject *k, PyObject *v);
#define __Pyx_SetItemOnTypeDict(tp, k, v) __Pyx__SetItemOnTypeDict((PyTypeObject*)tp, k, v)

/* FixUpExtensionType.proto */
static CYTHON_INLINE int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type);

/* PyObjectCallNoArg.proto (used by PyObjectCallMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);

/* PyObjectGetMethod.proto (used by PyObjectCallMethod0) */
#if !(CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000)))
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method);
#endif

/* PyObjectCallMethod0.proto (used by PyType_Ready) */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name);

/* ValidateBasesTuple.proto (used by PyType_Ready) */
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_USE_TYPE_SPECS
static int __Pyx_validate_bases_tuple(const char *type_name, Py_ssize_t dictoffset, PyObject *bases);
#endif

/* PyType_Ready.proto */
CYTHON_UNUSED static int __Pyx_PyType_Ready(PyTypeObject *t);

/* TypeImport.proto */
#ifndef __PYX_HAVE_RT_ImportType_proto_3_2_4
#define __PYX_HAVE_RT_ImportType_proto_3_2_4
#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#include <stdalign.h>
#endif
#if (defined (__STDC_VERSION__) && __STDC_VERSION__ >= 201112L) || __cplusplus >= 201103L
#define __PYX_GET_STRUCT_ALIGNMENT_3_2_4(s) alignof(s)
#else
#define __PYX_GET_STRUCT_ALIGNMENT_3_2_4(s) sizeof(void*)
#endif
enum __Pyx_ImportType_CheckSize_3_2_4 {
   __Pyx_ImportType_CheckSize_Error_3_2_4 = 0,
   __Pyx_ImportType_CheckSize_Warn_3_2_4 = 1,
   __Pyx_ImportType_CheckSize_Ignore_3_2_4 = 2
};
static PyTypeObject *__Pyx_ImportType_3_2_4(PyObject* module, const char *module_name, const char *class_name, size_t size, size_t alignment, enum __Pyx_ImportType_CheckSize_3_2_4 check_size);
#endif

/* GetVTable.proto */
static void* __Pyx_GetVtable(PyTypeObject *type);

/* FormatTypeName.proto (used by ValidateExternBase) */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%U"
#define __Pyx_DECREF_TypeName(obj) Py_XDECREF(obj)
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
#define __Pyx_PyType_GetFullyQualifiedName PyType_GetFullyQualifiedName
#else
static __Pyx_TypeName __Pyx_PyType_GetFullyQualifiedName(PyTypeObject* tp);
#endif
#else  // !LIMITED_API
typedef const char *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%.200s"
#define __Pyx_PyType_GetFullyQualifiedName(tp) ((tp)->tp_name)
#define __Pyx_DECREF_TypeName(obj)
#endif

/* ValidateExternBase.proto */
static int __Pyx_validate_extern_base(PyTypeObject *base);

/* SetVTable.proto */
static int __Pyx_SetVtable(PyTypeObject* typeptr , void* vtable);

/* MergeVTables.proto */
static int __Pyx_MergeVtables(PyTypeObject *type);

/* VoidPtrImport.proto */
static int __Pyx_ImportVoidPtr_3_2_4(PyObject *module, const char *name, void **p, const char *sig);

/* FunctionImport.proto */
static int __Pyx_ImportFunction_3_2_4(PyObject *module, const char *funcname, void (**f)(void), const char *sig);

/* HasAttr.proto (used by ImportImpl) */
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
#define __Pyx_HasAttr(o, n)  PyObject_HasAttrWithError(o, n)
#else
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *, PyObject *);
#endif

/* ImportImpl.export */
static PyObject *__Pyx__Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, PyObject *moddict, int level);

/* Import.proto */
static CYTHON_INLINE PyObject *__Pyx_Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, int level);

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* ListPack.proto */
static PyObject *__Pyx_PyList_Pack(Py_ssize_t n, ...);

/* GetModuleGlobalName.proto */
#include "src/gevent/_generated_include/GetModuleGlobalName_proto_35020a92d25e00989051b6cce92e00e13fc50c1cb05740bd074404c24babc545.h"
/* GetNameInClass.proto */
#define __Pyx_GetNameInClass(var, nmspace, name)  (var) = __Pyx__GetNameInClass(nmspace, name)
static PyObject *__Pyx__GetNameInClass(PyObject *nmspace, PyObject *name);

/* dict_setdefault.proto (used by FetchCommonType) */
static CYTHON_INLINE PyObject *__Pyx_PyDict_SetDefault(PyObject *d, PyObject *key, PyObject *default_value);

/* AddModuleRef.proto (used by FetchSharedCythonModule) */
#if ((CYTHON_COMPILING_IN_CPYTHON_FREETHREADING ) ||\
     __PYX_LIMITED_VERSION_HEX < 0x030d0000)
  static PyObject *__Pyx_PyImport_AddModuleRef(const char *name);
#else
  #define __Pyx_PyImport_AddModuleRef(name) PyImport_AddModuleRef(name)
#endif

/* FetchSharedCythonModule.proto (used by FetchCommonType) */
static PyObject *__Pyx_FetchSharedCythonABIModule(void);

/* FetchCommonType.proto (used by CommonTypesMetaclass) */
static PyTypeObject* __Pyx_FetchCommonTypeFromSpec(PyTypeObject *metaclass, PyObject *module, PyType_Spec *spec, PyObject *bases);

/* CommonTypesMetaclass.proto (used by CythonFunctionShared) */
static int __pyx_CommonTypesMetaclass_init(PyObject *module);
#define __Pyx_CommonTypesMetaclass_USED

/* PyMethodNew.proto (used by CythonFunctionShared) */
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ);

/* PyVectorcallFastCallDict.proto (used by CythonFunctionShared) */
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw);
#endif

/* CythonFunctionShared.proto (used by CythonFunction) */
#include "src/gevent/_generated_include/CythonFunctionShared_proto_cfd16e7b1cdcce8e6454094d94c7459b788326000c3b790f09af3662926ca152.h"
/* CythonFunction.proto */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);

/* Globals.proto */
static PyObject* __Pyx_Globals(void);

/* CLineInTraceback.proto (used by AddTraceback) */
#if CYTHON_CLINE_IN_TRACEBACK && CYTHON_CLINE_IN_TRACEBACK_RUNTIME
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#else
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#endif

/* CodeObjectCache.proto (used by AddTraceback) */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject __Pyx_CachedCodeObjectType;
#else
typedef PyCodeObject __Pyx_CachedCodeObjectType;
#endif
typedef struct {
    __Pyx_CachedCodeObjectType* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_atomic_int_type accessor_count;
  #endif
};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static __Pyx_CachedCodeObjectType *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, __Pyx_CachedCodeObjectType* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* GCCDiagnostics.proto */
#if !defined(__INTEL_COMPILER) && defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6))
#define __Pyx_HAS_GCC_DIAGNOSTIC
#endif

/* PyObjectVectorCallKwBuilder.proto (used by CIntToPy) */
CYTHON_UNUSED static int __Pyx_VectorcallBuilder_AddArg_Check(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n);
#if CYTHON_VECTORCALL
#if PY_VERSION_HEX >= 0x03090000
#define __Pyx_Object_Vectorcall_CallFromBuilder PyObject_Vectorcall
#else
#define __Pyx_Object_Vectorcall_CallFromBuilder _PyObject_Vectorcall
#endif
#define __Pyx_MakeVectorcallBuilderKwds(n) PyTuple_New(n)
static int __Pyx_VectorcallBuilder_AddArg(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n);
static int __Pyx_VectorcallBuilder_AddArgStr(const char *key, PyObject *value, PyObject *builder, PyObject **args, int n);
#else
#define __Pyx_Object_Vectorcall_CallFromBuilder __Pyx_PyObject_FastCallDict
#define __Pyx_MakeVectorcallBuilderKwds(n) __Pyx_PyDict_NewPresized(n)
#define __Pyx_VectorcallBuilder_AddArg(key, value, builder, args, n) PyDict_SetItem(builder, key, value)
#define __Pyx_VectorcallBuilder_AddArgStr(key, value, builder, args, n) PyDict_SetItemString(builder, key, value)
#endif

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_int(int value);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyLong_As_int(PyObject *);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_long(long value);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyLong_As_long(PyObject *);

/* FastTypeChecks.proto */
#include "src/gevent/_generated_include/FastTypeChecks_proto_b6a1eb5ffa2a3fc9ebedcc671e034de99427399b8e4cbe35bbcd118ac87e0e6e.h"
/* GetRuntimeVersion.proto */
#if __PYX_LIMITED_VERSION_HEX < 0x030b0000
static unsigned long __Pyx_cached_runtime_version = 0;
static void __Pyx_init_runtime_version(void);
#else
#define __Pyx_init_runtime_version()
#endif
static unsigned long __Pyx_get_runtime_version(void);

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer);

/* DecompressString.proto */
static PyObject *__Pyx_DecompressString(const char *s, Py_ssize_t length, int algo);

/* MultiPhaseInitModuleState.proto */
#if CYTHON_PEP489_MULTI_PHASE_INIT && CYTHON_USE_MODULE_STATE
static PyObject *__Pyx_State_FindModule(void*);
static int __Pyx_State_AddModule(PyObject* module, void*);
static int __Pyx_State_RemoveModule(void*);
#elif CYTHON_USE_MODULE_STATE
#define __Pyx_State_FindModule PyState_FindModule
#define __Pyx_State_AddModule PyState_AddModule
#define __Pyx_State_RemoveModule PyState_RemoveModule
#endif

/* #### Code section: module_declarations ### */
/* CythonABIVersion.proto */
#include "src/gevent/_generated_include/CythonABIVersion_proto_6de230514e3c249dc5d32a29298796e6371a56c148e74d1832d78a4b882841b1.h"
static PyObject *__pyx_f_6gevent_14_gevent_c_imap_13IMapUnordered__inext(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6gevent_14_gevent_c_imap_13IMapUnordered__ispawn(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *__pyx_v_self, PyObject *__pyx_v_func, PyObject *__pyx_v_item, int __pyx_v_item_index); /* proto*/
static PyObject *__pyx_f_6gevent_14_gevent_c_imap_13IMapUnordered__on_result(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *__pyx_v_self, PyObject *__pyx_v_greenlet, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6gevent_14_gevent_c_imap_13IMapUnordered__on_finish(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *__pyx_v_self, PyObject *__pyx_v_exception); /* proto*/
static PyObject *__pyx_f_6gevent_14_gevent_c_imap_13IMapUnordered__iqueue_value_for_success(CYTHON_UNUSED struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *__pyx_v_self, PyObject *__pyx_v_greenlet); /* proto*/
static PyObject *__pyx_f_6gevent_14_gevent_c_imap_13IMapUnordered__iqueue_value_for_failure(CYTHON_UNUSED struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *__pyx_v_self, PyObject *__pyx_v_greenlet); /* proto*/
static PyObject *__pyx_f_6gevent_14_gevent_c_imap_13IMapUnordered__iqueue_value_for_self_finished(CYTHON_UNUSED struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6gevent_14_gevent_c_imap_13IMapUnordered__iqueue_value_for_self_failure(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *__pyx_v_self, PyObject *__pyx_v_exception); /* proto*/
static PyObject *__pyx_f_6gevent_14_gevent_c_imap_4IMap__inext(struct __pyx_obj_6gevent_14_gevent_c_imap_IMap *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6gevent_14_gevent_c_imap_4IMap__iqueue_value_for_success(struct __pyx_obj_6gevent_14_gevent_c_imap_IMap *__pyx_v_self, PyObject *__pyx_v_greenlet); /* proto*/
static PyObject *__pyx_f_6gevent_14_gevent_c_imap_4IMap__iqueue_value_for_failure(struct __pyx_obj_6gevent_14_gevent_c_imap_IMap *__pyx_v_self, PyObject *__pyx_v_greenlet); /* proto*/
static PyObject *__pyx_f_6gevent_14_gevent_c_imap_4IMap__iqueue_value_for_self_finished(struct __pyx_obj_6gevent_14_gevent_c_imap_IMap *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6gevent_14_gevent_c_imap_4IMap__iqueue_value_for_self_failure(struct __pyx_obj_6gevent_14_gevent_c_imap_IMap *__pyx_v_self, PyObject *__pyx_v_exception); /* proto*/

/* Module declarations from "cython" */

/* Module declarations from "libc.string" */

/* Module declarations from "libc.stdio" */

/* Module declarations from "__builtin__" */

/* Module declarations from "cpython.type" */

/* Module declarations from "cpython" */

/* Module declarations from "cpython.object" */

/* Module declarations from "cpython.ref" */

/* Module declarations from "weakref" */

/* Module declarations from "gevent._gevent_c_ident" */
static PyObject **__pyx_vp_6gevent_15_gevent_c_ident_heappop = 0;
#define __pyx_v_6gevent_15_gevent_c_ident_heappop (*__pyx_vp_6gevent_15_gevent_c_ident_heappop)
static PyObject **__pyx_vp_6gevent_15_gevent_c_ident_heappush = 0;
#define __pyx_v_6gevent_15_gevent_c_ident_heappush (*__pyx_vp_6gevent_15_gevent_c_ident_heappush)
static PyObject **__pyx_vp_6gevent_15_gevent_c_ident_WeakKeyDictionary = 0;
#define __pyx_v_6gevent_15_gevent_c_ident_WeakKeyDictionary (*__pyx_vp_6gevent_15_gevent_c_ident_WeakKeyDictionary)

/* Module declarations from "greenlet" */

/* Module declarations from "gevent._gevent_c_greenlet_primitives" */
static PyObject **__pyx_vp_6gevent_29_gevent_c_greenlet_primitives_get_objects = 0;
#define __pyx_v_6gevent_29_gevent_c_greenlet_primitives_get_objects (*__pyx_vp_6gevent_29_gevent_c_greenlet_primitives_get_objects)
static PyObject **__pyx_vp_6gevent_29_gevent_c_greenlet_primitives_wref = 0;
#define __pyx_v_6gevent_29_gevent_c_greenlet_primitives_wref (*__pyx_vp_6gevent_29_gevent_c_greenlet_primitives_wref)
static PyObject **__pyx_vp_6gevent_29_gevent_c_greenlet_primitives_BlockingSwitchOutError = 0;
#define __pyx_v_6gevent_29_gevent_c_greenlet_primitives_BlockingSwitchOutError (*__pyx_vp_6gevent_29_gevent_c_greenlet_primitives_BlockingSwitchOutError)
static int *__pyx_vp_6gevent_29_gevent_c_greenlet_primitives__greenlet_imported = 0;
#define __pyx_v_6gevent_29_gevent_c_greenlet_primitives__greenlet_imported (*__pyx_vp_6gevent_29_gevent_c_greenlet_primitives__greenlet_imported)
static PyTypeObject **__pyx_vp_6gevent_29_gevent_c_greenlet_primitives__memoryview = 0;
#define __pyx_v_6gevent_29_gevent_c_greenlet_primitives__memoryview (*__pyx_vp_6gevent_29_gevent_c_greenlet_primitives__memoryview)
static PyTypeObject **__pyx_vp_6gevent_29_gevent_c_greenlet_primitives__buffer = 0;
#define __pyx_v_6gevent_29_gevent_c_greenlet_primitives__buffer (*__pyx_vp_6gevent_29_gevent_c_greenlet_primitives__buffer)

/* Module declarations from "gevent._gevent_c_hub_local" */
static PyObject **__pyx_vp_6gevent_19_gevent_c_hub_local__threadlocal = 0;
#define __pyx_v_6gevent_19_gevent_c_hub_local__threadlocal (*__pyx_vp_6gevent_19_gevent_c_hub_local__threadlocal)
static struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *(*__pyx_f_6gevent_19_gevent_c_hub_local_get_hub_if_exists)(int __pyx_skip_dispatch); /*proto*/
static struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *(*__pyx_f_6gevent_19_gevent_c_hub_local_get_hub_noargs)(int __pyx_skip_dispatch); /*proto*/

/* Module declarations from "gevent._gevent_c_waiter" */
static PyObject **__pyx_vp_6gevent_16_gevent_c_waiter_sys = 0;
#define __pyx_v_6gevent_16_gevent_c_waiter_sys (*__pyx_vp_6gevent_16_gevent_c_waiter_sys)
static PyObject **__pyx_vp_6gevent_16_gevent_c_waiter_ConcurrentObjectUseError = 0;
#define __pyx_v_6gevent_16_gevent_c_waiter_ConcurrentObjectUseError (*__pyx_vp_6gevent_16_gevent_c_waiter_ConcurrentObjectUseError)
static int *__pyx_vp_6gevent_16_gevent_c_waiter__greenlet_imported = 0;
#define __pyx_v_6gevent_16_gevent_c_waiter__greenlet_imported (*__pyx_vp_6gevent_16_gevent_c_waiter__greenlet_imported)
static PyObject **__pyx_vp_6gevent_16_gevent_c_waiter__NONE = 0;
#define __pyx_v_6gevent_16_gevent_c_waiter__NONE (*__pyx_vp_6gevent_16_gevent_c_waiter__NONE)

/* Module declarations from "gevent._gevent_cgreenlet" */
static int *__pyx_vp_6gevent_17_gevent_cgreenlet__PYPY = 0;
#define __pyx_v_6gevent_17_gevent_cgreenlet__PYPY (*__pyx_vp_6gevent_17_gevent_cgreenlet__PYPY)
static PyObject **__pyx_vp_6gevent_17_gevent_cgreenlet_sys_getframe = 0;
#define __pyx_v_6gevent_17_gevent_cgreenlet_sys_getframe (*__pyx_vp_6gevent_17_gevent_cgreenlet_sys_getframe)
static PyObject **__pyx_vp_6gevent_17_gevent_cgreenlet_sys_exc_info = 0;
#define __pyx_v_6gevent_17_gevent_cgreenlet_sys_exc_info (*__pyx_vp_6gevent_17_gevent_cgreenlet_sys_exc_info)
static PyObject **__pyx_vp_6gevent_17_gevent_cgreenlet_Timeout = 0;
#define __pyx_v_6gevent_17_gevent_cgreenlet_Timeout (*__pyx_vp_6gevent_17_gevent_cgreenlet_Timeout)
static PyObject **__pyx_vp_6gevent_17_gevent_cgreenlet_GreenletExit = 0;
#define __pyx_v_6gevent_17_gevent_cgreenlet_GreenletExit (*__pyx_vp_6gevent_17_gevent_cgreenlet_GreenletExit)
static PyObject **__pyx_vp_6gevent_17_gevent_cgreenlet_InvalidSwitchError = 0;
#define __pyx_v_6gevent_17_gevent_cgreenlet_InvalidSwitchError (*__pyx_vp_6gevent_17_gevent_cgreenlet_InvalidSwitchError)
static int *__pyx_vp_6gevent_17_gevent_cgreenlet__greenlet_imported = 0;
#define __pyx_v_6gevent_17_gevent_cgreenlet__greenlet_imported (*__pyx_vp_6gevent_17_gevent_cgreenlet__greenlet_imported)
static PyObject **__pyx_vp_6gevent_17_gevent_cgreenlet__greenlet__init__ = 0;
#define __pyx_v_6gevent_17_gevent_cgreenlet__greenlet__init__ (*__pyx_vp_6gevent_17_gevent_cgreenlet__greenlet__init__)
static PyObject **__pyx_vp_6gevent_17_gevent_cgreenlet__threadlocal = 0;
#define __pyx_v_6gevent_17_gevent_cgreenlet__threadlocal (*__pyx_vp_6gevent_17_gevent_cgreenlet__threadlocal)
static PyObject **__pyx_vp_6gevent_17_gevent_cgreenlet_get_hub_class = 0;
#define __pyx_v_6gevent_17_gevent_cgreenlet_get_hub_class (*__pyx_vp_6gevent_17_gevent_cgreenlet_get_hub_class)
static PyObject **__pyx_vp_6gevent_17_gevent_cgreenlet_wref = 0;
#define __pyx_v_6gevent_17_gevent_cgreenlet_wref (*__pyx_vp_6gevent_17_gevent_cgreenlet_wref)
static PyObject **__pyx_vp_6gevent_17_gevent_cgreenlet_dump_traceback = 0;
#define __pyx_v_6gevent_17_gevent_cgreenlet_dump_traceback (*__pyx_vp_6gevent_17_gevent_cgreenlet_dump_traceback)
static PyObject **__pyx_vp_6gevent_17_gevent_cgreenlet_load_traceback = 0;
#define __pyx_v_6gevent_17_gevent_cgreenlet_load_traceback (*__pyx_vp_6gevent_17_gevent_cgreenlet_load_traceback)
static PyObject **__pyx_vp_6gevent_17_gevent_cgreenlet_wait = 0;
#define __pyx_v_6gevent_17_gevent_cgreenlet_wait (*__pyx_vp_6gevent_17_gevent_cgreenlet_wait)
static PyObject **__pyx_vp_6gevent_17_gevent_cgreenlet_iwait = 0;
#define __pyx_v_6gevent_17_gevent_cgreenlet_iwait (*__pyx_vp_6gevent_17_gevent_cgreenlet_iwait)
static PyObject **__pyx_vp_6gevent_17_gevent_cgreenlet_reraise = 0;
#define __pyx_v_6gevent_17_gevent_cgreenlet_reraise (*__pyx_vp_6gevent_17_gevent_cgreenlet_reraise)
static PyObject **__pyx_vp_6gevent_17_gevent_cgreenlet_GEVENT_CONFIG = 0;
#define __pyx_v_6gevent_17_gevent_cgreenlet_GEVENT_CONFIG (*__pyx_vp_6gevent_17_gevent_cgreenlet_GEVENT_CONFIG)
static struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event **__pyx_vp_6gevent_17_gevent_cgreenlet__cancelled_start_event = 0;
#define __pyx_v_6gevent_17_gevent_cgreenlet__cancelled_start_event (*__pyx_vp_6gevent_17_gevent_cgreenlet__cancelled_start_event)
static struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event **__pyx_vp_6gevent_17_gevent_cgreenlet__start_completed_event = 0;
#define __pyx_v_6gevent_17_gevent_cgreenlet__start_completed_event (*__pyx_vp_6gevent_17_gevent_cgreenlet__start_completed_event)
static PyObject **__pyx_vp_6gevent_17_gevent_cgreenlet__spawn_callbacks = 0;
#define __pyx_v_6gevent_17_gevent_cgreenlet__spawn_callbacks (*__pyx_vp_6gevent_17_gevent_cgreenlet__spawn_callbacks)

/* Module declarations from "gevent._gevent_c_abstract_linkable" */
static PyObject **__pyx_vp_6gevent_27_gevent_c_abstract_linkable_InvalidSwitchError = 0;
#define __pyx_v_6gevent_27_gevent_c_abstract_linkable_InvalidSwitchError (*__pyx_vp_6gevent_27_gevent_c_abstract_linkable_InvalidSwitchError)
static PyObject **__pyx_vp_6gevent_27_gevent_c_abstract_linkable_InvalidThreadUseError = 0;
#define __pyx_v_6gevent_27_gevent_c_abstract_linkable_InvalidThreadUseError (*__pyx_vp_6gevent_27_gevent_c_abstract_linkable_InvalidThreadUseError)
static PyObject **__pyx_vp_6gevent_27_gevent_c_abstract_linkable_Timeout = 0;
#define __pyx_v_6gevent_27_gevent_c_abstract_linkable_Timeout (*__pyx_vp_6gevent_27_gevent_c_abstract_linkable_Timeout)
static PyObject **__pyx_vp_6gevent_27_gevent_c_abstract_linkable__get_thread_ident = 0;
#define __pyx_v_6gevent_27_gevent_c_abstract_linkable__get_thread_ident (*__pyx_vp_6gevent_27_gevent_c_abstract_linkable__get_thread_ident)
static int *__pyx_vp_6gevent_27_gevent_c_abstract_linkable__greenlet_imported = 0;
#define __pyx_v_6gevent_27_gevent_c_abstract_linkable__greenlet_imported (*__pyx_vp_6gevent_27_gevent_c_abstract_linkable__greenlet_imported)
static PyObject **__pyx_vp_6gevent_27_gevent_c_abstract_linkable_get_objects = 0;
#define __pyx_v_6gevent_27_gevent_c_abstract_linkable_get_objects (*__pyx_vp_6gevent_27_gevent_c_abstract_linkable_get_objects)

/* Module declarations from "gevent._gevent_c_semaphore" */
static PyObject **__pyx_vp_6gevent_19_gevent_c_semaphore_InvalidThreadUseError = 0;
#define __pyx_v_6gevent_19_gevent_c_semaphore_InvalidThreadUseError (*__pyx_vp_6gevent_19_gevent_c_semaphore_InvalidThreadUseError)
static PyObject **__pyx_vp_6gevent_19_gevent_c_semaphore_LoopExit = 0;
#define __pyx_v_6gevent_19_gevent_c_semaphore_LoopExit (*__pyx_vp_6gevent_19_gevent_c_semaphore_LoopExit)
static PyObject **__pyx_vp_6gevent_19_gevent_c_semaphore_Timeout = 0;
#define __pyx_v_6gevent_19_gevent_c_semaphore_Timeout (*__pyx_vp_6gevent_19_gevent_c_semaphore_Timeout)
static PyObject **__pyx_vp_6gevent_19_gevent_c_semaphore__native_sleep = 0;
#define __pyx_v_6gevent_19_gevent_c_semaphore__native_sleep (*__pyx_vp_6gevent_19_gevent_c_semaphore__native_sleep)
static PyObject **__pyx_vp_6gevent_19_gevent_c_semaphore_monotonic = 0;
#define __pyx_v_6gevent_19_gevent_c_semaphore_monotonic (*__pyx_vp_6gevent_19_gevent_c_semaphore_monotonic)
static PyObject **__pyx_vp_6gevent_19_gevent_c_semaphore_spawn_raw = 0;
#define __pyx_v_6gevent_19_gevent_c_semaphore_spawn_raw (*__pyx_vp_6gevent_19_gevent_c_semaphore_spawn_raw)
static PyObject **__pyx_vp_6gevent_19_gevent_c_semaphore__UNSET = 0;
#define __pyx_v_6gevent_19_gevent_c_semaphore__UNSET (*__pyx_vp_6gevent_19_gevent_c_semaphore__UNSET)
static PyObject **__pyx_vp_6gevent_19_gevent_c_semaphore__MULTI = 0;
#define __pyx_v_6gevent_19_gevent_c_semaphore__MULTI (*__pyx_vp_6gevent_19_gevent_c_semaphore__MULTI)

/* Module declarations from "gevent._gevent_cevent" */
static PyObject **__pyx_vp_6gevent_14_gevent_cevent__None = 0;
#define __pyx_v_6gevent_14_gevent_cevent__None (*__pyx_vp_6gevent_14_gevent_cevent__None)
static PyObject **__pyx_vp_6gevent_14_gevent_cevent_reraise = 0;
#define __pyx_v_6gevent_14_gevent_cevent_reraise (*__pyx_vp_6gevent_14_gevent_cevent_reraise)
static PyObject **__pyx_vp_6gevent_14_gevent_cevent_dump_traceback = 0;
#define __pyx_v_6gevent_14_gevent_cevent_dump_traceback (*__pyx_vp_6gevent_14_gevent_cevent_dump_traceback)
static PyObject **__pyx_vp_6gevent_14_gevent_cevent_load_traceback = 0;
#define __pyx_v_6gevent_14_gevent_cevent_load_traceback (*__pyx_vp_6gevent_14_gevent_cevent_load_traceback)
static PyObject **__pyx_vp_6gevent_14_gevent_cevent_Timeout = 0;
#define __pyx_v_6gevent_14_gevent_cevent_Timeout (*__pyx_vp_6gevent_14_gevent_cevent_Timeout)

/* Module declarations from "gevent._gevent_cqueue" */
static int *__pyx_vp_6gevent_14_gevent_cqueue__greenlet_imported = 0;
#define __pyx_v_6gevent_14_gevent_cqueue__greenlet_imported (*__pyx_vp_6gevent_14_gevent_cqueue__greenlet_imported)
static PyObject **__pyx_vp_6gevent_14_gevent_cqueue__heappush = 0;
#define __pyx_v_6gevent_14_gevent_cqueue__heappush (*__pyx_vp_6gevent_14_gevent_cqueue__heappush)
static PyObject **__pyx_vp_6gevent_14_gevent_cqueue__heappop = 0;
#define __pyx_v_6gevent_14_gevent_cqueue__heappop (*__pyx_vp_6gevent_14_gevent_cqueue__heappop)
static PyObject **__pyx_vp_6gevent_14_gevent_cqueue__heapify = 0;
#define __pyx_v_6gevent_14_gevent_cqueue__heapify (*__pyx_vp_6gevent_14_gevent_cqueue__heapify)
static PyObject **__pyx_vp_6gevent_14_gevent_cqueue__Empty = 0;
#define __pyx_v_6gevent_14_gevent_cqueue__Empty (*__pyx_vp_6gevent_14_gevent_cqueue__Empty)
static PyObject **__pyx_vp_6gevent_14_gevent_cqueue__Full = 0;
#define __pyx_v_6gevent_14_gevent_cqueue__Full (*__pyx_vp_6gevent_14_gevent_cqueue__Full)
static PyObject **__pyx_vp_6gevent_14_gevent_cqueue_Timeout = 0;
#define __pyx_v_6gevent_14_gevent_cqueue_Timeout (*__pyx_vp_6gevent_14_gevent_cqueue_Timeout)
static PyObject **__pyx_vp_6gevent_14_gevent_cqueue_InvalidSwitchError = 0;
#define __pyx_v_6gevent_14_gevent_cqueue_InvalidSwitchError (*__pyx_vp_6gevent_14_gevent_cqueue_InvalidSwitchError)

/* Module declarations from "gevent._gevent_c_imap" */
static CYTHON_INLINE PyObject *__pyx_f_6gevent_14_gevent_c_imap__raise_exc(struct __pyx_obj_6gevent_14_gevent_c_imap_Failure *); /*proto*/
/* #### Code section: typeinfo ### */
/* #### Code section: before_global_var ### */
#define __Pyx_MODULE_NAME "gevent._gevent_c_imap"
extern int __pyx_module_is_main_gevent___gevent_c_imap;
int __pyx_module_is_main_gevent___gevent_c_imap = 0;

/* Implementation of "gevent._gevent_c_imap" */
/* #### Code section: global_var ### */
static PyObject *__pyx_builtin___import__;
/* #### Code section: string_decls ### */
static const char __pyx_k_Iterators_across_greenlets_or_A[] = "\nIterators across greenlets or AsyncResult objects.\n\n";
/* #### Code section: decls ### */
static int __pyx_pf_6gevent_14_gevent_c_imap_7Failure___init__(struct __pyx_obj_6gevent_14_gevent_c_imap_Failure *__pyx_v_self, PyObject *__pyx_v_exc, PyObject *__pyx_v_raise_exception); /* proto */
static PyObject *__pyx_pf_6gevent_14_gevent_c_imap_7Failure_3exc___get__(struct __pyx_obj_6gevent_14_gevent_c_imap_Failure *__pyx_v_self); /* proto */
static int __pyx_pf_6gevent_14_gevent_c_imap_13IMapUnordered___init__(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *__pyx_v_self, PyObject *__pyx_v_func, PyObject *__pyx_v_iterable, PyObject *__pyx_v_spawn, PyObject *__pyx_v_maxsize, PyObject *__pyx_v__zipped); /* proto */
static PyObject *__pyx_pf_6gevent_14_gevent_c_imap_13IMapUnordered_2__iter__(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_14_gevent_c_imap_13IMapUnordered_4__next__(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_14_gevent_c_imap_13IMapUnordered_6_run(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_14_gevent_c_imap_13IMapUnordered_8_on_result(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *__pyx_v_self, PyObject *__pyx_v_greenlet); /* proto */
static PyObject *__pyx_pf_6gevent_14_gevent_c_imap_13IMapUnordered_5queue___get__(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_14_gevent_c_imap_13IMapUnordered_8finished___get__(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *__pyx_v_self); /* proto */
static int __pyx_pf_6gevent_14_gevent_c_imap_4IMap___init__(struct __pyx_obj_6gevent_14_gevent_c_imap_IMap *__pyx_v_self, PyObject *__pyx_v_args, PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_tp_new_6gevent_14_gevent_c_imap_Failure(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6gevent_14_gevent_c_imap_IMapUnordered(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6gevent_14_gevent_c_imap_IMap(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
/* #### Code section: late_includes ### */
/* #### Code section: module_state ### */
/* SmallCodeConfig */
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif

typedef struct {
  PyObject *__pyx_d;
  PyObject *__pyx_b;
  PyObject *__pyx_cython_runtime;
  PyObject *__pyx_empty_tuple;
  PyObject *__pyx_empty_bytes;
  PyObject *__pyx_empty_unicode;
  PyTypeObject *__pyx_ptype_7cpython_4type_type;
  PyTypeObject *__pyx_ptype_6gevent_15_gevent_c_ident_ref;
  PyTypeObject *__pyx_ptype_6gevent_15_gevent_c_ident_ValuedWeakRef;
  PyTypeObject *__pyx_ptype_6gevent_15_gevent_c_ident_IdentRegistry;
  PyTypeObject *__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_greenlet;
  PyTypeObject *__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet;
  PyTypeObject *__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop;
  PyTypeObject *__pyx_ptype_6gevent_16_gevent_c_waiter_greenlet;
  PyTypeObject *__pyx_ptype_6gevent_16_gevent_c_waiter_Waiter;
  PyTypeObject *__pyx_ptype_6gevent_16_gevent_c_waiter_MultipleWaiter;
  PyTypeObject *__pyx_ptype_6gevent_17_gevent_cgreenlet_greenlet;
  PyTypeObject *__pyx_ptype_6gevent_17_gevent_cgreenlet_SpawnedLink;
  PyTypeObject *__pyx_ptype_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink;
  PyTypeObject *__pyx_ptype_6gevent_17_gevent_cgreenlet_FailureSpawnedLink;
  PyTypeObject *__pyx_ptype_6gevent_17_gevent_cgreenlet__Frame;
  PyTypeObject *__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet;
  PyTypeObject *__pyx_ptype_6gevent_17_gevent_cgreenlet__dummy_event;
  PyTypeObject *__pyx_ptype_6gevent_27_gevent_c_abstract_linkable_greenlet;
  PyTypeObject *__pyx_ptype_6gevent_27_gevent_c_abstract_linkable__FakeNotifier;
  PyTypeObject *__pyx_ptype_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable;
  PyTypeObject *__pyx_ptype_6gevent_19_gevent_c_semaphore__LockReleaseLink;
  PyTypeObject *__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore;
  PyTypeObject *__pyx_ptype_6gevent_19_gevent_c_semaphore_BoundedSemaphore;
  PyTypeObject *__pyx_ptype_6gevent_14_gevent_cevent_Event;
  PyTypeObject *__pyx_ptype_6gevent_14_gevent_cevent_AsyncResult;
  PyTypeObject *__pyx_ptype_6gevent_14_gevent_cqueue_greenlet;
  PyTypeObject *__pyx_ptype_6gevent_14_gevent_cqueue_SimpleQueue;
  PyTypeObject *__pyx_ptype_6gevent_14_gevent_cqueue_Queue;
  PyTypeObject *__pyx_ptype_6gevent_14_gevent_cqueue_ItemWaiter;
  PyTypeObject *__pyx_ptype_6gevent_14_gevent_cqueue_UnboundQueue;
  PyTypeObject *__pyx_ptype_6gevent_14_gevent_cqueue_PriorityQueue;
  PyTypeObject *__pyx_ptype_6gevent_14_gevent_cqueue_LifoQueue;
  PyTypeObject *__pyx_ptype_6gevent_14_gevent_cqueue_Channel;
  PyObject *__pyx_type_6gevent_14_gevent_c_imap_Failure;
  PyObject *__pyx_type_6gevent_14_gevent_c_imap_IMapUnordered;
  PyObject *__pyx_type_6gevent_14_gevent_c_imap_IMap;
  PyTypeObject *__pyx_ptype_6gevent_14_gevent_c_imap_Failure;
  PyTypeObject *__pyx_ptype_6gevent_14_gevent_c_imap_IMapUnordered;
  PyTypeObject *__pyx_ptype_6gevent_14_gevent_c_imap_IMap;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_items;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_pop;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_values;
  PyObject *__pyx_tuple[1];
  PyObject *__pyx_codeobj_tab[2];
  PyObject *__pyx_string_tab[78];
/* #### Code section: module_state_contents ### */
/* CommonTypesMetaclass.module_state_decls */
PyTypeObject *__pyx_CommonTypesMetaclassType;

/* CachedMethodType.module_state_decls */
#if CYTHON_COMPILING_IN_LIMITED_API
PyObject *__Pyx_CachedMethodType;
#endif

/* CythonFunctionShared.module_state_decls */
PyTypeObject *__pyx_CyFunctionType;

/* CodeObjectCache.module_state_decls */
struct __Pyx_CodeObjectCache __pyx_code_cache;

/* #### Code section: module_state_end ### */
} __pyx_mstatetype;

#if CYTHON_USE_MODULE_STATE
#ifdef __cplusplus
namespace {
extern struct PyModuleDef __pyx_moduledef;
} /* anonymous namespace */
#else
static struct PyModuleDef __pyx_moduledef;
#endif

#define __pyx_mstate_global (__Pyx_PyModule_GetState(__Pyx_State_FindModule(&__pyx_moduledef)))

#define __pyx_m (__Pyx_State_FindModule(&__pyx_moduledef))
#else
static __pyx_mstatetype __pyx_mstate_global_static =
#ifdef __cplusplus
    {};
#else
    {0};
#endif
static __pyx_mstatetype * const __pyx_mstate_global = &__pyx_mstate_global_static;
#endif
/* #### Code section: constant_name_defines ### */
#define __pyx_kp_u_ __pyx_string_tab[0]
#define __pyx_kp_u__2 __pyx_string_tab[1]
#define __pyx_kp_u_disable __pyx_string_tab[2]
#define __pyx_kp_u_enable __pyx_string_tab[3]
#define __pyx_kp_u_gc __pyx_string_tab[4]
#define __pyx_kp_u_gevent___imap __pyx_string_tab[5]
#define __pyx_kp_u_isenabled __pyx_string_tab[6]
#define __pyx_kp_u_src_gevent__imap_py __pyx_string_tab[7]
#define __pyx_n_u_Failure __pyx_string_tab[8]
#define __pyx_n_u_Greenlet __pyx_string_tab[9]
#define __pyx_n_u_IMap __pyx_string_tab[10]
#define __pyx_n_u_IMapUnordered __pyx_string_tab[11]
#define __pyx_n_u_IMapUnordered__on_result __pyx_string_tab[12]
#define __pyx_n_u_IMapUnordered__run __pyx_string_tab[13]
#define __pyx_n_u_Pyx_PyDict_NextRef __pyx_string_tab[14]
#define __pyx_n_u_Semaphore __pyx_string_tab[15]
#define __pyx_n_u_UnboundQueue __pyx_string_tab[16]
#define __pyx_n_u_all __pyx_string_tab[17]
#define __pyx_n_u_asyncio_coroutines __pyx_string_tab[18]
#define __pyx_n_u_cline_in_traceback __pyx_string_tab[19]
#define __pyx_n_u_dict __pyx_string_tab[20]
#define __pyx_n_u_e __pyx_string_tab[21]
#define __pyx_n_u_exc __pyx_string_tab[22]
#define __pyx_n_u_exception __pyx_string_tab[23]
#define __pyx_n_u_func __pyx_string_tab[24]
#define __pyx_n_u_func_2 __pyx_string_tab[25]
#define __pyx_n_u_gevent __pyx_string_tab[26]
#define __pyx_n_u_gevent__gevent_c_imap __pyx_string_tab[27]
#define __pyx_n_u_gevent__util __pyx_string_tab[28]
#define __pyx_n_u_greenlet __pyx_string_tab[29]
#define __pyx_n_u_imap_task_index __pyx_string_tab[30]
#define __pyx_n_u_import __pyx_string_tab[31]
#define __pyx_n_u_import_c_accel __pyx_string_tab[32]
#define __pyx_n_u_init __pyx_string_tab[33]
#define __pyx_n_u_is_coroutine __pyx_string_tab[34]
#define __pyx_n_u_item __pyx_string_tab[35]
#define __pyx_n_u_items __pyx_string_tab[36]
#define __pyx_n_u_iterable __pyx_string_tab[37]
#define __pyx_n_u_lock __pyx_string_tab[38]
#define __pyx_n_u_main __pyx_string_tab[39]
#define __pyx_n_u_maxsize __pyx_string_tab[40]
#define __pyx_n_u_module __pyx_string_tab[41]
#define __pyx_n_u_name __pyx_string_tab[42]
#define __pyx_n_u_next __pyx_string_tab[43]
#define __pyx_n_u_next_2 __pyx_string_tab[44]
#define __pyx_n_u_on_result __pyx_string_tab[45]
#define __pyx_n_u_pop __pyx_string_tab[46]
#define __pyx_n_u_pyx_capi __pyx_string_tab[47]
#define __pyx_n_u_pyx_vtable __pyx_string_tab[48]
#define __pyx_n_u_qualname __pyx_string_tab[49]
#define __pyx_n_u_queue __pyx_string_tab[50]
#define __pyx_n_u_raise_exception __pyx_string_tab[51]
#define __pyx_n_u_raise_exception_2 __pyx_string_tab[52]
#define __pyx_n_u_rawlink __pyx_string_tab[53]
#define __pyx_n_u_run __pyx_string_tab[54]
#define __pyx_n_u_self __pyx_string_tab[55]
#define __pyx_n_u_set_name __pyx_string_tab[56]
#define __pyx_n_u_setdefault __pyx_string_tab[57]
#define __pyx_n_u_slots __pyx_string_tab[58]
#define __pyx_n_u_spawn __pyx_string_tab[59]
#define __pyx_n_u_successful __pyx_string_tab[60]
#define __pyx_n_u_test __pyx_string_tab[61]
#define __pyx_n_u_value __pyx_string_tab[62]
#define __pyx_n_u_values __pyx_string_tab[63]
#define __pyx_n_u_zipped __pyx_string_tab[64]
#define __pyx_kp_b_PyObject_InvalidThreadUseError_L __pyx_string_tab[65]
#define __pyx_kp_b_PyObject_PyTypeObject_int_Blocki __pyx_string_tab[66]
#define __pyx_kp_b_PyObject_Timeout__None_dump_trac __pyx_string_tab[67]
#define __pyx_kp_b_PyObject_WeakKeyDictionary_heapp __pyx_string_tab[68]
#define __pyx_kp_b_PyObject__threadlocal __pyx_string_tab[69]
#define __pyx_kp_b_PyObject_int_ConcurrentObjectUse __pyx_string_tab[70]
#define __pyx_kp_b_PyObject_int_InvalidSwitchError __pyx_string_tab[71]
#define __pyx_kp_b_PyObject_int_InvalidSwitchError_2 __pyx_string_tab[72]
#define __pyx_kp_b_PyObject_int_struct___pyx_obj_6g __pyx_string_tab[73]
#define __pyx_kp_b_PyObject_struct___pyx_obj_6geven __pyx_string_tab[74]
#define __pyx_kp_b_iso88591_A_1_A_4q_F_q_6_V3b_D_t_q_1_8_a_d __pyx_string_tab[75]
#define __pyx_kp_b_iso88591_A_4q_A_O1_HAV6_Q_1A_1A_A_Q __pyx_string_tab[76]
#define __pyx_kp_b_struct___pyx_obj_6gevent_29_geve __pyx_string_tab[77]
/* #### Code section: module_state_clear ### */
#if CYTHON_USE_MODULE_STATE
static CYTHON_SMALL_CODE int __pyx_m_clear(PyObject *m) {
  __pyx_mstatetype *clear_module_state = __Pyx_PyModule_GetState(m);
  if (!clear_module_state) return 0;
  Py_CLEAR(clear_module_state->__pyx_d);
  Py_CLEAR(clear_module_state->__pyx_b);
  Py_CLEAR(clear_module_state->__pyx_cython_runtime);
  Py_CLEAR(clear_module_state->__pyx_empty_tuple);
  Py_CLEAR(clear_module_state->__pyx_empty_bytes);
  Py_CLEAR(clear_module_state->__pyx_empty_unicode);
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __Pyx_State_RemoveModule(NULL);
  #endif
  Py_CLEAR(clear_module_state->__pyx_ptype_7cpython_4type_type);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_15_gevent_c_ident_ref);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_15_gevent_c_ident_ValuedWeakRef);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_15_gevent_c_ident_IdentRegistry);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_greenlet);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_16_gevent_c_waiter_greenlet);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_16_gevent_c_waiter_Waiter);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_16_gevent_c_waiter_MultipleWaiter);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet_greenlet);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet_SpawnedLink);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet_FailureSpawnedLink);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet__Frame);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet__dummy_event);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_27_gevent_c_abstract_linkable_greenlet);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_27_gevent_c_abstract_linkable__FakeNotifier);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_19_gevent_c_semaphore__LockReleaseLink);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_19_gevent_c_semaphore_BoundedSemaphore);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_14_gevent_cevent_Event);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_14_gevent_cevent_AsyncResult);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_14_gevent_cqueue_greenlet);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_14_gevent_cqueue_SimpleQueue);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_14_gevent_cqueue_Queue);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_14_gevent_cqueue_ItemWaiter);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_14_gevent_cqueue_UnboundQueue);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_14_gevent_cqueue_PriorityQueue);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_14_gevent_cqueue_LifoQueue);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_14_gevent_cqueue_Channel);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_14_gevent_c_imap_Failure);
  Py_CLEAR(clear_module_state->__pyx_type_6gevent_14_gevent_c_imap_Failure);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_14_gevent_c_imap_IMapUnordered);
  Py_CLEAR(clear_module_state->__pyx_type_6gevent_14_gevent_c_imap_IMapUnordered);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_14_gevent_c_imap_IMap);
  Py_CLEAR(clear_module_state->__pyx_type_6gevent_14_gevent_c_imap_IMap);
  for (int i=0; i<1; ++i) { Py_CLEAR(clear_module_state->__pyx_tuple[i]); }
  for (int i=0; i<2; ++i) { Py_CLEAR(clear_module_state->__pyx_codeobj_tab[i]); }
  for (int i=0; i<78; ++i) { Py_CLEAR(clear_module_state->__pyx_string_tab[i]); }
/* #### Code section: module_state_clear_contents ### */
/* CommonTypesMetaclass.module_state_clear */
Py_CLEAR(clear_module_state->__pyx_CommonTypesMetaclassType);

/* CythonFunctionShared.module_state_clear */
Py_CLEAR(clear_module_state->__pyx_CyFunctionType);

/* #### Code section: module_state_clear_end ### */
return 0;
}
#endif
/* #### Code section: module_state_traverse ### */
#if CYTHON_USE_MODULE_STATE
static CYTHON_SMALL_CODE int __pyx_m_traverse(PyObject *m, visitproc visit, void *arg) {
  __pyx_mstatetype *traverse_module_state = __Pyx_PyModule_GetState(m);
  if (!traverse_module_state) return 0;
  Py_VISIT(traverse_module_state->__pyx_d);
  Py_VISIT(traverse_module_state->__pyx_b);
  Py_VISIT(traverse_module_state->__pyx_cython_runtime);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_tuple);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_bytes);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_unicode);
  Py_VISIT(traverse_module_state->__pyx_ptype_7cpython_4type_type);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_15_gevent_c_ident_ref);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_15_gevent_c_ident_ValuedWeakRef);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_15_gevent_c_ident_IdentRegistry);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_greenlet);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_16_gevent_c_waiter_greenlet);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_16_gevent_c_waiter_Waiter);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_16_gevent_c_waiter_MultipleWaiter);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet_greenlet);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet_SpawnedLink);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet_FailureSpawnedLink);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet__Frame);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet__dummy_event);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_27_gevent_c_abstract_linkable_greenlet);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_27_gevent_c_abstract_linkable__FakeNotifier);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_19_gevent_c_semaphore__LockReleaseLink);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_19_gevent_c_semaphore_BoundedSemaphore);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_14_gevent_cevent_Event);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_14_gevent_cevent_AsyncResult);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_14_gevent_cqueue_greenlet);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_14_gevent_cqueue_SimpleQueue);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_14_gevent_cqueue_Queue);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_14_gevent_cqueue_ItemWaiter);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_14_gevent_cqueue_UnboundQueue);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_14_gevent_cqueue_PriorityQueue);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_14_gevent_cqueue_LifoQueue);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_14_gevent_cqueue_Channel);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_14_gevent_c_imap_Failure);
  Py_VISIT(traverse_module_state->__pyx_type_6gevent_14_gevent_c_imap_Failure);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_14_gevent_c_imap_IMapUnordered);
  Py_VISIT(traverse_module_state->__pyx_type_6gevent_14_gevent_c_imap_IMapUnordered);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_14_gevent_c_imap_IMap);
  Py_VISIT(traverse_module_state->__pyx_type_6gevent_14_gevent_c_imap_IMap);
  for (int i=0; i<1; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_tuple[i]); }
  for (int i=0; i<2; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_codeobj_tab[i]); }
  for (int i=0; i<78; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_string_tab[i]); }
/* #### Code section: module_state_traverse_contents ### */
/* CommonTypesMetaclass.module_state_traverse */
Py_VISIT(traverse_module_state->__pyx_CommonTypesMetaclassType);

/* CythonFunctionShared.module_state_traverse */
Py_VISIT(traverse_module_state->__pyx_CyFunctionType);

/* #### Code section: module_state_traverse_end ### */
return 0;
}
#endif
/* #### Code section: module_code ### */

/* "gevent/_gevent_c_greenlet_primitives.pxd":22
 *     void PyGreenlet_Import()
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef inline greenlet getcurrent():
 *     return PyGreenlet_GetCurrent()
*/

static CYTHON_INLINE PyGreenlet *__pyx_f_6gevent_29_gevent_c_greenlet_primitives_getcurrent(void) {
  PyGreenlet *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getcurrent", 0);

  /* "gevent/_gevent_c_greenlet_primitives.pxd":24
 * @cython.final
 * cdef inline greenlet getcurrent():
 *     return PyGreenlet_GetCurrent()             # <<<<<<<<<<<<<<
 * 
 * cdef bint _greenlet_imported
*/
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __pyx_t_1 = ((PyObject *)PyGreenlet_GetCurrent()); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = ((PyGreenlet *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "gevent/_gevent_c_greenlet_primitives.pxd":22
 *     void PyGreenlet_Import()
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef inline greenlet getcurrent():
 *     return PyGreenlet_GetCurrent()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_c_greenlet_primitives.getcurrent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/_gevent_c_greenlet_primitives.pxd":28
 * cdef bint _greenlet_imported
 * 
 * cdef inline void greenlet_init():             # <<<<<<<<<<<<<<
 *     global _greenlet_imported
 *     if not _greenlet_imported:
*/

static CYTHON_INLINE void __pyx_f_6gevent_29_gevent_c_greenlet_primitives_greenlet_init(void) {
  int __pyx_t_1;

  /* "gevent/_gevent_c_greenlet_primitives.pxd":30
 * cdef inline void greenlet_init():
 *     global _greenlet_imported
 *     if not _greenlet_imported:             # <<<<<<<<<<<<<<
 *         PyGreenlet_Import()
 *         _greenlet_imported = True
*/
  __pyx_t_1 = (!__pyx_v_6gevent_29_gevent_c_greenlet_primitives__greenlet_imported);
  if (__pyx_t_1) {

    /* "gevent/_gevent_c_greenlet_primitives.pxd":31
 *     global _greenlet_imported
 *     if not _greenlet_imported:
 *         PyGreenlet_Import()             # <<<<<<<<<<<<<<
 *         _greenlet_imported = True
 * 
*/
    PyGreenlet_Import();

    /* "gevent/_gevent_c_greenlet_primitives.pxd":32
 *     if not _greenlet_imported:
 *         PyGreenlet_Import()
 *         _greenlet_imported = True             # <<<<<<<<<<<<<<
 * 
 * cdef inline object _greenlet_switch(greenlet self):
*/
    __pyx_v_6gevent_29_gevent_c_greenlet_primitives__greenlet_imported = 1;

    /* "gevent/_gevent_c_greenlet_primitives.pxd":30
 * cdef inline void greenlet_init():
 *     global _greenlet_imported
 *     if not _greenlet_imported:             # <<<<<<<<<<<<<<
 *         PyGreenlet_Import()
 *         _greenlet_imported = True
*/
  }

  /* "gevent/_gevent_c_greenlet_primitives.pxd":28
 * cdef bint _greenlet_imported
 * 
 * cdef inline void greenlet_init():             # <<<<<<<<<<<<<<
 *     global _greenlet_imported
 *     if not _greenlet_imported:
*/

  /* function exit code */
}

/* "gevent/_gevent_c_greenlet_primitives.pxd":34
 *         _greenlet_imported = True
 * 
 * cdef inline object _greenlet_switch(greenlet self):             # <<<<<<<<<<<<<<
 *     return PyGreenlet_Switch(self, NULL, NULL)
 * 
*/

static CYTHON_INLINE PyObject *__pyx_f_6gevent_29_gevent_c_greenlet_primitives__greenlet_switch(PyGreenlet *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_greenlet_switch", 0);

  /* "gevent/_gevent_c_greenlet_primitives.pxd":35
 * 
 * cdef inline object _greenlet_switch(greenlet self):
 *     return PyGreenlet_Switch(self, NULL, NULL)             # <<<<<<<<<<<<<<
 * 
 * cdef class TrackedRawGreenlet(greenlet):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyGreenlet_Switch(__pyx_v_self, NULL, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 35, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "gevent/_gevent_c_greenlet_primitives.pxd":34
 *         _greenlet_imported = True
 * 
 * cdef inline object _greenlet_switch(greenlet self):             # <<<<<<<<<<<<<<
 *     return PyGreenlet_Switch(self, NULL, NULL)
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_c_greenlet_primitives._greenlet_switch", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/_gevent_c_waiter.pxd":24
 *     void PyGreenlet_Import()
 * 
 * cdef inline greenlet getcurrent():             # <<<<<<<<<<<<<<
 *     return PyGreenlet_GetCurrent()
 * 
*/

static CYTHON_INLINE PyGreenlet *__pyx_f_6gevent_16_gevent_c_waiter_getcurrent(void) {
  PyGreenlet *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getcurrent", 0);

  /* "gevent/_gevent_c_waiter.pxd":25
 * 
 * cdef inline greenlet getcurrent():
 *     return PyGreenlet_GetCurrent()             # <<<<<<<<<<<<<<
 * 
 * cdef inline void greenlet_init():
*/
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __pyx_t_1 = ((PyObject *)PyGreenlet_GetCurrent()); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = ((PyGreenlet *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "gevent/_gevent_c_waiter.pxd":24
 *     void PyGreenlet_Import()
 * 
 * cdef inline greenlet getcurrent():             # <<<<<<<<<<<<<<
 *     return PyGreenlet_GetCurrent()
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_c_waiter.getcurrent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/_gevent_c_waiter.pxd":27
 *     return PyGreenlet_GetCurrent()
 * 
 * cdef inline void greenlet_init():             # <<<<<<<<<<<<<<
 *     global _greenlet_imported
 *     if not _greenlet_imported:
*/

static CYTHON_INLINE void __pyx_f_6gevent_16_gevent_c_waiter_greenlet_init(void) {
  int __pyx_t_1;

  /* "gevent/_gevent_c_waiter.pxd":29
 * cdef inline void greenlet_init():
 *     global _greenlet_imported
 *     if not _greenlet_imported:             # <<<<<<<<<<<<<<
 *         PyGreenlet_Import()
 *         _greenlet_imported = True
*/
  __pyx_t_1 = (!__pyx_v_6gevent_16_gevent_c_waiter__greenlet_imported);
  if (__pyx_t_1) {

    /* "gevent/_gevent_c_waiter.pxd":30
 *     global _greenlet_imported
 *     if not _greenlet_imported:
 *         PyGreenlet_Import()             # <<<<<<<<<<<<<<
 *         _greenlet_imported = True
 * 
*/
    PyGreenlet_Import();

    /* "gevent/_gevent_c_waiter.pxd":31
 *     if not _greenlet_imported:
 *         PyGreenlet_Import()
 *         _greenlet_imported = True             # <<<<<<<<<<<<<<
 * 
 * cdef class Waiter:
*/
    __pyx_v_6gevent_16_gevent_c_waiter__greenlet_imported = 1;

    /* "gevent/_gevent_c_waiter.pxd":29
 * cdef inline void greenlet_init():
 *     global _greenlet_imported
 *     if not _greenlet_imported:             # <<<<<<<<<<<<<<
 *         PyGreenlet_Import()
 *         _greenlet_imported = True
*/
  }

  /* "gevent/_gevent_c_waiter.pxd":27
 *     return PyGreenlet_GetCurrent()
 * 
 * cdef inline void greenlet_init():             # <<<<<<<<<<<<<<
 *     global _greenlet_imported
 *     if not _greenlet_imported:
*/

  /* function exit code */
}

/* "gevent/_gevent_cgreenlet.pxd":36
 *     void PyGreenlet_Import()
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef inline greenlet getcurrent():
 *     return PyGreenlet_GetCurrent()
*/

static CYTHON_INLINE PyGreenlet *__pyx_f_6gevent_17_gevent_cgreenlet_getcurrent(void) {
  PyGreenlet *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getcurrent", 0);

  /* "gevent/_gevent_cgreenlet.pxd":38
 * @cython.final
 * cdef inline greenlet getcurrent():
 *     return PyGreenlet_GetCurrent()             # <<<<<<<<<<<<<<
 * 
 * cdef inline object get_generic_parent(greenlet s):
*/
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __pyx_t_1 = ((PyObject *)PyGreenlet_GetCurrent()); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 38, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = ((PyGreenlet *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "gevent/_gevent_cgreenlet.pxd":36
 *     void PyGreenlet_Import()
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef inline greenlet getcurrent():
 *     return PyGreenlet_GetCurrent()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.getcurrent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/_gevent_cgreenlet.pxd":40
 *     return PyGreenlet_GetCurrent()
 * 
 * cdef inline object get_generic_parent(greenlet s):             # <<<<<<<<<<<<<<
 *     # We don't use any typed functions on the return of this,
 *     # so save the type check by making it just an object.
*/

static CYTHON_INLINE PyObject *__pyx_f_6gevent_17_gevent_cgreenlet_get_generic_parent(PyGreenlet *__pyx_v_s) {
  PyObject *__pyx_v_result = 0;
  void *__pyx_v_parent;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("get_generic_parent", 0);

  /* "gevent/_gevent_cgreenlet.pxd":44
 *     # so save the type check by making it just an object.
 *     cdef object result
 *     cdef void* parent = PyGreenlet_GetParent(s)             # <<<<<<<<<<<<<<
 *     if parent != NULL:
 *         # The cast will perform an incref; but the GetParent
*/
  __pyx_v_parent = PyGreenlet_GetParent(__pyx_v_s);

  /* "gevent/_gevent_cgreenlet.pxd":45
 *     cdef object result
 *     cdef void* parent = PyGreenlet_GetParent(s)
 *     if parent != NULL:             # <<<<<<<<<<<<<<
 *         # The cast will perform an incref; but the GetParent
 *         # function already did an incref if we got it (and not NULL).
*/
  __pyx_t_1 = (__pyx_v_parent != NULL);
  if (__pyx_t_1) {

    /* "gevent/_gevent_cgreenlet.pxd":49
 *         # function already did an incref if we got it (and not NULL).
 *         # Therefore, we must DECREF immediately.
 *         result = <object>parent             # <<<<<<<<<<<<<<
 *         Py_DECREF(result)
 *         return result
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_parent);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v_result = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "gevent/_gevent_cgreenlet.pxd":50
 *         # Therefore, we must DECREF immediately.
 *         result = <object>parent
 *         Py_DECREF(result)             # <<<<<<<<<<<<<<
 *         return result
 * 
*/
    Py_DECREF(__pyx_v_result);

    /* "gevent/_gevent_cgreenlet.pxd":51
 *         result = <object>parent
 *         Py_DECREF(result)
 *         return result             # <<<<<<<<<<<<<<
 * 
 * cdef inline SwitchOutGreenletWithLoop get_my_hub(greenlet s):
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_result);
    __pyx_r = __pyx_v_result;
    goto __pyx_L0;

    /* "gevent/_gevent_cgreenlet.pxd":45
 *     cdef object result
 *     cdef void* parent = PyGreenlet_GetParent(s)
 *     if parent != NULL:             # <<<<<<<<<<<<<<
 *         # The cast will perform an incref; but the GetParent
 *         # function already did an incref if we got it (and not NULL).
*/
  }

  /* "gevent/_gevent_cgreenlet.pxd":40
 *     return PyGreenlet_GetCurrent()
 * 
 * cdef inline object get_generic_parent(greenlet s):             # <<<<<<<<<<<<<<
 *     # We don't use any typed functions on the return of this,
 *     # so save the type check by making it just an object.
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/_gevent_cgreenlet.pxd":53
 *         return result
 * 
 * cdef inline SwitchOutGreenletWithLoop get_my_hub(greenlet s):             # <<<<<<<<<<<<<<
 *     # This one we do want type checked on the return value.
 *     # Must not be called with s = None
*/

static CYTHON_INLINE struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *__pyx_f_6gevent_17_gevent_cgreenlet_get_my_hub(PyGreenlet *__pyx_v_s) {
  PyObject *__pyx_v_result = 0;
  void *__pyx_v_parent;
  struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_my_hub", 0);

  /* "gevent/_gevent_cgreenlet.pxd":57
 *     # Must not be called with s = None
 *     cdef object result
 *     cdef void* parent = PyGreenlet_GetParent(s)             # <<<<<<<<<<<<<<
 *     if parent != NULL:
 *         result = <object>parent
*/
  __pyx_v_parent = PyGreenlet_GetParent(__pyx_v_s);

  /* "gevent/_gevent_cgreenlet.pxd":58
 *     cdef object result
 *     cdef void* parent = PyGreenlet_GetParent(s)
 *     if parent != NULL:             # <<<<<<<<<<<<<<
 *         result = <object>parent
 *         # See above
*/
  __pyx_t_1 = (__pyx_v_parent != NULL);
  if (__pyx_t_1) {

    /* "gevent/_gevent_cgreenlet.pxd":59
 *     cdef void* parent = PyGreenlet_GetParent(s)
 *     if parent != NULL:
 *         result = <object>parent             # <<<<<<<<<<<<<<
 *         # See above
 *         Py_DECREF(result)
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_parent);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v_result = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "gevent/_gevent_cgreenlet.pxd":61
 *         result = <object>parent
 *         # See above
 *         Py_DECREF(result)             # <<<<<<<<<<<<<<
 *         return result
 * 
*/
    Py_DECREF(__pyx_v_result);

    /* "gevent/_gevent_cgreenlet.pxd":62
 *         # See above
 *         Py_DECREF(result)
 *         return result             # <<<<<<<<<<<<<<
 * 
 * cdef bint _greenlet_imported
*/
    __Pyx_XDECREF((PyObject *)__pyx_r);
    if (!(likely(((__pyx_v_result) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_result, __pyx_mstate_global->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop))))) __PYX_ERR(3, 62, __pyx_L1_error)
    __Pyx_INCREF(__pyx_v_result);
    __pyx_r = ((struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *)__pyx_v_result);
    goto __pyx_L0;

    /* "gevent/_gevent_cgreenlet.pxd":58
 *     cdef object result
 *     cdef void* parent = PyGreenlet_GetParent(s)
 *     if parent != NULL:             # <<<<<<<<<<<<<<
 *         result = <object>parent
 *         # See above
*/
  }

  /* "gevent/_gevent_cgreenlet.pxd":53
 *         return result
 * 
 * cdef inline SwitchOutGreenletWithLoop get_my_hub(greenlet s):             # <<<<<<<<<<<<<<
 *     # This one we do want type checked on the return value.
 *     # Must not be called with s = None
*/

  /* function exit code */
  __pyx_r = ((struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *)Py_None); __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.get_my_hub", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/_gevent_cgreenlet.pxd":66
 * cdef bint _greenlet_imported
 * 
 * cdef inline void greenlet_init():             # <<<<<<<<<<<<<<
 *     global _greenlet_imported
 *     if not _greenlet_imported:
*/

static CYTHON_INLINE void __pyx_f_6gevent_17_gevent_cgreenlet_greenlet_init(void) {
  int __pyx_t_1;

  /* "gevent/_gevent_cgreenlet.pxd":68
 * cdef inline void greenlet_init():
 *     global _greenlet_imported
 *     if not _greenlet_imported:             # <<<<<<<<<<<<<<
 *         PyGreenlet_Import()
 *         _greenlet_imported = True
*/
  __pyx_t_1 = (!__pyx_v_6gevent_17_gevent_cgreenlet__greenlet_imported);
  if (__pyx_t_1) {

    /* "gevent/_gevent_cgreenlet.pxd":69
 *     global _greenlet_imported
 *     if not _greenlet_imported:
 *         PyGreenlet_Import()             # <<<<<<<<<<<<<<
 *         _greenlet_imported = True
 * 
*/
    PyGreenlet_Import();

    /* "gevent/_gevent_cgreenlet.pxd":70
 *     if not _greenlet_imported:
 *         PyGreenlet_Import()
 *         _greenlet_imported = True             # <<<<<<<<<<<<<<
 * 
 * ctypedef object CodeType
*/
    __pyx_v_6gevent_17_gevent_cgreenlet__greenlet_imported = 1;

    /* "gevent/_gevent_cgreenlet.pxd":68
 * cdef inline void greenlet_init():
 *     global _greenlet_imported
 *     if not _greenlet_imported:             # <<<<<<<<<<<<<<
 *         PyGreenlet_Import()
 *         _greenlet_imported = True
*/
  }

  /* "gevent/_gevent_cgreenlet.pxd":66
 * cdef bint _greenlet_imported
 * 
 * cdef inline void greenlet_init():             # <<<<<<<<<<<<<<
 *     global _greenlet_imported
 *     if not _greenlet_imported:
*/

  /* function exit code */
}

/* "gevent/_gevent_c_abstract_linkable.pxd":25
 *     void PyGreenlet_Import()
 * 
 * cdef inline greenlet getcurrent():             # <<<<<<<<<<<<<<
 *     return PyGreenlet_GetCurrent()
 * 
*/

static CYTHON_INLINE PyGreenlet *__pyx_f_6gevent_27_gevent_c_abstract_linkable_getcurrent(void) {
  PyGreenlet *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getcurrent", 0);

  /* "gevent/_gevent_c_abstract_linkable.pxd":26
 * 
 * cdef inline greenlet getcurrent():
 *     return PyGreenlet_GetCurrent()             # <<<<<<<<<<<<<<
 * 
 * cdef inline void greenlet_init():
*/
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __pyx_t_1 = ((PyObject *)PyGreenlet_GetCurrent()); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = ((PyGreenlet *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "gevent/_gevent_c_abstract_linkable.pxd":25
 *     void PyGreenlet_Import()
 * 
 * cdef inline greenlet getcurrent():             # <<<<<<<<<<<<<<
 *     return PyGreenlet_GetCurrent()
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_c_abstract_linkable.getcurrent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/_gevent_c_abstract_linkable.pxd":28
 *     return PyGreenlet_GetCurrent()
 * 
 * cdef inline void greenlet_init():             # <<<<<<<<<<<<<<
 *     global _greenlet_imported
 *     if not _greenlet_imported:
*/

static CYTHON_INLINE void __pyx_f_6gevent_27_gevent_c_abstract_linkable_greenlet_init(void) {
  int __pyx_t_1;

  /* "gevent/_gevent_c_abstract_linkable.pxd":30
 * cdef inline void greenlet_init():
 *     global _greenlet_imported
 *     if not _greenlet_imported:             # <<<<<<<<<<<<<<
 *         PyGreenlet_Import()
 *         _greenlet_imported = True
*/
  __pyx_t_1 = (!__pyx_v_6gevent_27_gevent_c_abstract_linkable__greenlet_imported);
  if (__pyx_t_1) {

    /* "gevent/_gevent_c_abstract_linkable.pxd":31
 *     global _greenlet_imported
 *     if not _greenlet_imported:
 *         PyGreenlet_Import()             # <<<<<<<<<<<<<<
 *         _greenlet_imported = True
 * 
*/
    PyGreenlet_Import();

    /* "gevent/_gevent_c_abstract_linkable.pxd":32
 *     if not _greenlet_imported:
 *         PyGreenlet_Import()
 *         _greenlet_imported = True             # <<<<<<<<<<<<<<
 * 
 * cdef void _init()
*/
    __pyx_v_6gevent_27_gevent_c_abstract_linkable__greenlet_imported = 1;

    /* "gevent/_gevent_c_abstract_linkable.pxd":30
 * cdef inline void greenlet_init():
 *     global _greenlet_imported
 *     if not _greenlet_imported:             # <<<<<<<<<<<<<<
 *         PyGreenlet_Import()
 *         _greenlet_imported = True
*/
  }

  /* "gevent/_gevent_c_abstract_linkable.pxd":28
 *     return PyGreenlet_GetCurrent()
 * 
 * cdef inline void greenlet_init():             # <<<<<<<<<<<<<<
 *     global _greenlet_imported
 *     if not _greenlet_imported:
*/

  /* function exit code */
}

/* "gevent/_gevent_cqueue.pxd":26
 *     void PyGreenlet_Import()
 * 
 * cdef inline greenlet getcurrent():             # <<<<<<<<<<<<<<
 *     return PyGreenlet_GetCurrent()
 * 
*/

static CYTHON_INLINE PyGreenlet *__pyx_f_6gevent_14_gevent_cqueue_getcurrent(void) {
  PyGreenlet *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getcurrent", 0);

  /* "gevent/_gevent_cqueue.pxd":27
 * 
 * cdef inline greenlet getcurrent():
 *     return PyGreenlet_GetCurrent()             # <<<<<<<<<<<<<<
 * 
 * cdef inline void greenlet_init():
*/
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __pyx_t_1 = ((PyObject *)PyGreenlet_GetCurrent()); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 27, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = ((PyGreenlet *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "gevent/_gevent_cqueue.pxd":26
 *     void PyGreenlet_Import()
 * 
 * cdef inline greenlet getcurrent():             # <<<<<<<<<<<<<<
 *     return PyGreenlet_GetCurrent()
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_cqueue.getcurrent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/_gevent_cqueue.pxd":29
 *     return PyGreenlet_GetCurrent()
 * 
 * cdef inline void greenlet_init():             # <<<<<<<<<<<<<<
 *     global _greenlet_imported
 *     if not _greenlet_imported:
*/

static CYTHON_INLINE void __pyx_f_6gevent_14_gevent_cqueue_greenlet_init(void) {
  int __pyx_t_1;

  /* "gevent/_gevent_cqueue.pxd":31
 * cdef inline void greenlet_init():
 *     global _greenlet_imported
 *     if not _greenlet_imported:             # <<<<<<<<<<<<<<
 *         PyGreenlet_Import()
 *         _greenlet_imported = True
*/
  __pyx_t_1 = (!__pyx_v_6gevent_14_gevent_cqueue__greenlet_imported);
  if (__pyx_t_1) {

    /* "gevent/_gevent_cqueue.pxd":32
 *     global _greenlet_imported
 *     if not _greenlet_imported:
 *         PyGreenlet_Import()             # <<<<<<<<<<<<<<
 *         _greenlet_imported = True
 * 
*/
    PyGreenlet_Import();

    /* "gevent/_gevent_cqueue.pxd":33
 *     if not _greenlet_imported:
 *         PyGreenlet_Import()
 *         _greenlet_imported = True             # <<<<<<<<<<<<<<
 * 
 * 
*/
    __pyx_v_6gevent_14_gevent_cqueue__greenlet_imported = 1;

    /* "gevent/_gevent_cqueue.pxd":31
 * cdef inline void greenlet_init():
 *     global _greenlet_imported
 *     if not _greenlet_imported:             # <<<<<<<<<<<<<<
 *         PyGreenlet_Import()
 *         _greenlet_imported = True
*/
  }

  /* "gevent/_gevent_cqueue.pxd":29
 *     return PyGreenlet_GetCurrent()
 * 
 * cdef inline void greenlet_init():             # <<<<<<<<<<<<<<
 *     global _greenlet_imported
 *     if not _greenlet_imported:
*/

  /* function exit code */
}

/* "src/gevent/_imap.py":31
 *     __slots__ = ('exc', 'raise_exception')
 * 
 *     def __init__(self, exc, raise_exception=None):             # <<<<<<<<<<<<<<
 *         self.exc = exc
 *         self.raise_exception = raise_exception
*/

/* Python wrapper */
static int __pyx_pw_6gevent_14_gevent_c_imap_7Failure_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6gevent_14_gevent_c_imap_7Failure_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_exc = 0;
  PyObject *__pyx_v_raise_exception = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_exc,&__pyx_mstate_global->__pyx_n_u_raise_exception,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 31, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 31, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 31, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__init__", 0) < (0)) __PYX_ERR(0, 31, __pyx_L3_error)
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__init__", 0, 1, 2, i); __PYX_ERR(0, 31, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 31, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 31, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_exc = values[0];
    __pyx_v_raise_exception = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 31, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("gevent._gevent_c_imap.Failure.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6gevent_14_gevent_c_imap_7Failure___init__(((struct __pyx_obj_6gevent_14_gevent_c_imap_Failure *)__pyx_v_self), __pyx_v_exc, __pyx_v_raise_exception);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6gevent_14_gevent_c_imap_7Failure___init__(struct __pyx_obj_6gevent_14_gevent_c_imap_Failure *__pyx_v_self, PyObject *__pyx_v_exc, PyObject *__pyx_v_raise_exception) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "src/gevent/_imap.py":32
 * 
 *     def __init__(self, exc, raise_exception=None):
 *         self.exc = exc             # <<<<<<<<<<<<<<
 *         self.raise_exception = raise_exception
 * 
*/
  __Pyx_INCREF(__pyx_v_exc);
  __Pyx_GIVEREF(__pyx_v_exc);
  __Pyx_GOTREF(__pyx_v_self->exc);
  __Pyx_DECREF(__pyx_v_self->exc);
  __pyx_v_self->exc = __pyx_v_exc;

  /* "src/gevent/_imap.py":33
 *     def __init__(self, exc, raise_exception=None):
 *         self.exc = exc
 *         self.raise_exception = raise_exception             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_INCREF(__pyx_v_raise_exception);
  __Pyx_GIVEREF(__pyx_v_raise_exception);
  __Pyx_GOTREF(__pyx_v_self->raise_exception);
  __Pyx_DECREF(__pyx_v_self->raise_exception);
  __pyx_v_self->raise_exception = __pyx_v_raise_exception;

  /* "src/gevent/_imap.py":31
 *     __slots__ = ('exc', 'raise_exception')
 * 
 *     def __init__(self, exc, raise_exception=None):             # <<<<<<<<<<<<<<
 *         self.exc = exc
 *         self.raise_exception = raise_exception
*/

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/_gevent_c_imap.pxd":10
 * @cython.final
 * cdef class Failure:
 *     cdef readonly exc             # <<<<<<<<<<<<<<
 *     cdef raise_exception
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_14_gevent_c_imap_7Failure_3exc_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6gevent_14_gevent_c_imap_7Failure_3exc_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_14_gevent_c_imap_7Failure_3exc___get__(((struct __pyx_obj_6gevent_14_gevent_c_imap_Failure *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_14_gevent_c_imap_7Failure_3exc___get__(struct __pyx_obj_6gevent_14_gevent_c_imap_Failure *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->exc);
  __pyx_r = __pyx_v_self->exc;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/_imap.py":36
 * 
 * 
 * def _raise_exc(failure):             # <<<<<<<<<<<<<<
 *     # For cython.
 *     if failure.raise_exception:
*/

static CYTHON_INLINE PyObject *__pyx_f_6gevent_14_gevent_c_imap__raise_exc(struct __pyx_obj_6gevent_14_gevent_c_imap_Failure *__pyx_v_failure) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_raise_exc", 0);

  /* "src/gevent/_imap.py":38
 * def _raise_exc(failure):
 *     # For cython.
 *     if failure.raise_exception:             # <<<<<<<<<<<<<<
 *         failure.raise_exception()
 *     else:
*/
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_failure->raise_exception); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 38, __pyx_L1_error)
  if (likely(__pyx_t_1)) {

    /* "src/gevent/_imap.py":39
 *     # For cython.
 *     if failure.raise_exception:
 *         failure.raise_exception()             # <<<<<<<<<<<<<<
 *     else:
 *         raise failure.exc
*/
    __pyx_t_3 = NULL;
    __Pyx_INCREF(__pyx_v_failure->raise_exception);
    __pyx_t_4 = __pyx_v_failure->raise_exception; 
    __pyx_t_5 = 1;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      assert(__pyx_t_3);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
      __pyx_t_5 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 39, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "src/gevent/_imap.py":38
 * def _raise_exc(failure):
 *     # For cython.
 *     if failure.raise_exception:             # <<<<<<<<<<<<<<
 *         failure.raise_exception()
 *     else:
*/
    goto __pyx_L3;
  }

  /* "src/gevent/_imap.py":41
 *         failure.raise_exception()
 *     else:
 *         raise failure.exc             # <<<<<<<<<<<<<<
 * 
 * class IMapUnordered(Greenlet): # pylint:disable=undefined-variable
*/
  /*else*/ {
    __Pyx_Raise(__pyx_v_failure->exc, 0, 0, 0);
    __PYX_ERR(0, 41, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "src/gevent/_imap.py":36
 * 
 * 
 * def _raise_exc(failure):             # <<<<<<<<<<<<<<
 *     # For cython.
 *     if failure.raise_exception:
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("gevent._gevent_c_imap._raise_exc", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/_imap.py":48
 *     """
 * 
 *     def __init__(self, func, iterable, spawn, maxsize=None, _zipped=False):             # <<<<<<<<<<<<<<
 *         """
 *         An iterator that.
*/

/* Python wrapper */
static int __pyx_pw_6gevent_14_gevent_c_imap_13IMapUnordered_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_14_gevent_c_imap_13IMapUnordered___init__, "\n        An iterator that.\n\n        :param callable spawn: The function we use to create new greenlets.\n        :keyword int maxsize: If given and not-None, specifies the maximum number of\n            finished results that will be allowed to accumulated awaiting the reader;\n            more than that number of results will cause map function greenlets to begin\n            to block. This is most useful is there is a great disparity in the speed of\n            the mapping code and the consumer and the results consume a great deal of resources.\n            Using a bound is more computationally expensive than not using a bound.\n\n        .. versionchanged:: 1.1b3\n            Added the *maxsize* parameter.\n        ");
#if CYTHON_UPDATE_DESCRIPTOR_DOC
struct wrapperbase __pyx_wrapperbase_6gevent_14_gevent_c_imap_13IMapUnordered___init__;
#endif
static int __pyx_pw_6gevent_14_gevent_c_imap_13IMapUnordered_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_func = 0;
  PyObject *__pyx_v_iterable = 0;
  PyObject *__pyx_v_spawn = 0;
  PyObject *__pyx_v_maxsize = 0;
  PyObject *__pyx_v__zipped = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_func,&__pyx_mstate_global->__pyx_n_u_iterable,&__pyx_mstate_global->__pyx_n_u_spawn,&__pyx_mstate_global->__pyx_n_u_maxsize,&__pyx_mstate_global->__pyx_n_u_zipped,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 48, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  5:
        values[4] = __Pyx_ArgRef_VARARGS(__pyx_args, 4);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[4])) __PYX_ERR(0, 48, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  4:
        values[3] = __Pyx_ArgRef_VARARGS(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 48, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_VARARGS(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 48, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 48, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 48, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__init__", 0) < (0)) __PYX_ERR(0, 48, __pyx_L3_error)
      if (!values[3]) values[3] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[4]) values[4] = __Pyx_NewRef(((PyObject *)Py_False));
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__init__", 0, 3, 5, i); __PYX_ERR(0, 48, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  5:
        values[4] = __Pyx_ArgRef_VARARGS(__pyx_args, 4);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[4])) __PYX_ERR(0, 48, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  4:
        values[3] = __Pyx_ArgRef_VARARGS(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 48, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_VARARGS(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 48, __pyx_L3_error)
        values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 48, __pyx_L3_error)
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 48, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[3]) values[3] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[4]) values[4] = __Pyx_NewRef(((PyObject *)Py_False));
    }
    __pyx_v_func = values[0];
    __pyx_v_iterable = values[1];
    __pyx_v_spawn = values[2];
    __pyx_v_maxsize = values[3];
    __pyx_v__zipped = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 3, 5, __pyx_nargs); __PYX_ERR(0, 48, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("gevent._gevent_c_imap.IMapUnordered.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6gevent_14_gevent_c_imap_13IMapUnordered___init__(((struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *)__pyx_v_self), __pyx_v_func, __pyx_v_iterable, __pyx_v_spawn, __pyx_v_maxsize, __pyx_v__zipped);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6gevent_14_gevent_c_imap_13IMapUnordered___init__(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *__pyx_v_self, PyObject *__pyx_v_func, PyObject *__pyx_v_iterable, PyObject *__pyx_v_spawn, PyObject *__pyx_v_maxsize, PyObject *__pyx_v__zipped) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "src/gevent/_imap.py":63
 *             Added the *maxsize* parameter.
 *         """
 *         Greenlet.__init__(self) # pylint:disable=undefined-variable             # <<<<<<<<<<<<<<
 *         self.spawn = spawn
 *         self._zipped = _zipped
*/
  __pyx_t_2 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, ((PyObject *)__pyx_v_self)};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_init, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 63, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "src/gevent/_imap.py":64
 *         """
 *         Greenlet.__init__(self) # pylint:disable=undefined-variable
 *         self.spawn = spawn             # <<<<<<<<<<<<<<
 *         self._zipped = _zipped
 *         self.func = func
*/
  __Pyx_INCREF(__pyx_v_spawn);
  __Pyx_GIVEREF(__pyx_v_spawn);
  __Pyx_GOTREF(__pyx_v_self->spawn);
  __Pyx_DECREF(__pyx_v_self->spawn);
  __pyx_v_self->spawn = __pyx_v_spawn;

  /* "src/gevent/_imap.py":65
 *         Greenlet.__init__(self) # pylint:disable=undefined-variable
 *         self.spawn = spawn
 *         self._zipped = _zipped             # <<<<<<<<<<<<<<
 *         self.func = func
 *         self.iterable = iterable
*/
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v__zipped); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 65, __pyx_L1_error)
  __pyx_v_self->_zipped = __pyx_t_4;

  /* "src/gevent/_imap.py":66
 *         self.spawn = spawn
 *         self._zipped = _zipped
 *         self.func = func             # <<<<<<<<<<<<<<
 *         self.iterable = iterable
 *         self.queue = UnboundQueue() # pylint:disable=undefined-variable
*/
  __Pyx_INCREF(__pyx_v_func);
  __Pyx_GIVEREF(__pyx_v_func);
  __Pyx_GOTREF(__pyx_v_self->func);
  __Pyx_DECREF(__pyx_v_self->func);
  __pyx_v_self->func = __pyx_v_func;

  /* "src/gevent/_imap.py":67
 *         self._zipped = _zipped
 *         self.func = func
 *         self.iterable = iterable             # <<<<<<<<<<<<<<
 *         self.queue = UnboundQueue() # pylint:disable=undefined-variable
 * 
*/
  __Pyx_INCREF(__pyx_v_iterable);
  __Pyx_GIVEREF(__pyx_v_iterable);
  __Pyx_GOTREF(__pyx_v_self->iterable);
  __Pyx_DECREF(__pyx_v_self->iterable);
  __pyx_v_self->iterable = __pyx_v_iterable;

  /* "src/gevent/_imap.py":68
 *         self.func = func
 *         self.iterable = iterable
 *         self.queue = UnboundQueue() # pylint:disable=undefined-variable             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_2 = NULL;
  __pyx_t_3 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_cqueue_UnboundQueue, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 68, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_1);
  }
  __Pyx_GIVEREF((PyObject *)__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->queue);
  __Pyx_DECREF((PyObject *)__pyx_v_self->queue);
  __pyx_v_self->queue = ((struct __pyx_obj_6gevent_14_gevent_cqueue_UnboundQueue *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "src/gevent/_imap.py":71
 * 
 * 
 *         if maxsize:             # <<<<<<<<<<<<<<
 *             # Bounding the queue is not enough if we want to keep from
 *             # accumulating objects; the result value will be around as
*/
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_maxsize); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 71, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "src/gevent/_imap.py":87
 *             # of self.rawlink() to avoid having blocking methods called in the
 *             # hub greenlet.
 *             self._result_semaphore = Semaphore(maxsize) # pylint:disable=undefined-variable             # <<<<<<<<<<<<<<
 *         else:
 *             self._result_semaphore = None
*/
    __pyx_t_2 = NULL;
    __pyx_t_3 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_maxsize};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 87, __pyx_L1_error)
      __Pyx_GOTREF((PyObject *)__pyx_t_1);
    }
    __Pyx_GIVEREF((PyObject *)__pyx_t_1);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->_result_semaphore);
    __Pyx_DECREF((PyObject *)__pyx_v_self->_result_semaphore);
    __pyx_v_self->_result_semaphore = ((struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "src/gevent/_imap.py":71
 * 
 * 
 *         if maxsize:             # <<<<<<<<<<<<<<
 *             # Bounding the queue is not enough if we want to keep from
 *             # accumulating objects; the result value will be around as
*/
    goto __pyx_L3;
  }

  /* "src/gevent/_imap.py":89
 *             self._result_semaphore = Semaphore(maxsize) # pylint:disable=undefined-variable
 *         else:
 *             self._result_semaphore = None             # <<<<<<<<<<<<<<
 * 
 *         self._outstanding_tasks = 0
*/
  /*else*/ {
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->_result_semaphore);
    __Pyx_DECREF((PyObject *)__pyx_v_self->_result_semaphore);
    __pyx_v_self->_result_semaphore = ((struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *)Py_None);
  }
  __pyx_L3:;

  /* "src/gevent/_imap.py":91
 *             self._result_semaphore = None
 * 
 *         self._outstanding_tasks = 0             # <<<<<<<<<<<<<<
 *         # The index (zero based) of the maximum number of
 *         # results we will have.
*/
  __pyx_v_self->_outstanding_tasks = 0;

  /* "src/gevent/_imap.py":94
 *         # The index (zero based) of the maximum number of
 *         # results we will have.
 *         self._max_index = -1             # <<<<<<<<<<<<<<
 *         self.finished = False
 * 
*/
  __pyx_v_self->_max_index = -1;

  /* "src/gevent/_imap.py":95
 *         # results we will have.
 *         self._max_index = -1
 *         self.finished = False             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_v_self->finished = 0;

  /* "src/gevent/_imap.py":48
 *     """
 * 
 *     def __init__(self, func, iterable, spawn, maxsize=None, _zipped=False):             # <<<<<<<<<<<<<<
 *         """
 *         An iterator that.
*/

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("gevent._gevent_c_imap.IMapUnordered.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/_imap.py":99
 * 
 *     # We're iterating in a different greenlet than we're running.
 *     def __iter__(self):             # <<<<<<<<<<<<<<
 *         return self
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_14_gevent_c_imap_13IMapUnordered_3__iter__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6gevent_14_gevent_c_imap_13IMapUnordered_3__iter__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__iter__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_14_gevent_c_imap_13IMapUnordered_2__iter__(((struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_14_gevent_c_imap_13IMapUnordered_2__iter__(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__iter__", 0);

  /* "src/gevent/_imap.py":100
 *     # We're iterating in a different greenlet than we're running.
 *     def __iter__(self):
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def __next__(self):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __pyx_r = ((PyObject *)__pyx_v_self);
  goto __pyx_L0;

  /* "src/gevent/_imap.py":99
 * 
 *     # We're iterating in a different greenlet than we're running.
 *     def __iter__(self):             # <<<<<<<<<<<<<<
 *         return self
 * 
*/

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/_imap.py":102
 *         return self
 * 
 *     def __next__(self):             # <<<<<<<<<<<<<<
 *         if self._result_semaphore is not None:
 *             self._result_semaphore.release()
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_14_gevent_c_imap_13IMapUnordered_5__next__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6gevent_14_gevent_c_imap_13IMapUnordered_5__next__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__next__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_14_gevent_c_imap_13IMapUnordered_4__next__(((struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_14_gevent_c_imap_13IMapUnordered_4__next__(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *__pyx_v_self) {
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__next__", 0);

  /* "src/gevent/_imap.py":103
 * 
 *     def __next__(self):
 *         if self._result_semaphore is not None:             # <<<<<<<<<<<<<<
 *             self._result_semaphore.release()
 *         value = self._inext()
*/
  __pyx_t_1 = (((PyObject *)__pyx_v_self->_result_semaphore) != Py_None);
  if (__pyx_t_1) {

    /* "src/gevent/_imap.py":104
 *     def __next__(self):
 *         if self._result_semaphore is not None:
 *             self._result_semaphore.release()             # <<<<<<<<<<<<<<
 *         value = self._inext()
 *         if isinstance(value, Failure):
*/
    __pyx_t_2 = ((struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self->_result_semaphore->__pyx_base.__pyx_vtab)->release(__pyx_v_self->_result_semaphore, 0); if (unlikely(__pyx_t_2 == ((int)-1000))) __PYX_ERR(0, 104, __pyx_L1_error)

    /* "src/gevent/_imap.py":103
 * 
 *     def __next__(self):
 *         if self._result_semaphore is not None:             # <<<<<<<<<<<<<<
 *             self._result_semaphore.release()
 *         value = self._inext()
*/
  }

  /* "src/gevent/_imap.py":105
 *         if self._result_semaphore is not None:
 *             self._result_semaphore.release()
 *         value = self._inext()             # <<<<<<<<<<<<<<
 *         if isinstance(value, Failure):
 *             _raise_exc(value)
*/
  __pyx_t_3 = ((struct __pyx_vtabstruct_6gevent_14_gevent_c_imap_IMapUnordered *)__pyx_v_self->__pyx_base.__pyx_vtab)->_inext(__pyx_v_self); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_value = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "src/gevent/_imap.py":106
 *             self._result_semaphore.release()
 *         value = self._inext()
 *         if isinstance(value, Failure):             # <<<<<<<<<<<<<<
 *             _raise_exc(value)
 *         return value
*/
  __pyx_t_1 = __Pyx_TypeCheck(__pyx_v_value, __pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_c_imap_Failure); 
  if (__pyx_t_1) {

    /* "src/gevent/_imap.py":107
 *         value = self._inext()
 *         if isinstance(value, Failure):
 *             _raise_exc(value)             # <<<<<<<<<<<<<<
 *         return value
 * 
*/
    if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_c_imap_Failure))))) __PYX_ERR(0, 107, __pyx_L1_error)
    __pyx_t_3 = __pyx_f_6gevent_14_gevent_c_imap__raise_exc(((struct __pyx_obj_6gevent_14_gevent_c_imap_Failure *)__pyx_v_value)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 107, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "src/gevent/_imap.py":106
 *             self._result_semaphore.release()
 *         value = self._inext()
 *         if isinstance(value, Failure):             # <<<<<<<<<<<<<<
 *             _raise_exc(value)
 *         return value
*/
  }

  /* "src/gevent/_imap.py":108
 *         if isinstance(value, Failure):
 *             _raise_exc(value)
 *         return value             # <<<<<<<<<<<<<<
 * 
 *     next = __next__ # Py2
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_value);
  __pyx_r = __pyx_v_value;
  goto __pyx_L0;

  /* "src/gevent/_imap.py":102
 *         return self
 * 
 *     def __next__(self):             # <<<<<<<<<<<<<<
 *         if self._result_semaphore is not None:
 *             self._result_semaphore.release()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("gevent._gevent_c_imap.IMapUnordered.__next__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/_imap.py":112
 *     next = __next__ # Py2
 * 
 *     def _inext(self):             # <<<<<<<<<<<<<<
 *         return self.queue.get()
 * 
*/

static PyObject *__pyx_f_6gevent_14_gevent_c_imap_13IMapUnordered__inext(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_inext", 0);

  /* "src/gevent/_imap.py":113
 * 
 *     def _inext(self):
 *         return self.queue.get()             # <<<<<<<<<<<<<<
 * 
 *     def _ispawn(self, func, item, item_index):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((struct __pyx_vtabstruct_6gevent_14_gevent_cqueue_UnboundQueue *)__pyx_v_self->queue->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.get(((struct __pyx_obj_6gevent_14_gevent_cqueue_SimpleQueue *)__pyx_v_self->queue), 0, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 113, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "src/gevent/_imap.py":112
 *     next = __next__ # Py2
 * 
 *     def _inext(self):             # <<<<<<<<<<<<<<
 *         return self.queue.get()
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_c_imap.IMapUnordered._inext", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/_imap.py":115
 *         return self.queue.get()
 * 
 *     def _ispawn(self, func, item, item_index):             # <<<<<<<<<<<<<<
 *         if self._result_semaphore is not None:
 *             self._result_semaphore.acquire()
*/

static PyObject *__pyx_f_6gevent_14_gevent_c_imap_13IMapUnordered__ispawn(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *__pyx_v_self, PyObject *__pyx_v_func, PyObject *__pyx_v_item, int __pyx_v_item_index) {
  PyObject *__pyx_v_g = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_ispawn", 0);

  /* "src/gevent/_imap.py":116
 * 
 *     def _ispawn(self, func, item, item_index):
 *         if self._result_semaphore is not None:             # <<<<<<<<<<<<<<
 *             self._result_semaphore.acquire()
 *         self._outstanding_tasks += 1
*/
  __pyx_t_1 = (((PyObject *)__pyx_v_self->_result_semaphore) != Py_None);
  if (__pyx_t_1) {

    /* "src/gevent/_imap.py":117
 *     def _ispawn(self, func, item, item_index):
 *         if self._result_semaphore is not None:
 *             self._result_semaphore.acquire()             # <<<<<<<<<<<<<<
 *         self._outstanding_tasks += 1
 *         g = self.spawn(func, item) if not self._zipped else self.spawn(func, *item)
*/
    __pyx_t_1 = ((struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self->_result_semaphore->__pyx_base.__pyx_vtab)->acquire(__pyx_v_self->_result_semaphore, 0, NULL); if (unlikely(__pyx_t_1 == ((int)-1000))) __PYX_ERR(0, 117, __pyx_L1_error)

    /* "src/gevent/_imap.py":116
 * 
 *     def _ispawn(self, func, item, item_index):
 *         if self._result_semaphore is not None:             # <<<<<<<<<<<<<<
 *             self._result_semaphore.acquire()
 *         self._outstanding_tasks += 1
*/
  }

  /* "src/gevent/_imap.py":118
 *         if self._result_semaphore is not None:
 *             self._result_semaphore.acquire()
 *         self._outstanding_tasks += 1             # <<<<<<<<<<<<<<
 *         g = self.spawn(func, item) if not self._zipped else self.spawn(func, *item)
 *         g._imap_task_index = item_index
*/
  __pyx_v_self->_outstanding_tasks = (__pyx_v_self->_outstanding_tasks + 1);

  /* "src/gevent/_imap.py":119
 *             self._result_semaphore.acquire()
 *         self._outstanding_tasks += 1
 *         g = self.spawn(func, item) if not self._zipped else self.spawn(func, *item)             # <<<<<<<<<<<<<<
 *         g._imap_task_index = item_index
 *         g.rawlink(self._on_result)
*/
  __pyx_t_1 = (!__pyx_v_self->_zipped);
  if (__pyx_t_1) {
    __pyx_t_4 = NULL;
    __Pyx_INCREF(__pyx_v_self->spawn);
    __pyx_t_5 = __pyx_v_self->spawn; 
    __pyx_t_6 = 1;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      assert(__pyx_t_4);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
      __pyx_t_6 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_v_func, __pyx_v_item};
      __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (3-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 119, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __pyx_t_2 = __pyx_t_3;
    __pyx_t_3 = 0;
  } else {
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 119, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_func);
    __Pyx_GIVEREF(__pyx_v_func);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_func) != (0)) __PYX_ERR(0, 119, __pyx_L1_error);
    __pyx_t_5 = __Pyx_PySequence_Tuple(__pyx_v_item); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 119, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = PyNumber_Add(__pyx_t_3, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 119, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_v_self->spawn, __pyx_t_4, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 119, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_2 = __pyx_t_5;
    __pyx_t_5 = 0;
  }
  __pyx_v_g = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "src/gevent/_imap.py":120
 *         self._outstanding_tasks += 1
 *         g = self.spawn(func, item) if not self._zipped else self.spawn(func, *item)
 *         g._imap_task_index = item_index             # <<<<<<<<<<<<<<
 *         g.rawlink(self._on_result)
 *         return g
*/
  __pyx_t_2 = __Pyx_PyLong_From_int(__pyx_v_item_index); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_g, __pyx_mstate_global->__pyx_n_u_imap_task_index, __pyx_t_2) < (0)) __PYX_ERR(0, 120, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/_imap.py":121
 *         g = self.spawn(func, item) if not self._zipped else self.spawn(func, *item)
 *         g._imap_task_index = item_index
 *         g.rawlink(self._on_result)             # <<<<<<<<<<<<<<
 *         return g
 * 
*/
  __pyx_t_5 = __pyx_v_g;
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_on_result); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_4};
    __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_rawlink, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 121, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/_imap.py":122
 *         g._imap_task_index = item_index
 *         g.rawlink(self._on_result)
 *         return g             # <<<<<<<<<<<<<<
 * 
 *     def _run(self): # pylint:disable=method-hidden
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_g);
  __pyx_r = __pyx_v_g;
  goto __pyx_L0;

  /* "src/gevent/_imap.py":115
 *         return self.queue.get()
 * 
 *     def _ispawn(self, func, item, item_index):             # <<<<<<<<<<<<<<
 *         if self._result_semaphore is not None:
 *             self._result_semaphore.acquire()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("gevent._gevent_c_imap.IMapUnordered._ispawn", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_g);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/_imap.py":124
 *         return g
 * 
 *     def _run(self): # pylint:disable=method-hidden             # <<<<<<<<<<<<<<
 *         try:
 *             func = self.func
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_14_gevent_c_imap_13IMapUnordered_7_run(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_14_gevent_c_imap_13IMapUnordered_6_run, "IMapUnordered._run(self)");
static PyMethodDef __pyx_mdef_6gevent_14_gevent_c_imap_13IMapUnordered_7_run = {"_run", (PyCFunction)__pyx_pw_6gevent_14_gevent_c_imap_13IMapUnordered_7_run, METH_NOARGS, __pyx_doc_6gevent_14_gevent_c_imap_13IMapUnordered_6_run};
static PyObject *__pyx_pw_6gevent_14_gevent_c_imap_13IMapUnordered_7_run(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_run (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_14_gevent_c_imap_13IMapUnordered_6_run(((struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_14_gevent_c_imap_13IMapUnordered_6_run(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *__pyx_v_self) {
  PyObject *__pyx_v_func = NULL;
  PyObject *__pyx_v_item = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  PyObject *(*__pyx_t_6)(PyObject *);
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  char const *__pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  char const *__pyx_t_19;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_run", 0);

  /* "src/gevent/_imap.py":125
 * 
 *     def _run(self): # pylint:disable=method-hidden
 *         try:             # <<<<<<<<<<<<<<
 *             func = self.func
 *             for item in self.iterable:
*/
  /*try:*/ {
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_1);
      __Pyx_XGOTREF(__pyx_t_2);
      __Pyx_XGOTREF(__pyx_t_3);
      /*try:*/ {

        /* "src/gevent/_imap.py":126
 *     def _run(self): # pylint:disable=method-hidden
 *         try:
 *             func = self.func             # <<<<<<<<<<<<<<
 *             for item in self.iterable:
 *                 self._max_index += 1
*/
        __pyx_t_4 = __pyx_v_self->func;
        __Pyx_INCREF(__pyx_t_4);
        __pyx_v_func = __pyx_t_4;
        __pyx_t_4 = 0;

        /* "src/gevent/_imap.py":127
 *         try:
 *             func = self.func
 *             for item in self.iterable:             # <<<<<<<<<<<<<<
 *                 self._max_index += 1
 *                 self._ispawn(func, item, self._max_index)
*/
        if (likely(PyList_CheckExact(__pyx_v_self->iterable)) || PyTuple_CheckExact(__pyx_v_self->iterable)) {
          __pyx_t_4 = __pyx_v_self->iterable; __Pyx_INCREF(__pyx_t_4);
          __pyx_t_5 = 0;
          __pyx_t_6 = NULL;
        } else {
          __pyx_t_5 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_v_self->iterable); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 127, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_6 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 127, __pyx_L6_error)
        }
        for (;;) {
          if (likely(!__pyx_t_6)) {
            if (likely(PyList_CheckExact(__pyx_t_4))) {
              {
                Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_4);
                #if !CYTHON_ASSUME_SAFE_SIZE
                if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 127, __pyx_L6_error)
                #endif
                if (__pyx_t_5 >= __pyx_temp) break;
              }
              __pyx_t_7 = __Pyx_PyList_GetItemRefFast(__pyx_t_4, __pyx_t_5, __Pyx_ReferenceSharing_OwnStrongReference);
              ++__pyx_t_5;
            } else {
              {
                Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_4);
                #if !CYTHON_ASSUME_SAFE_SIZE
                if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 127, __pyx_L6_error)
                #endif
                if (__pyx_t_5 >= __pyx_temp) break;
              }
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_7 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_5));
              #else
              __pyx_t_7 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_5);
              #endif
              ++__pyx_t_5;
            }
            if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 127, __pyx_L6_error)
          } else {
            __pyx_t_7 = __pyx_t_6(__pyx_t_4);
            if (unlikely(!__pyx_t_7)) {
              PyObject* exc_type = PyErr_Occurred();
              if (exc_type) {
                if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 127, __pyx_L6_error)
                PyErr_Clear();
              }
              break;
            }
          }
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_XDECREF_SET(__pyx_v_item, __pyx_t_7);
          __pyx_t_7 = 0;

          /* "src/gevent/_imap.py":128
 *             func = self.func
 *             for item in self.iterable:
 *                 self._max_index += 1             # <<<<<<<<<<<<<<
 *                 self._ispawn(func, item, self._max_index)
 *             self._on_finish(None)
*/
          __pyx_v_self->_max_index = (__pyx_v_self->_max_index + 1);

          /* "src/gevent/_imap.py":129
 *             for item in self.iterable:
 *                 self._max_index += 1
 *                 self._ispawn(func, item, self._max_index)             # <<<<<<<<<<<<<<
 *             self._on_finish(None)
 *         except BaseException as e:
*/
          __pyx_t_7 = ((struct __pyx_vtabstruct_6gevent_14_gevent_c_imap_IMapUnordered *)__pyx_v_self->__pyx_base.__pyx_vtab)->_ispawn(__pyx_v_self, __pyx_v_func, __pyx_v_item, __pyx_v_self->_max_index); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 129, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

          /* "src/gevent/_imap.py":127
 *         try:
 *             func = self.func
 *             for item in self.iterable:             # <<<<<<<<<<<<<<
 *                 self._max_index += 1
 *                 self._ispawn(func, item, self._max_index)
*/
        }
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "src/gevent/_imap.py":130
 *                 self._max_index += 1
 *                 self._ispawn(func, item, self._max_index)
 *             self._on_finish(None)             # <<<<<<<<<<<<<<
 *         except BaseException as e:
 *             self._on_finish(e)
*/
        __pyx_t_4 = ((struct __pyx_vtabstruct_6gevent_14_gevent_c_imap_IMapUnordered *)__pyx_v_self->__pyx_base.__pyx_vtab)->_on_finish(__pyx_v_self, Py_None); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 130, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "src/gevent/_imap.py":125
 * 
 *     def _run(self): # pylint:disable=method-hidden
 *         try:             # <<<<<<<<<<<<<<
 *             func = self.func
 *             for item in self.iterable:
*/
      }
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      goto __pyx_L11_try_end;
      __pyx_L6_error:;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "src/gevent/_imap.py":131
 *                 self._ispawn(func, item, self._max_index)
 *             self._on_finish(None)
 *         except BaseException as e:             # <<<<<<<<<<<<<<
 *             self._on_finish(e)
 *             raise
*/
      __pyx_t_8 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_BaseException))));
      if (__pyx_t_8) {
        __Pyx_AddTraceback("gevent._gevent_c_imap.IMapUnordered._run", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_7, &__pyx_t_9) < 0) __PYX_ERR(0, 131, __pyx_L8_except_error)
        __Pyx_XGOTREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_t_7);
        __Pyx_XGOTREF(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_7);
        __pyx_v_e = __pyx_t_7;
        /*try:*/ {

          /* "src/gevent/_imap.py":132
 *             self._on_finish(None)
 *         except BaseException as e:
 *             self._on_finish(e)             # <<<<<<<<<<<<<<
 *             raise
 *         finally:
*/
          __pyx_t_10 = ((struct __pyx_vtabstruct_6gevent_14_gevent_c_imap_IMapUnordered *)__pyx_v_self->__pyx_base.__pyx_vtab)->_on_finish(__pyx_v_self, __pyx_v_e); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 132, __pyx_L20_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

          /* "src/gevent/_imap.py":133
 *         except BaseException as e:
 *             self._on_finish(e)
 *             raise             # <<<<<<<<<<<<<<
 *         finally:
 *             self.spawn = None
*/
          __Pyx_GIVEREF(__pyx_t_4);
          __Pyx_GIVEREF(__pyx_t_7);
          __Pyx_XGIVEREF(__pyx_t_9);
          __Pyx_ErrRestoreWithState(__pyx_t_4, __pyx_t_7, __pyx_t_9);
          __pyx_t_4 = 0;  __pyx_t_7 = 0;  __pyx_t_9 = 0; 
          __PYX_ERR(0, 133, __pyx_L20_error)
        }

        /* "src/gevent/_imap.py":131
 *                 self._ispawn(func, item, self._max_index)
 *             self._on_finish(None)
 *         except BaseException as e:             # <<<<<<<<<<<<<<
 *             self._on_finish(e)
 *             raise
*/
        /*finally:*/ {
          __pyx_L20_error:;
          /*exception exit:*/{
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0;
            __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
             __Pyx_ExceptionSwap(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18);
            if ( unlikely(__Pyx_GetException(&__pyx_t_13, &__pyx_t_14, &__pyx_t_15) < 0)) __Pyx_ErrFetch(&__pyx_t_13, &__pyx_t_14, &__pyx_t_15);
            __Pyx_XGOTREF(__pyx_t_13);
            __Pyx_XGOTREF(__pyx_t_14);
            __Pyx_XGOTREF(__pyx_t_15);
            __Pyx_XGOTREF(__pyx_t_16);
            __Pyx_XGOTREF(__pyx_t_17);
            __Pyx_XGOTREF(__pyx_t_18);
            __pyx_t_8 = __pyx_lineno; __pyx_t_11 = __pyx_clineno; __pyx_t_12 = __pyx_filename;
            {
              __Pyx_DECREF(__pyx_v_e); __pyx_v_e = 0;
            }
            __Pyx_XGIVEREF(__pyx_t_16);
            __Pyx_XGIVEREF(__pyx_t_17);
            __Pyx_XGIVEREF(__pyx_t_18);
            __Pyx_ExceptionReset(__pyx_t_16, __pyx_t_17, __pyx_t_18);
            __Pyx_XGIVEREF(__pyx_t_13);
            __Pyx_XGIVEREF(__pyx_t_14);
            __Pyx_XGIVEREF(__pyx_t_15);
            __Pyx_ErrRestore(__pyx_t_13, __pyx_t_14, __pyx_t_15);
            __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0;
            __pyx_lineno = __pyx_t_8; __pyx_clineno = __pyx_t_11; __pyx_filename = __pyx_t_12;
            goto __pyx_L8_except_error;
          }
        }
      }
      goto __pyx_L8_except_error;

      /* "src/gevent/_imap.py":125
 * 
 *     def _run(self): # pylint:disable=method-hidden
 *         try:             # <<<<<<<<<<<<<<
 *             func = self.func
 *             for item in self.iterable:
*/
      __pyx_L8_except_error:;
      __Pyx_XGIVEREF(__pyx_t_1);
      __Pyx_XGIVEREF(__pyx_t_2);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
      goto __pyx_L4_error;
      __pyx_L11_try_end:;
    }
  }

  /* "src/gevent/_imap.py":135
 *             raise
 *         finally:
 *             self.spawn = None             # <<<<<<<<<<<<<<
 *             self.func = None
 *             self.iterable = None
*/
  /*finally:*/ {
    /*normal exit:*/{
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->spawn);
      __Pyx_DECREF(__pyx_v_self->spawn);
      __pyx_v_self->spawn = Py_None;

      /* "src/gevent/_imap.py":136
 *         finally:
 *             self.spawn = None
 *             self.func = None             # <<<<<<<<<<<<<<
 *             self.iterable = None
 *             self._result_semaphore = None
*/
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->func);
      __Pyx_DECREF(__pyx_v_self->func);
      __pyx_v_self->func = Py_None;

      /* "src/gevent/_imap.py":137
 *             self.spawn = None
 *             self.func = None
 *             self.iterable = None             # <<<<<<<<<<<<<<
 *             self._result_semaphore = None
 * 
*/
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->iterable);
      __Pyx_DECREF(__pyx_v_self->iterable);
      __pyx_v_self->iterable = Py_None;

      /* "src/gevent/_imap.py":138
 *             self.func = None
 *             self.iterable = None
 *             self._result_semaphore = None             # <<<<<<<<<<<<<<
 * 
 *     def _on_result(self, greenlet):
*/
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF((PyObject *)__pyx_v_self->_result_semaphore);
      __Pyx_DECREF((PyObject *)__pyx_v_self->_result_semaphore);
      __pyx_v_self->_result_semaphore = ((struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *)Py_None);
      goto __pyx_L5;
    }
    __pyx_L4_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_3 = 0; __pyx_t_2 = 0; __pyx_t_1 = 0; __pyx_t_18 = 0; __pyx_t_17 = 0; __pyx_t_16 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
       __Pyx_ExceptionSwap(&__pyx_t_18, &__pyx_t_17, &__pyx_t_16);
      if ( unlikely(__Pyx_GetException(&__pyx_t_3, &__pyx_t_2, &__pyx_t_1) < 0)) __Pyx_ErrFetch(&__pyx_t_3, &__pyx_t_2, &__pyx_t_1);
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_2);
      __Pyx_XGOTREF(__pyx_t_1);
      __Pyx_XGOTREF(__pyx_t_18);
      __Pyx_XGOTREF(__pyx_t_17);
      __Pyx_XGOTREF(__pyx_t_16);
      __pyx_t_11 = __pyx_lineno; __pyx_t_8 = __pyx_clineno; __pyx_t_19 = __pyx_filename;
      {

        /* "src/gevent/_imap.py":135
 *             raise
 *         finally:
 *             self.spawn = None             # <<<<<<<<<<<<<<
 *             self.func = None
 *             self.iterable = None
*/
        __Pyx_INCREF(Py_None);
        __Pyx_GIVEREF(Py_None);
        __Pyx_GOTREF(__pyx_v_self->spawn);
        __Pyx_DECREF(__pyx_v_self->spawn);
        __pyx_v_self->spawn = Py_None;

        /* "src/gevent/_imap.py":136
 *         finally:
 *             self.spawn = None
 *             self.func = None             # <<<<<<<<<<<<<<
 *             self.iterable = None
 *             self._result_semaphore = None
*/
        __Pyx_INCREF(Py_None);
        __Pyx_GIVEREF(Py_None);
        __Pyx_GOTREF(__pyx_v_self->func);
        __Pyx_DECREF(__pyx_v_self->func);
        __pyx_v_self->func = Py_None;

        /* "src/gevent/_imap.py":137
 *             self.spawn = None
 *             self.func = None
 *             self.iterable = None             # <<<<<<<<<<<<<<
 *             self._result_semaphore = None
 * 
*/
        __Pyx_INCREF(Py_None);
        __Pyx_GIVEREF(Py_None);
        __Pyx_GOTREF(__pyx_v_self->iterable);
        __Pyx_DECREF(__pyx_v_self->iterable);
        __pyx_v_self->iterable = Py_None;

        /* "src/gevent/_imap.py":138
 *             self.func = None
 *             self.iterable = None
 *             self._result_semaphore = None             # <<<<<<<<<<<<<<
 * 
 *     def _on_result(self, greenlet):
*/
        __Pyx_INCREF(Py_None);
        __Pyx_GIVEREF(Py_None);
        __Pyx_GOTREF((PyObject *)__pyx_v_self->_result_semaphore);
        __Pyx_DECREF((PyObject *)__pyx_v_self->_result_semaphore);
        __pyx_v_self->_result_semaphore = ((struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *)Py_None);
      }
      __Pyx_XGIVEREF(__pyx_t_18);
      __Pyx_XGIVEREF(__pyx_t_17);
      __Pyx_XGIVEREF(__pyx_t_16);
      __Pyx_ExceptionReset(__pyx_t_18, __pyx_t_17, __pyx_t_16);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_2);
      __Pyx_XGIVEREF(__pyx_t_1);
      __Pyx_ErrRestore(__pyx_t_3, __pyx_t_2, __pyx_t_1);
      __pyx_t_3 = 0; __pyx_t_2 = 0; __pyx_t_1 = 0; __pyx_t_18 = 0; __pyx_t_17 = 0; __pyx_t_16 = 0;
      __pyx_lineno = __pyx_t_11; __pyx_clineno = __pyx_t_8; __pyx_filename = __pyx_t_19;
      goto __pyx_L1_error;
    }
    __pyx_L5:;
  }

  /* "src/gevent/_imap.py":124
 *         return g
 * 
 *     def _run(self): # pylint:disable=method-hidden             # <<<<<<<<<<<<<<
 *         try:
 *             func = self.func
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("gevent._gevent_c_imap.IMapUnordered._run", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_func);
  __Pyx_XDECREF(__pyx_v_item);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/_imap.py":140
 *             self._result_semaphore = None
 * 
 *     def _on_result(self, greenlet):             # <<<<<<<<<<<<<<
 *         # This method will be called in the hub greenlet (we rawlink)
 *         self._outstanding_tasks -= 1
*/

static PyObject *__pyx_pw_6gevent_14_gevent_c_imap_13IMapUnordered_9_on_result(PyObject *__pyx_v_self, PyObject *__pyx_v_greenlet); /*proto*/
static PyObject *__pyx_f_6gevent_14_gevent_c_imap_13IMapUnordered__on_result(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *__pyx_v_self, PyObject *__pyx_v_greenlet, int __pyx_skip_dispatch) {
  int __pyx_v_count;
  int __pyx_v_finished;
  int __pyx_v_ready;
  int __pyx_v_put_finished;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_on_result", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (
  #if !CYTHON_USE_TYPE_SLOTS
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_c_imap_IMapUnordered &&
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
  #else
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
  #endif
  ) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_on_result); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 140, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_6gevent_14_gevent_c_imap_13IMapUnordered_9_on_result)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_greenlet};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 140, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "src/gevent/_imap.py":142
 *     def _on_result(self, greenlet):
 *         # This method will be called in the hub greenlet (we rawlink)
 *         self._outstanding_tasks -= 1             # <<<<<<<<<<<<<<
 *         count = self._outstanding_tasks
 *         finished = self.finished
*/
  __pyx_v_self->_outstanding_tasks = (__pyx_v_self->_outstanding_tasks - 1);

  /* "src/gevent/_imap.py":143
 *         # This method will be called in the hub greenlet (we rawlink)
 *         self._outstanding_tasks -= 1
 *         count = self._outstanding_tasks             # <<<<<<<<<<<<<<
 *         finished = self.finished
 *         ready = self.ready()
*/
  __pyx_t_6 = __pyx_v_self->_outstanding_tasks;
  __pyx_v_count = __pyx_t_6;

  /* "src/gevent/_imap.py":144
 *         self._outstanding_tasks -= 1
 *         count = self._outstanding_tasks
 *         finished = self.finished             # <<<<<<<<<<<<<<
 *         ready = self.ready()
 *         put_finished = False
*/
  __pyx_t_7 = __pyx_v_self->finished;
  __pyx_v_finished = __pyx_t_7;

  /* "src/gevent/_imap.py":145
 *         count = self._outstanding_tasks
 *         finished = self.finished
 *         ready = self.ready()             # <<<<<<<<<<<<<<
 *         put_finished = False
 * 
*/
  __pyx_t_7 = ((struct __pyx_vtabstruct_6gevent_14_gevent_c_imap_IMapUnordered *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.ready(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self), 0); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 145, __pyx_L1_error)
  __pyx_v_ready = __pyx_t_7;

  /* "src/gevent/_imap.py":146
 *         finished = self.finished
 *         ready = self.ready()
 *         put_finished = False             # <<<<<<<<<<<<<<
 * 
 *         if ready and count <= 0 and not finished:
*/
  __pyx_v_put_finished = 0;

  /* "src/gevent/_imap.py":148
 *         put_finished = False
 * 
 *         if ready and count <= 0 and not finished:             # <<<<<<<<<<<<<<
 *             finished = self.finished = True
 *             put_finished = True
*/
  if (__pyx_v_ready) {
  } else {
    __pyx_t_7 = __pyx_v_ready;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_8 = (__pyx_v_count <= 0);
  if (__pyx_t_8) {
  } else {
    __pyx_t_7 = __pyx_t_8;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_8 = (!__pyx_v_finished);
  __pyx_t_7 = __pyx_t_8;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_7) {

    /* "src/gevent/_imap.py":149
 * 
 *         if ready and count <= 0 and not finished:
 *             finished = self.finished = True             # <<<<<<<<<<<<<<
 *             put_finished = True
 * 
*/
    __pyx_v_finished = 1;
    __pyx_v_self->finished = 1;

    /* "src/gevent/_imap.py":150
 *         if ready and count <= 0 and not finished:
 *             finished = self.finished = True
 *             put_finished = True             # <<<<<<<<<<<<<<
 * 
 *         if greenlet.successful():
*/
    __pyx_v_put_finished = 1;

    /* "src/gevent/_imap.py":148
 *         put_finished = False
 * 
 *         if ready and count <= 0 and not finished:             # <<<<<<<<<<<<<<
 *             finished = self.finished = True
 *             put_finished = True
*/
  }

  /* "src/gevent/_imap.py":152
 *             put_finished = True
 * 
 *         if greenlet.successful():             # <<<<<<<<<<<<<<
 *             self.queue.put(self._iqueue_value_for_success(greenlet))
 *         else:
*/
  __pyx_t_2 = __pyx_v_greenlet;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_successful, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 152, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 152, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_7) {

    /* "src/gevent/_imap.py":153
 * 
 *         if greenlet.successful():
 *             self.queue.put(self._iqueue_value_for_success(greenlet))             # <<<<<<<<<<<<<<
 *         else:
 *             self.queue.put(self._iqueue_value_for_failure(greenlet))
*/
    __pyx_t_1 = ((struct __pyx_vtabstruct_6gevent_14_gevent_c_imap_IMapUnordered *)__pyx_v_self->__pyx_base.__pyx_vtab)->_iqueue_value_for_success(__pyx_v_self, __pyx_v_greenlet); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 153, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = ((struct __pyx_vtabstruct_6gevent_14_gevent_cqueue_UnboundQueue *)__pyx_v_self->queue->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.put(((struct __pyx_obj_6gevent_14_gevent_cqueue_SimpleQueue *)__pyx_v_self->queue), __pyx_t_1, 0, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 153, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "src/gevent/_imap.py":152
 *             put_finished = True
 * 
 *         if greenlet.successful():             # <<<<<<<<<<<<<<
 *             self.queue.put(self._iqueue_value_for_success(greenlet))
 *         else:
*/
    goto __pyx_L7;
  }

  /* "src/gevent/_imap.py":155
 *             self.queue.put(self._iqueue_value_for_success(greenlet))
 *         else:
 *             self.queue.put(self._iqueue_value_for_failure(greenlet))             # <<<<<<<<<<<<<<
 * 
 *         if put_finished:
*/
  /*else*/ {
    __pyx_t_2 = ((struct __pyx_vtabstruct_6gevent_14_gevent_c_imap_IMapUnordered *)__pyx_v_self->__pyx_base.__pyx_vtab)->_iqueue_value_for_failure(__pyx_v_self, __pyx_v_greenlet); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 155, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = ((struct __pyx_vtabstruct_6gevent_14_gevent_cqueue_UnboundQueue *)__pyx_v_self->queue->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.put(((struct __pyx_obj_6gevent_14_gevent_cqueue_SimpleQueue *)__pyx_v_self->queue), __pyx_t_2, 0, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 155, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L7:;

  /* "src/gevent/_imap.py":157
 *             self.queue.put(self._iqueue_value_for_failure(greenlet))
 * 
 *         if put_finished:             # <<<<<<<<<<<<<<
 *             self.queue.put(self._iqueue_value_for_self_finished())
 * 
*/
  if (__pyx_v_put_finished) {

    /* "src/gevent/_imap.py":158
 * 
 *         if put_finished:
 *             self.queue.put(self._iqueue_value_for_self_finished())             # <<<<<<<<<<<<<<
 * 
 *     def _on_finish(self, exception):
*/
    __pyx_t_1 = ((struct __pyx_vtabstruct_6gevent_14_gevent_c_imap_IMapUnordered *)__pyx_v_self->__pyx_base.__pyx_vtab)->_iqueue_value_for_self_finished(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 158, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = ((struct __pyx_vtabstruct_6gevent_14_gevent_cqueue_UnboundQueue *)__pyx_v_self->queue->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.put(((struct __pyx_obj_6gevent_14_gevent_cqueue_SimpleQueue *)__pyx_v_self->queue), __pyx_t_1, 0, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 158, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "src/gevent/_imap.py":157
 *             self.queue.put(self._iqueue_value_for_failure(greenlet))
 * 
 *         if put_finished:             # <<<<<<<<<<<<<<
 *             self.queue.put(self._iqueue_value_for_self_finished())
 * 
*/
  }

  /* "src/gevent/_imap.py":140
 *             self._result_semaphore = None
 * 
 *     def _on_result(self, greenlet):             # <<<<<<<<<<<<<<
 *         # This method will be called in the hub greenlet (we rawlink)
 *         self._outstanding_tasks -= 1
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("gevent._gevent_c_imap.IMapUnordered._on_result", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_14_gevent_c_imap_13IMapUnordered_9_on_result(PyObject *__pyx_v_self, PyObject *__pyx_v_greenlet); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_14_gevent_c_imap_13IMapUnordered_8_on_result, "IMapUnordered._on_result(self, greenlet)");
static PyMethodDef __pyx_mdef_6gevent_14_gevent_c_imap_13IMapUnordered_9_on_result = {"_on_result", (PyCFunction)__pyx_pw_6gevent_14_gevent_c_imap_13IMapUnordered_9_on_result, METH_O, __pyx_doc_6gevent_14_gevent_c_imap_13IMapUnordered_8_on_result};
static PyObject *__pyx_pw_6gevent_14_gevent_c_imap_13IMapUnordered_9_on_result(PyObject *__pyx_v_self, PyObject *__pyx_v_greenlet) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_on_result (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_14_gevent_c_imap_13IMapUnordered_8_on_result(((struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *)__pyx_v_self), ((PyObject *)__pyx_v_greenlet));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_14_gevent_c_imap_13IMapUnordered_8_on_result(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *__pyx_v_self, PyObject *__pyx_v_greenlet) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_on_result", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6gevent_14_gevent_c_imap_13IMapUnordered__on_result(__pyx_v_self, __pyx_v_greenlet, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_c_imap.IMapUnordered._on_result", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/_imap.py":160
 *             self.queue.put(self._iqueue_value_for_self_finished())
 * 
 *     def _on_finish(self, exception):             # <<<<<<<<<<<<<<
 *         # Called in this greenlet.
 *         if self.finished:
*/

static PyObject *__pyx_f_6gevent_14_gevent_c_imap_13IMapUnordered__on_finish(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *__pyx_v_self, PyObject *__pyx_v_exception) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_on_finish", 0);

  /* "src/gevent/_imap.py":162
 *     def _on_finish(self, exception):
 *         # Called in this greenlet.
 *         if self.finished:             # <<<<<<<<<<<<<<
 *             return
 * 
*/
  if (__pyx_v_self->finished) {

    /* "src/gevent/_imap.py":163
 *         # Called in this greenlet.
 *         if self.finished:
 *             return             # <<<<<<<<<<<<<<
 * 
 *         if exception is not None:
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "src/gevent/_imap.py":162
 *     def _on_finish(self, exception):
 *         # Called in this greenlet.
 *         if self.finished:             # <<<<<<<<<<<<<<
 *             return
 * 
*/
  }

  /* "src/gevent/_imap.py":165
 *             return
 * 
 *         if exception is not None:             # <<<<<<<<<<<<<<
 *             self.finished = True
 *             self.queue.put(self._iqueue_value_for_self_failure(exception))
*/
  __pyx_t_1 = (__pyx_v_exception != Py_None);
  if (__pyx_t_1) {

    /* "src/gevent/_imap.py":166
 * 
 *         if exception is not None:
 *             self.finished = True             # <<<<<<<<<<<<<<
 *             self.queue.put(self._iqueue_value_for_self_failure(exception))
 *             return
*/
    __pyx_v_self->finished = 1;

    /* "src/gevent/_imap.py":167
 *         if exception is not None:
 *             self.finished = True
 *             self.queue.put(self._iqueue_value_for_self_failure(exception))             # <<<<<<<<<<<<<<
 *             return
 * 
*/
    __pyx_t_2 = ((struct __pyx_vtabstruct_6gevent_14_gevent_c_imap_IMapUnordered *)__pyx_v_self->__pyx_base.__pyx_vtab)->_iqueue_value_for_self_failure(__pyx_v_self, __pyx_v_exception); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 167, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = ((struct __pyx_vtabstruct_6gevent_14_gevent_cqueue_UnboundQueue *)__pyx_v_self->queue->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.put(((struct __pyx_obj_6gevent_14_gevent_cqueue_SimpleQueue *)__pyx_v_self->queue), __pyx_t_2, 0, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 167, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "src/gevent/_imap.py":168
 *             self.finished = True
 *             self.queue.put(self._iqueue_value_for_self_failure(exception))
 *             return             # <<<<<<<<<<<<<<
 * 
 *         if self._outstanding_tasks <= 0:
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "src/gevent/_imap.py":165
 *             return
 * 
 *         if exception is not None:             # <<<<<<<<<<<<<<
 *             self.finished = True
 *             self.queue.put(self._iqueue_value_for_self_failure(exception))
*/
  }

  /* "src/gevent/_imap.py":170
 *             return
 * 
 *         if self._outstanding_tasks <= 0:             # <<<<<<<<<<<<<<
 *             self.finished = True
 *             self.queue.put(self._iqueue_value_for_self_finished())
*/
  __pyx_t_1 = (__pyx_v_self->_outstanding_tasks <= 0);
  if (__pyx_t_1) {

    /* "src/gevent/_imap.py":171
 * 
 *         if self._outstanding_tasks <= 0:
 *             self.finished = True             # <<<<<<<<<<<<<<
 *             self.queue.put(self._iqueue_value_for_self_finished())
 * 
*/
    __pyx_v_self->finished = 1;

    /* "src/gevent/_imap.py":172
 *         if self._outstanding_tasks <= 0:
 *             self.finished = True
 *             self.queue.put(self._iqueue_value_for_self_finished())             # <<<<<<<<<<<<<<
 * 
 *     def _iqueue_value_for_success(self, greenlet):
*/
    __pyx_t_3 = ((struct __pyx_vtabstruct_6gevent_14_gevent_c_imap_IMapUnordered *)__pyx_v_self->__pyx_base.__pyx_vtab)->_iqueue_value_for_self_finished(__pyx_v_self); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 172, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = ((struct __pyx_vtabstruct_6gevent_14_gevent_cqueue_UnboundQueue *)__pyx_v_self->queue->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.put(((struct __pyx_obj_6gevent_14_gevent_cqueue_SimpleQueue *)__pyx_v_self->queue), __pyx_t_3, 0, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 172, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "src/gevent/_imap.py":170
 *             return
 * 
 *         if self._outstanding_tasks <= 0:             # <<<<<<<<<<<<<<
 *             self.finished = True
 *             self.queue.put(self._iqueue_value_for_self_finished())
*/
  }

  /* "src/gevent/_imap.py":160
 *             self.queue.put(self._iqueue_value_for_self_finished())
 * 
 *     def _on_finish(self, exception):             # <<<<<<<<<<<<<<
 *         # Called in this greenlet.
 *         if self.finished:
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("gevent._gevent_c_imap.IMapUnordered._on_finish", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/_imap.py":174
 *             self.queue.put(self._iqueue_value_for_self_finished())
 * 
 *     def _iqueue_value_for_success(self, greenlet):             # <<<<<<<<<<<<<<
 *         return greenlet.value
 * 
*/

static PyObject *__pyx_f_6gevent_14_gevent_c_imap_13IMapUnordered__iqueue_value_for_success(CYTHON_UNUSED struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *__pyx_v_self, PyObject *__pyx_v_greenlet) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_iqueue_value_for_success", 0);

  /* "src/gevent/_imap.py":175
 * 
 *     def _iqueue_value_for_success(self, greenlet):
 *         return greenlet.value             # <<<<<<<<<<<<<<
 * 
 *     def _iqueue_value_for_failure(self, greenlet):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_greenlet, __pyx_mstate_global->__pyx_n_u_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 175, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "src/gevent/_imap.py":174
 *             self.queue.put(self._iqueue_value_for_self_finished())
 * 
 *     def _iqueue_value_for_success(self, greenlet):             # <<<<<<<<<<<<<<
 *         return greenlet.value
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_c_imap.IMapUnordered._iqueue_value_for_success", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/_imap.py":177
 *         return greenlet.value
 * 
 *     def _iqueue_value_for_failure(self, greenlet):             # <<<<<<<<<<<<<<
 *         return Failure(greenlet.exception, getattr(greenlet, '_raise_exception'))
 * 
*/

static PyObject *__pyx_f_6gevent_14_gevent_c_imap_13IMapUnordered__iqueue_value_for_failure(CYTHON_UNUSED struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *__pyx_v_self, PyObject *__pyx_v_greenlet) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_iqueue_value_for_failure", 0);

  /* "src/gevent/_imap.py":178
 * 
 *     def _iqueue_value_for_failure(self, greenlet):
 *         return Failure(greenlet.exception, getattr(greenlet, '_raise_exception'))             # <<<<<<<<<<<<<<
 * 
 *     def _iqueue_value_for_self_finished(self):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = NULL;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_greenlet, __pyx_mstate_global->__pyx_n_u_exception); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_GetAttr(__pyx_v_greenlet, __pyx_mstate_global->__pyx_n_u_raise_exception_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = 1;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_t_3, __pyx_t_4};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_c_imap_Failure, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 178, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_1);
  }
  __pyx_r = ((PyObject *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "src/gevent/_imap.py":177
 *         return greenlet.value
 * 
 *     def _iqueue_value_for_failure(self, greenlet):             # <<<<<<<<<<<<<<
 *         return Failure(greenlet.exception, getattr(greenlet, '_raise_exception'))
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("gevent._gevent_c_imap.IMapUnordered._iqueue_value_for_failure", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/_imap.py":180
 *         return Failure(greenlet.exception, getattr(greenlet, '_raise_exception'))
 * 
 *     def _iqueue_value_for_self_finished(self):             # <<<<<<<<<<<<<<
 *         return Failure(StopIteration())
 * 
*/

static PyObject *__pyx_f_6gevent_14_gevent_c_imap_13IMapUnordered__iqueue_value_for_self_finished(CYTHON_UNUSED struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_iqueue_value_for_self_finished", 0);

  /* "src/gevent/_imap.py":181
 * 
 *     def _iqueue_value_for_self_finished(self):
 *         return Failure(StopIteration())             # <<<<<<<<<<<<<<
 * 
 *     def _iqueue_value_for_self_failure(self, exception):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = NULL;
  __pyx_t_4 = NULL;
  __pyx_t_5 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
    __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_StopIteration)), __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 181, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_t_5 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_c_imap_Failure, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 181, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_1);
  }
  __pyx_r = ((PyObject *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "src/gevent/_imap.py":180
 *         return Failure(greenlet.exception, getattr(greenlet, '_raise_exception'))
 * 
 *     def _iqueue_value_for_self_finished(self):             # <<<<<<<<<<<<<<
 *         return Failure(StopIteration())
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("gevent._gevent_c_imap.IMapUnordered._iqueue_value_for_self_finished", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/_imap.py":183
 *         return Failure(StopIteration())
 * 
 *     def _iqueue_value_for_self_failure(self, exception):             # <<<<<<<<<<<<<<
 *         return Failure(exception, self._raise_exception)
 * 
*/

static PyObject *__pyx_f_6gevent_14_gevent_c_imap_13IMapUnordered__iqueue_value_for_self_failure(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *__pyx_v_self, PyObject *__pyx_v_exception) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_iqueue_value_for_self_failure", 0);

  /* "src/gevent/_imap.py":184
 * 
 *     def _iqueue_value_for_self_failure(self, exception):
 *         return Failure(exception, self._raise_exception)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = NULL;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_raise_exception_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 184, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = 1;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_exception, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_c_imap_Failure, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 184, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_1);
  }
  __pyx_r = ((PyObject *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "src/gevent/_imap.py":183
 *         return Failure(StopIteration())
 * 
 *     def _iqueue_value_for_self_failure(self, exception):             # <<<<<<<<<<<<<<
 *         return Failure(exception, self._raise_exception)
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("gevent._gevent_c_imap.IMapUnordered._iqueue_value_for_self_failure", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/_gevent_c_imap.pxd":24
 *     cdef int _max_index
 * 
 *     cdef readonly UnboundQueue queue             # <<<<<<<<<<<<<<
 *     cdef readonly bint finished
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_14_gevent_c_imap_13IMapUnordered_5queue_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6gevent_14_gevent_c_imap_13IMapUnordered_5queue_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_14_gevent_c_imap_13IMapUnordered_5queue___get__(((struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_14_gevent_c_imap_13IMapUnordered_5queue___get__(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->queue);
  __pyx_r = ((PyObject *)__pyx_v_self->queue);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/_gevent_c_imap.pxd":25
 * 
 *     cdef readonly UnboundQueue queue
 *     cdef readonly bint finished             # <<<<<<<<<<<<<<
 * 
 *     cdef _inext(self)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_14_gevent_c_imap_13IMapUnordered_8finished_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6gevent_14_gevent_c_imap_13IMapUnordered_8finished_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_14_gevent_c_imap_13IMapUnordered_8finished___get__(((struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_14_gevent_c_imap_13IMapUnordered_8finished___get__(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->finished); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_c_imap.IMapUnordered.finished.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/_imap.py":192
 *     # the order in which they finish.
 * 
 *     def __init__(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         # The result dictionary: {index: value}
 *         self._results = {}
*/

/* Python wrapper */
static int __pyx_pw_6gevent_14_gevent_c_imap_4IMap_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6gevent_14_gevent_c_imap_4IMap_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_v_kwargs = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return -1;
  if (__pyx_kwds_len > 0) {
    if (unlikely(__Pyx_CheckKeywordStrings("__init__", __pyx_kwds) == -1)) return -1;
    __pyx_v_kwargs = __Pyx_KwargsAsDict_VARARGS(__pyx_kwds, __pyx_kwvalues);
    if (unlikely(!__pyx_v_kwargs)) return -1;
    __Pyx_GOTREF(__pyx_v_kwargs);
  } else {
    __pyx_v_kwargs = PyDict_New();
    if (unlikely(!__pyx_v_kwargs)) return -1;
    __Pyx_GOTREF(__pyx_v_kwargs);
  }
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6gevent_14_gevent_c_imap_4IMap___init__(((struct __pyx_obj_6gevent_14_gevent_c_imap_IMap *)__pyx_v_self), __pyx_v_args, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_DECREF(__pyx_v_kwargs);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6gevent_14_gevent_c_imap_4IMap___init__(struct __pyx_obj_6gevent_14_gevent_c_imap_IMap *__pyx_v_self, PyObject *__pyx_v_args, PyObject *__pyx_v_kwargs) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "src/gevent/_imap.py":194
 *     def __init__(self, *args, **kwargs):
 *         # The result dictionary: {index: value}
 *         self._results = {}             # <<<<<<<<<<<<<<
 * 
 *         # The index of the result to return next.
*/
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 194, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_results);
  __Pyx_DECREF(__pyx_v_self->_results);
  __pyx_v_self->_results = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "src/gevent/_imap.py":197
 * 
 *         # The index of the result to return next.
 *         self.index = 0             # <<<<<<<<<<<<<<
 *         IMapUnordered.__init__(self, *args, **kwargs)
 * 
*/
  __pyx_v_self->index = 0;

  /* "src/gevent/_imap.py":198
 *         # The index of the result to return next.
 *         self.index = 0
 *         IMapUnordered.__init__(self, *args, **kwargs)             # <<<<<<<<<<<<<<
 * 
 *     def _inext(self):
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_c_imap_IMapUnordered), __pyx_mstate_global->__pyx_n_u_init); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 198, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 198, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_self)) != (0)) __PYX_ERR(0, 198, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_2, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 198, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyDict_Copy(__pyx_v_kwargs); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 198, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 198, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/_imap.py":192
 *     # the order in which they finish.
 * 
 *     def __init__(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         # The result dictionary: {index: value}
 *         self._results = {}
*/

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("gevent._gevent_c_imap.IMap.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/_imap.py":200
 *         IMapUnordered.__init__(self, *args, **kwargs)
 * 
 *     def _inext(self):             # <<<<<<<<<<<<<<
 *         try:
 *             value = self._results.pop(self.index)
*/

static PyObject *__pyx_f_6gevent_14_gevent_c_imap_4IMap__inext(struct __pyx_obj_6gevent_14_gevent_c_imap_IMap *__pyx_v_self) {
  int __pyx_v_index;
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *(*__pyx_t_12)(PyObject *);
  int __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_inext", 0);

  /* "src/gevent/_imap.py":201
 * 
 *     def _inext(self):
 *         try:             # <<<<<<<<<<<<<<
 *             value = self._results.pop(self.index)
 *         except KeyError:
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "src/gevent/_imap.py":202
 *     def _inext(self):
 *         try:
 *             value = self._results.pop(self.index)             # <<<<<<<<<<<<<<
 *         except KeyError:
 *             # Wait for our index to finish.
*/
      if (unlikely(__pyx_v_self->_results == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "pop");
        __PYX_ERR(0, 202, __pyx_L3_error)
      }
      __pyx_t_4 = __Pyx_PyLong_From_int(__pyx_v_self->index); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 202, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyDict_Pop(__pyx_v_self->_results, __pyx_t_4, ((PyObject *)NULL)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 202, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_v_value = __pyx_t_5;
      __pyx_t_5 = 0;

      /* "src/gevent/_imap.py":201
 * 
 *     def _inext(self):
 *         try:             # <<<<<<<<<<<<<<
 *             value = self._results.pop(self.index)
 *         except KeyError:
*/
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "src/gevent/_imap.py":203
 *         try:
 *             value = self._results.pop(self.index)
 *         except KeyError:             # <<<<<<<<<<<<<<
 *             # Wait for our index to finish.
 *             while 1:
*/
    __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_KeyError))));
    if (__pyx_t_6) {
      __Pyx_AddTraceback("gevent._gevent_c_imap.IMap._inext", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_4, &__pyx_t_7) < 0) __PYX_ERR(0, 203, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_7);

      /* "src/gevent/_imap.py":205
 *         except KeyError:
 *             # Wait for our index to finish.
 *             while 1:             # <<<<<<<<<<<<<<
 *                 index, value = self.queue.get()
 *                 if index == self.index:
*/
      while (1) {

        /* "src/gevent/_imap.py":206
 *             # Wait for our index to finish.
 *             while 1:
 *                 index, value = self.queue.get()             # <<<<<<<<<<<<<<
 *                 if index == self.index:
 *                     break
*/
        __pyx_t_8 = ((struct __pyx_vtabstruct_6gevent_14_gevent_cqueue_UnboundQueue *)__pyx_v_self->__pyx_base.queue->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.get(((struct __pyx_obj_6gevent_14_gevent_cqueue_SimpleQueue *)__pyx_v_self->__pyx_base.queue), 0, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 206, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_8);
        if ((likely(PyTuple_CheckExact(__pyx_t_8))) || (PyList_CheckExact(__pyx_t_8))) {
          PyObject* sequence = __pyx_t_8;
          Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
          if (unlikely(size != 2)) {
            if (size > 2) __Pyx_RaiseTooManyValuesError(2);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            __PYX_ERR(0, 206, __pyx_L5_except_error)
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          if (likely(PyTuple_CheckExact(sequence))) {
            __pyx_t_9 = PyTuple_GET_ITEM(sequence, 0);
            __Pyx_INCREF(__pyx_t_9);
            __pyx_t_10 = PyTuple_GET_ITEM(sequence, 1);
            __Pyx_INCREF(__pyx_t_10);
          } else {
            __pyx_t_9 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
            if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 206, __pyx_L5_except_error)
            __Pyx_XGOTREF(__pyx_t_9);
            __pyx_t_10 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
            if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 206, __pyx_L5_except_error)
            __Pyx_XGOTREF(__pyx_t_10);
          }
          #else
          __pyx_t_9 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 206, __pyx_L5_except_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_10 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 206, __pyx_L5_except_error)
          __Pyx_GOTREF(__pyx_t_10);
          #endif
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        } else {
          Py_ssize_t index = -1;
          __pyx_t_11 = PyObject_GetIter(__pyx_t_8); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 206, __pyx_L5_except_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __pyx_t_12 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_11);
          index = 0; __pyx_t_9 = __pyx_t_12(__pyx_t_11); if (unlikely(!__pyx_t_9)) goto __pyx_L13_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_9);
          index = 1; __pyx_t_10 = __pyx_t_12(__pyx_t_11); if (unlikely(!__pyx_t_10)) goto __pyx_L13_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_10);
          if (__Pyx_IternextUnpackEndCheck(__pyx_t_12(__pyx_t_11), 2) < (0)) __PYX_ERR(0, 206, __pyx_L5_except_error)
          __pyx_t_12 = NULL;
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          goto __pyx_L14_unpacking_done;
          __pyx_L13_unpacking_failed:;
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __pyx_t_12 = NULL;
          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
          __PYX_ERR(0, 206, __pyx_L5_except_error)
          __pyx_L14_unpacking_done:;
        }
        __pyx_t_6 = __Pyx_PyLong_As_int(__pyx_t_9); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 206, __pyx_L5_except_error)
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_v_index = __pyx_t_6;
        __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_10);
        __pyx_t_10 = 0;

        /* "src/gevent/_imap.py":207
 *             while 1:
 *                 index, value = self.queue.get()
 *                 if index == self.index:             # <<<<<<<<<<<<<<
 *                     break
 *                 self._results[index] = value
*/
        __pyx_t_13 = (__pyx_v_index == __pyx_v_self->index);
        if (__pyx_t_13) {

          /* "src/gevent/_imap.py":208
 *                 index, value = self.queue.get()
 *                 if index == self.index:
 *                     break             # <<<<<<<<<<<<<<
 *                 self._results[index] = value
 *         self.index += 1
*/
          goto __pyx_L12_break;

          /* "src/gevent/_imap.py":207
 *             while 1:
 *                 index, value = self.queue.get()
 *                 if index == self.index:             # <<<<<<<<<<<<<<
 *                     break
 *                 self._results[index] = value
*/
        }

        /* "src/gevent/_imap.py":209
 *                 if index == self.index:
 *                     break
 *                 self._results[index] = value             # <<<<<<<<<<<<<<
 *         self.index += 1
 *         return value
*/
        if (unlikely(__pyx_v_self->_results == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 209, __pyx_L5_except_error)
        }
        __pyx_t_8 = __Pyx_PyLong_From_int(__pyx_v_index); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 209, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (unlikely((PyDict_SetItem(__pyx_v_self->_results, __pyx_t_8, __pyx_v_value) < 0))) __PYX_ERR(0, 209, __pyx_L5_except_error)
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __pyx_L12_break:;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;

    /* "src/gevent/_imap.py":201
 * 
 *     def _inext(self):
 *         try:             # <<<<<<<<<<<<<<
 *             value = self._results.pop(self.index)
 *         except KeyError:
*/
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    __pyx_L8_try_end:;
  }

  /* "src/gevent/_imap.py":210
 *                     break
 *                 self._results[index] = value
 *         self.index += 1             # <<<<<<<<<<<<<<
 *         return value
 * 
*/
  __pyx_v_self->index = (__pyx_v_self->index + 1);

  /* "src/gevent/_imap.py":211
 *                 self._results[index] = value
 *         self.index += 1
 *         return value             # <<<<<<<<<<<<<<
 * 
 *     def _iqueue_value_for_success(self, greenlet):
*/
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_v_value)) { __Pyx_RaiseUnboundLocalError("value"); __PYX_ERR(0, 211, __pyx_L1_error) }
  __Pyx_INCREF(__pyx_v_value);
  __pyx_r = __pyx_v_value;
  goto __pyx_L0;

  /* "src/gevent/_imap.py":200
 *         IMapUnordered.__init__(self, *args, **kwargs)
 * 
 *     def _inext(self):             # <<<<<<<<<<<<<<
 *         try:
 *             value = self._results.pop(self.index)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("gevent._gevent_c_imap.IMap._inext", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/_imap.py":213
 *         return value
 * 
 *     def _iqueue_value_for_success(self, greenlet):             # <<<<<<<<<<<<<<
 *         return (greenlet._imap_task_index, IMapUnordered._iqueue_value_for_success(self, greenlet))
 * 
*/

static PyObject *__pyx_f_6gevent_14_gevent_c_imap_4IMap__iqueue_value_for_success(struct __pyx_obj_6gevent_14_gevent_c_imap_IMap *__pyx_v_self, PyObject *__pyx_v_greenlet) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_iqueue_value_for_success", 0);

  /* "src/gevent/_imap.py":214
 * 
 *     def _iqueue_value_for_success(self, greenlet):
 *         return (greenlet._imap_task_index, IMapUnordered._iqueue_value_for_success(self, greenlet))             # <<<<<<<<<<<<<<
 * 
 *     def _iqueue_value_for_failure(self, greenlet):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_greenlet, __pyx_mstate_global->__pyx_n_u_imap_task_index); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 214, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_6gevent_14_gevent_c_imap_13IMapUnordered__iqueue_value_for_success(((struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *)__pyx_v_self), __pyx_v_greenlet); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 214, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 214, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1) != (0)) __PYX_ERR(0, 214, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_2) != (0)) __PYX_ERR(0, 214, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "src/gevent/_imap.py":213
 *         return value
 * 
 *     def _iqueue_value_for_success(self, greenlet):             # <<<<<<<<<<<<<<
 *         return (greenlet._imap_task_index, IMapUnordered._iqueue_value_for_success(self, greenlet))
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("gevent._gevent_c_imap.IMap._iqueue_value_for_success", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/_imap.py":216
 *         return (greenlet._imap_task_index, IMapUnordered._iqueue_value_for_success(self, greenlet))
 * 
 *     def _iqueue_value_for_failure(self, greenlet):             # <<<<<<<<<<<<<<
 *         return (greenlet._imap_task_index, IMapUnordered._iqueue_value_for_failure(self, greenlet))
 * 
*/

static PyObject *__pyx_f_6gevent_14_gevent_c_imap_4IMap__iqueue_value_for_failure(struct __pyx_obj_6gevent_14_gevent_c_imap_IMap *__pyx_v_self, PyObject *__pyx_v_greenlet) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_iqueue_value_for_failure", 0);

  /* "src/gevent/_imap.py":217
 * 
 *     def _iqueue_value_for_failure(self, greenlet):
 *         return (greenlet._imap_task_index, IMapUnordered._iqueue_value_for_failure(self, greenlet))             # <<<<<<<<<<<<<<
 * 
 *     def _iqueue_value_for_self_finished(self):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_greenlet, __pyx_mstate_global->__pyx_n_u_imap_task_index); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_6gevent_14_gevent_c_imap_13IMapUnordered__iqueue_value_for_failure(((struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *)__pyx_v_self), __pyx_v_greenlet); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1) != (0)) __PYX_ERR(0, 217, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_2) != (0)) __PYX_ERR(0, 217, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "src/gevent/_imap.py":216
 *         return (greenlet._imap_task_index, IMapUnordered._iqueue_value_for_success(self, greenlet))
 * 
 *     def _iqueue_value_for_failure(self, greenlet):             # <<<<<<<<<<<<<<
 *         return (greenlet._imap_task_index, IMapUnordered._iqueue_value_for_failure(self, greenlet))
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("gevent._gevent_c_imap.IMap._iqueue_value_for_failure", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/_imap.py":219
 *         return (greenlet._imap_task_index, IMapUnordered._iqueue_value_for_failure(self, greenlet))
 * 
 *     def _iqueue_value_for_self_finished(self):             # <<<<<<<<<<<<<<
 *         return (self._max_index + 1, IMapUnordered._iqueue_value_for_self_finished(self))
 * 
*/

static PyObject *__pyx_f_6gevent_14_gevent_c_imap_4IMap__iqueue_value_for_self_finished(struct __pyx_obj_6gevent_14_gevent_c_imap_IMap *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_iqueue_value_for_self_finished", 0);

  /* "src/gevent/_imap.py":220
 * 
 *     def _iqueue_value_for_self_finished(self):
 *         return (self._max_index + 1, IMapUnordered._iqueue_value_for_self_finished(self))             # <<<<<<<<<<<<<<
 * 
 *     def _iqueue_value_for_self_failure(self, exception):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyLong_From_long((__pyx_v_self->__pyx_base._max_index + 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 220, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_6gevent_14_gevent_c_imap_13IMapUnordered__iqueue_value_for_self_finished(((struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *)__pyx_v_self)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 220, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 220, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1) != (0)) __PYX_ERR(0, 220, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_2) != (0)) __PYX_ERR(0, 220, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "src/gevent/_imap.py":219
 *         return (greenlet._imap_task_index, IMapUnordered._iqueue_value_for_failure(self, greenlet))
 * 
 *     def _iqueue_value_for_self_finished(self):             # <<<<<<<<<<<<<<
 *         return (self._max_index + 1, IMapUnordered._iqueue_value_for_self_finished(self))
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("gevent._gevent_c_imap.IMap._iqueue_value_for_self_finished", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/_imap.py":222
 *         return (self._max_index + 1, IMapUnordered._iqueue_value_for_self_finished(self))
 * 
 *     def _iqueue_value_for_self_failure(self, exception):             # <<<<<<<<<<<<<<
 *         return (self._max_index + 1, IMapUnordered._iqueue_value_for_self_failure(self, exception))
 * 
*/

static PyObject *__pyx_f_6gevent_14_gevent_c_imap_4IMap__iqueue_value_for_self_failure(struct __pyx_obj_6gevent_14_gevent_c_imap_IMap *__pyx_v_self, PyObject *__pyx_v_exception) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_iqueue_value_for_self_failure", 0);

  /* "src/gevent/_imap.py":223
 * 
 *     def _iqueue_value_for_self_failure(self, exception):
 *         return (self._max_index + 1, IMapUnordered._iqueue_value_for_self_failure(self, exception))             # <<<<<<<<<<<<<<
 * 
 * from gevent._util import import_c_accel
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyLong_From_long((__pyx_v_self->__pyx_base._max_index + 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_6gevent_14_gevent_c_imap_13IMapUnordered__iqueue_value_for_self_failure(((struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *)__pyx_v_self), __pyx_v_exception); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1) != (0)) __PYX_ERR(0, 223, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_2) != (0)) __PYX_ERR(0, 223, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "src/gevent/_imap.py":222
 *         return (self._max_index + 1, IMapUnordered._iqueue_value_for_self_finished(self))
 * 
 *     def _iqueue_value_for_self_failure(self, exception):             # <<<<<<<<<<<<<<
 *         return (self._max_index + 1, IMapUnordered._iqueue_value_for_self_failure(self, exception))
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("gevent._gevent_c_imap.IMap._iqueue_value_for_self_failure", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
/* #### Code section: module_exttypes ### */

static PyObject *__pyx_tp_new_6gevent_14_gevent_c_imap_Failure(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_6gevent_14_gevent_c_imap_Failure *p;
  PyObject *o;
  o = __Pyx_AllocateExtensionType(t, 1);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6gevent_14_gevent_c_imap_Failure *)o);
  p->exc = Py_None; Py_INCREF(Py_None);
  p->raise_exception = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6gevent_14_gevent_c_imap_Failure(PyObject *o) {
  struct __pyx_obj_6gevent_14_gevent_c_imap_Failure *p = (struct __pyx_obj_6gevent_14_gevent_c_imap_Failure *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->exc);
  Py_CLEAR(p->raise_exception);
  PyTypeObject *tp = Py_TYPE(o);
  #if CYTHON_USE_TYPE_SLOTS
  (*tp->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  Py_DECREF(tp);
  #endif
}

static int __pyx_tp_traverse_6gevent_14_gevent_c_imap_Failure(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6gevent_14_gevent_c_imap_Failure *p = (struct __pyx_obj_6gevent_14_gevent_c_imap_Failure *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->exc) {
    e = (*v)(p->exc, a); if (e) return e;
  }
  if (p->raise_exception) {
    e = (*v)(p->raise_exception, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6gevent_14_gevent_c_imap_Failure(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6gevent_14_gevent_c_imap_Failure *p = (struct __pyx_obj_6gevent_14_gevent_c_imap_Failure *)o;
  tmp = ((PyObject*)p->exc);
  p->exc = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->raise_exception);
  p->raise_exception = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6gevent_14_gevent_c_imap_7Failure_exc(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6gevent_14_gevent_c_imap_7Failure_3exc_1__get__(o);
}

static PyMethodDef __pyx_methods_6gevent_14_gevent_c_imap_Failure[] = {
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6gevent_14_gevent_c_imap_Failure[] = {
  {"exc", __pyx_getprop_6gevent_14_gevent_c_imap_7Failure_exc, 0, 0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6gevent_14_gevent_c_imap_Failure_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6gevent_14_gevent_c_imap_Failure},
  {Py_tp_doc, (void *)PyDoc_STR("Failure(exc, raise_exception=None)")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6gevent_14_gevent_c_imap_Failure},
  {Py_tp_clear, (void *)__pyx_tp_clear_6gevent_14_gevent_c_imap_Failure},
  {Py_tp_methods, (void *)__pyx_methods_6gevent_14_gevent_c_imap_Failure},
  {Py_tp_getset, (void *)__pyx_getsets_6gevent_14_gevent_c_imap_Failure},
  {Py_tp_init, (void *)__pyx_pw_6gevent_14_gevent_c_imap_7Failure_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6gevent_14_gevent_c_imap_Failure},
  {0, 0},
};
static PyType_Spec __pyx_type_6gevent_14_gevent_c_imap_Failure_spec = {
  "gevent._gevent_c_imap.Failure",
  sizeof(struct __pyx_obj_6gevent_14_gevent_c_imap_Failure),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6gevent_14_gevent_c_imap_Failure_slots,
};
#else

static PyTypeObject __pyx_type_6gevent_14_gevent_c_imap_Failure = {
  PyVarObject_HEAD_INIT(0, 0)
  "gevent._gevent_c_imap.""Failure", /*tp_name*/
  sizeof(struct __pyx_obj_6gevent_14_gevent_c_imap_Failure), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6gevent_14_gevent_c_imap_Failure, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("Failure(exc, raise_exception=None)"), /*tp_doc*/
  __pyx_tp_traverse_6gevent_14_gevent_c_imap_Failure, /*tp_traverse*/
  __pyx_tp_clear_6gevent_14_gevent_c_imap_Failure, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6gevent_14_gevent_c_imap_Failure, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6gevent_14_gevent_c_imap_Failure, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6gevent_14_gevent_c_imap_7Failure_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6gevent_14_gevent_c_imap_Failure, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6gevent_14_gevent_c_imap_IMapUnordered __pyx_vtable_6gevent_14_gevent_c_imap_IMapUnordered;

static PyObject *__pyx_tp_new_6gevent_14_gevent_c_imap_IMapUnordered(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *p;
  PyObject *o = __Pyx_PyType_GetSlot(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, tp_new, newfunc)(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet*)__pyx_vtabptr_6gevent_14_gevent_c_imap_IMapUnordered;
  p->func = Py_None; Py_INCREF(Py_None);
  p->iterable = Py_None; Py_INCREF(Py_None);
  p->spawn = Py_None; Py_INCREF(Py_None);
  p->_result_semaphore = ((struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *)Py_None); Py_INCREF(Py_None);
  p->queue = ((struct __pyx_obj_6gevent_14_gevent_cqueue_UnboundQueue *)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6gevent_14_gevent_c_imap_IMapUnordered(PyObject *o) {
  struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *p = (struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6gevent_14_gevent_c_imap_IMapUnordered) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->func);
  Py_CLEAR(p->iterable);
  Py_CLEAR(p->spawn);
  Py_CLEAR(p->_result_semaphore);
  Py_CLEAR(p->queue);
  if (PyType_IS_GC(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet)) PyObject_GC_Track(o);
  #if !CYTHON_USE_MODULE_STATE
  if (likely(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet)) __Pyx_PyType_GetSlot(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, tp_dealloc, destructor)(o); else
  #endif
  __Pyx_call_next_tp_dealloc(o, __pyx_tp_dealloc_6gevent_14_gevent_c_imap_IMapUnordered);
}

static int __pyx_tp_traverse_6gevent_14_gevent_c_imap_IMapUnordered(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *p = (struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *)o;
  #if !CYTHON_USE_MODULE_STATE
  e = 0;
  if (likely(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet)) {
    traverseproc traverse = __Pyx_PyType_GetSlot(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, tp_traverse, traverseproc);
    if (traverse) { e = traverse(o, v, a); }
  } else
  #endif
  { e = __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_6gevent_14_gevent_c_imap_IMapUnordered); }
  if (e) return e;
  {
    e = __Pyx_call_type_traverse(o, 0, v, a);
    if (e) return e;
  }
  if (p->func) {
    e = (*v)(p->func, a); if (e) return e;
  }
  if (p->iterable) {
    e = (*v)(p->iterable, a); if (e) return e;
  }
  if (p->spawn) {
    e = (*v)(p->spawn, a); if (e) return e;
  }
  if (p->_result_semaphore) {
    e = (*v)(((PyObject *)p->_result_semaphore), a); if (e) return e;
  }
  if (p->queue) {
    e = (*v)(((PyObject *)p->queue), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6gevent_14_gevent_c_imap_IMapUnordered(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *p = (struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *)o;
  #if !CYTHON_USE_MODULE_STATE
  if (likely(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet)) {
    inquiry clear = __Pyx_PyType_GetSlot(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, tp_clear, inquiry);
    if (clear) clear(o);
  } else
  #endif
  { __Pyx_call_next_tp_clear(o, __pyx_tp_clear_6gevent_14_gevent_c_imap_IMapUnordered); }
  tmp = ((PyObject*)p->func);
  p->func = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->iterable);
  p->iterable = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->spawn);
  p->spawn = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_result_semaphore);
  p->_result_semaphore = ((struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->queue);
  p->queue = ((struct __pyx_obj_6gevent_14_gevent_cqueue_UnboundQueue *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6gevent_14_gevent_c_imap_13IMapUnordered_queue(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6gevent_14_gevent_c_imap_13IMapUnordered_5queue_1__get__(o);
}

static PyObject *__pyx_getprop_6gevent_14_gevent_c_imap_13IMapUnordered_finished(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6gevent_14_gevent_c_imap_13IMapUnordered_8finished_1__get__(o);
}

static PyObject *__pyx_specialmethod___pyx_pw_6gevent_14_gevent_c_imap_13IMapUnordered_5__next__(PyObject *self, CYTHON_UNUSED PyObject *arg) {
  PyObject *res = __pyx_pw_6gevent_14_gevent_c_imap_13IMapUnordered_5__next__(self);
  if (!res && !PyErr_Occurred()) { PyErr_SetNone(PyExc_StopIteration); }
  return res;
}

static PyMethodDef __pyx_methods_6gevent_14_gevent_c_imap_IMapUnordered[] = {
  {"__next__", (PyCFunction)__pyx_specialmethod___pyx_pw_6gevent_14_gevent_c_imap_13IMapUnordered_5__next__, METH_NOARGS|METH_COEXIST, 0},
  {"_run", (PyCFunction)__pyx_pw_6gevent_14_gevent_c_imap_13IMapUnordered_7_run, METH_NOARGS, __pyx_doc_6gevent_14_gevent_c_imap_13IMapUnordered_6_run},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6gevent_14_gevent_c_imap_IMapUnordered[] = {
  {"queue", __pyx_getprop_6gevent_14_gevent_c_imap_13IMapUnordered_queue, 0, 0, 0},
  {"finished", __pyx_getprop_6gevent_14_gevent_c_imap_13IMapUnordered_finished, 0, 0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6gevent_14_gevent_c_imap_IMapUnordered_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6gevent_14_gevent_c_imap_IMapUnordered},
  {Py_tp_doc, (void *)PyDoc_STR("IMapUnordered(func, iterable, spawn, maxsize=None, _zipped=False)\n\nAt iterator of map results.")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6gevent_14_gevent_c_imap_IMapUnordered},
  {Py_tp_clear, (void *)__pyx_tp_clear_6gevent_14_gevent_c_imap_IMapUnordered},
  {Py_tp_iter, (void *)__pyx_pw_6gevent_14_gevent_c_imap_13IMapUnordered_3__iter__},
  {Py_tp_iternext, (void *)__pyx_pw_6gevent_14_gevent_c_imap_13IMapUnordered_5__next__},
  {Py_tp_methods, (void *)__pyx_methods_6gevent_14_gevent_c_imap_IMapUnordered},
  {Py_tp_getset, (void *)__pyx_getsets_6gevent_14_gevent_c_imap_IMapUnordered},
  {Py_tp_init, (void *)__pyx_pw_6gevent_14_gevent_c_imap_13IMapUnordered_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6gevent_14_gevent_c_imap_IMapUnordered},
  {0, 0},
};
static PyType_Spec __pyx_type_6gevent_14_gevent_c_imap_IMapUnordered_spec = {
  "gevent._gevent_c_imap.IMapUnordered",
  sizeof(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6gevent_14_gevent_c_imap_IMapUnordered_slots,
};
#else

static PyTypeObject __pyx_type_6gevent_14_gevent_c_imap_IMapUnordered = {
  PyVarObject_HEAD_INIT(0, 0)
  "gevent._gevent_c_imap.""IMapUnordered", /*tp_name*/
  sizeof(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6gevent_14_gevent_c_imap_IMapUnordered, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("IMapUnordered(func, iterable, spawn, maxsize=None, _zipped=False)\n\nAt iterator of map results."), /*tp_doc*/
  __pyx_tp_traverse_6gevent_14_gevent_c_imap_IMapUnordered, /*tp_traverse*/
  __pyx_tp_clear_6gevent_14_gevent_c_imap_IMapUnordered, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  __pyx_pw_6gevent_14_gevent_c_imap_13IMapUnordered_3__iter__, /*tp_iter*/
  __pyx_pw_6gevent_14_gevent_c_imap_13IMapUnordered_5__next__, /*tp_iternext*/
  __pyx_methods_6gevent_14_gevent_c_imap_IMapUnordered, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6gevent_14_gevent_c_imap_IMapUnordered, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6gevent_14_gevent_c_imap_13IMapUnordered_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6gevent_14_gevent_c_imap_IMapUnordered, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6gevent_14_gevent_c_imap_IMap __pyx_vtable_6gevent_14_gevent_c_imap_IMap;

static PyObject *__pyx_tp_new_6gevent_14_gevent_c_imap_IMap(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6gevent_14_gevent_c_imap_IMap *p;
  PyObject *o = __pyx_tp_new_6gevent_14_gevent_c_imap_IMapUnordered(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6gevent_14_gevent_c_imap_IMap *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet*)__pyx_vtabptr_6gevent_14_gevent_c_imap_IMap;
  p->_results = ((PyObject*)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6gevent_14_gevent_c_imap_IMap(PyObject *o) {
  struct __pyx_obj_6gevent_14_gevent_c_imap_IMap *p = (struct __pyx_obj_6gevent_14_gevent_c_imap_IMap *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6gevent_14_gevent_c_imap_IMap) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->_results);
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_6gevent_14_gevent_c_imap_IMapUnordered(o);
}

static int __pyx_tp_traverse_6gevent_14_gevent_c_imap_IMap(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6gevent_14_gevent_c_imap_IMap *p = (struct __pyx_obj_6gevent_14_gevent_c_imap_IMap *)o;
  e = __pyx_tp_traverse_6gevent_14_gevent_c_imap_IMapUnordered(o, v, a); if (e) return e;
  if (p->_results) {
    e = (*v)(p->_results, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6gevent_14_gevent_c_imap_IMap(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6gevent_14_gevent_c_imap_IMap *p = (struct __pyx_obj_6gevent_14_gevent_c_imap_IMap *)o;
  __pyx_tp_clear_6gevent_14_gevent_c_imap_IMapUnordered(o);
  tmp = ((PyObject*)p->_results);
  p->_results = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_6gevent_14_gevent_c_imap_IMap[] = {
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6gevent_14_gevent_c_imap_IMap_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6gevent_14_gevent_c_imap_IMap},
  {Py_tp_doc, (void *)PyDoc_STR("IMap(*args, **kwargs)")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6gevent_14_gevent_c_imap_IMap},
  {Py_tp_clear, (void *)__pyx_tp_clear_6gevent_14_gevent_c_imap_IMap},
  {Py_tp_methods, (void *)__pyx_methods_6gevent_14_gevent_c_imap_IMap},
  {Py_tp_init, (void *)__pyx_pw_6gevent_14_gevent_c_imap_4IMap_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6gevent_14_gevent_c_imap_IMap},
  {0, 0},
};
static PyType_Spec __pyx_type_6gevent_14_gevent_c_imap_IMap_spec = {
  "gevent._gevent_c_imap.IMap",
  sizeof(struct __pyx_obj_6gevent_14_gevent_c_imap_IMap),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6gevent_14_gevent_c_imap_IMap_slots,
};
#else

static PyTypeObject __pyx_type_6gevent_14_gevent_c_imap_IMap = {
  PyVarObject_HEAD_INIT(0, 0)
  "gevent._gevent_c_imap.""IMap", /*tp_name*/
  sizeof(struct __pyx_obj_6gevent_14_gevent_c_imap_IMap), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6gevent_14_gevent_c_imap_IMap, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("IMap(*args, **kwargs)"), /*tp_doc*/
  __pyx_tp_traverse_6gevent_14_gevent_c_imap_IMap, /*tp_traverse*/
  __pyx_tp_clear_6gevent_14_gevent_c_imap_IMap, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6gevent_14_gevent_c_imap_13IMapUnordered_3__iter__, /*tp_iter*/
  #else
  0, /*tp_iter*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6gevent_14_gevent_c_imap_13IMapUnordered_5__next__, /*tp_iternext*/
  #else
  0, /*tp_iternext*/
  #endif
  __pyx_methods_6gevent_14_gevent_c_imap_IMap, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6gevent_14_gevent_c_imap_4IMap_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6gevent_14_gevent_c_imap_IMap, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};
/* #### Code section: initfunc_declarations ### */
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitConstants(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_CreateCodeObjects(__pyx_mstatetype *__pyx_mstate); /*proto*/
/* #### Code section: init_module ### */

static int __Pyx_modinit_global_init_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  {
    __pyx_t_1 = __Pyx_ApiExport_GetApiDict(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_export_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_PyObject_struct___pyx_obj_6geven);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_export_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_export_name = __pyx_export_signature + 64;
    void (*const __pyx_export_pointers[])(void) = {(void (*)(void))&__pyx_f_6gevent_14_gevent_c_imap__raise_exc, (void (*)(void)) NULL};
    void (*const *__pyx_export_pointer)(void) = __pyx_export_pointers;
    const char *__pyx_export_current_signature = __pyx_export_signature;
    while (*__pyx_export_pointer) {
      if (__Pyx_ExportFunction(__pyx_t_1, __pyx_export_name, *__pyx_export_pointer, __pyx_export_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_export_pointer;
      __pyx_export_name = strchr(__pyx_export_name, '\0') + 1;
      __pyx_export_signature = strchr(__pyx_export_signature, '\0') + 1;
      if (*__pyx_export_signature != '\0') __pyx_export_current_signature = __pyx_export_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_init_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_6gevent_14_gevent_c_imap_Failure = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6gevent_14_gevent_c_imap_Failure_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_6gevent_14_gevent_c_imap_Failure)) __PYX_ERR(0, 28, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6gevent_14_gevent_c_imap_Failure_spec, __pyx_mstate->__pyx_ptype_6gevent_14_gevent_c_imap_Failure) < (0)) __PYX_ERR(0, 28, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6gevent_14_gevent_c_imap_Failure = &__pyx_type_6gevent_14_gevent_c_imap_Failure;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6gevent_14_gevent_c_imap_Failure) < (0)) __PYX_ERR(0, 28, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6gevent_14_gevent_c_imap_Failure);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6gevent_14_gevent_c_imap_Failure->tp_dictoffset && __pyx_mstate->__pyx_ptype_6gevent_14_gevent_c_imap_Failure->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6gevent_14_gevent_c_imap_Failure->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_Failure, (PyObject *) __pyx_mstate->__pyx_ptype_6gevent_14_gevent_c_imap_Failure) < (0)) __PYX_ERR(0, 28, __pyx_L1_error)
  __pyx_t_1 = PyImport_ImportModule("gevent._gevent_cgreenlet"); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet = __Pyx_ImportType_3_2_4(__pyx_t_1, "gevent._gevent_cgreenlet", "Greenlet",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet),
  #else
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_vtabptr_6gevent_17_gevent_cgreenlet_Greenlet = (struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet); if (unlikely(!__pyx_vtabptr_6gevent_17_gevent_cgreenlet_Greenlet)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_vtabptr_6gevent_14_gevent_c_imap_IMapUnordered = &__pyx_vtable_6gevent_14_gevent_c_imap_IMapUnordered;
  __pyx_vtable_6gevent_14_gevent_c_imap_IMapUnordered.__pyx_base = *__pyx_vtabptr_6gevent_17_gevent_cgreenlet_Greenlet;
  __pyx_vtable_6gevent_14_gevent_c_imap_IMapUnordered._inext = (PyObject *(*)(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *))__pyx_f_6gevent_14_gevent_c_imap_13IMapUnordered__inext;
  __pyx_vtable_6gevent_14_gevent_c_imap_IMapUnordered._ispawn = (PyObject *(*)(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *, PyObject *, PyObject *, int))__pyx_f_6gevent_14_gevent_c_imap_13IMapUnordered__ispawn;
  __pyx_vtable_6gevent_14_gevent_c_imap_IMapUnordered._on_result = (PyObject *(*)(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *, PyObject *, int __pyx_skip_dispatch))__pyx_f_6gevent_14_gevent_c_imap_13IMapUnordered__on_result;
  __pyx_vtable_6gevent_14_gevent_c_imap_IMapUnordered._on_finish = (PyObject *(*)(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *, PyObject *))__pyx_f_6gevent_14_gevent_c_imap_13IMapUnordered__on_finish;
  __pyx_vtable_6gevent_14_gevent_c_imap_IMapUnordered._iqueue_value_for_success = (PyObject *(*)(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *, PyObject *))__pyx_f_6gevent_14_gevent_c_imap_13IMapUnordered__iqueue_value_for_success;
  __pyx_vtable_6gevent_14_gevent_c_imap_IMapUnordered._iqueue_value_for_failure = (PyObject *(*)(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *, PyObject *))__pyx_f_6gevent_14_gevent_c_imap_13IMapUnordered__iqueue_value_for_failure;
  __pyx_vtable_6gevent_14_gevent_c_imap_IMapUnordered._iqueue_value_for_self_finished = (PyObject *(*)(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *))__pyx_f_6gevent_14_gevent_c_imap_13IMapUnordered__iqueue_value_for_self_finished;
  __pyx_vtable_6gevent_14_gevent_c_imap_IMapUnordered._iqueue_value_for_self_failure = (PyObject *(*)(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *, PyObject *))__pyx_f_6gevent_14_gevent_c_imap_13IMapUnordered__iqueue_value_for_self_failure;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_2 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_mstate->__pyx_ptype_6gevent_14_gevent_c_imap_IMapUnordered = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6gevent_14_gevent_c_imap_IMapUnordered_spec, __pyx_t_2);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_6gevent_14_gevent_c_imap_IMapUnordered)) __PYX_ERR(0, 43, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6gevent_14_gevent_c_imap_IMapUnordered_spec, __pyx_mstate->__pyx_ptype_6gevent_14_gevent_c_imap_IMapUnordered) < (0)) __PYX_ERR(0, 43, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6gevent_14_gevent_c_imap_IMapUnordered = &__pyx_type_6gevent_14_gevent_c_imap_IMapUnordered;
  #endif
  if (sizeof(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered) != sizeof(PyGreenlet)) {
    if (__Pyx_validate_extern_base(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet) < (0)) __PYX_ERR(0, 43, __pyx_L1_error)
  }
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_c_imap_IMapUnordered->tp_base = __pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6gevent_14_gevent_c_imap_IMapUnordered) < (0)) __PYX_ERR(0, 43, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6gevent_14_gevent_c_imap_IMapUnordered);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6gevent_14_gevent_c_imap_IMapUnordered->tp_dictoffset && __pyx_mstate->__pyx_ptype_6gevent_14_gevent_c_imap_IMapUnordered->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6gevent_14_gevent_c_imap_IMapUnordered->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  #if CYTHON_UPDATE_DESCRIPTOR_DOC
  {
    PyObject *wrapper = PyObject_GetAttrString((PyObject *)__pyx_mstate->__pyx_ptype_6gevent_14_gevent_c_imap_IMapUnordered, "__init__"); if (unlikely(!wrapper)) __PYX_ERR(0, 43, __pyx_L1_error)
    if (__Pyx_IS_TYPE(wrapper, &PyWrapperDescr_Type)) {
      __pyx_wrapperbase_6gevent_14_gevent_c_imap_13IMapUnordered___init__ = *((PyWrapperDescrObject *)wrapper)->d_base;
      __pyx_wrapperbase_6gevent_14_gevent_c_imap_13IMapUnordered___init__.doc = __pyx_doc_6gevent_14_gevent_c_imap_13IMapUnordered___init__;
      ((PyWrapperDescrObject *)wrapper)->d_base = &__pyx_wrapperbase_6gevent_14_gevent_c_imap_13IMapUnordered___init__;
    }
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_6gevent_14_gevent_c_imap_IMapUnordered, __pyx_vtabptr_6gevent_14_gevent_c_imap_IMapUnordered) < (0)) __PYX_ERR(0, 43, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_6gevent_14_gevent_c_imap_IMapUnordered) < (0)) __PYX_ERR(0, 43, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_IMapUnordered, (PyObject *) __pyx_mstate->__pyx_ptype_6gevent_14_gevent_c_imap_IMapUnordered) < (0)) __PYX_ERR(0, 43, __pyx_L1_error)
  __pyx_vtabptr_6gevent_14_gevent_c_imap_IMap = &__pyx_vtable_6gevent_14_gevent_c_imap_IMap;
  __pyx_vtable_6gevent_14_gevent_c_imap_IMap.__pyx_base = *__pyx_vtabptr_6gevent_14_gevent_c_imap_IMapUnordered;
  __pyx_vtable_6gevent_14_gevent_c_imap_IMap.__pyx_base._inext = (PyObject *(*)(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *))__pyx_f_6gevent_14_gevent_c_imap_4IMap__inext;
  __pyx_vtable_6gevent_14_gevent_c_imap_IMap.__pyx_base._iqueue_value_for_success = (PyObject *(*)(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *, PyObject *))__pyx_f_6gevent_14_gevent_c_imap_4IMap__iqueue_value_for_success;
  __pyx_vtable_6gevent_14_gevent_c_imap_IMap.__pyx_base._iqueue_value_for_failure = (PyObject *(*)(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *, PyObject *))__pyx_f_6gevent_14_gevent_c_imap_4IMap__iqueue_value_for_failure;
  __pyx_vtable_6gevent_14_gevent_c_imap_IMap.__pyx_base._iqueue_value_for_self_finished = (PyObject *(*)(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *))__pyx_f_6gevent_14_gevent_c_imap_4IMap__iqueue_value_for_self_finished;
  __pyx_vtable_6gevent_14_gevent_c_imap_IMap.__pyx_base._iqueue_value_for_self_failure = (PyObject *(*)(struct __pyx_obj_6gevent_14_gevent_c_imap_IMapUnordered *, PyObject *))__pyx_f_6gevent_14_gevent_c_imap_4IMap__iqueue_value_for_self_failure;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_2 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_c_imap_IMapUnordered); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_mstate->__pyx_ptype_6gevent_14_gevent_c_imap_IMap = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6gevent_14_gevent_c_imap_IMap_spec, __pyx_t_2);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_6gevent_14_gevent_c_imap_IMap)) __PYX_ERR(0, 187, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6gevent_14_gevent_c_imap_IMap_spec, __pyx_mstate->__pyx_ptype_6gevent_14_gevent_c_imap_IMap) < (0)) __PYX_ERR(0, 187, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6gevent_14_gevent_c_imap_IMap = &__pyx_type_6gevent_14_gevent_c_imap_IMap;
  #endif
  if (sizeof(struct __pyx_obj_6gevent_14_gevent_c_imap_IMap) != sizeof(PyGreenlet)) {
    if (__Pyx_validate_extern_base(__pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_c_imap_IMapUnordered) < (0)) __PYX_ERR(0, 187, __pyx_L1_error)
  }
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_c_imap_IMap->tp_base = __pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_c_imap_IMapUnordered;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6gevent_14_gevent_c_imap_IMap) < (0)) __PYX_ERR(0, 187, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6gevent_14_gevent_c_imap_IMap);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6gevent_14_gevent_c_imap_IMap->tp_dictoffset && __pyx_mstate->__pyx_ptype_6gevent_14_gevent_c_imap_IMap->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6gevent_14_gevent_c_imap_IMap->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_6gevent_14_gevent_c_imap_IMap, __pyx_vtabptr_6gevent_14_gevent_c_imap_IMap) < (0)) __PYX_ERR(0, 187, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_6gevent_14_gevent_c_imap_IMap) < (0)) __PYX_ERR(0, 187, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_IMap, (PyObject *) __pyx_mstate->__pyx_ptype_6gevent_14_gevent_c_imap_IMap) < (0)) __PYX_ERR(0, 187, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __pyx_t_1 = PyImport_ImportModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_t_1)) __PYX_ERR(7, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_7cpython_4type_type = __Pyx_ImportType_3_2_4(__pyx_t_1, __Pyx_BUILTIN_MODULE_NAME, "type",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyTypeObject), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyTypeObject),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  0, 0,
  #else
  sizeof(PyHeapTypeObject), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyHeapTypeObject),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_7cpython_4type_type) __PYX_ERR(7, 9, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("weakref"); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_6gevent_15_gevent_c_ident_ref = __Pyx_ImportType_3_2_4(__pyx_t_1, "weakref", "ref",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyWeakReference), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyWeakReference),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(PyWeakReference), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyWeakReference),
  #else
  sizeof(PyWeakReference), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyWeakReference),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_15_gevent_c_ident_ref) __PYX_ERR(8, 5, __pyx_L1_error)
  __pyx_t_2 = PyImport_ImportModule("gevent._gevent_c_ident"); if (unlikely(!__pyx_t_2)) __PYX_ERR(8, 13, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_mstate->__pyx_ptype_6gevent_15_gevent_c_ident_ValuedWeakRef = __Pyx_ImportType_3_2_4(__pyx_t_2, "gevent._gevent_c_ident", "ValuedWeakRef",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_15_gevent_c_ident_ValuedWeakRef), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_15_gevent_c_ident_ValuedWeakRef),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_15_gevent_c_ident_ValuedWeakRef), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_15_gevent_c_ident_ValuedWeakRef),
  #else
  sizeof(struct __pyx_obj_6gevent_15_gevent_c_ident_ValuedWeakRef), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_15_gevent_c_ident_ValuedWeakRef),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_15_gevent_c_ident_ValuedWeakRef) __PYX_ERR(8, 13, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6gevent_15_gevent_c_ident_IdentRegistry = __Pyx_ImportType_3_2_4(__pyx_t_2, "gevent._gevent_c_ident", "IdentRegistry",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_15_gevent_c_ident_IdentRegistry), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_15_gevent_c_ident_IdentRegistry),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_15_gevent_c_ident_IdentRegistry), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_15_gevent_c_ident_IdentRegistry),
  #else
  sizeof(struct __pyx_obj_6gevent_15_gevent_c_ident_IdentRegistry), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_15_gevent_c_ident_IdentRegistry),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_15_gevent_c_ident_IdentRegistry) __PYX_ERR(8, 18, __pyx_L1_error)
  __pyx_vtabptr_6gevent_15_gevent_c_ident_IdentRegistry = (struct __pyx_vtabstruct_6gevent_15_gevent_c_ident_IdentRegistry*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6gevent_15_gevent_c_ident_IdentRegistry); if (unlikely(!__pyx_vtabptr_6gevent_15_gevent_c_ident_IdentRegistry)) __PYX_ERR(8, 18, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyImport_ImportModule("greenlet"); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_mstate->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_greenlet = __Pyx_ImportType_3_2_4(__pyx_t_2, "greenlet", "greenlet",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyGreenlet),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(PyGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyGreenlet),
  #else
  sizeof(PyGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyGreenlet),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_greenlet) __PYX_ERR(1, 12, __pyx_L1_error)
  __pyx_t_1 = PyImport_ImportModule("gevent._gevent_c_greenlet_primitives"); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet = __Pyx_ImportType_3_2_4(__pyx_t_1, "gevent._gevent_c_greenlet_primitives", "TrackedRawGreenlet",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet),
  #else
  sizeof(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet) __PYX_ERR(1, 37, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop = __Pyx_ImportType_3_2_4(__pyx_t_1, "gevent._gevent_c_greenlet_primitives", "SwitchOutGreenletWithLoop",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop),
  #else
  sizeof(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop) __PYX_ERR(1, 40, __pyx_L1_error)
  __pyx_vtabptr_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop = (struct __pyx_vtabstruct_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop); if (unlikely(!__pyx_vtabptr_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop)) __PYX_ERR(1, 40, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("greenlet"); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_6gevent_16_gevent_c_waiter_greenlet = __Pyx_ImportType_3_2_4(__pyx_t_1, "greenlet", "greenlet",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyGreenlet),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(PyGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyGreenlet),
  #else
  sizeof(PyGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyGreenlet),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_16_gevent_c_waiter_greenlet) __PYX_ERR(2, 15, __pyx_L1_error)
  __pyx_t_2 = PyImport_ImportModule("gevent._gevent_c_waiter"); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 33, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_mstate->__pyx_ptype_6gevent_16_gevent_c_waiter_Waiter = __Pyx_ImportType_3_2_4(__pyx_t_2, "gevent._gevent_c_waiter", "Waiter",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_16_gevent_c_waiter_Waiter), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_16_gevent_c_waiter_Waiter),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_16_gevent_c_waiter_Waiter), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_16_gevent_c_waiter_Waiter),
  #else
  sizeof(struct __pyx_obj_6gevent_16_gevent_c_waiter_Waiter), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_16_gevent_c_waiter_Waiter),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_16_gevent_c_waiter_Waiter) __PYX_ERR(2, 33, __pyx_L1_error)
  __pyx_vtabptr_6gevent_16_gevent_c_waiter_Waiter = (struct __pyx_vtabstruct_6gevent_16_gevent_c_waiter_Waiter*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6gevent_16_gevent_c_waiter_Waiter); if (unlikely(!__pyx_vtabptr_6gevent_16_gevent_c_waiter_Waiter)) __PYX_ERR(2, 33, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6gevent_16_gevent_c_waiter_MultipleWaiter = __Pyx_ImportType_3_2_4(__pyx_t_2, "gevent._gevent_c_waiter", "MultipleWaiter",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_16_gevent_c_waiter_MultipleWaiter), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_16_gevent_c_waiter_MultipleWaiter),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_16_gevent_c_waiter_MultipleWaiter), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_16_gevent_c_waiter_MultipleWaiter),
  #else
  sizeof(struct __pyx_obj_6gevent_16_gevent_c_waiter_MultipleWaiter), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_16_gevent_c_waiter_MultipleWaiter),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_16_gevent_c_waiter_MultipleWaiter) __PYX_ERR(2, 45, __pyx_L1_error)
  __pyx_vtabptr_6gevent_16_gevent_c_waiter_MultipleWaiter = (struct __pyx_vtabstruct_6gevent_16_gevent_c_waiter_MultipleWaiter*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6gevent_16_gevent_c_waiter_MultipleWaiter); if (unlikely(!__pyx_vtabptr_6gevent_16_gevent_c_waiter_MultipleWaiter)) __PYX_ERR(2, 45, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyImport_ImportModule("greenlet"); if (unlikely(!__pyx_t_2)) __PYX_ERR(3, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_greenlet = __Pyx_ImportType_3_2_4(__pyx_t_2, "greenlet", "greenlet",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyGreenlet),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(PyGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyGreenlet),
  #else
  sizeof(PyGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyGreenlet),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_greenlet) __PYX_ERR(3, 20, __pyx_L1_error)
  __pyx_t_1 = PyImport_ImportModule("gevent._gevent_cgreenlet"); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 100, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_SpawnedLink = __Pyx_ImportType_3_2_4(__pyx_t_1, "gevent._gevent_cgreenlet", "SpawnedLink",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink),
  #else
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_SpawnedLink) __PYX_ERR(3, 100, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink = __Pyx_ImportType_3_2_4(__pyx_t_1, "gevent._gevent_cgreenlet", "SuccessSpawnedLink",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink),
  #else
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink) __PYX_ERR(3, 104, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_FailureSpawnedLink = __Pyx_ImportType_3_2_4(__pyx_t_1, "gevent._gevent_cgreenlet", "FailureSpawnedLink",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet_FailureSpawnedLink), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_17_gevent_cgreenlet_FailureSpawnedLink),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet_FailureSpawnedLink), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_17_gevent_cgreenlet_FailureSpawnedLink),
  #else
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet_FailureSpawnedLink), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_17_gevent_cgreenlet_FailureSpawnedLink),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_FailureSpawnedLink) __PYX_ERR(3, 108, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet__Frame = __Pyx_ImportType_3_2_4(__pyx_t_1, "gevent._gevent_cgreenlet", "_Frame",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame),
  #else
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet__Frame) __PYX_ERR(3, 112, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet__dummy_event = __Pyx_ImportType_3_2_4(__pyx_t_1, "gevent._gevent_cgreenlet", "_dummy_event",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event),
  #else
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet__dummy_event) __PYX_ERR(3, 199, __pyx_L1_error)
  __pyx_vtabptr_6gevent_17_gevent_cgreenlet__dummy_event = (struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet__dummy_event*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet__dummy_event); if (unlikely(!__pyx_vtabptr_6gevent_17_gevent_cgreenlet__dummy_event)) __PYX_ERR(3, 199, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("greenlet"); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_6gevent_27_gevent_c_abstract_linkable_greenlet = __Pyx_ImportType_3_2_4(__pyx_t_1, "greenlet", "greenlet",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyGreenlet),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(PyGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyGreenlet),
  #else
  sizeof(PyGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyGreenlet),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_27_gevent_c_abstract_linkable_greenlet) __PYX_ERR(4, 16, __pyx_L1_error)
  __pyx_t_2 = PyImport_ImportModule("gevent._gevent_c_abstract_linkable"); if (unlikely(!__pyx_t_2)) __PYX_ERR(4, 38, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_mstate->__pyx_ptype_6gevent_27_gevent_c_abstract_linkable__FakeNotifier = __Pyx_ImportType_3_2_4(__pyx_t_2, "gevent._gevent_c_abstract_linkable", "_FakeNotifier",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable__FakeNotifier), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable__FakeNotifier),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable__FakeNotifier), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable__FakeNotifier),
  #else
  sizeof(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable__FakeNotifier), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable__FakeNotifier),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_27_gevent_c_abstract_linkable__FakeNotifier) __PYX_ERR(4, 38, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable = __Pyx_ImportType_3_2_4(__pyx_t_2, "gevent._gevent_c_abstract_linkable", "AbstractLinkable",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable),
  #else
  sizeof(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable) __PYX_ERR(4, 41, __pyx_L1_error)
  __pyx_vtabptr_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable = (struct __pyx_vtabstruct_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable); if (unlikely(!__pyx_vtabptr_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable)) __PYX_ERR(4, 41, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyImport_ImportModule("gevent._gevent_c_semaphore"); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 18, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore__LockReleaseLink = __Pyx_ImportType_3_2_4(__pyx_t_2, "gevent._gevent_c_semaphore", "_LockReleaseLink",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_19_gevent_c_semaphore__LockReleaseLink), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_19_gevent_c_semaphore__LockReleaseLink),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_19_gevent_c_semaphore__LockReleaseLink), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_19_gevent_c_semaphore__LockReleaseLink),
  #else
  sizeof(struct __pyx_obj_6gevent_19_gevent_c_semaphore__LockReleaseLink), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_19_gevent_c_semaphore__LockReleaseLink),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore__LockReleaseLink) __PYX_ERR(9, 18, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore = __Pyx_ImportType_3_2_4(__pyx_t_2, "gevent._gevent_c_semaphore", "Semaphore",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore),
  #else
  sizeof(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore) __PYX_ERR(9, 22, __pyx_L1_error)
  __pyx_vtabptr_6gevent_19_gevent_c_semaphore_Semaphore = (struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore); if (unlikely(!__pyx_vtabptr_6gevent_19_gevent_c_semaphore_Semaphore)) __PYX_ERR(9, 22, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore_BoundedSemaphore = __Pyx_ImportType_3_2_4(__pyx_t_2, "gevent._gevent_c_semaphore", "BoundedSemaphore",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_19_gevent_c_semaphore_BoundedSemaphore), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_19_gevent_c_semaphore_BoundedSemaphore),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_19_gevent_c_semaphore_BoundedSemaphore), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_19_gevent_c_semaphore_BoundedSemaphore),
  #else
  sizeof(struct __pyx_obj_6gevent_19_gevent_c_semaphore_BoundedSemaphore), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_19_gevent_c_semaphore_BoundedSemaphore),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore_BoundedSemaphore) __PYX_ERR(9, 67, __pyx_L1_error)
  __pyx_vtabptr_6gevent_19_gevent_c_semaphore_BoundedSemaphore = (struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_BoundedSemaphore*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore_BoundedSemaphore); if (unlikely(!__pyx_vtabptr_6gevent_19_gevent_c_semaphore_BoundedSemaphore)) __PYX_ERR(9, 67, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyImport_ImportModule("gevent._gevent_cevent"); if (unlikely(!__pyx_t_2)) __PYX_ERR(10, 13, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_mstate->__pyx_ptype_6gevent_14_gevent_cevent_Event = __Pyx_ImportType_3_2_4(__pyx_t_2, "gevent._gevent_cevent", "Event",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_14_gevent_cevent_Event), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_14_gevent_cevent_Event),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_14_gevent_cevent_Event), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_14_gevent_cevent_Event),
  #else
  sizeof(struct __pyx_obj_6gevent_14_gevent_cevent_Event), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_14_gevent_cevent_Event),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_14_gevent_cevent_Event) __PYX_ERR(10, 13, __pyx_L1_error)
  __pyx_vtabptr_6gevent_14_gevent_cevent_Event = (struct __pyx_vtabstruct_6gevent_14_gevent_cevent_Event*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6gevent_14_gevent_cevent_Event); if (unlikely(!__pyx_vtabptr_6gevent_14_gevent_cevent_Event)) __PYX_ERR(10, 13, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6gevent_14_gevent_cevent_AsyncResult = __Pyx_ImportType_3_2_4(__pyx_t_2, "gevent._gevent_cevent", "AsyncResult",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_14_gevent_cevent_AsyncResult), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_14_gevent_cevent_AsyncResult),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_14_gevent_cevent_AsyncResult), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_14_gevent_cevent_AsyncResult),
  #else
  sizeof(struct __pyx_obj_6gevent_14_gevent_cevent_AsyncResult), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_14_gevent_cevent_AsyncResult),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_14_gevent_cevent_AsyncResult) __PYX_ERR(10, 16, __pyx_L1_error)
  __pyx_vtabptr_6gevent_14_gevent_cevent_AsyncResult = (struct __pyx_vtabstruct_6gevent_14_gevent_cevent_AsyncResult*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6gevent_14_gevent_cevent_AsyncResult); if (unlikely(!__pyx_vtabptr_6gevent_14_gevent_cevent_AsyncResult)) __PYX_ERR(10, 16, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyImport_ImportModule("greenlet"); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_mstate->__pyx_ptype_6gevent_14_gevent_cqueue_greenlet = __Pyx_ImportType_3_2_4(__pyx_t_2, "greenlet", "greenlet",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyGreenlet),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(PyGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyGreenlet),
  #else
  sizeof(PyGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyGreenlet),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_14_gevent_cqueue_greenlet) __PYX_ERR(5, 17, __pyx_L1_error)
  __pyx_t_1 = PyImport_ImportModule("gevent._gevent_cqueue"); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 39, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_6gevent_14_gevent_cqueue_SimpleQueue = __Pyx_ImportType_3_2_4(__pyx_t_1, "gevent._gevent_cqueue", "SimpleQueue",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_14_gevent_cqueue_SimpleQueue), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_14_gevent_cqueue_SimpleQueue),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_14_gevent_cqueue_SimpleQueue), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_14_gevent_cqueue_SimpleQueue),
  #else
  sizeof(struct __pyx_obj_6gevent_14_gevent_cqueue_SimpleQueue), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_14_gevent_cqueue_SimpleQueue),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_14_gevent_cqueue_SimpleQueue) __PYX_ERR(5, 39, __pyx_L1_error)
  __pyx_vtabptr_6gevent_14_gevent_cqueue_SimpleQueue = (struct __pyx_vtabstruct_6gevent_14_gevent_cqueue_SimpleQueue*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6gevent_14_gevent_cqueue_SimpleQueue); if (unlikely(!__pyx_vtabptr_6gevent_14_gevent_cqueue_SimpleQueue)) __PYX_ERR(5, 39, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6gevent_14_gevent_cqueue_Queue = __Pyx_ImportType_3_2_4(__pyx_t_1, "gevent._gevent_cqueue", "Queue",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_14_gevent_cqueue_Queue), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_14_gevent_cqueue_Queue),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_14_gevent_cqueue_Queue), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_14_gevent_cqueue_Queue),
  #else
  sizeof(struct __pyx_obj_6gevent_14_gevent_cqueue_Queue), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_14_gevent_cqueue_Queue),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_14_gevent_cqueue_Queue) __PYX_ERR(5, 83, __pyx_L1_error)
  __pyx_vtabptr_6gevent_14_gevent_cqueue_Queue = (struct __pyx_vtabstruct_6gevent_14_gevent_cqueue_Queue*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6gevent_14_gevent_cqueue_Queue); if (unlikely(!__pyx_vtabptr_6gevent_14_gevent_cqueue_Queue)) __PYX_ERR(5, 83, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6gevent_14_gevent_cqueue_ItemWaiter = __Pyx_ImportType_3_2_4(__pyx_t_1, "gevent._gevent_cqueue", "ItemWaiter",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_14_gevent_cqueue_ItemWaiter), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_14_gevent_cqueue_ItemWaiter),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_14_gevent_cqueue_ItemWaiter), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_14_gevent_cqueue_ItemWaiter),
  #else
  sizeof(struct __pyx_obj_6gevent_14_gevent_cqueue_ItemWaiter), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_14_gevent_cqueue_ItemWaiter),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_14_gevent_cqueue_ItemWaiter) __PYX_ERR(5, 93, __pyx_L1_error)
  __pyx_vtabptr_6gevent_14_gevent_cqueue_ItemWaiter = (struct __pyx_vtabstruct_6gevent_14_gevent_cqueue_ItemWaiter*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6gevent_14_gevent_cqueue_ItemWaiter); if (unlikely(!__pyx_vtabptr_6gevent_14_gevent_cqueue_ItemWaiter)) __PYX_ERR(5, 93, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6gevent_14_gevent_cqueue_UnboundQueue = __Pyx_ImportType_3_2_4(__pyx_t_1, "gevent._gevent_cqueue", "UnboundQueue",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_14_gevent_cqueue_UnboundQueue), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_14_gevent_cqueue_UnboundQueue),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_14_gevent_cqueue_UnboundQueue), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_14_gevent_cqueue_UnboundQueue),
  #else
  sizeof(struct __pyx_obj_6gevent_14_gevent_cqueue_UnboundQueue), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_14_gevent_cqueue_UnboundQueue),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_14_gevent_cqueue_UnboundQueue) __PYX_ERR(5, 100, __pyx_L1_error)
  __pyx_vtabptr_6gevent_14_gevent_cqueue_UnboundQueue = (struct __pyx_vtabstruct_6gevent_14_gevent_cqueue_UnboundQueue*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6gevent_14_gevent_cqueue_UnboundQueue); if (unlikely(!__pyx_vtabptr_6gevent_14_gevent_cqueue_UnboundQueue)) __PYX_ERR(5, 100, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6gevent_14_gevent_cqueue_PriorityQueue = __Pyx_ImportType_3_2_4(__pyx_t_1, "gevent._gevent_cqueue", "PriorityQueue",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_14_gevent_cqueue_PriorityQueue), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_14_gevent_cqueue_PriorityQueue),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_14_gevent_cqueue_PriorityQueue), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_14_gevent_cqueue_PriorityQueue),
  #else
  sizeof(struct __pyx_obj_6gevent_14_gevent_cqueue_PriorityQueue), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_14_gevent_cqueue_PriorityQueue),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_14_gevent_cqueue_PriorityQueue) __PYX_ERR(5, 103, __pyx_L1_error)
  __pyx_vtabptr_6gevent_14_gevent_cqueue_PriorityQueue = (struct __pyx_vtabstruct_6gevent_14_gevent_cqueue_PriorityQueue*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6gevent_14_gevent_cqueue_PriorityQueue); if (unlikely(!__pyx_vtabptr_6gevent_14_gevent_cqueue_PriorityQueue)) __PYX_ERR(5, 103, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6gevent_14_gevent_cqueue_LifoQueue = __Pyx_ImportType_3_2_4(__pyx_t_1, "gevent._gevent_cqueue", "LifoQueue",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_14_gevent_cqueue_LifoQueue), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_14_gevent_cqueue_LifoQueue),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_14_gevent_cqueue_LifoQueue), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_14_gevent_cqueue_LifoQueue),
  #else
  sizeof(struct __pyx_obj_6gevent_14_gevent_cqueue_LifoQueue), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_14_gevent_cqueue_LifoQueue),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_14_gevent_cqueue_LifoQueue) __PYX_ERR(5, 106, __pyx_L1_error)
  __pyx_vtabptr_6gevent_14_gevent_cqueue_LifoQueue = (struct __pyx_vtabstruct_6gevent_14_gevent_cqueue_LifoQueue*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6gevent_14_gevent_cqueue_LifoQueue); if (unlikely(!__pyx_vtabptr_6gevent_14_gevent_cqueue_LifoQueue)) __PYX_ERR(5, 106, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6gevent_14_gevent_cqueue_Channel = __Pyx_ImportType_3_2_4(__pyx_t_1, "gevent._gevent_cqueue", "Channel",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_14_gevent_cqueue_Channel), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_14_gevent_cqueue_Channel),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_14_gevent_cqueue_Channel), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_14_gevent_cqueue_Channel),
  #else
  sizeof(struct __pyx_obj_6gevent_14_gevent_cqueue_Channel), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_14_gevent_cqueue_Channel),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_14_gevent_cqueue_Channel) __PYX_ERR(5, 109, __pyx_L1_error)
  __pyx_vtabptr_6gevent_14_gevent_cqueue_Channel = (struct __pyx_vtabstruct_6gevent_14_gevent_cqueue_Channel*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6gevent_14_gevent_cqueue_Channel); if (unlikely(!__pyx_vtabptr_6gevent_14_gevent_cqueue_Channel)) __PYX_ERR(5, 109, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_variable_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  {
    __pyx_t_1 = PyImport_ImportModule("gevent._gevent_c_ident"); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_import_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_PyObject_WeakKeyDictionary_heapp);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_import_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_import_name = __pyx_import_signature + 13;
    void **const __pyx_import_pointers[] = {(void **)&__pyx_vp_6gevent_15_gevent_c_ident_WeakKeyDictionary, (void **)&__pyx_vp_6gevent_15_gevent_c_ident_heappop, (void **)&__pyx_vp_6gevent_15_gevent_c_ident_heappush, (void **) NULL};
    void **const *__pyx_import_pointer = __pyx_import_pointers;
    const char *__pyx_import_current_signature = __pyx_import_signature;
    while (*__pyx_import_pointer) {
      if (__Pyx_ImportVoidPtr_3_2_4(__pyx_t_1, __pyx_import_name, *__pyx_import_pointer, __pyx_import_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_import_pointer;
      __pyx_import_name = strchr(__pyx_import_name, '\0') + 1;
      __pyx_import_signature = strchr(__pyx_import_signature, '\0') + 1;
      if (*__pyx_import_signature != '\0') __pyx_import_current_signature = __pyx_import_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  {
    __pyx_t_1 = PyImport_ImportModule("gevent._gevent_c_greenlet_primitives"); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_import_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_PyObject_PyTypeObject_int_Blocki);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_import_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_import_name = __pyx_import_signature + 33;
    void **const __pyx_import_pointers[] = {(void **)&__pyx_vp_6gevent_29_gevent_c_greenlet_primitives_BlockingSwitchOutError, (void **)&__pyx_vp_6gevent_29_gevent_c_greenlet_primitives_get_objects, (void **)&__pyx_vp_6gevent_29_gevent_c_greenlet_primitives_wref, (void **)&__pyx_vp_6gevent_29_gevent_c_greenlet_primitives__buffer, (void **)&__pyx_vp_6gevent_29_gevent_c_greenlet_primitives__memoryview, (void **)&__pyx_vp_6gevent_29_gevent_c_greenlet_primitives__greenlet_imported, (void **) NULL};
    void **const *__pyx_import_pointer = __pyx_import_pointers;
    const char *__pyx_import_current_signature = __pyx_import_signature;
    while (*__pyx_import_pointer) {
      if (__Pyx_ImportVoidPtr_3_2_4(__pyx_t_1, __pyx_import_name, *__pyx_import_pointer, __pyx_import_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_import_pointer;
      __pyx_import_name = strchr(__pyx_import_name, '\0') + 1;
      __pyx_import_signature = strchr(__pyx_import_signature, '\0') + 1;
      if (*__pyx_import_signature != '\0') __pyx_import_current_signature = __pyx_import_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  {
    __pyx_t_1 = PyImport_ImportModule("gevent._gevent_c_hub_local"); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_import_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_PyObject__threadlocal);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_import_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_import_name = __pyx_import_signature + 11;
    void **const __pyx_import_pointers[] = {(void **)&__pyx_vp_6gevent_19_gevent_c_hub_local__threadlocal, (void **) NULL};
    void **const *__pyx_import_pointer = __pyx_import_pointers;
    const char *__pyx_import_current_signature = __pyx_import_signature;
    while (*__pyx_import_pointer) {
      if (__Pyx_ImportVoidPtr_3_2_4(__pyx_t_1, __pyx_import_name, *__pyx_import_pointer, __pyx_import_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_import_pointer;
      __pyx_import_name = strchr(__pyx_import_name, '\0') + 1;
      __pyx_import_signature = strchr(__pyx_import_signature, '\0') + 1;
      if (*__pyx_import_signature != '\0') __pyx_import_current_signature = __pyx_import_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  {
    __pyx_t_1 = PyImport_ImportModule("gevent._gevent_c_waiter"); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_import_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_PyObject_int_ConcurrentObjectUse);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_import_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_import_name = __pyx_import_signature + 17;
    void **const __pyx_import_pointers[] = {(void **)&__pyx_vp_6gevent_16_gevent_c_waiter_ConcurrentObjectUseError, (void **)&__pyx_vp_6gevent_16_gevent_c_waiter__NONE, (void **)&__pyx_vp_6gevent_16_gevent_c_waiter_sys, (void **)&__pyx_vp_6gevent_16_gevent_c_waiter__greenlet_imported, (void **) NULL};
    void **const *__pyx_import_pointer = __pyx_import_pointers;
    const char *__pyx_import_current_signature = __pyx_import_signature;
    while (*__pyx_import_pointer) {
      if (__Pyx_ImportVoidPtr_3_2_4(__pyx_t_1, __pyx_import_name, *__pyx_import_pointer, __pyx_import_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_import_pointer;
      __pyx_import_name = strchr(__pyx_import_name, '\0') + 1;
      __pyx_import_signature = strchr(__pyx_import_signature, '\0') + 1;
      if (*__pyx_import_signature != '\0') __pyx_import_current_signature = __pyx_import_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  {
    __pyx_t_1 = PyImport_ImportModule("gevent._gevent_cgreenlet"); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_import_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_PyObject_int_struct___pyx_obj_6g);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_import_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_import_name = __pyx_import_signature + 92;
    void **const __pyx_import_pointers[] = {(void **)&__pyx_vp_6gevent_17_gevent_cgreenlet_GEVENT_CONFIG, (void **)&__pyx_vp_6gevent_17_gevent_cgreenlet_GreenletExit, (void **)&__pyx_vp_6gevent_17_gevent_cgreenlet_InvalidSwitchError, (void **)&__pyx_vp_6gevent_17_gevent_cgreenlet_Timeout, (void **)&__pyx_vp_6gevent_17_gevent_cgreenlet__greenlet__init__, (void **)&__pyx_vp_6gevent_17_gevent_cgreenlet__spawn_callbacks, (void **)&__pyx_vp_6gevent_17_gevent_cgreenlet__threadlocal, (void **)&__pyx_vp_6gevent_17_gevent_cgreenlet_dump_traceback, (void **)&__pyx_vp_6gevent_17_gevent_cgreenlet_get_hub_class, (void **)&__pyx_vp_6gevent_17_gevent_cgreenlet_iwait, (void **)&__pyx_vp_6gevent_17_gevent_cgreenlet_load_traceback, (void **)&__pyx_vp_6gevent_17_gevent_cgreenlet_reraise, (void **)&__pyx_vp_6gevent_17_gevent_cgreenlet_sys_exc_info, (void **)&__pyx_vp_6gevent_17_gevent_cgreenlet_sys_getframe, (void **)&__pyx_vp_6gevent_17_gevent_cgreenlet_wait, (void **)&__pyx_vp_6gevent_17_gevent_cgreenlet_wref, (void **)&__pyx_vp_6gevent_17_gevent_cgreenlet__PYPY, (void **)&__pyx_vp_6gevent_17_gevent_cgreenlet__greenlet_imported, (void **)&__pyx_vp_6gevent_17_gevent_cgreenlet__cancelled_start_event, (void **)&__pyx_vp_6gevent_17_gevent_cgreenlet__start_completed_event, (void **) NULL};
    void **const *__pyx_import_pointer = __pyx_import_pointers;
    const char *__pyx_import_current_signature = __pyx_import_signature;
    while (*__pyx_import_pointer) {
      if (__Pyx_ImportVoidPtr_3_2_4(__pyx_t_1, __pyx_import_name, *__pyx_import_pointer, __pyx_import_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_import_pointer;
      __pyx_import_name = strchr(__pyx_import_name, '\0') + 1;
      __pyx_import_signature = strchr(__pyx_import_signature, '\0') + 1;
      if (*__pyx_import_signature != '\0') __pyx_import_current_signature = __pyx_import_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  {
    __pyx_t_1 = PyImport_ImportModule("gevent._gevent_c_abstract_linkable"); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_import_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_PyObject_int_InvalidSwitchError);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_import_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_import_name = __pyx_import_signature + 19;
    void **const __pyx_import_pointers[] = {(void **)&__pyx_vp_6gevent_27_gevent_c_abstract_linkable_InvalidSwitchError, (void **)&__pyx_vp_6gevent_27_gevent_c_abstract_linkable_InvalidThreadUseError, (void **)&__pyx_vp_6gevent_27_gevent_c_abstract_linkable_Timeout, (void **)&__pyx_vp_6gevent_27_gevent_c_abstract_linkable__get_thread_ident, (void **)&__pyx_vp_6gevent_27_gevent_c_abstract_linkable_get_objects, (void **)&__pyx_vp_6gevent_27_gevent_c_abstract_linkable__greenlet_imported, (void **) NULL};
    void **const *__pyx_import_pointer = __pyx_import_pointers;
    const char *__pyx_import_current_signature = __pyx_import_signature;
    while (*__pyx_import_pointer) {
      if (__Pyx_ImportVoidPtr_3_2_4(__pyx_t_1, __pyx_import_name, *__pyx_import_pointer, __pyx_import_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_import_pointer;
      __pyx_import_name = strchr(__pyx_import_name, '\0') + 1;
      __pyx_import_signature = strchr(__pyx_import_signature, '\0') + 1;
      if (*__pyx_import_signature != '\0') __pyx_import_current_signature = __pyx_import_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  {
    __pyx_t_1 = PyImport_ImportModule("gevent._gevent_c_semaphore"); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_import_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_PyObject_InvalidThreadUseError_L);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_import_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_import_name = __pyx_import_signature + 18;
    void **const __pyx_import_pointers[] = {(void **)&__pyx_vp_6gevent_19_gevent_c_semaphore_InvalidThreadUseError, (void **)&__pyx_vp_6gevent_19_gevent_c_semaphore_LoopExit, (void **)&__pyx_vp_6gevent_19_gevent_c_semaphore_Timeout, (void **)&__pyx_vp_6gevent_19_gevent_c_semaphore__MULTI, (void **)&__pyx_vp_6gevent_19_gevent_c_semaphore__UNSET, (void **)&__pyx_vp_6gevent_19_gevent_c_semaphore__native_sleep, (void **)&__pyx_vp_6gevent_19_gevent_c_semaphore_monotonic, (void **)&__pyx_vp_6gevent_19_gevent_c_semaphore_spawn_raw, (void **) NULL};
    void **const *__pyx_import_pointer = __pyx_import_pointers;
    const char *__pyx_import_current_signature = __pyx_import_signature;
    while (*__pyx_import_pointer) {
      if (__Pyx_ImportVoidPtr_3_2_4(__pyx_t_1, __pyx_import_name, *__pyx_import_pointer, __pyx_import_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_import_pointer;
      __pyx_import_name = strchr(__pyx_import_name, '\0') + 1;
      __pyx_import_signature = strchr(__pyx_import_signature, '\0') + 1;
      if (*__pyx_import_signature != '\0') __pyx_import_current_signature = __pyx_import_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  {
    __pyx_t_1 = PyImport_ImportModule("gevent._gevent_cevent"); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_import_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_PyObject_Timeout__None_dump_trac);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_import_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_import_name = __pyx_import_signature + 15;
    void **const __pyx_import_pointers[] = {(void **)&__pyx_vp_6gevent_14_gevent_cevent_Timeout, (void **)&__pyx_vp_6gevent_14_gevent_cevent__None, (void **)&__pyx_vp_6gevent_14_gevent_cevent_dump_traceback, (void **)&__pyx_vp_6gevent_14_gevent_cevent_load_traceback, (void **)&__pyx_vp_6gevent_14_gevent_cevent_reraise, (void **) NULL};
    void **const *__pyx_import_pointer = __pyx_import_pointers;
    const char *__pyx_import_current_signature = __pyx_import_signature;
    while (*__pyx_import_pointer) {
      if (__Pyx_ImportVoidPtr_3_2_4(__pyx_t_1, __pyx_import_name, *__pyx_import_pointer, __pyx_import_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_import_pointer;
      __pyx_import_name = strchr(__pyx_import_name, '\0') + 1;
      __pyx_import_signature = strchr(__pyx_import_signature, '\0') + 1;
      if (*__pyx_import_signature != '\0') __pyx_import_current_signature = __pyx_import_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  {
    __pyx_t_1 = PyImport_ImportModule("gevent._gevent_cqueue"); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_import_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_PyObject_int_InvalidSwitchError_2);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_import_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_import_name = __pyx_import_signature + 21;
    void **const __pyx_import_pointers[] = {(void **)&__pyx_vp_6gevent_14_gevent_cqueue_InvalidSwitchError, (void **)&__pyx_vp_6gevent_14_gevent_cqueue_Timeout, (void **)&__pyx_vp_6gevent_14_gevent_cqueue__Empty, (void **)&__pyx_vp_6gevent_14_gevent_cqueue__Full, (void **)&__pyx_vp_6gevent_14_gevent_cqueue__heapify, (void **)&__pyx_vp_6gevent_14_gevent_cqueue__heappop, (void **)&__pyx_vp_6gevent_14_gevent_cqueue__heappush, (void **)&__pyx_vp_6gevent_14_gevent_cqueue__greenlet_imported, (void **) NULL};
    void **const *__pyx_import_pointer = __pyx_import_pointers;
    const char *__pyx_import_current_signature = __pyx_import_signature;
    while (*__pyx_import_pointer) {
      if (__Pyx_ImportVoidPtr_3_2_4(__pyx_t_1, __pyx_import_name, *__pyx_import_pointer, __pyx_import_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_import_pointer;
      __pyx_import_name = strchr(__pyx_import_name, '\0') + 1;
      __pyx_import_signature = strchr(__pyx_import_signature, '\0') + 1;
      if (*__pyx_import_signature != '\0') __pyx_import_current_signature = __pyx_import_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_function_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  {
    __pyx_t_1 = PyImport_ImportModule("gevent._gevent_c_hub_local"); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_import_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_struct___pyx_obj_6gevent_29_geve);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_import_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_import_name = __pyx_import_signature + 111;
    void (**const __pyx_import_pointers[])(void) = {(void (**)(void))&__pyx_f_6gevent_19_gevent_c_hub_local_get_hub_if_exists, (void (**)(void))&__pyx_f_6gevent_19_gevent_c_hub_local_get_hub_noargs, (void (**)(void)) NULL};
    void (**const *__pyx_import_pointer)(void) = __pyx_import_pointers;
    const char *__pyx_import_current_signature = __pyx_import_signature;
    while (*__pyx_import_pointer) {
      if (__Pyx_ImportFunction_3_2_4(__pyx_t_1, __pyx_import_name, *__pyx_import_pointer, __pyx_import_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_import_pointer;
      __pyx_import_name = strchr(__pyx_import_name, '\0') + 1;
      __pyx_import_signature = strchr(__pyx_import_signature, '\0') + 1;
      if (*__pyx_import_signature != '\0') __pyx_import_current_signature = __pyx_import_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec__gevent_c_imap(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec__gevent_c_imap},
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
  {Py_mod_gil, __Pyx_FREETHREADING_COMPATIBLE},
  #endif
  #if PY_VERSION_HEX >= 0x030C0000 && CYTHON_USE_MODULE_STATE
  {Py_mod_multiple_interpreters, Py_MOD_MULTIPLE_INTERPRETERS_NOT_SUPPORTED},
  #endif
  {0, NULL}
};
#endif

#ifdef __cplusplus
namespace {
  struct PyModuleDef __pyx_moduledef =
  #else
  static struct PyModuleDef __pyx_moduledef =
  #endif
  {
      PyModuleDef_HEAD_INIT,
      "_gevent_c_imap",
      __pyx_k_Iterators_across_greenlets_or_A, /* m_doc */
    #if CYTHON_USE_MODULE_STATE
      sizeof(__pyx_mstatetype), /* m_size */
    #else
      (CYTHON_PEP489_MULTI_PHASE_INIT) ? 0 : -1, /* m_size */
    #endif
      __pyx_methods /* m_methods */,
    #if CYTHON_PEP489_MULTI_PHASE_INIT
      __pyx_moduledef_slots, /* m_slots */
    #else
      NULL, /* m_reload */
    #endif
    #if CYTHON_USE_MODULE_STATE
      __pyx_m_traverse, /* m_traverse */
      __pyx_m_clear, /* m_clear */
      NULL /* m_free */
    #else
      NULL, /* m_traverse */
      NULL, /* m_clear */
      NULL /* m_free */
    #endif
  };
  #ifdef __cplusplus
} /* anonymous namespace */
#endif

/* PyModInitFuncType */
#ifndef CYTHON_NO_PYINIT_EXPORT
  #define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#else
  #ifdef __cplusplus
  #define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
  #else
  #define __Pyx_PyMODINIT_FUNC PyObject *
  #endif
#endif

__Pyx_PyMODINIT_FUNC PyInit__gevent_c_imap(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit__gevent_c_imap(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
/* ModuleCreationPEP489 */
#include "src/gevent/_generated_include/ModuleCreationPEP489_impl_e8e48a7033664eca332c0112edbc6a62057c1d998b2c8eee547bdd9088e6ab4c.h"

static CYTHON_SMALL_CODE int __pyx_pymod_exec__gevent_c_imap(PyObject *__pyx_pyinit_module)
#endif
{
  int stringtab_initialized = 0;
  #if CYTHON_USE_MODULE_STATE
  int pystate_addmodule_run = 0;
  #endif
  __pyx_mstatetype *__pyx_mstate = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module '_gevent_c_imap' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #else
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_t_1 = __pyx_pyinit_module;
  Py_INCREF(__pyx_t_1);
  #else
  __pyx_t_1 = PyModule_Create(&__pyx_moduledef); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #if CYTHON_USE_MODULE_STATE
  {
    int add_module_result = __Pyx_State_AddModule(__pyx_t_1, &__pyx_moduledef);
    __pyx_t_1 = 0; /* transfer ownership from __pyx_t_1 to "_gevent_c_imap" pseudovariable */
    if (unlikely((add_module_result < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    pystate_addmodule_run = 1;
  }
  #else
  __pyx_m = __pyx_t_1;
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
  PyUnstable_Module_SetGIL(__pyx_m, Py_MOD_GIL_USED);
  #endif
  __pyx_mstate = __pyx_mstate_global;
  CYTHON_UNUSED_VAR(__pyx_t_1);
  __pyx_mstate->__pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_mstate->__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_mstate->__pyx_d);
  __pyx_mstate->__pyx_b = __Pyx_PyImport_AddModuleRef(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_mstate->__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_cython_runtime = __Pyx_PyImport_AddModuleRef("cython_runtime"); if (unlikely(!__pyx_mstate->__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_mstate->__pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /* ImportRefnannyAPI */
  #if CYTHON_REFNANNY
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
  if (!__Pyx_RefNanny) {
    PyErr_Clear();
    __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
    if (!__Pyx_RefNanny)
        Py_FatalError("failed to import 'refnanny' module");
  }
  #endif
  
__Pyx_RefNannySetupContext("PyInit__gevent_c_imap", 0);
  __Pyx_init_runtime_version();
  if (__Pyx_check_binary_version(__PYX_LIMITED_VERSION_HEX, __Pyx_get_runtime_version(), CYTHON_COMPILING_IN_LIMITED_API) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_mstate->__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_mstate->__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_mstate->__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Library function declarations ---*/
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitConstants(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  stringtab_initialized = 1;
  if (__Pyx_InitGlobals() < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__pyx_module_is_main_gevent___gevent_c_imap) {
    if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_name, __pyx_mstate_global->__pyx_n_u_main) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "gevent._gevent_c_imap")) {
      if (unlikely((PyDict_SetItemString(modules, "gevent._gevent_c_imap", __pyx_m) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_CreateCodeObjects(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code(__pyx_mstate);
  (void)__Pyx_modinit_variable_export_code(__pyx_mstate);
  if (unlikely((__Pyx_modinit_function_export_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely((__Pyx_modinit_type_init_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely((__Pyx_modinit_type_import_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely((__Pyx_modinit_variable_import_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely((__Pyx_modinit_function_import_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Execution code ---*/

  /* "src/gevent/_imap.py":14
 * 
 * 
 * from gevent import lock             # <<<<<<<<<<<<<<
 * from gevent import queue
 * 
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_lock};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_gevent, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 14, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_lock};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 14, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 14, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/_imap.py":15
 * 
 * from gevent import lock
 * from gevent import queue             # <<<<<<<<<<<<<<
 * 
 * 
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_queue};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_gevent, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 15, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_queue};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 15, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 15, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/_imap.py":18
 * 
 * 
 * __all__ = [             # <<<<<<<<<<<<<<
 *     'IMapUnordered',
 *     'IMap',
*/
  __pyx_t_2 = __Pyx_PyList_Pack(2, __pyx_mstate_global->__pyx_n_u_IMapUnordered, __pyx_mstate_global->__pyx_n_u_IMap); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 18, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_all, __pyx_t_2) < (0)) __PYX_ERR(0, 18, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/_imap.py":23
 * ]
 * 
 * locals()['Greenlet'] = __import__('gevent').Greenlet             # <<<<<<<<<<<<<<
 * locals()['Semaphore'] = lock.Semaphore
 * locals()['UnboundQueue'] = queue.UnboundQueue
*/
  __pyx_t_4 = NULL;
  __pyx_t_5 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_mstate_global->__pyx_n_u_gevent};
    __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin___import__, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 23, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_Greenlet); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_Globals(); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (unlikely((PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_Greenlet, __pyx_t_4) < 0))) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/_imap.py":24
 * 
 * locals()['Greenlet'] = __import__('gevent').Greenlet
 * locals()['Semaphore'] = lock.Semaphore             # <<<<<<<<<<<<<<
 * locals()['UnboundQueue'] = queue.UnboundQueue
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_lock); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_Semaphore); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_Globals(); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (unlikely((PyDict_SetItem(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_Semaphore, __pyx_t_2) < 0))) __PYX_ERR(0, 24, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/_imap.py":25
 * locals()['Greenlet'] = __import__('gevent').Greenlet
 * locals()['Semaphore'] = lock.Semaphore
 * locals()['UnboundQueue'] = queue.UnboundQueue             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_queue); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_UnboundQueue); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_Globals(); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (unlikely((PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_UnboundQueue, __pyx_t_4) < 0))) __PYX_ERR(0, 25, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/_imap.py":29
 * 
 * class Failure(object):
 *     __slots__ = ('exc', 'raise_exception')             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, exc, raise_exception=None):
*/
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_c_imap_Failure, __pyx_mstate_global->__pyx_n_u_slots, __pyx_mstate_global->__pyx_tuple[0]) < (0)) __PYX_ERR(0, 29, __pyx_L1_error)

  /* "src/gevent/_imap.py":110
 *         return value
 * 
 *     next = __next__ # Py2             # <<<<<<<<<<<<<<
 * 
 *     def _inext(self):
*/
  __Pyx_GetNameInClass(__pyx_t_4, (PyObject*)__pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_c_imap_IMapUnordered, __pyx_mstate_global->__pyx_n_u_next); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_c_imap_IMapUnordered, __pyx_mstate_global->__pyx_n_u_next_2, __pyx_t_4) < (0)) __PYX_ERR(0, 110, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/_imap.py":124
 *         return g
 * 
 *     def _run(self): # pylint:disable=method-hidden             # <<<<<<<<<<<<<<
 *         try:
 *             func = self.func
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_14_gevent_c_imap_13IMapUnordered_7_run, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_IMapUnordered__run, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_c_imap, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[0])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 124, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_c_imap_IMapUnordered, __pyx_mstate_global->__pyx_n_u_run, __pyx_t_4) < (0)) __PYX_ERR(0, 124, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/_imap.py":140
 *             self._result_semaphore = None
 * 
 *     def _on_result(self, greenlet):             # <<<<<<<<<<<<<<
 *         # This method will be called in the hub greenlet (we rawlink)
 *         self._outstanding_tasks -= 1
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_14_gevent_c_imap_13IMapUnordered_9_on_result, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_IMapUnordered__on_result, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_c_imap, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[1])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_14_gevent_c_imap_IMapUnordered, __pyx_mstate_global->__pyx_n_u_on_result, __pyx_t_4) < (0)) __PYX_ERR(0, 140, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/_imap.py":225
 *         return (self._max_index + 1, IMapUnordered._iqueue_value_for_self_failure(self, exception))
 * 
 * from gevent._util import import_c_accel             # <<<<<<<<<<<<<<
 * import_c_accel(globals(), 'gevent.__imap')
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_import_c_accel};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_gevent__util, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 225, __pyx_L1_error)
  }
  __pyx_t_4 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_4);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_import_c_accel};
    __pyx_t_3 = 0; {
      __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_4, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 225, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_2) < (0)) __PYX_ERR(0, 225, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/_imap.py":226
 * 
 * from gevent._util import import_c_accel
 * import_c_accel(globals(), 'gevent.__imap')             # <<<<<<<<<<<<<<
*/
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_import_c_accel); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_Globals(); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_5 = 1;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_t_7, __pyx_mstate_global->__pyx_kp_u_gevent___imap};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 226, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/_imap.py":1
 * # -*- coding: utf-8 -*-             # <<<<<<<<<<<<<<
 * # Copyright (c) 2018 gevent
 * # cython: auto_pickle=False,embedsignature=True,always_allow_keywords=False,infer_types=True
*/
  __pyx_t_4 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_test, __pyx_t_4) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  if (__pyx_m) {
    if (__pyx_mstate->__pyx_d && stringtab_initialized) {
      __Pyx_AddTraceback("init gevent._gevent_c_imap", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    #if !CYTHON_USE_MODULE_STATE
    Py_CLEAR(__pyx_m);
    #else
    Py_DECREF(__pyx_m);
    if (pystate_addmodule_run) {
      PyObject *tp, *value, *tb;
      PyErr_Fetch(&tp, &value, &tb);
      PyState_RemoveModule(&__pyx_moduledef);
      PyErr_Restore(tp, value, tb);
    }
    #endif
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init gevent._gevent_c_imap");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #else
  return __pyx_m;
  #endif
}
/* #### Code section: pystring_table ### */
/* #### Code section: cached_builtins ### */

static int __Pyx_InitCachedBuiltins(__pyx_mstatetype *__pyx_mstate) {
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __pyx_builtin___import__ = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_import); if (!__pyx_builtin___import__) __PYX_ERR(0, 23, __pyx_L1_error)

  /* Cached unbound methods */
  __pyx_mstate->__pyx_umethod_PyDict_Type_items.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_items.method_name = &__pyx_mstate->__pyx_n_u_items;
  __pyx_mstate->__pyx_umethod_PyDict_Type_pop.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_pop.method_name = &__pyx_mstate->__pyx_n_u_pop;
  __pyx_mstate->__pyx_umethod_PyDict_Type_values.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_values.method_name = &__pyx_mstate->__pyx_n_u_values;
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cached_constants ### */

static int __Pyx_InitCachedConstants(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "src/gevent/_imap.py":29
 * 
 * class Failure(object):
 *     __slots__ = ('exc', 'raise_exception')             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, exc, raise_exception=None):
*/
  __pyx_mstate_global->__pyx_tuple[0] = PyTuple_Pack(2, __pyx_mstate_global->__pyx_n_u_exc, __pyx_mstate_global->__pyx_n_u_raise_exception); if (unlikely(!__pyx_mstate_global->__pyx_tuple[0])) __PYX_ERR(0, 29, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[0]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[0]);
  #if CYTHON_IMMORTAL_CONSTANTS
  {
    PyObject **table = __pyx_mstate->__pyx_tuple;
    for (Py_ssize_t i=0; i<1; ++i) {
      #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
      #if PY_VERSION_HEX < 0x030E0000
      if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
      #else
      if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
      #endif
      {
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
      }
      #else
      Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
      #endif
    }
  }
  #endif
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}
/* #### Code section: init_constants ### */

static int __Pyx_InitConstants(__pyx_mstatetype *__pyx_mstate) {
  CYTHON_UNUSED_VAR(__pyx_mstate);
  {
    const struct { const unsigned int length: 9; } index[] = {{1},{1},{7},{6},{2},{13},{9},{19},{7},{8},{4},{13},{24},{18},{20},{9},{12},{7},{18},{18},{8},{1},{3},{9},{4},{8},{6},{21},{12},{8},{16},{10},{14},{8},{13},{4},{5},{8},{4},{8},{7},{10},{8},{8},{4},{10},{3},{12},{14},{12},{5},{15},{16},{7},{4},{4},{12},{10},{9},{5},{10},{8},{5},{6},{7},{104},{111},{66},{47},{23},{70},{116},{107},{358},{74},{137},{101},{143}};
    #if (CYTHON_COMPRESS_STRINGS) == 3 && __PYX_LIMITED_VERSION_HEX >= 0x030e0000 /* compression: zstd (1022 bytes) */
const char* const cstring = "(\265/\375`\006\007\245\037\00064\2424 \223\332@\241\002`\000\201a@\211@\030\006\033\350N\255vw{\345\362\321\264O\222b\377\354\246U\265AHWvU0%)\315\377\205\010\316\257\237\003T\313\207\000\211\000\217\000\215\177~\267\364\030aGlim96\277c.\304\235\222\261\273\343\314\331\244\217kl\2717\326\035\023!\312#\264\270\347\267\317\227\361\372|\234\251\245\021D?\316\355\302n)a\267g\317*\330\314\0245On\251\312Y2_\301-\0375\216/\322\332J\3353[,\363u\333\2236\010s\353\230\245\363Ta\212\tv9\335-\211\333,\037\216l\025DA\021\355\305\356W\250}7\010O\227\361TLMw\211\202\3671\220G\361'\305tR\355Uwy\333e\036\303\331\317$b\031\235\372\231\230PN)\375p\246\256\275\351\341o\211*\245(\317RkE~O\030t\2532a?M\336D\003\216\016\203\"m%\314k\375\231\276\236%\224\351\306\327q\267\314\331\275\036c\276\223\005\353\305T\302\3141\354\267;\223~c\346K\026\264\335~\037\332\225\204y\205e\272\277\302\330\255\255vWZ58\273\273]f\214\372\314\337\326|\250Qi\035\377\325\034\177\337\357\016.\245\307\tc\277\227\322K\351\271\006mF3\374\220\365\357^(c\243\262\352\312~\217\304ddD\ni\323H\324\"\"\351M\3232\326\031!\214\316\026\337\327\331\367\2232\217\364\333p\325Dx:\366}\267\373D#\322\250\361tks\2344DB\334\252\233+\255\025\272\352m\026\372I\014t\027\213A*_\3252\366|\322Q?\226\277\314f\251\346Z?\353Y\226Q\3752\267\254wicO\341LRE\374,\226\324|\220\207\347{\335L[\251_7e!\235\027\337oyg\377$`\275\217u\375\230;_\205\337\245\357ko\353F\205\212\013\342\203\363\361\034t\003\005\036\000W\203\001\216A\027\352\010Tl\022l0\\-\335GW\022r\221\270\204\317\353\243\013\350:\236\327\000\315\352\306#\224\343psp\263\301\200s\3219t\030'\300}</\330qp\032\241n\301\363Z\271::\314)x^\0006\"\256\000\027\252\263\350Z\270\004\016\243\206\240\223\263\342\024:/\207nd\305]p\010\235\327\007\027\300}:\257\220\353\301\203\343\351\344|\320<\211\211\206\276\210\300\034\273\254\032\215\017[\210oc\001\200\235\250Q\035$J!\221\221\021IR\220\024: \204 f\254n\003\2214\206\rb$\001IAAI\nRi\014\025\306\017\312\007\331\266\272\013-_J\320<\213hF\006\016i\376DE""\036\205Ih\345F[cMV\235^Y\251W4\246\212\007h\000s\37352b\260\306@i\323\020\372\023\026\222\222\204\326c2\020\253\263U\242\323\252\253}\300\221\353\241q\347\241\275\035\346*\325\026(\250\240\363;\364MXi\360\272\214\263\312D\351M\246\300[\033o\266\370\004\351\351\345\320\271fdmA\021'\001\364\372\022\007\004\231c@.\215[(u\001\375>\026\216pUfI\273\002]\372\323\210\277?\363)\356\224y\225u\270\246\007\277\307y\273\302\026\023o*\270\210\336\321\013\262\010\260\271z/\3721\245\351\363\210\"{k\235\243\005\362\255(v\033\245\260\350\026\202\010\341\346\324^\312\363\026\376hb\224\270/\2639b\022\254a\374\334\010\262p\224\364\360\305\234\006+U\372\r\353\257\016\022h D\014\237\244\tb\326`(\230\270\220\t\311\347\tA\206\367P\327\261\231%f\\\251\345\024B\3572G\244\031\017#]9\247\342\351C\214\026\203\307\333\034oG\213&\305\320\021=\262j\n!=\240W1\200Y\332v\256\330\257\251\031J1\315";
    PyObject *data = __Pyx_DecompressString(cstring, 1022, 3);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #elif (CYTHON_COMPRESS_STRINGS) == 2 /* compression: bz2 (1138 bytes) */
const char* const cstring = "BZh91AY&SYb\266C\252\000\000\205\377\373mn\354\210\352q\275\354\277\357\377\240\277\377\377\360@@@@@@\000@@@@\000P\004>\323kh\000\0003\206\211O&T\375I\350\322=C#j\031\0004\311\243L\200\r\000\320\017D4\365\003\332\240\324\002\247\351\211\252m\252\000\000\000`F\020\000\000\311\3522\000z&\230\341\352\003&@\301\014 \003 \320\000\014\200\000\000\310\301\0072i\241\220\000\304d\031\0004\301\003\020\r\032h\000\310\032\000\022$\020\010\320CB\236\247\2210#\310CM4h\032\000\000\003A\214\246\34444\320\331\272#\364hc\350\205\371\222p\310\217\345\311\375>\323\372$y\177\217\330\361\225\227\033\325;\271\261I\025\2378%Ls\222\022\225!\200\030ZW\033.\025q$M5\323\213\240\350\205\323\324\r\020\272\300\310\223\006\322\352\262t\354\316(D\022\021\324])wK0\234\313\026I\033^\226\035\333\303\002\3148OQ\370\004\2559\207\275\345\312[\270\214\216\016\247\022=\374\220\202\230JR\221\301h-t\346!\306\223$Si\347\211\2768/\326]\030\214\314\361\304,SM\363\343\013Z6\254\237,\255\302%2\354\373a\2368\300\266\014\235\263\t-@\001\002\207\264B\232\304\204\033L\260\266@\272L\254\251\326RXWC\325\345\006\213F1\243d\031d\260\374\330j57\306!\004\024\213\226\227\2656t\327\265)\310<\3544\037\363\233\342\353H\347>\314$R\332\335m1\360\004\270\332\037\021\234\300\363\200\3038\363\025jqA\362r\022\342F\246\"\334\260\364R\201'\024\216#_*P\352\241\031m\234\321k\244E\232\224\314\0311k\253S\266en\212\267\206\271]2D\313\256\255\271\333H\177\035\0321\026\013\3043\240\363\321\035\302z\216\224]\0352+\202\235\276\2600\213a\206\032\n\276<6O\213\002J\356\266\205\202.\301w\2013\322\2141\267\233\031\223\r\373\010V`\321\235j\241\367k\250T\252-\034\370\031\2734\214\023\3112\334!\004I\026\222m\227\313%K\256u,\302\\GeY\226\313\341=\261\033f\363\352\221Ef\353\021\323\336F\372;b[\324Md\314\224\201<\340\351\346\2367d\345\342\273K\246\362\026w4`\320U\023\271r[Se\252\330\306\312\324\305\034i\213\030!\304E\213I\000\330\034XH\271\344\316\214OL\325\366\306\234+\243(\276\310\263\205\0231\263og\314\250\212<\230\265\3430\265\2212\346\356\347*\246""\245\217\243c\301\024\336u\263\224\222.FP\224\231e\010\3562_6G\263\367y\265\334\027u\357\325\2124\307iH\330z\350\335\313\301\330\214\215s\347@f\027\262W\304=\351\216\376I\312,\206U\226\002\323g%\310\273E\362(\3603%\350\306\252\245\306\266\025q p\2119\312\331\310\356Q/\014\365\322x\325\262(Y\252\352?~\323\017n\222\272\032\266\310\223m\\\nV\251\225\276\250\252lK\310\216\304\2616\336\210\r\033)1\371;q\272\261\3437\031\217\256\226+\243\022i[<\270\365\"\322\342\037\003hx\305\247\010n\302h\234\032a*\3145\334\247S\2774p\217\352\360\036G\240W7\212\032\251\271\354\316\253\214{\350\261|K\276\203\220\337\314\300\333\262i^a\312\224\024\0323V\022\227\004\373/7\226\230\335RP\3372a\261\340[\221\303\330\321EW\255\372\323\300\221\332\247M\230\324\262\212H\231\202 \203\230\010bh\225[\346\221\215'%\025%\033\361J\351\235\200\312\002\2439\350h\306\364R\3048S\213e%\202\335\213-\247\006V#\005cs\263\223\253\221WB\320_\256\261\327\345\337\361\335\251\311_CDZi\322M\036\351\252\r\250\316[!$\370\345-\023\335\341D\202\n\321\211\245\314N\027\253\236\177\ng\240\210f\303d\311\344\250\024\351\364a\214\257\021\r\337a\371\322>\013\001]\030Dc\336\251h>>{\344(\235\030\273\003\245\227\316\277\365w\331+\257E\231\030p\222\207\335\\\342\204dh\242\221\330KUs\310=Q\tx\351\360\000\000~\376.\344\212p\241 \305l\207T";
    PyObject *data = __Pyx_DecompressString(cstring, 1138, 2);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #elif (CYTHON_COMPRESS_STRINGS) != 0 /* compression: zlib (1013 bytes) */
const char* const cstring = "x\332\215U\315n\333F\020\336\000F\241 *\342\240\006r\350!6\212\002M\016\016\334\032N\203\006\010\334Dv\215&\262]\313\016r\032\254\310\241\2645\271K\355.-1\247\034{\344\221G\035\375\010~\014\037u\364\243t\226+Q\226c7\025\304Y\356\314\354\374|3;|\275\036\n\303\2731\242t\264\027\364\360\014\245]\007\020\tO\205\361\354\320\350\340\271\227<\257\004\353i\276\303E\234i\334\325t4F\273\367\236\247\3569\226J\207\2501\\\330\254\203\222\240\321d\261\275\301\327\231\0048\310G\364\274\025\201\2056\216\354_\030\035!y\351+\215\307\262\2532\031\036f\230!\000\217c\"&\227\201P\353\201\322*\263B\242\tb\242 $X\315\003\354\362\340\024 t\326\000q\024\270\177j\205\222Q&\003\000O}6\263l\375\nA\225\334\214I\266\343\3364\275J\000\226\233Sr\023\342\310\341\223*m\3535\000\036\004H\321\t)\210\013\302@\035\237\260\230\270\307\020\321\016\317X\271\010\023N\021\023\035\031\361\211rKT\230\305\264\002H\236\370\225\260\230\322\032\276T\245\000)\341\025Py\234\222{?\263\316\252\333\r2\036\373\343\003\207\230\346TB\250\001\200\033{\315\207\204\334\251+\202\3018\0020\224\251?No!F\234<\322{\254\254\241%\345Ci2J\323\230(\243T-\032\222\236\3618\303\212\030\370$\322\024\303\203|\277\3737\006v\365\031\233\376\366$)\210\260\323\327\310\303c\203-\255\225f\357\224J[#aYG$HP1x\177\374\256\263\307\340\270}\324\3520\212\304\2123$\367\210)K\224TVI\021\260*\016Je\270\340\347 \357\344)\316\031BZ\366\273\003Z\310\336\321P\330\240\277\237Y\357\267GY\252J\321\260\241\306\210A7\213\"\324\014\022L\224\316\317\004\016\031\\+\275\253\360\027i\325A\267\225D\026fI:o?\026+\036^\333j_\211\005\013\037\220\237\376\211U\327S)\270\316Y\037yJ\365\365kf\372\327\324\301V\320Q><^\260\342\322|\243d\220iMM\353\0055\300\320\336o\267\230\311\315\327\263qv\246U\362hy\013\267\027\256N\335!\351#\003\021\222\377\005h\277\352\363N\257\265\375V\222\332\234\301N\026\307\014\034,\"\312\375\213\303\tf@\375\037W\365\317\371d\306\352\214\204\376\372P\300\2605\035\001\033/\352aP\333\004*n\222C\305v\366v['\255v\007\336\354\267w\366v\331l\002V\235\374_""\311\314\355\371\031\301\374\215\242\233\034\307\256K\314B\225ov\224C\266\237u!\210\2711L\0149y\273\275\313\\\301\335\035'7\221\2526t6\322t\255Yu\312\267\374\301\307\203\217\267\340\306(\034I\203\214\206>\030\313i\262Ui\263\351&PIJ\352$\254\330s\224\177\272\033\321\315\305\361\n\323/\307\352\263\247l>\220>o_5\232\227\315\037\306\033\223\306r\261TlO\032\337\025\233\305\300\357v\312\265I\343q1\270j<\370g\253X)N\312_\312\356xi\374\366\374\336\244\371\270\260\345\253\361`\322\374\276\334p\n\277\026\277\225|\322\\.\276)\302r\255\334\274|\362\362\342\321\305\332\325\227\034R\336XP|}1\370L\236\357O\232\3369\311\032\345R\271=Y^)\366)4Z\376(\267\313\223\361\326\371\312\371\241\023?(7H\334xx\371pu|o\316h~\353\334\335/\037y\023\225\244\351\370\313\227\313?\216\017\357\004\353\347\227s\260\352\332\244Z\320\367\203F\241\201z\222\315\272\356\203\260}7G\251\002\324\330S\213\346T\244\364\001\244\366\"\345\247\254\356\035\021\021\324\302\320\335\234q\244\342\272g\376\005\306\252\375w";
    PyObject *data = __Pyx_DecompressString(cstring, 1013, 1);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #else /* compression: none (2054 bytes) */
const char* const bytes = "?.disableenablegcgevent.__imapisenabledsrc/gevent/_imap.pyFailureGreenletIMapIMapUnorderedIMapUnordered._on_resultIMapUnordered._run__Pyx_PyDict_NextRefSemaphoreUnboundQueue__all__asyncio.coroutinescline_in_traceback__dict__eexcexceptionfunc__func__geventgevent._gevent_c_imapgevent._utilgreenlet_imap_task_index__import__import_c_accel__init___is_coroutineitemitemsiterablelock__main__maxsize__module____name____next__next_on_resultpop__pyx_capi____pyx_vtable____qualname__queueraise_exception_raise_exceptionrawlink_runself__set_name__setdefault__slots__spawnsuccessful__test__valuevalues_zippedPyObject *\000\000\000\000\000\000\000\000InvalidThreadUseError\000LoopExit\000Timeout\000_MULTI\000_UNSET\000_native_sleep\000monotonic\000spawn_rawPyObject *\000\000\000PyTypeObject *\000\000int\000BlockingSwitchOutError\000get_objects\000wref\000_buffer\000_memoryview\000_greenlet_importedPyObject *\000\000\000\000\000Timeout\000_None\000dump_traceback\000load_traceback\000reraisePyObject *\000\000\000WeakKeyDictionary\000heappop\000heappushPyObject *\000_threadlocalPyObject *\000\000\000int\000ConcurrentObjectUseError\000_NONE\000sys\000_greenlet_importedPyObject *\000\000\000\000\000int\000InvalidSwitchError\000InvalidThreadUseError\000Timeout\000_get_thread_ident\000get_objects\000_greenlet_importedPyObject *\000\000\000\000\000\000\000int\000InvalidSwitchError\000Timeout\000_Empty\000_Full\000_heapify\000_heappop\000_heappush\000_greenlet_importedPyObject *\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000int\000\000struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *\000\000GEVENT_CONFIG\000GreenletExit\000InvalidSwitchError\000Timeout\000_greenlet__init__\000_spawn_callbacks\000_threadlocal\000dump_traceback\000get_hub_class\000iwait\000load_traceback\000reraise\000sys_exc_info\000sys_getframe\000wait\000wref\000_PYPY\000_greenlet_imported\000_cancelled_start_event\000_start_completed_eventPyObject *(struct __pyx_obj_6gevent_14_gevent_c_imap_Failure *"")\000_raise_exc\200A\340\010\014\320\014#\2401\330\010\020\220\004\220A\330\010\023\2204\220q\330\010\020\220\004\220F\230!\330\010\027\220q\340\010\013\2106\220\024\220V\2303\230b\240\004\240D\250\001\330\014\027\220t\230<\240q\330\014\033\2301\340\010\013\2108\220;\230a\330\014\020\220\006\220d\230!\2304\320\0379\270\021\270!\340\014\020\220\006\220d\230!\2304\320\0379\270\021\270!\340\010\013\2101\330\014\020\220\006\220d\230!\2304\320\037?\270q\200A\330\010\t\330\014\023\2204\220q\330\014\020\220\010\230\004\230A\330\020\024\220O\2401\330\020\024\220H\230A\230V\2406\250\024\250Q\330\014\020\220\013\2301\230A\330\010\017\320\017 \240\001\330\014\020\220\013\2301\230A\330\014\r\340\014\020\220\t\230\021\330\014\020\220\010\230\001\330\014\020\220\014\230A\330\014\020\320\020%\240Qstruct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *(int __pyx_skip_dispatch)\000\000get_hub_if_exists\000get_hub_noargs";
    PyObject *data = NULL;
    CYTHON_UNUSED_VAR(__Pyx_DecompressString);
    #endif
    PyObject **stringtab = __pyx_mstate->__pyx_string_tab;
    Py_ssize_t pos = 0;
    for (int i = 0; i < 65; i++) {
      Py_ssize_t bytes_length = index[i].length;
      PyObject *string = PyUnicode_DecodeUTF8(bytes + pos, bytes_length, NULL);
      if (likely(string) && i >= 8) PyUnicode_InternInPlace(&string);
      if (unlikely(!string)) {
        Py_XDECREF(data);
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
      stringtab[i] = string;
      pos += bytes_length;
    }
    for (int i = 65; i < 78; i++) {
      Py_ssize_t bytes_length = index[i].length;
      PyObject *string = PyBytes_FromStringAndSize(bytes + pos, bytes_length);
      stringtab[i] = string;
      pos += bytes_length;
      if (unlikely(!string)) {
        Py_XDECREF(data);
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
    }
    Py_XDECREF(data);
    for (Py_ssize_t i = 0; i < 78; i++) {
      if (unlikely(PyObject_Hash(stringtab[i]) == -1)) {
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
    }
    #if CYTHON_IMMORTAL_CONSTANTS
    {
      PyObject **table = stringtab + 65;
      for (Py_ssize_t i=0; i<13; ++i) {
        #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
        #if PY_VERSION_HEX < 0x030E0000
        if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
        #else
        if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
        #endif
        {
          Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
        }
        #else
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
        #endif
      }
    }
    #endif
  }
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: init_codeobjects ### */
typedef struct {
    unsigned int argcount : 2;
    unsigned int num_posonly_args : 1;
    unsigned int num_kwonly_args : 1;
    unsigned int nlocals : 3;
    unsigned int flags : 10;
    unsigned int first_line : 8;
} __Pyx_PyCode_New_function_description;
/* NewCodeObj.proto */
static PyObject* __Pyx_PyCode_New(
        const __Pyx_PyCode_New_function_description descr,
        PyObject * const *varnames,
        PyObject *filename,
        PyObject *funcname,
        PyObject *line_table,
        PyObject *tuple_dedup_map
);


static int __Pyx_CreateCodeObjects(__pyx_mstatetype *__pyx_mstate) {
  PyObject* tuple_dedup_map = PyDict_New();
  if (unlikely(!tuple_dedup_map)) return -1;
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 124};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_func, __pyx_mstate->__pyx_n_u_item, __pyx_mstate->__pyx_n_u_e};
    __pyx_mstate_global->__pyx_codeobj_tab[0] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent__imap_py, __pyx_mstate->__pyx_n_u_run, __pyx_mstate->__pyx_kp_b_iso88591_A_4q_A_O1_HAV6_Q_1A_1A_A_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[0])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 140};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_greenlet};
    __pyx_mstate_global->__pyx_codeobj_tab[1] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent__imap_py, __pyx_mstate->__pyx_n_u_on_result, __pyx_mstate->__pyx_kp_b_iso88591_A_1_A_4q_F_q_6_V3b_D_t_q_1_8_a_d, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[1])) goto bad;
  }
  Py_DECREF(tuple_dedup_map);
  return 0;
  bad:
  Py_DECREF(tuple_dedup_map);
  return -1;
}
/* #### Code section: init_globals ### */

static int __Pyx_InitGlobals(void) {
  /* PythonCompatibility.init */
  if (likely(__Pyx_init_co_variables() == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CommonTypesMetaclass.init */
  if (likely(__pyx_CommonTypesMetaclass_init(__pyx_m) == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CachedMethodType.init */
  #if CYTHON_COMPILING_IN_LIMITED_API
  {
      PyObject *typesModule=NULL;
      typesModule = PyImport_ImportModule("types");
      if (typesModule) {
          __pyx_mstate_global->__Pyx_CachedMethodType = PyObject_GetAttrString(typesModule, "MethodType");
          Py_DECREF(typesModule);
      }
  } // error handling follows
  #endif
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CythonFunctionShared.init */
  if (likely(__pyx_CyFunction_init(__pyx_m) == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cleanup_globals ### */
/* #### Code section: cleanup_module ### */
/* #### Code section: main_method ### */
/* #### Code section: utility_code_pragmas ### */
#ifdef _MSC_VER
#pragma warning( push )
/* Warning 4127: conditional expression is constant
 * Cython uses constant conditional expressions to allow in inline functions to be optimized at
 * compile-time, so this warning is not useful
 */
#pragma warning( disable : 4127 )
#endif



/* #### Code section: utility_code_def ### */

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyErrExceptionMatches (used by PyObjectGetAttrStrNoError) */
#include "src/gevent/_generated_include/PyErrExceptionMatches_impl_7b4f377310190df92a521563db80ecc2f42d95506fc867b739186a972ce9c8f6.h"
/* PyErrFetchRestore (used by PyObjectGetAttrStrNoError) */
#include "src/gevent/_generated_include/PyErrFetchRestore_impl_83072c493b1583a48ff3aad9f8dc7ade3be268831a2ab8ada440fe395cf916ad.h"
/* PyObjectGetAttrStr (used by PyObjectGetAttrStrNoError) */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* PyObjectGetAttrStrNoError (used by GetBuiltinName) */
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
static void __Pyx_PyObject_GetAttrStr_ClearAttributeError(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (likely(__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        __Pyx_PyErr_Clear();
}
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name) {
    PyObject *result;
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    (void) PyObject_GetOptionalAttr(obj, attr_name, &result);
    return result;
#else
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_TYPE_SLOTS
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro == PyObject_GenericGetAttr)) {
        return _PyObject_GenericGetAttrWithDict(obj, attr_name, NULL, 1);
    }
#endif
    result = __Pyx_PyObject_GetAttrStr(obj, attr_name);
    if (unlikely(!result)) {
        __Pyx_PyObject_GetAttrStr_ClearAttributeError();
    }
    return result;
#endif
}

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStrNoError(__pyx_mstate_global->__pyx_b, name);
    if (unlikely(!result) && !PyErr_Occurred()) {
        PyErr_Format(PyExc_NameError,
            "name '%U' is not defined", name);
    }
    return result;
}

/* ExtTypeTest */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type) {
    __Pyx_TypeName obj_type_name;
    __Pyx_TypeName type_name;
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (likely(__Pyx_TypeCheck(obj, type)))
        return 1;
    obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    type_name = __Pyx_PyType_GetFullyQualifiedName(type);
    PyErr_Format(PyExc_TypeError,
                 "Cannot convert " __Pyx_FMT_TYPENAME " to " __Pyx_FMT_TYPENAME,
                 obj_type_name, type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    __Pyx_DECREF_TypeName(type_name);
    return 0;
}

/* TupleAndListFromArray (used by fastcall) */
#include "src/gevent/_generated_include/TupleAndListFromArray_impl_d69ed499f68cd42feaee4b5942c18d0f8efd9989393e455f897298c58b9fa8dd.h"
/* BytesEquals (used by UnicodeEquals) */
#include "src/gevent/_generated_include/BytesEquals_impl_d48b3ef06490e9921f32936be4dcafdc3250ac7ef2252e904b8f20e24a665cc0.h"
/* UnicodeEquals (used by fastcall) */
#include "src/gevent/_generated_include/UnicodeEquals_impl_836cabebedcde255d7b2e14d2d3ec8ae093224d9992c111dd33f6f1ba2aecbef.h"
/* fastcall */
#include "src/gevent/_generated_include/fastcall_impl_2d371982e998467e5c3fa3d5d125a44afb3a07b23828be3d6b5d120f6be5ca37.h"
/* PyObjectCall (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = Py_TYPE(func)->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallMethO (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = __Pyx_CyOrPyCFunction_GET_FUNCTION(func);
    self = __Pyx_CyOrPyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectFastCall (used by PyObjectCallOneArg) */
#include "src/gevent/_generated_include/PyObjectFastCall_impl_49781168209ae59e1c56f88d63362765f980ea90cc34bbbe49d64735688b114b.h"
/* PyObjectCallOneArg (used by CallUnboundCMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *args[2] = {NULL, arg};
    return __Pyx_PyObject_FastCall(func, args+1, 1 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* UnpackUnboundCMethod (used by CallUnboundCMethod0) */
#include "src/gevent/_generated_include/UnpackUnboundCMethod_impl_73fbc94f885e37a7810c861231fd30d7a9eae7cde8890c6786a4ce1f346a7810.h"
/* CallUnboundCMethod0 */
#include "src/gevent/_generated_include/CallUnboundCMethod0_impl_506503ba83409bc78d50e6c2a64d54ddd95a836cba396a015c59c17bbf915db5.h"
/* py_dict_items (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Items(PyObject* d) {
    return __Pyx_CallUnboundCMethod0(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_items, d);
}

/* py_dict_values (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Values(PyObject* d) {
    return __Pyx_CallUnboundCMethod0(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_values, d);
}

/* OwnedDictNext (used by ParseKeywordsImpl) */
#if CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, PyObject **ppos, PyObject **pkey, PyObject **pvalue) {
    PyObject *next = NULL;
    if (!*ppos) {
        if (pvalue) {
            PyObject *dictview = pkey ? __Pyx_PyDict_Items(p) : __Pyx_PyDict_Values(p);
            if (unlikely(!dictview)) goto bad;
            *ppos = PyObject_GetIter(dictview);
            Py_DECREF(dictview);
        } else {
            *ppos = PyObject_GetIter(p);
        }
        if (unlikely(!*ppos)) goto bad;
    }
    next = PyIter_Next(*ppos);
    if (!next) {
        if (PyErr_Occurred()) goto bad;
        return 0;
    }
    if (pkey && pvalue) {
        *pkey = __Pyx_PySequence_ITEM(next, 0);
        if (unlikely(*pkey)) goto bad;
        *pvalue = __Pyx_PySequence_ITEM(next, 1);
        if (unlikely(*pvalue)) goto bad;
        Py_DECREF(next);
    } else if (pkey) {
        *pkey = next;
    } else {
        assert(pvalue);
        *pvalue = next;
    }
    return 1;
  bad:
    Py_XDECREF(next);
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d0000
    PyErr_FormatUnraisable("Exception ignored in __Pyx_PyDict_NextRef");
#else
    PyErr_WriteUnraisable(__pyx_mstate_global->__pyx_n_u_Pyx_PyDict_NextRef);
#endif
    if (pkey) *pkey = NULL;
    if (pvalue) *pvalue = NULL;
    return 0;
}
#else // !CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, Py_ssize_t *ppos, PyObject **pkey, PyObject **pvalue) {
    int result = PyDict_Next(p, ppos, pkey, pvalue);
    if (likely(result == 1)) {
        if (pkey) Py_INCREF(*pkey);
        if (pvalue) Py_INCREF(*pvalue);
    }
    return result;
}
#endif

/* RaiseDoubleKeywords (used by ParseKeywordsImpl) */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
}

/* CallUnboundCMethod2 */
#include "src/gevent/_generated_include/CallUnboundCMethod2_impl_15aa7f0a5154a4d6051e84dd189b6dc929e7450de4be5cb5e9cc003766aec24d.h"
/* ParseKeywordsImpl (used by ParseKeywords) */
static int __Pyx_ValidateDuplicatePosArgs(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    const char* function_name)
{
    PyObject ** const *name = argnames;
    while (name != first_kw_arg) {
        PyObject *key = **name;
        int found = PyDict_Contains(kwds, key);
        if (unlikely(found)) {
            if (found == 1) __Pyx_RaiseDoubleKeywordsError(function_name, key);
            goto bad;
        }
        name++;
    }
    return 0;
bad:
    return -1;
}
#if CYTHON_USE_UNICODE_INTERNALS
static CYTHON_INLINE int __Pyx_UnicodeKeywordsEqual(PyObject *s1, PyObject *s2) {
    int kind;
    Py_ssize_t len = PyUnicode_GET_LENGTH(s1);
    if (len != PyUnicode_GET_LENGTH(s2)) return 0;
    kind = PyUnicode_KIND(s1);
    if (kind != PyUnicode_KIND(s2)) return 0;
    const void *data1 = PyUnicode_DATA(s1);
    const void *data2 = PyUnicode_DATA(s2);
    return (memcmp(data1, data2, (size_t) len * (size_t) kind) == 0);
}
#endif
static int __Pyx_MatchKeywordArg_str(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    PyObject ** const *name;
    #if CYTHON_USE_UNICODE_INTERNALS
    Py_hash_t key_hash = ((PyASCIIObject*)key)->hash;
    if (unlikely(key_hash == -1)) {
        key_hash = PyObject_Hash(key);
        if (unlikely(key_hash == -1))
            goto bad;
    }
    #endif
    name = first_kw_arg;
    while (*name) {
        PyObject *name_str = **name;
        #if CYTHON_USE_UNICODE_INTERNALS
        if (key_hash == ((PyASCIIObject*)name_str)->hash && __Pyx_UnicodeKeywordsEqual(name_str, key)) {
            *index_found = (size_t) (name - argnames);
            return 1;
        }
        #else
        #if CYTHON_ASSUME_SAFE_SIZE
        if (PyUnicode_GET_LENGTH(name_str) == PyUnicode_GET_LENGTH(key))
        #endif
        {
            int cmp = PyUnicode_Compare(name_str, key);
            if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
            if (cmp == 0) {
                *index_found = (size_t) (name - argnames);
                return 1;
            }
        }
        #endif
        name++;
    }
    name = argnames;
    while (name != first_kw_arg) {
        PyObject *name_str = **name;
        #if CYTHON_USE_UNICODE_INTERNALS
        if (unlikely(key_hash == ((PyASCIIObject*)name_str)->hash)) {
            if (__Pyx_UnicodeKeywordsEqual(name_str, key))
                goto arg_passed_twice;
        }
        #else
        #if CYTHON_ASSUME_SAFE_SIZE
        if (PyUnicode_GET_LENGTH(name_str) == PyUnicode_GET_LENGTH(key))
        #endif
        {
            if (unlikely(name_str == key)) goto arg_passed_twice;
            int cmp = PyUnicode_Compare(name_str, key);
            if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
            if (cmp == 0) goto arg_passed_twice;
        }
        #endif
        name++;
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
bad:
    return -1;
}
static int __Pyx_MatchKeywordArg_nostr(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    PyObject ** const *name;
    if (unlikely(!PyUnicode_Check(key))) goto invalid_keyword_type;
    name = first_kw_arg;
    while (*name) {
        int cmp = PyObject_RichCompareBool(**name, key, Py_EQ);
        if (cmp == 1) {
            *index_found = (size_t) (name - argnames);
            return 1;
        }
        if (unlikely(cmp == -1)) goto bad;
        name++;
    }
    name = argnames;
    while (name != first_kw_arg) {
        int cmp = PyObject_RichCompareBool(**name, key, Py_EQ);
        if (unlikely(cmp != 0)) {
            if (cmp == 1) goto arg_passed_twice;
            else goto bad;
        }
        name++;
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
bad:
    return -1;
}
static CYTHON_INLINE int __Pyx_MatchKeywordArg(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    return likely(PyUnicode_CheckExact(key)) ?
        __Pyx_MatchKeywordArg_str(key, argnames, first_kw_arg, index_found, function_name) :
        __Pyx_MatchKeywordArg_nostr(key, argnames, first_kw_arg, index_found, function_name);
}
static void __Pyx_RejectUnknownKeyword(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    const char *function_name)
{
    #if CYTHON_AVOID_BORROWED_REFS
    PyObject *pos = NULL;
    #else
    Py_ssize_t pos = 0;
    #endif
    PyObject *key = NULL;
    __Pyx_BEGIN_CRITICAL_SECTION(kwds);
    while (
        #if CYTHON_AVOID_BORROWED_REFS
        __Pyx_PyDict_NextRef(kwds, &pos, &key, NULL)
        #else
        PyDict_Next(kwds, &pos, &key, NULL)
        #endif
    ) {
        PyObject** const *name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (!*name) {
            size_t index_found = 0;
            int cmp = __Pyx_MatchKeywordArg(key, argnames, first_kw_arg, &index_found, function_name);
            if (cmp != 1) {
                if (cmp == 0) {
                    PyErr_Format(PyExc_TypeError,
                        "%s() got an unexpected keyword argument '%U'",
                        function_name, key);
                }
                #if CYTHON_AVOID_BORROWED_REFS
                Py_DECREF(key);
                #endif
                break;
            }
        }
        #if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(key);
        #endif
    }
    __Pyx_END_CRITICAL_SECTION();
    #if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(pos);
    #endif
    assert(PyErr_Occurred());
}
static int __Pyx_ParseKeywordDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    PyObject** const *name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    Py_ssize_t extracted = 0;
#if !CYTHON_COMPILING_IN_PYPY || defined(PyArg_ValidateKeywordArguments)
    if (unlikely(!PyArg_ValidateKeywordArguments(kwds))) return -1;
#endif
    name = first_kw_arg;
    while (*name && num_kwargs > extracted) {
        PyObject * key = **name;
        PyObject *value;
        int found = 0;
        #if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
        found = PyDict_GetItemRef(kwds, key, &value);
        #else
        value = PyDict_GetItemWithError(kwds, key);
        if (value) {
            Py_INCREF(value);
            found = 1;
        } else {
            if (unlikely(PyErr_Occurred())) goto bad;
        }
        #endif
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
            extracted++;
        }
        name++;
    }
    if (num_kwargs > extracted) {
        if (ignore_unknown_kwargs) {
            if (unlikely(__Pyx_ValidateDuplicatePosArgs(kwds, argnames, first_kw_arg, function_name) == -1))
                goto bad;
        } else {
            __Pyx_RejectUnknownKeyword(kwds, argnames, first_kw_arg, function_name);
            goto bad;
        }
    }
    return 0;
bad:
    return -1;
}
static int __Pyx_ParseKeywordDictToDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject** const *name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    Py_ssize_t len;
#if !CYTHON_COMPILING_IN_PYPY || defined(PyArg_ValidateKeywordArguments)
    if (unlikely(!PyArg_ValidateKeywordArguments(kwds))) return -1;
#endif
    if (PyDict_Update(kwds2, kwds) < 0) goto bad;
    name = first_kw_arg;
    while (*name) {
        PyObject *key = **name;
        PyObject *value;
#if !CYTHON_COMPILING_IN_LIMITED_API && (PY_VERSION_HEX >= 0x030d00A2 || defined(PyDict_Pop))
        int found = PyDict_Pop(kwds2, key, &value);
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
        }
#elif __PYX_LIMITED_VERSION_HEX >= 0x030d0000
        int found = PyDict_GetItemRef(kwds2, key, &value);
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
            if (unlikely(PyDict_DelItem(kwds2, key) < 0)) goto bad;
        }
#else
    #if CYTHON_COMPILING_IN_CPYTHON
        value = _PyDict_Pop(kwds2, key, kwds2);
    #else
        value = __Pyx_CallUnboundCMethod2(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_pop, kwds2, key, kwds2);
    #endif
        if (value == kwds2) {
            Py_DECREF(value);
        } else {
            if (unlikely(!value)) goto bad;
            values[name-argnames] = value;
        }
#endif
        name++;
    }
    len = PyDict_Size(kwds2);
    if (len > 0) {
        return __Pyx_ValidateDuplicatePosArgs(kwds, argnames, first_kw_arg, function_name);
    } else if (unlikely(len == -1)) {
        goto bad;
    }
    return 0;
bad:
    return -1;
}
static int __Pyx_ParseKeywordsTuple(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    PyObject *key = NULL;
    PyObject** const * name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    for (Py_ssize_t pos = 0; pos < num_kwargs; pos++) {
#if CYTHON_AVOID_BORROWED_REFS
        key = __Pyx_PySequence_ITEM(kwds, pos);
#else
        key = __Pyx_PyTuple_GET_ITEM(kwds, pos);
#endif
#if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(!key)) goto bad;
#endif
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            PyObject *value = kwvalues[pos];
            values[name-argnames] = __Pyx_NewRef(value);
        } else {
            size_t index_found = 0;
            int cmp = __Pyx_MatchKeywordArg(key, argnames, first_kw_arg, &index_found, function_name);
            if (cmp == 1) {
                PyObject *value = kwvalues[pos];
                values[index_found] = __Pyx_NewRef(value);
            } else {
                if (unlikely(cmp == -1)) goto bad;
                if (kwds2) {
                    PyObject *value = kwvalues[pos];
                    if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
                } else if (!ignore_unknown_kwargs) {
                    goto invalid_keyword;
                }
            }
        }
        #if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(key);
        key = NULL;
        #endif
    }
    return 0;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    goto bad;
bad:
    #if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(key);
    #endif
    return -1;
}

/* ParseKeywords */
static int __Pyx_ParseKeywords(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    if (CYTHON_METH_FASTCALL && likely(PyTuple_Check(kwds)))
        return __Pyx_ParseKeywordsTuple(kwds, kwvalues, argnames, kwds2, values, num_pos_args, num_kwargs, function_name, ignore_unknown_kwargs);
    else if (kwds2)
        return __Pyx_ParseKeywordDictToDict(kwds, argnames, kwds2, values, num_pos_args, function_name);
    else
        return __Pyx_ParseKeywordDict(kwds, argnames, values, num_pos_args, num_kwargs, function_name, ignore_unknown_kwargs);
}

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* RaiseException */
#include "src/gevent/_generated_include/RaiseException_impl_5214b4470ab1cce407ca930811cfafb701053719a58763807254160af0a39f69.h"
/* PyObjectFastCallMethod */
#if !CYTHON_VECTORCALL || PY_VERSION_HEX < 0x03090000
static PyObject *__Pyx_PyObject_FastCallMethod(PyObject *name, PyObject *const *args, size_t nargsf) {
    PyObject *result;
    PyObject *attr = PyObject_GetAttr(args[0], name);
    if (unlikely(!attr))
        return NULL;
    result = __Pyx_PyObject_FastCall(attr, args+1, nargsf - 1);
    Py_DECREF(attr);
    return result;
}
#endif

/* PyObjectSetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
    return PyObject_SetAttr(obj, attr_name, value);
}
#endif

/* GetTopmostException (used by SaveResetException) */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem *
__Pyx_PyErr_GetTopmostException(PyThreadState *tstate)
{
    _PyErr_StackItem *exc_info = tstate->exc_info;
    while ((exc_info->exc_value == NULL || exc_info->exc_value == Py_None) &&
           exc_info->previous_item != NULL)
    {
        exc_info = exc_info->previous_item;
    }
    return exc_info;
}
#endif

/* SaveResetException */
#include "src/gevent/_generated_include/SaveResetException_impl_b3e76ed9bc3819093e52b1558c2bbad485040cdc5a28b71844e50bfc92f51cf0.h"
/* GetException */
#include "src/gevent/_generated_include/GetException_impl_36bcd44414c3b1ebf6a1c0f320ee2c6e2baced19353f70d825d0fd0338e3c175.h"
/* SwapException */
#include "src/gevent/_generated_include/SwapException_impl_3529c43002b85b6a88333a1994598a58e361312e8462c9c4553bcc16b799892a.h"
/* PyDictVersioning */
#include "src/gevent/_generated_include/PyDictVersioning_impl_f179ad268abce9726a76569141f76d5dcd0550225ef9a9e9f73d478d7be0c345.h"
/* GetAttr */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *o, PyObject *n) {
#if CYTHON_USE_TYPE_SLOTS
    if (likely(PyUnicode_Check(n)))
        return __Pyx_PyObject_GetAttrStr(o, n);
#endif
    return PyObject_GetAttr(o, n);
}

/* KeywordStringCheck */
#include "src/gevent/_generated_include/KeywordStringCheck_impl_ab906f68bdf90466d372bd85a39d7cf8593483145096621667739080797c0f42.h"
/* PyObjectCall2Args (used by CallUnboundCMethod1) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2) {
    PyObject *args[3] = {NULL, arg1, arg2};
    return __Pyx_PyObject_FastCall(function, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* CallUnboundCMethod1 */
#include "src/gevent/_generated_include/CallUnboundCMethod1_impl_0820fa80b637dcac9bcf44c709c1dc323f347b99ab227a86488e6c6ecf6c876e.h"
/* py_dict_pop */
static CYTHON_INLINE PyObject *__Pyx_PyDict_Pop(PyObject *d, PyObject *key, PyObject *default_value) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d00A2 || defined(PyDict_Pop)
    PyObject *value;
    if (PyDict_Pop(d, key, &value) == 0) {
        if (default_value) {
            Py_INCREF(default_value);
        } else {
            PyErr_SetObject(PyExc_KeyError, key);
        }
        value = default_value;
    }
    return value;
#elif CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000
    return _PyDict_Pop(d, key, default_value);
#else
    if (default_value) {
        return __Pyx_CallUnboundCMethod2(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_pop, d, key, default_value);
    } else {
        return __Pyx_CallUnboundCMethod1(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_pop, d, key);
    }
#endif
}

/* RaiseTooManyValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

/* RaiseNeedMoreValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%.1s to unpack",
                 index, (index == 1) ? "" : "s");
}

/* IterFinish */
static CYTHON_INLINE int __Pyx_IterFinish(void) {
    PyObject* exc_type;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    exc_type = __Pyx_PyErr_CurrentExceptionType();
    if (unlikely(exc_type)) {
        if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)))
            return -1;
        __Pyx_PyErr_Clear();
        return 0;
    }
    return 0;
}

/* UnpackItemEndCheck */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    }
    return __Pyx_IterFinish();
}

/* RaiseUnboundLocalError */
static void __Pyx_RaiseUnboundLocalError(const char *varname) {
    PyErr_Format(PyExc_UnboundLocalError, "local variable '%s' referenced before assignment", varname);
}

/* AllocateExtensionType */
static PyObject *__Pyx_AllocateExtensionType(PyTypeObject *t, int is_final) {
    if (is_final || likely(!__Pyx_PyType_HasFeature(t, Py_TPFLAGS_IS_ABSTRACT))) {
        allocfunc alloc_func = __Pyx_PyType_GetSlot(t, tp_alloc, allocfunc);
        return alloc_func(t, 0);
    } else {
        newfunc tp_new = __Pyx_PyType_TryGetSlot(&PyBaseObject_Type, tp_new, newfunc);
    #if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
        if (!tp_new) {
            PyObject *new_str = PyUnicode_FromString("__new__");
            if (likely(new_str)) {
                PyObject *o = PyObject_CallMethodObjArgs((PyObject *)&PyBaseObject_Type, new_str, t, NULL);
                Py_DECREF(new_str);
                return o;
            } else
                return NULL;
        } else
    #endif
        return tp_new(t, __pyx_mstate_global->__pyx_empty_tuple, 0);
    }
}

/* CallTypeTraverse */
#if !CYTHON_USE_TYPE_SPECS || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x03090000)
#else
static int __Pyx_call_type_traverse(PyObject *o, int always_call, visitproc visit, void *arg) {
    #if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x03090000
    if (__Pyx_get_runtime_version() < 0x03090000) return 0;
    #endif
    if (!always_call) {
        PyTypeObject *base = __Pyx_PyObject_GetSlot(o, tp_base, PyTypeObject*);
        unsigned long flags = PyType_GetFlags(base);
        if (flags & Py_TPFLAGS_HEAPTYPE) {
            return 0;
        }
    }
    Py_VISIT((PyObject*)Py_TYPE(o));
    return 0;
}
#endif

/* CallNextTpDealloc */
static void __Pyx_call_next_tp_dealloc(PyObject* obj, destructor current_tp_dealloc) {
    PyTypeObject* type = Py_TYPE(obj);
    destructor tp_dealloc = NULL;
    while (type && __Pyx_PyType_GetSlot(type, tp_dealloc, destructor) != current_tp_dealloc)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    while (type && (tp_dealloc = __Pyx_PyType_GetSlot(type, tp_dealloc, destructor)) == current_tp_dealloc)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    if (type)
        tp_dealloc(obj);
}

/* CallNextTpTraverse */
static int __Pyx_call_next_tp_traverse(PyObject* obj, visitproc v, void *a, traverseproc current_tp_traverse) {
    PyTypeObject* type = Py_TYPE(obj);
    traverseproc tp_traverse = NULL;
    while (type && __Pyx_PyType_GetSlot(type, tp_traverse, traverseproc) != current_tp_traverse)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    while (type && (tp_traverse = __Pyx_PyType_GetSlot(type, tp_traverse, traverseproc)) == current_tp_traverse)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    if (type && tp_traverse)
        return tp_traverse(obj, v, a);
    return 0;
}

/* CallNextTpClear */
static void __Pyx_call_next_tp_clear(PyObject* obj, inquiry current_tp_clear) {
    PyTypeObject* type = Py_TYPE(obj);
    inquiry tp_clear = NULL;
    while (type && __Pyx_PyType_GetSlot(type, tp_clear, inquiry) != current_tp_clear)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    while (type && (tp_clear = __Pyx_PyType_GetSlot(type, tp_clear, inquiry)) == current_tp_clear)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    if (type && tp_clear)
        tp_clear(obj);
}

/* FunctionExport */
static int __Pyx_ExportFunction(PyObject *api_dict, const char *name, void (*f)(void), const char *sig) {
    PyObject *cobj;
    union {
        void (*fp)(void);
        void *p;
    } tmp;
    tmp.fp = f;
    cobj = PyCapsule_New(tmp.p, sig, 0);
    if (!cobj)
        goto bad;
    if (PyDict_SetItemString(api_dict, name, cobj) < 0)
        goto bad;
    Py_DECREF(cobj);
    return 0;
bad:
    Py_XDECREF(cobj);
    return -1;
}

/* GetApiDict */
static PyObject *__Pyx_ApiExport_GetApiDict(void) {
    PyObject *d;
    if (__Pyx_PyDict_GetItemRef(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_pyx_capi, &d) == -1)
        return NULL;
    if (!d) {
        d = PyDict_New();
        if (!d)
            goto bad;
        if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_pyx_capi, d) < 0)
            goto bad;
    }
    return d;
bad:
    Py_XDECREF(d);
    return NULL;
}

/* LimitedApiGetTypeDict (used by SetItemOnTypeDict) */
#include "src/gevent/_generated_include/LimitedApiGetTypeDict_impl_fd5385b0b7d81c54e35b8e8be86f2a48fa376c140ad1a251d94cb50d5e2fb049.h"
/* SetItemOnTypeDict (used by FixUpExtensionType) */
static int __Pyx__SetItemOnTypeDict(PyTypeObject *tp, PyObject *k, PyObject *v) {
    int result;
    PyObject *tp_dict;
#if CYTHON_COMPILING_IN_LIMITED_API
    tp_dict = __Pyx_GetTypeDict(tp);
    if (unlikely(!tp_dict)) return -1;
#else
    tp_dict = tp->tp_dict;
#endif
    result = PyDict_SetItem(tp_dict, k, v);
    if (likely(!result)) {
        PyType_Modified(tp);
        if (unlikely(PyObject_HasAttr(v, __pyx_mstate_global->__pyx_n_u_set_name))) {
            PyObject *setNameResult = PyObject_CallMethodObjArgs(v, __pyx_mstate_global->__pyx_n_u_set_name,  (PyObject *) tp, k, NULL);
            if (!setNameResult) return -1;
            Py_DECREF(setNameResult);
        }
    }
    return result;
}

/* FixUpExtensionType */
#include "src/gevent/_generated_include/FixUpExtensionType_impl_968625585c074793d4236a363113043104c99af679f80b0b7d0ea5e03b43f419.h"
/* PyObjectCallNoArg (used by PyObjectCallMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
    PyObject *arg[2] = {NULL, NULL};
    return __Pyx_PyObject_FastCall(func, arg + 1, 0 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* PyObjectGetMethod (used by PyObjectCallMethod0) */
#include "src/gevent/_generated_include/PyObjectGetMethod_impl_e128eb9d3930413c3ed54abc40d4953c55ff9ea67a8c08ac7b5c2fd8494b6c00.h"
/* PyObjectCallMethod0 (used by PyType_Ready) */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name) {
#if CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000))
    PyObject *args[1] = {obj};
    (void) __Pyx_PyObject_CallOneArg;
    (void) __Pyx_PyObject_CallNoArg;
    return PyObject_VectorcallMethod(method_name, args, 1 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#else
    PyObject *method = NULL, *result = NULL;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_CallOneArg(method, obj);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) goto bad;
    result = __Pyx_PyObject_CallNoArg(method);
    Py_DECREF(method);
bad:
    return result;
#endif
}

/* ValidateBasesTuple (used by PyType_Ready) */
#include "src/gevent/_generated_include/ValidateBasesTuple_impl_3b9fdcb5e55f23d97a6405040c32f85cd06688a92f7d1964c3b28bc807f560c9.h"
/* PyType_Ready */
CYTHON_UNUSED static int __Pyx_PyType_HasMultipleInheritance(PyTypeObject *t) {
    while (t) {
        PyObject *bases = __Pyx_PyType_GetSlot(t, tp_bases, PyObject*);
        if (bases) {
            return 1;
        }
        t = __Pyx_PyType_GetSlot(t, tp_base, PyTypeObject*);
    }
    return 0;
}
static int __Pyx_PyType_Ready(PyTypeObject *t) {
#if CYTHON_USE_TYPE_SPECS || !CYTHON_COMPILING_IN_CPYTHON || defined(PYSTON_MAJOR_VERSION)
    (void)__Pyx_PyObject_CallMethod0;
#if CYTHON_USE_TYPE_SPECS
    (void)__Pyx_validate_bases_tuple;
#endif
    return PyType_Ready(t);
#else
    int r;
    if (!__Pyx_PyType_HasMultipleInheritance(t)) {
        return PyType_Ready(t);
    }
    PyObject *bases = __Pyx_PyType_GetSlot(t, tp_bases, PyObject*);
    if (bases && unlikely(__Pyx_validate_bases_tuple(t->tp_name, t->tp_dictoffset, bases) == -1))
        return -1;
#if !defined(PYSTON_MAJOR_VERSION)
    {
        int gc_was_enabled;
    #if PY_VERSION_HEX >= 0x030A00b1
        gc_was_enabled = PyGC_Disable();
        (void)__Pyx_PyObject_CallMethod0;
    #else
        PyObject *ret, *py_status;
        PyObject *gc = NULL;
        #if (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM+0 >= 0x07030400) &&\
                !CYTHON_COMPILING_IN_GRAAL
        gc = PyImport_GetModule(__pyx_mstate_global->__pyx_kp_u_gc);
        #endif
        if (unlikely(!gc)) gc = PyImport_Import(__pyx_mstate_global->__pyx_kp_u_gc);
        if (unlikely(!gc)) return -1;
        py_status = __Pyx_PyObject_CallMethod0(gc, __pyx_mstate_global->__pyx_kp_u_isenabled);
        if (unlikely(!py_status)) {
            Py_DECREF(gc);
            return -1;
        }
        gc_was_enabled = __Pyx_PyObject_IsTrue(py_status);
        Py_DECREF(py_status);
        if (gc_was_enabled > 0) {
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_mstate_global->__pyx_kp_u_disable);
            if (unlikely(!ret)) {
                Py_DECREF(gc);
                return -1;
            }
            Py_DECREF(ret);
        } else if (unlikely(gc_was_enabled == -1)) {
            Py_DECREF(gc);
            return -1;
        }
    #endif
        t->tp_flags |= Py_TPFLAGS_HEAPTYPE;
#if PY_VERSION_HEX >= 0x030A0000
        t->tp_flags |= Py_TPFLAGS_IMMUTABLETYPE;
#endif
#else
        (void)__Pyx_PyObject_CallMethod0;
#endif
    r = PyType_Ready(t);
#if !defined(PYSTON_MAJOR_VERSION)
        t->tp_flags &= ~Py_TPFLAGS_HEAPTYPE;
    #if PY_VERSION_HEX >= 0x030A00b1
        if (gc_was_enabled)
            PyGC_Enable();
    #else
        if (gc_was_enabled) {
            PyObject *tp, *v, *tb;
            PyErr_Fetch(&tp, &v, &tb);
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_mstate_global->__pyx_kp_u_enable);
            if (likely(ret || r == -1)) {
                Py_XDECREF(ret);
                PyErr_Restore(tp, v, tb);
            } else {
                Py_XDECREF(tp);
                Py_XDECREF(v);
                Py_XDECREF(tb);
                r = -1;
            }
        }
        Py_DECREF(gc);
    #endif
    }
#endif
    return r;
#endif
}

/* TypeImport */
#include "src/gevent/_generated_include/TypeImport_impl_e30d056ae329ba5e94fee4709e4266a267c585bd5c229f7cd6121597afbfaa4e.h"
/* GetVTable */
static void* __Pyx_GetVtable(PyTypeObject *type) {
    void* ptr;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *ob = PyObject_GetAttr((PyObject *)type, __pyx_mstate_global->__pyx_n_u_pyx_vtable);
#else
    PyObject *ob = PyObject_GetItem(type->tp_dict, __pyx_mstate_global->__pyx_n_u_pyx_vtable);
#endif
    if (!ob)
        goto bad;
    ptr = PyCapsule_GetPointer(ob, 0);
    if (!ptr && !PyErr_Occurred())
        PyErr_SetString(PyExc_RuntimeError, "invalid vtable found for imported type");
    Py_DECREF(ob);
    return ptr;
bad:
    Py_XDECREF(ob);
    return NULL;
}

/* FormatTypeName (used by ValidateExternBase) */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030d0000
static __Pyx_TypeName
__Pyx_PyType_GetFullyQualifiedName(PyTypeObject* tp)
{
    PyObject *module = NULL, *name = NULL, *result = NULL;
    #if __PYX_LIMITED_VERSION_HEX < 0x030b0000
    name = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_mstate_global->__pyx_n_u_qualname);
    #else
    name = PyType_GetQualName(tp);
    #endif
    if (unlikely(name == NULL) || unlikely(!PyUnicode_Check(name))) goto bad;
    module = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_mstate_global->__pyx_n_u_module);
    if (unlikely(module == NULL) || unlikely(!PyUnicode_Check(module))) goto bad;
    if (PyUnicode_CompareWithASCIIString(module, "builtins") == 0) {
        result = name;
        name = NULL;
        goto done;
    }
    result = PyUnicode_FromFormat("%U.%U", module, name);
    if (unlikely(result == NULL)) goto bad;
  done:
    Py_XDECREF(name);
    Py_XDECREF(module);
    return result;
  bad:
    PyErr_Clear();
    if (name) {
        result = name;
        name = NULL;
    } else {
        result = __Pyx_NewRef(__pyx_mstate_global->__pyx_kp_u_);
    }
    goto done;
}
#endif

/* ValidateExternBase */
static int __Pyx_validate_extern_base(PyTypeObject *base) {
    Py_ssize_t itemsize;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_itemsize;
#endif
#if !CYTHON_COMPILING_IN_LIMITED_API
    itemsize = ((PyTypeObject *)base)->tp_itemsize;
#else
    py_itemsize = PyObject_GetAttrString((PyObject*)base, "__itemsize__");
    if (!py_itemsize)
        return -1;
    itemsize = PyLong_AsSsize_t(py_itemsize);
    Py_DECREF(py_itemsize);
    py_itemsize = 0;
    if (itemsize == (Py_ssize_t)-1 && PyErr_Occurred())
        return -1;
#endif
    if (itemsize) {
        __Pyx_TypeName b_name = __Pyx_PyType_GetFullyQualifiedName(base);
        PyErr_Format(PyExc_TypeError,
                "inheritance from PyVarObject types like '" __Pyx_FMT_TYPENAME "' not currently supported", b_name);
        __Pyx_DECREF_TypeName(b_name);
        return -1;
    }
    return 0;
}

/* SetVTable */
static int __Pyx_SetVtable(PyTypeObject *type, void *vtable) {
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
    if (unlikely(!ob))
        goto bad;
#if CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(PyObject_SetAttr((PyObject *) type, __pyx_mstate_global->__pyx_n_u_pyx_vtable, ob) < 0))
#else
    if (unlikely(PyDict_SetItem(type->tp_dict, __pyx_mstate_global->__pyx_n_u_pyx_vtable, ob) < 0))
#endif
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

/* MergeVTables */
#include "src/gevent/_generated_include/MergeVTables_impl_cc0b823a0ed067bdca31ab6afca82ec940b10d68e9ecebbaec0a3d49b6244e8c.h"
/* PxdImportShared (used by VoidPtrImport) */
#include "src/gevent/_generated_include/PxdImportShared_impl_df92e4b607edac2b8480e2c8668970e8115d694234fa83cf1c26cb7dc602ab00.h"
/* VoidPtrImport */
#ifndef __PYX_HAVE_RT_ImportVoidPtr_3_2_4
#define __PYX_HAVE_RT_ImportVoidPtr_3_2_4
static int __Pyx_ImportVoidPtr_3_2_4(PyObject *module, const char *name, void **p, const char *sig) {
    return __Pyx_ImportFromPxd_3_2_4(module, name, p, sig, "variable");
}
#endif

/* FunctionImport */
#ifndef __PYX_HAVE_RT_ImportFunction_3_2_4
#define __PYX_HAVE_RT_ImportFunction_3_2_4
static int __Pyx_ImportFunction_3_2_4(PyObject *module, const char *funcname, void (**f)(void), const char *sig) {
    union {
        void (*fp)(void);
        void *p;
    } tmp;
    int result = __Pyx_ImportFromPxd_3_2_4(module, funcname, &tmp.p, sig, "function");
    if (result == 0) {
        *f = tmp.fp;
    }
    return result;
}
#endif

/* HasAttr (used by ImportImpl) */
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *o, PyObject *n) {
    PyObject *r;
    if (unlikely(!PyUnicode_Check(n))) {
        PyErr_SetString(PyExc_TypeError,
                        "hasattr(): attribute name must be string");
        return -1;
    }
    r = __Pyx_PyObject_GetAttrStrNoError(o, n);
    if (!r) {
        return (unlikely(PyErr_Occurred())) ? -1 : 0;
    } else {
        Py_DECREF(r);
        return 1;
    }
}
#endif

/* ImportImpl (used by Import) */
#include "src/gevent/_generated_include/ImportImpl_impl_54add44d3961eb3adfb567f9d1292a4ce092acafbf7b2d11f026c8e90ea281d3.h"
/* Import */
static PyObject *__Pyx_Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, int level) {
    return __Pyx__Import(name, imported_names, len_imported_names, qualname, __pyx_mstate_global->__pyx_d, level);
}

/* ImportFrom */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        const char* module_name_str = 0;
        PyObject* module_name = 0;
        PyObject* module_dot = 0;
        PyObject* full_name = 0;
        PyErr_Clear();
        module_name_str = PyModule_GetName(module);
        if (unlikely(!module_name_str)) { goto modbad; }
        module_name = PyUnicode_FromString(module_name_str);
        if (unlikely(!module_name)) { goto modbad; }
        module_dot = PyUnicode_Concat(module_name, __pyx_mstate_global->__pyx_kp_u__2);
        if (unlikely(!module_dot)) { goto modbad; }
        full_name = PyUnicode_Concat(module_dot, name);
        if (unlikely(!full_name)) { goto modbad; }
        #if (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM  < 0x07030400) ||\
                CYTHON_COMPILING_IN_GRAAL
        {
            PyObject *modules = PyImport_GetModuleDict();
            if (unlikely(!modules))
                goto modbad;
            value = PyObject_GetItem(modules, full_name);
        }
        #else
        value = PyImport_GetModule(full_name);
        #endif
      modbad:
        Py_XDECREF(full_name);
        Py_XDECREF(module_dot);
        Py_XDECREF(module_name);
    }
    if (unlikely(!value)) {
        PyErr_Format(PyExc_ImportError, "cannot import name %S", name);
    }
    return value;
}

/* ListPack */
static PyObject *__Pyx_PyList_Pack(Py_ssize_t n, ...) {
    va_list va;
    PyObject *l = PyList_New(n);
    va_start(va, n);
    if (unlikely(!l)) goto end;
    for (Py_ssize_t i=0; i<n; ++i) {
        PyObject *arg = va_arg(va, PyObject*);
        Py_INCREF(arg);
        if (__Pyx_PyList_SET_ITEM(l, i, arg) != (0)) {
            Py_CLEAR(l);
            goto end;
        }
    }
    end:
    va_end(va);
    return l;
}

/* GetModuleGlobalName */
#include "src/gevent/_generated_include/GetModuleGlobalName_impl_b2394fa294c641220c991c48f5c953347ba392e1233755a6228b28d5e679fef0.h"
/* GetNameInClass */
static PyObject *__Pyx__GetNameInClass(PyObject *nmspace, PyObject *name) {
    PyObject *result;
    PyObject *dict;
    assert(PyType_Check(nmspace));
#if CYTHON_USE_TYPE_SLOTS
    dict = ((PyTypeObject*)nmspace)->tp_dict;
    Py_XINCREF(dict);
#else
    dict = PyObject_GetAttr(nmspace, __pyx_mstate_global->__pyx_n_u_dict);
#endif
    if (likely(dict)) {
        result = PyObject_GetItem(dict, name);
        Py_DECREF(dict);
        if (result) {
            return result;
        }
    }
    PyErr_Clear();
    __Pyx_GetModuleGlobalNameUncached(result, name);
    return result;
}

/* dict_setdefault (used by FetchCommonType) */
static CYTHON_INLINE PyObject *__Pyx_PyDict_SetDefault(PyObject *d, PyObject *key, PyObject *default_value) {
    PyObject* value;
#if __PYX_LIMITED_VERSION_HEX >= 0x030F0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4)
    PyDict_SetDefaultRef(d, key, default_value, &value);
#elif CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX >= 0x030C0000
    PyObject *args[] = {d, key, default_value};
    value = PyObject_VectorcallMethod(__pyx_mstate_global->__pyx_n_u_setdefault, args, 3 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#elif CYTHON_COMPILING_IN_LIMITED_API
    value = PyObject_CallMethodObjArgs(d, __pyx_mstate_global->__pyx_n_u_setdefault, key, default_value, NULL);
#else
    value = PyDict_SetDefault(d, key, default_value);
    if (unlikely(!value)) return NULL;
    Py_INCREF(value);
#endif
    return value;
}

/* AddModuleRef (used by FetchSharedCythonModule) */
#include "src/gevent/_generated_include/AddModuleRef_impl_59efe7a55c2d1acdb632a2a6953f1ce31c634c9f98f262a8d338db6996845385.h"
/* FetchSharedCythonModule (used by FetchCommonType) */
static PyObject *__Pyx_FetchSharedCythonABIModule(void) {
    return __Pyx_PyImport_AddModuleRef(__PYX_ABI_MODULE_NAME);
}

/* FetchCommonType (used by CommonTypesMetaclass) */
#include "src/gevent/_generated_include/FetchCommonType_impl_8ddf5d6e0d45314935e4d87502d7fa32ec8f3d50d91ca9715a35d7f0fc2dda28.h"
/* CommonTypesMetaclass (used by CythonFunctionShared) */
#include "src/gevent/_generated_include/CommonTypesMetaclass_impl_5345023feb7cb35c8a99997be95973c1bfc904b959ef880ae7125f77d296af2b.h"
/* PyMethodNew (used by CythonFunctionShared) */
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    PyObject *result;
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    #if __PYX_LIMITED_VERSION_HEX >= 0x030C0000
    {
        PyObject *args[] = {func, self};
        result = PyObject_Vectorcall(__pyx_mstate_global->__Pyx_CachedMethodType, args, 2, NULL);
    }
    #else
    result = PyObject_CallFunctionObjArgs(__pyx_mstate_global->__Pyx_CachedMethodType, func, self, NULL);
    #endif
    return result;
}
#else
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    return PyMethod_New(func, self);
}
#endif

/* PyVectorcallFastCallDict (used by CythonFunctionShared) */
#include "src/gevent/_generated_include/PyVectorcallFastCallDict_impl_3616dfa798c1c336b0933a7ec9d88cb291d491f6315b48f846f69828df4619eb.h"
/* CythonFunctionShared (used by CythonFunction) */
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunctionNoMethod(PyObject *func, void (*cfunc)(void)) {
    if (__Pyx_CyFunction_Check(func)) {
        return PyCFunction_GetFunction(((__pyx_CyFunctionObject*)func)->func) == (PyCFunction) cfunc;
    } else if (PyCFunction_Check(func)) {
        return PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void (*cfunc)(void)) {
    if ((PyObject*)Py_TYPE(func) == __pyx_mstate_global->__Pyx_CachedMethodType) {
        int result;
        PyObject *newFunc = PyObject_GetAttr(func, __pyx_mstate_global->__pyx_n_u_func_2);
        if (unlikely(!newFunc)) {
            PyErr_Clear(); // It's only an optimization, so don't throw an error
            return 0;
        }
        result = __Pyx__IsSameCyOrCFunctionNoMethod(newFunc, cfunc);
        Py_DECREF(newFunc);
        return result;
    }
    return __Pyx__IsSameCyOrCFunctionNoMethod(func, cfunc);
}
#else
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void (*cfunc)(void)) {
    if (PyMethod_Check(func)) {
        func = PyMethod_GET_FUNCTION(func);
    }
    return __Pyx_CyOrPyCFunction_Check(func) && __Pyx_CyOrPyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
}
#endif
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj) {
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    __Pyx_Py_XDECREF_SET(
        __Pyx_CyFunction_GetClassObj(f),
            ((classobj) ? __Pyx_NewRef(classobj) : NULL));
#else
    __Pyx_Py_XDECREF_SET(
        ((PyCMethodObject *) (f))->mm_class,
        (PyTypeObject*)((classobj) ? __Pyx_NewRef(classobj) : NULL));
#endif
}
static PyObject *
__Pyx_CyFunction_get_doc_locked(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_doc == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_doc = PyObject_GetAttrString(op->func, "__doc__");
        if (unlikely(!op->func_doc)) return NULL;
#else
        if (((PyCFunctionObject*)op)->m_ml->ml_doc) {
            op->func_doc = PyUnicode_FromString(((PyCFunctionObject*)op)->m_ml->ml_doc);
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
#endif
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, void *closure) {
    PyObject *result;
    CYTHON_UNUSED_VAR(closure);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_doc_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (value == NULL) {
        value = Py_None;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_doc, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name_locked(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_name == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_name = PyObject_GetAttrString(op->func, "__name__");
#else
        op->func_name = PyUnicode_InternFromString(((PyCFunctionObject*)op)->m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op, void *context)
{
    PyObject *result = NULL;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_name_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_name, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    PyObject *result;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    Py_INCREF(op->func_qualname);
    result = op->func_qualname;
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_qualname, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
#endif
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(op);
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op, void *context)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    int result = 0;
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    #else
    op->defaults_tuple = __Pyx_PySequence_ITEM(res, 0);
    if (unlikely(!op->defaults_tuple)) result = -1;
    else {
        op->defaults_kwdict = __Pyx_PySequence_ITEM(res, 1);
        if (unlikely(!op->defaults_kwdict)) result = -1;
    }
    #endif
    Py_DECREF(res);
    return result;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyTuple_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__defaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->defaults_tuple, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_tuple;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = NULL;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_defaults_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__kwdefaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->defaults_kwdict, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_kwdict;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_kwdefaults_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value || value == Py_None) {
        value = NULL;
    } else if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_annotations, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->func_annotations;
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op, void *context) {
    PyObject *result;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_annotations_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static PyObject *
__Pyx_CyFunction_get_is_coroutine_value(__pyx_CyFunctionObject *op) {
    int is_coroutine = op->flags & __Pyx_CYFUNCTION_COROUTINE;
    if (is_coroutine) {
        PyObject *is_coroutine_value, *module, *fromlist, *marker = __pyx_mstate_global->__pyx_n_u_is_coroutine;
        fromlist = PyList_New(1);
        if (unlikely(!fromlist)) return NULL;
        Py_INCREF(marker);
#if CYTHON_ASSUME_SAFE_MACROS
        PyList_SET_ITEM(fromlist, 0, marker);
#else
        if (unlikely(PyList_SetItem(fromlist, 0, marker) < 0)) {
            Py_DECREF(marker);
            Py_DECREF(fromlist);
            return NULL;
        }
#endif
        module = PyImport_ImportModuleLevelObject(__pyx_mstate_global->__pyx_n_u_asyncio_coroutines, NULL, NULL, fromlist, 0);
        Py_DECREF(fromlist);
        if (unlikely(!module)) goto ignore;
        is_coroutine_value = __Pyx_PyObject_GetAttrStr(module, marker);
        Py_DECREF(module);
        if (likely(is_coroutine_value)) {
            return is_coroutine_value;
        }
ignore:
        PyErr_Clear();
    }
    return __Pyx_PyBool_FromLong(is_coroutine);
}
static PyObject *
__Pyx_CyFunction_get_is_coroutine(__pyx_CyFunctionObject *op, void *context) {
    PyObject *result;
    CYTHON_UNUSED_VAR(context);
    if (op->func_is_coroutine) {
        return __Pyx_NewRef(op->func_is_coroutine);
    }
    result = __Pyx_CyFunction_get_is_coroutine_value(op);
    if (unlikely(!result))
        return NULL;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    if (op->func_is_coroutine) {
        Py_DECREF(result);
        result = __Pyx_NewRef(op->func_is_coroutine);
    } else {
        op->func_is_coroutine = __Pyx_NewRef(result);
    }
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static void __Pyx_CyFunction_raise_argument_count_error(__pyx_CyFunctionObject *func, const char* message, Py_ssize_t size) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_name = __Pyx_CyFunction_get_name(func, NULL);
    if (!py_name) return;
    PyErr_Format(PyExc_TypeError,
        "%.200S() %s (%" CYTHON_FORMAT_SSIZE_T "d given)",
        py_name, message, size);
    Py_DECREF(py_name);
#else
    const char* name = ((PyCFunctionObject*)func)->m_ml->ml_name;
    PyErr_Format(PyExc_TypeError,
        "%.200s() %s (%" CYTHON_FORMAT_SSIZE_T "d given)",
        name, message, size);
#endif
}
static void __Pyx_CyFunction_raise_type_error(__pyx_CyFunctionObject *func, const char* message) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_name = __Pyx_CyFunction_get_name(func, NULL);
    if (!py_name) return;
    PyErr_Format(PyExc_TypeError,
        "%.200S() %s",
        py_name, message);
    Py_DECREF(py_name);
#else
    const char* name = ((PyCFunctionObject*)func)->m_ml->ml_name;
    PyErr_Format(PyExc_TypeError,
        "%.200s() %s",
        name, message);
#endif
}
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *
__Pyx_CyFunction_get_module(__pyx_CyFunctionObject *op, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_GetAttrString(op->func, "__module__");
}
static int
__Pyx_CyFunction_set_module(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_SetAttrString(op->func, "__module__", value);
}
#endif
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {"func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {"__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {"func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {"__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {"__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
    {"func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)PyObject_GenericSetDict, 0, 0},
    {"__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)PyObject_GenericSetDict, 0, 0},
#else
    {"func_dict", (getter)PyObject_GenericGetDict, (setter)PyObject_GenericSetDict, 0, 0},
    {"__dict__", (getter)PyObject_GenericGetDict, (setter)PyObject_GenericSetDict, 0, 0},
#endif
    {"func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {"__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {"func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {"__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {"func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {"__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {"func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {"__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {"__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {"__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {"_is_coroutine", (getter)__Pyx_CyFunction_get_is_coroutine, 0, 0, 0},
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__module__", (getter)__Pyx_CyFunction_get_module, (setter)__Pyx_CyFunction_set_module, 0, 0},
#endif
    {0, 0, 0, 0, 0}
};
static PyMemberDef __pyx_CyFunction_members[] = {
#if !CYTHON_COMPILING_IN_LIMITED_API
    {"__module__", T_OBJECT, offsetof(PyCFunctionObject, m_module), 0, 0},
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    {"__dictoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_dict), READONLY, 0},
#endif
#if CYTHON_METH_FASTCALL
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__vectorcalloffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_vectorcall), READONLY, 0},
#else
    {"__vectorcalloffset__", T_PYSSIZET, offsetof(PyCFunctionObject, vectorcall), READONLY, 0},
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__weaklistoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_weakreflist), READONLY, 0},
#else
    {"__weaklistoffset__", T_PYSSIZET, offsetof(PyCFunctionObject, m_weakreflist), READONLY, 0},
#endif
#endif
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, PyObject *args)
{
    PyObject *result = NULL;
    CYTHON_UNUSED_VAR(args);
    __Pyx_BEGIN_CRITICAL_SECTION(m);
    Py_INCREF(m->func_qualname);
    result = m->func_qualname;
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {"__reduce__", (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
#if CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func_weakreflist)
#else
#define __Pyx_CyFunction_weakreflist(cyfunc) (((PyCFunctionObject*)cyfunc)->m_weakreflist)
#endif
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject *op, PyMethodDef *ml, int flags, PyObject* qualname,
                                       PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
#if !CYTHON_COMPILING_IN_LIMITED_API
    PyCFunctionObject *cf = (PyCFunctionObject*) op;
#endif
    if (unlikely(op == NULL))
        return NULL;
#if CYTHON_COMPILING_IN_LIMITED_API
    op->func = PyCFunction_NewEx(ml, (PyObject*)op, module);
    if (unlikely(!op->func)) return NULL;
#endif
    op->flags = flags;
    __Pyx_CyFunction_weakreflist(op) = NULL;
#if !CYTHON_COMPILING_IN_LIMITED_API
    cf->m_ml = ml;
    cf->m_self = (PyObject *) op;
#endif
    Py_XINCREF(closure);
    op->func_closure = closure;
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_XINCREF(module);
    cf->m_module = module;
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    op->func_dict = NULL;
#endif
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    op->func_classobj = NULL;
#else
    ((PyCMethodObject*)op)->mm_class = NULL;
#endif
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    op->func_is_coroutine = NULL;
#if CYTHON_METH_FASTCALL
    switch (ml->ml_flags & (METH_VARARGS | METH_FASTCALL | METH_NOARGS | METH_O | METH_KEYWORDS | METH_METHOD)) {
    case METH_NOARGS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_NOARGS;
        break;
    case METH_O:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_O;
        break;
    case METH_METHOD | METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD;
        break;
    case METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS;
        break;
    case METH_VARARGS | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = NULL;
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        Py_DECREF(op);
        return NULL;
    }
#endif
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_CLEAR(m->func);
#else
    Py_CLEAR(((PyCFunctionObject*)m)->m_module);
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    Py_CLEAR(m->func_dict);
#elif PY_VERSION_HEX < 0x030d0000
    _PyObject_ClearManagedDict((PyObject*)m);
#else
    PyObject_ClearManagedDict((PyObject*)m);
#endif
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
#if PY_VERSION_HEX < 0x030900B1
    Py_CLEAR(__Pyx_CyFunction_GetClassObj(m));
#else
    {
        PyObject *cls = (PyObject*) ((PyCMethodObject *) (m))->mm_class;
        ((PyCMethodObject *) (m))->mm_class = NULL;
        Py_XDECREF(cls);
    }
#endif
#endif
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    Py_CLEAR(m->func_is_coroutine);
    Py_CLEAR(m->defaults);
    return 0;
}
static void __Pyx__CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    if (__Pyx_CyFunction_weakreflist(m) != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    __Pyx_PyHeapTypeObject_GC_Del(m);
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    __Pyx__CyFunction_dealloc(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    {
        int e = __Pyx_call_type_traverse((PyObject*)m, 1, visit, arg);
        if (e) return e;
    }
    Py_VISIT(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(m->func);
#else
    Py_VISIT(((PyCFunctionObject*)m)->m_module);
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(m->func_dict);
#else
    {
        int e =
#if PY_VERSION_HEX < 0x030d0000
            _PyObject_VisitManagedDict
#else
            PyObject_VisitManagedDict
#endif
                ((PyObject*)m, visit, arg);
        if (e != 0) return e;
    }
#endif
    __Pyx_VISIT_CONST(m->func_name);
    __Pyx_VISIT_CONST(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    __Pyx_VISIT_CONST(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(__Pyx_CyFunction_GetClassObj(m));
#endif
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    Py_VISIT(m->func_is_coroutine);
    Py_VISIT(m->defaults);
    return 0;
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
    PyObject *repr;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    repr = PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
    __Pyx_END_CRITICAL_SECTION();
    return repr;
}
static PyObject * __Pyx_CyFunction_CallMethod(PyObject *func, PyObject *self, PyObject *arg, PyObject *kw) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *f = ((__pyx_CyFunctionObject*)func)->func;
    PyCFunction meth;
    int flags;
    meth = PyCFunction_GetFunction(f);
    if (unlikely(!meth)) return NULL;
    flags = PyCFunction_GetFlags(f);
    if (unlikely(flags < 0)) return NULL;
#else
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = f->m_ml->ml_meth;
    int flags = f->m_ml->ml_flags;
#endif
    Py_ssize_t size;
    switch (flags & (METH_VARARGS | METH_KEYWORDS | METH_NOARGS | METH_O)) {
    case METH_VARARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0))
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)(void(*)(void))meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_SIZE
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 0))
                return (*meth)(self, NULL);
            __Pyx_CyFunction_raise_argument_count_error(
                (__pyx_CyFunctionObject*)func,
                "takes no arguments", size);
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_SIZE
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 1)) {
                PyObject *result, *arg0;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                arg0 = PyTuple_GET_ITEM(arg, 0);
                #else
                arg0 = __Pyx_PySequence_ITEM(arg, 0); if (unlikely(!arg0)) return NULL;
                #endif
                result = (*meth)(self, arg0);
                #if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
                Py_DECREF(arg0);
                #endif
                return result;
            }
            __Pyx_CyFunction_raise_argument_count_error(
                (__pyx_CyFunctionObject*)func,
                "takes exactly one argument", size);
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        return NULL;
    }
    __Pyx_CyFunction_raise_type_error(
        (__pyx_CyFunctionObject*)func, "takes no keyword arguments");
    return NULL;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *self, *result;
#if CYTHON_COMPILING_IN_LIMITED_API
    self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)func)->func);
    if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
    self = ((PyCFunctionObject*)func)->m_self;
#endif
    result = __Pyx_CyFunction_CallMethod(func, self, arg, kw);
    return result;
}
static PyObject *__Pyx_CyFunction_CallAsMethod(PyObject *func, PyObject *args, PyObject *kw) {
    PyObject *result;
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
     __pyx_vectorcallfunc vc = __Pyx_CyFunction_func_vectorcall(cyfunc);
    if (vc) {
#if CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE
        return __Pyx_PyVectorcall_FastCallDict(func, vc, &PyTuple_GET_ITEM(args, 0), (size_t)PyTuple_GET_SIZE(args), kw);
#else
        (void) &__Pyx_PyVectorcall_FastCallDict;
        return PyVectorcall_Call(func, args, kw);
#endif
    }
#endif
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        Py_ssize_t argc;
        PyObject *new_args;
        PyObject *self;
#if CYTHON_ASSUME_SAFE_SIZE
        argc = PyTuple_GET_SIZE(args);
#else
        argc = PyTuple_Size(args);
        if (unlikely(argc < 0)) return NULL;
#endif
        new_args = PyTuple_GetSlice(args, 1, argc);
        if (unlikely(!new_args))
            return NULL;
        self = PyTuple_GetItem(args, 0);
        if (unlikely(!self)) {
            Py_DECREF(new_args);
            PyErr_Format(PyExc_TypeError,
                         "unbound method %.200S() needs an argument",
                         cyfunc->func_qualname);
            return NULL;
        }
        result = __Pyx_CyFunction_CallMethod(func, self, new_args, kw);
        Py_DECREF(new_args);
    } else {
        result = __Pyx_CyFunction_Call(func, args, kw);
    }
    return result;
}
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
static CYTHON_INLINE int __Pyx_CyFunction_Vectorcall_CheckArgs(__pyx_CyFunctionObject *cyfunc, Py_ssize_t nargs, PyObject *kwnames)
{
    int ret = 0;
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        if (unlikely(nargs < 1)) {
            __Pyx_CyFunction_raise_type_error(
                cyfunc, "needs an argument");
            return -1;
        }
        ret = 1;
    }
    if (unlikely(kwnames) && unlikely(__Pyx_PyTuple_GET_SIZE(kwnames))) {
        __Pyx_CyFunction_raise_type_error(
            cyfunc, "takes no keyword arguments");
        return -1;
    }
    return ret;
}
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 0)) {
        __Pyx_CyFunction_raise_argument_count_error(
            cyfunc, "takes no arguments", nargs);
        return NULL;
    }
    return meth(self, NULL);
}
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 1)) {
        __Pyx_CyFunction_raise_argument_count_error(
            cyfunc, "takes exactly one argument", nargs);
        return NULL;
    }
    return meth(self, args[0]);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    return ((__Pyx_PyCFunctionFastWithKeywords)(void(*)(void))meth)(self, args, nargs, kwnames);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyTypeObject *cls = (PyTypeObject *) __Pyx_CyFunction_GetClassObj(cyfunc);
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    #if PY_VERSION_HEX < 0x030e00A6
    size_t nargs_value = (size_t) nargs;
    #else
    Py_ssize_t nargs_value = nargs;
    #endif
    return ((__Pyx_PyCMethod)(void(*)(void))meth)(self, cls, args, nargs_value, kwnames);
}
#endif
static PyType_Slot __pyx_CyFunctionType_slots[] = {
    {Py_tp_dealloc, (void *)__Pyx_CyFunction_dealloc},
    {Py_tp_repr, (void *)__Pyx_CyFunction_repr},
    {Py_tp_call, (void *)__Pyx_CyFunction_CallAsMethod},
    {Py_tp_traverse, (void *)__Pyx_CyFunction_traverse},
    {Py_tp_clear, (void *)__Pyx_CyFunction_clear},
    {Py_tp_methods, (void *)__pyx_CyFunction_methods},
    {Py_tp_members, (void *)__pyx_CyFunction_members},
    {Py_tp_getset, (void *)__pyx_CyFunction_getsets},
    {Py_tp_descr_get, (void *)__Pyx_PyMethod_New},
    {0, 0},
};
static PyType_Spec __pyx_CyFunctionType_spec = {
    __PYX_TYPE_MODULE_PREFIX "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
#ifdef Py_TPFLAGS_METHOD_DESCRIPTOR
    Py_TPFLAGS_METHOD_DESCRIPTOR |
#endif
#if CYTHON_METH_FASTCALL
#if defined(Py_TPFLAGS_HAVE_VECTORCALL)
    Py_TPFLAGS_HAVE_VECTORCALL |
#elif defined(_Py_TPFLAGS_HAVE_VECTORCALL)
    _Py_TPFLAGS_HAVE_VECTORCALL |
#endif
#endif // CYTHON_METH_FASTCALL
#if PY_VERSION_HEX >= 0x030C0000 && !CYTHON_COMPILING_IN_LIMITED_API
    Py_TPFLAGS_MANAGED_DICT |
#endif
    Py_TPFLAGS_IMMUTABLETYPE | Py_TPFLAGS_DISALLOW_INSTANTIATION |
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    __pyx_CyFunctionType_slots
};
static int __pyx_CyFunction_init(PyObject *module) {
    __pyx_mstatetype *mstate = __Pyx_PyModule_GetState(module);
    mstate->__pyx_CyFunctionType = __Pyx_FetchCommonTypeFromSpec(
        mstate->__pyx_CommonTypesMetaclassType, module, &__pyx_CyFunctionType_spec, NULL);
    if (unlikely(mstate->__pyx_CyFunctionType == NULL)) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_InitDefaults(PyObject *func, PyTypeObject *defaults_type) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyObject_CallObject((PyObject*)defaults_type, NULL); // _PyObject_New(defaults_type);
    if (unlikely(!m->defaults))
        return NULL;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

/* CythonFunction */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    PyObject *op = __Pyx_CyFunction_Init(
        PyObject_GC_New(__pyx_CyFunctionObject, __pyx_mstate_global->__pyx_CyFunctionType),
        ml, flags, qualname, closure, module, globals, code
    );
    if (likely(op)) {
        PyObject_GC_Track(op);
    }
    return op;
}

/* Globals */
static PyObject* __Pyx_Globals(void) {
    return __Pyx_NewRef(__pyx_mstate_global->__pyx_d);
}

/* CLineInTraceback (used by AddTraceback) */
#if CYTHON_CLINE_IN_TRACEBACK && CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
#define __Pyx_PyProbablyModule_GetDict(o) __Pyx_XNewRef(PyModule_GetDict(o))
#elif !CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyProbablyModule_GetDict(o) PyObject_GenericGetDict(o, NULL);
#else
PyObject* __Pyx_PyProbablyModule_GetDict(PyObject *o) {
    PyObject **dict_ptr = _PyObject_GetDictPtr(o);
    return dict_ptr ? __Pyx_XNewRef(*dict_ptr) : NULL;
}
#endif
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line) {
    PyObject *use_cline = NULL;
    PyObject *ptype, *pvalue, *ptraceback;
    PyObject *cython_runtime_dict;
    CYTHON_MAYBE_UNUSED_VAR(tstate);
    if (unlikely(!__pyx_mstate_global->__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
    cython_runtime_dict = __Pyx_PyProbablyModule_GetDict(__pyx_mstate_global->__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, cython_runtime_dict,
            __Pyx_PyDict_SetDefault(cython_runtime_dict, __pyx_mstate_global->__pyx_n_u_cline_in_traceback, Py_False))
    }
    if (use_cline == NULL || use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    Py_XDECREF(use_cline);
    Py_XDECREF(cython_runtime_dict);
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache (used by AddTraceback) */
#include "src/gevent/_generated_include/CodeObjectCache_impl_ffc81bf87e547a82e6009d64a2466eb1a5f6677afcbab3333a029ea24e45c012.h"
/* AddTraceback */
#include "src/gevent/_generated_include/AddTraceback_impl_5c53b964023228d90bdfcfa91919f5c3c484446268d5ef056f29421d654f5af4.h"
/* CIntFromPyVerify */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* PyObjectVectorCallKwBuilder (used by CIntToPy) */
#include "src/gevent/_generated_include/PyObjectVectorCallKwBuilder_impl_fd859cdb6cbc3b35f6b10f5733f06af41f621c00f218f3658f8b944bf821c5f8.h"
/* CIntToPy */
#include "src/gevent/_generated_include/CIntToPy_impl_04d273d7fd8d781e47c953336d9035c05b46b928eb9a876491735d34363bfe94.h"
/* CIntFromPy */
#include "src/gevent/_generated_include/CIntFromPy_impl_ceb8d340f976d387a193f777f2c34549caaafc1e59b58b253b09ec2b16efbddf.h"
/* CIntToPy */
#include "src/gevent/_generated_include/CIntToPy_impl_3a4503f42bed1a339a5a77cabbacbe22d845586eaf8fe2b8bf391ccbe75ae64a.h"
/* CIntFromPy */
#include "src/gevent/_generated_include/CIntFromPy_impl_b91de55768d50878c1454209403f531c1ef9ecfc0f5cfff0eb0b925c62c994e2.h"
/* FastTypeChecks */
#include "src/gevent/_generated_include/FastTypeChecks_impl_f9d18941833a215bcf3276e2b6a57d81e032bd85ed1fb021b834da49989898c9.h"
/* GetRuntimeVersion */
#if __PYX_LIMITED_VERSION_HEX < 0x030b0000
void __Pyx_init_runtime_version(void) {
    if (__Pyx_cached_runtime_version == 0) {
        const char* rt_version = Py_GetVersion();
        unsigned long version = 0;
        unsigned long factor = 0x01000000UL;
        unsigned int digit = 0;
        int i = 0;
        while (factor) {
            while ('0' <= rt_version[i] && rt_version[i] <= '9') {
                digit = digit * 10 + (unsigned int) (rt_version[i] - '0');
                ++i;
            }
            version += factor * digit;
            if (rt_version[i] != '.')
                break;
            digit = 0;
            factor >>= 8;
            ++i;
        }
        __Pyx_cached_runtime_version = version;
    }
}
#endif
static unsigned long __Pyx_get_runtime_version(void) {
#if __PYX_LIMITED_VERSION_HEX >= 0x030b0000
    return Py_Version & ~0xFFUL;
#else
    return __Pyx_cached_runtime_version;
#endif
}

/* CheckBinaryVersion */
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer) {
    const unsigned long MAJOR_MINOR = 0xFFFF0000UL;
    if ((rt_version & MAJOR_MINOR) == (ct_version & MAJOR_MINOR))
        return 0;
    if (likely(allow_newer && (rt_version & MAJOR_MINOR) > (ct_version & MAJOR_MINOR)))
        return 1;
    {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compile time Python version %d.%d "
                      "of module '%.100s' "
                      "%s "
                      "runtime version %d.%d",
                       (int) (ct_version >> 24), (int) ((ct_version >> 16) & 0xFF),
                       __Pyx_MODULE_NAME,
                       (allow_newer) ? "was newer than" : "does not match",
                       (int) (rt_version >> 24), (int) ((rt_version >> 16) & 0xFF)
       );
        return PyErr_WarnEx(NULL, message, 1);
    }
}

/* NewCodeObj */
#include "src/gevent/_generated_include/NewCodeObj_impl_a437ae594518b78f515ea800eae13a23abf85c5a9a57d6d2c88c6b9b215ff54c.h"
/* DecompressString */
#include "src/gevent/_generated_include/DecompressString_impl_08916ce6b33dc899db1820b9329c4da53ddc4f977613e2296edf3d94850c4279.h"
#include <string.h>
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s) {
    size_t len = strlen(s);
    if (unlikely(len > (size_t) PY_SSIZE_T_MAX)) {
        PyErr_SetString(PyExc_OverflowError, "byte string is too long");
        return -1;
    }
    return (Py_ssize_t) len;
}
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return __Pyx_PyUnicode_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return PyByteArray_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if CYTHON_COMPILING_IN_LIMITED_API
    {
        const char* result;
        Py_ssize_t unicode_length;
        CYTHON_MAYBE_UNUSED_VAR(unicode_length); // only for __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        #if __PYX_LIMITED_VERSION_HEX < 0x030A0000
        if (unlikely(PyArg_Parse(o, "s#", &result, length) < 0)) return NULL;
        #else
        result = PyUnicode_AsUTF8AndSize(o, length);
        #endif
        #if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        unicode_length = PyUnicode_GetLength(o);
        if (unlikely(unicode_length < 0)) return NULL;
        if (unlikely(unicode_length != *length)) {
            PyUnicode_AsASCIIString(o);
            return NULL;
        }
        #endif
        return result;
    }
#else
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
#endif
}
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
    if (PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
    if (PyByteArray_Check(o)) {
#if (CYTHON_ASSUME_SAFE_SIZE && CYTHON_ASSUME_SAFE_MACROS) || (CYTHON_COMPILING_IN_PYPY && (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE)))
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
#else
        *length = PyByteArray_Size(o);
        if (*length == -1) return NULL;
        return PyByteArray_AsString(o);
#endif
    } else
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_LongWrongResultType(PyObject* result) {
    __Pyx_TypeName result_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(result));
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ").  "
                "The ability to return an instance of a strict subclass of int is deprecated, "
                "and may be removed in a future version of Python.",
                result_type_name)) {
            __Pyx_DECREF_TypeName(result_type_name);
            Py_DECREF(result);
            return NULL;
        }
        __Pyx_DECREF_TypeName(result_type_name);
        return result;
    }
    PyErr_Format(PyExc_TypeError,
                 "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ")",
                 result_type_name);
    __Pyx_DECREF_TypeName(result_type_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Long(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  PyObject *res = NULL;
  if (likely(PyLong_Check(x)))
      return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  if (likely(m && m->nb_int)) {
      res = m->nb_int(x);
  }
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
      res = PyNumber_Long(x);
  }
#endif
  if (likely(res)) {
      if (unlikely(!PyLong_CheckExact(res))) {
          return __Pyx_PyNumber_LongWrongResultType(res);
      }
  }
  else if (!PyErr_Occurred()) {
      PyErr_SetString(PyExc_TypeError,
                      "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(__Pyx_PyLong_IsCompact(b))) {
        return __Pyx_PyLong_CompactValue(b);
    } else {
      const digit* digits = __Pyx_PyLong_Digits(b);
      const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(b);
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyLong_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject* o) {
  if (sizeof(Py_hash_t) == sizeof(Py_ssize_t)) {
    return (Py_hash_t) __Pyx_PyIndex_AsSsize_t(o);
  } else {
    Py_ssize_t ival;
    PyObject *x;
    x = PyNumber_Index(o);
    if (!x) return -1;
    ival = PyLong_AsLong(x);
    Py_DECREF(x);
    return ival;
  }
}
static CYTHON_INLINE PyObject *__Pyx_Owned_Py_None(int b) {
    CYTHON_UNUSED_VAR(b);
    return __Pyx_NewRef(Py_None);
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return __Pyx_NewRef(b ? Py_True: Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyLong_FromSize_t(size_t ival) {
    return PyLong_FromSize_t(ival);
}


/* MultiPhaseInitModuleState */
#include "src/gevent/_generated_include/MultiPhaseInitModuleState_impl_41d512917574f55c289a94dba0e3ef9c60f8de37a71dd41f0dd086494a351cae.h"
/* #### Code section: utility_code_pragmas_end ### */
#ifdef _MSC_VER
#pragma warning( pop )
#endif



/* #### Code section: end ### */
#endif /* Py_PYTHON_H */
