/* Generated by Cython 3.2.4 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "define_macros": [
            [
                "CYTHON_FAST_THREAD_STATE",
                "0"
            ]
        ],
        "depends": [
            "src/gevent/_gevent_c_semaphore.pxd"
        ],
        "include_dirs": [
            "/usr/include/python3.14",
            "/usr/include/python3.14",
            "/build/python-gevent/src/python-gevent/deps"
        ],
        "name": "gevent._gevent_c_semaphore",
        "sources": [
            "src/gevent/_semaphore.py"
        ]
    },
    "module_name": "gevent._gevent_c_semaphore"
}
END: Cython Metadata */

#ifndef PY_SSIZE_T_CLEAN
#define PY_SSIZE_T_CLEAN
#endif /* PY_SSIZE_T_CLEAN */
/* InitLimitedAPI */
#if defined(Py_LIMITED_API)
  #if !defined(CYTHON_LIMITED_API)
  #define CYTHON_LIMITED_API 1
  #endif
#elif defined(CYTHON_LIMITED_API)
  #ifdef _MSC_VER
  #pragma message ("Limited API usage is enabled with 'CYTHON_LIMITED_API' but 'Py_LIMITED_API' does not define a Python target version. Consider setting 'Py_LIMITED_API' instead.")
  #else
  #warning Limited API usage is enabled with 'CYTHON_LIMITED_API' but 'Py_LIMITED_API' does not define a Python target version. Consider setting 'Py_LIMITED_API' instead.
  #endif
#endif

#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x03080000
    #error Cython requires Python 3.8+.
#else
#define __PYX_ABI_VERSION "3_2_4"
#define CYTHON_HEX_VERSION 0x030204F0
#define CYTHON_FUTURE_DIVISION 1
/* CModulePreamble */
#include "src/gevent/_generated_include/CModulePreamble_impl_67ff8da3bafbaee898fb2680a081f9cf07617f9b80d936bf5254c02966774c38.h"
/* CInitCode */
#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

/* PythonCompatibility */
#include "src/gevent/_generated_include/PythonCompatibility_impl_9f6bc6a154e6d1f4d1d9250f48a0e6d407560d70233eabffbe0fccfe1f684e75.h"
/* MathInitCode */
#if defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)
  #ifndef _USE_MATH_DEFINES
    #define _USE_MATH_DEFINES
  #endif
#endif
#include <math.h>
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#ifndef CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#define CYTHON_CLINE_IN_TRACEBACK_RUNTIME 0
#endif
#ifndef CYTHON_CLINE_IN_TRACEBACK
#define CYTHON_CLINE_IN_TRACEBACK CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#endif
#if CYTHON_CLINE_IN_TRACEBACK
#define __PYX_MARK_ERR_POS(f_index, lineno)  { __pyx_filename = __pyx_f[f_index]; (void) __pyx_filename; __pyx_lineno = lineno; (void) __pyx_lineno; __pyx_clineno = __LINE__; (void) __pyx_clineno; }
#else
#define __PYX_MARK_ERR_POS(f_index, lineno)  { __pyx_filename = __pyx_f[f_index]; (void) __pyx_filename; __pyx_lineno = lineno; (void) __pyx_lineno; (void) __pyx_clineno; }
#endif
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifdef CYTHON_EXTERN_C
    #undef __PYX_EXTERN_C
    #define __PYX_EXTERN_C CYTHON_EXTERN_C
#elif defined(__PYX_EXTERN_C)
    #ifdef _MSC_VER
    #pragma message ("Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.")
    #else
    #warning Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.
    #endif
#else
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__gevent___gevent_c_semaphore
#define __PYX_HAVE_API__gevent___gevent_c_semaphore
/* Early includes */
#include "greenlet/greenlet.h"
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

#ifdef CYTHON_FREETHREADING_COMPATIBLE
#if CYTHON_FREETHREADING_COMPATIBLE
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_NOT_USED
#else
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_USED
#endif
#else
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_USED
#endif
#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s);
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char*);
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyByteArray_AsString(s) PyByteArray_AS_STRING(s)
#else
    #define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AsString(s))
    #define __Pyx_PyByteArray_AsString(s) PyByteArray_AsString(s)
#endif
#define __Pyx_PyObject_AsWritableString(s)    ((char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
#define __Pyx_PyUnicode_FromOrdinal(o)       PyUnicode_FromOrdinal((int)o)
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
static CYTHON_INLINE PyObject *__Pyx_NewRef(PyObject *obj) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030a0000 || defined(Py_NewRef)
    return Py_NewRef(obj);
#else
    Py_INCREF(obj);
    return obj;
#endif
}
static CYTHON_INLINE PyObject *__Pyx_XNewRef(PyObject *obj) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030a0000 || defined(Py_XNewRef)
    return Py_XNewRef(obj);
#else
    Py_XINCREF(obj);
    return obj;
#endif
}
static CYTHON_INLINE PyObject *__Pyx_Owned_Py_None(int b);
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Long(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyLong_FromSize_t(size_t);
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject*);
#if CYTHON_ASSUME_SAFE_MACROS
#define __Pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#define __Pyx_PyFloat_AS_DOUBLE(x) PyFloat_AS_DOUBLE(x)
#else
#define __Pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#define __Pyx_PyFloat_AS_DOUBLE(x) PyFloat_AsDouble(x)
#endif
#define __Pyx_PyFloat_AsFloat(x) ((float) __Pyx_PyFloat_AsDouble(x))
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_VERSION_HEX >= 0x030C00A7
  #ifndef _PyLong_SIGN_MASK
    #define _PyLong_SIGN_MASK 3
  #endif
  #ifndef _PyLong_NON_SIZE_BITS
    #define _PyLong_NON_SIZE_BITS 3
  #endif
  #define __Pyx_PyLong_Sign(x)  (((PyLongObject*)x)->long_value.lv_tag & _PyLong_SIGN_MASK)
  #define __Pyx_PyLong_IsNeg(x)  ((__Pyx_PyLong_Sign(x) & 2) != 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (!__Pyx_PyLong_IsNeg(x))
  #define __Pyx_PyLong_IsZero(x)  (__Pyx_PyLong_Sign(x) & 1)
  #define __Pyx_PyLong_IsPos(x)  (__Pyx_PyLong_Sign(x) == 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  (__Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  ((Py_ssize_t) (((PyLongObject*)x)->long_value.lv_tag >> _PyLong_NON_SIZE_BITS))
  #define __Pyx_PyLong_SignedDigitCount(x)\
        ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * __Pyx_PyLong_DigitCount(x))
  #if defined(PyUnstable_Long_IsCompact) && defined(PyUnstable_Long_CompactValue)
    #define __Pyx_PyLong_IsCompact(x)     PyUnstable_Long_IsCompact((PyLongObject*) x)
    #define __Pyx_PyLong_CompactValue(x)  PyUnstable_Long_CompactValue((PyLongObject*) x)
  #else
    #define __Pyx_PyLong_IsCompact(x)     (((PyLongObject*)x)->long_value.lv_tag < (2 << _PyLong_NON_SIZE_BITS))
    #define __Pyx_PyLong_CompactValue(x)  ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * (Py_ssize_t) __Pyx_PyLong_Digits(x)[0])
  #endif
  typedef Py_ssize_t  __Pyx_compact_pylong;
  typedef size_t  __Pyx_compact_upylong;
  #else
  #define __Pyx_PyLong_IsNeg(x)  (Py_SIZE(x) < 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (Py_SIZE(x) >= 0)
  #define __Pyx_PyLong_IsZero(x)  (Py_SIZE(x) == 0)
  #define __Pyx_PyLong_IsPos(x)  (Py_SIZE(x) > 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  ((Py_SIZE(x) == 0) ? 0 : __Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  __Pyx_sst_abs(Py_SIZE(x))
  #define __Pyx_PyLong_SignedDigitCount(x)  Py_SIZE(x)
  #define __Pyx_PyLong_IsCompact(x)  (Py_SIZE(x) == 0 || Py_SIZE(x) == 1 || Py_SIZE(x) == -1)
  #define __Pyx_PyLong_CompactValue(x)\
        ((Py_SIZE(x) == 0) ? (sdigit) 0 : ((Py_SIZE(x) < 0) ? -(sdigit)__Pyx_PyLong_Digits(x)[0] : (sdigit)__Pyx_PyLong_Digits(x)[0]))
  typedef sdigit  __Pyx_compact_pylong;
  typedef digit  __Pyx_compact_upylong;
  #endif
  #if PY_VERSION_HEX >= 0x030C00A5
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->long_value.ob_digit)
  #else
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->ob_digit)
  #endif
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#elif __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeASCII(c_str, size, NULL)
#else
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
/* PretendToInitialize */
#ifdef __cplusplus
#if __cplusplus > 201103L
#include <type_traits>
#endif
template <typename T>
static void __Pyx_pretend_to_initialize(T* ptr) {
#if __cplusplus > 201103L
    if ((std::is_trivially_default_constructible<T>::value))
#endif
        *ptr = T();
    (void)ptr;
}
#else
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }
#endif


#if !CYTHON_USE_MODULE_STATE
static PyObject *__pyx_m = NULL;
#endif
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * const __pyx_cfilenm = __FILE__;
static const char *__pyx_filename;

/* #### Code section: filename_table ### */

static const char* const __pyx_f[] = {
  "src/gevent/_semaphore.py",
  "src/gevent/_gevent_c_greenlet_primitives.pxd",
  "src/gevent/_gevent_c_abstract_linkable.pxd",
  "src/gevent/_gevent_c_semaphore.pxd",
};
/* #### Code section: utility_code_proto_before_types ### */
/* Atomics.proto (used by UnpackUnboundCMethod) */
#include "src/gevent/_generated_include/Atomics_proto_3c6d386cad499e8bf66734864569013c6cb59adf2353bb94c6c6798eea3c07cc.h"
/* CriticalSectionsDefinition.proto (used by CriticalSections) */
#if !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyCriticalSection void*
#define __Pyx_PyCriticalSection2 void*
#define __Pyx_PyCriticalSection_End(cs)
#define __Pyx_PyCriticalSection2_End(cs)
#else
#define __Pyx_PyCriticalSection PyCriticalSection
#define __Pyx_PyCriticalSection2 PyCriticalSection2
#define __Pyx_PyCriticalSection_End PyCriticalSection_End
#define __Pyx_PyCriticalSection2_End PyCriticalSection2_End
#endif

/* CriticalSections.proto (used by ParseKeywordsImpl) */
#if !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyCriticalSection_Begin(cs, arg) (void)(cs)
#define __Pyx_PyCriticalSection2_Begin(cs, arg1, arg2) (void)(cs)
#else
#define __Pyx_PyCriticalSection_Begin PyCriticalSection_Begin
#define __Pyx_PyCriticalSection2_Begin PyCriticalSection2_Begin
#endif
#if PY_VERSION_HEX < 0x030d0000 || CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_BEGIN_CRITICAL_SECTION(o) {
#define __Pyx_END_CRITICAL_SECTION() }
#else
#define __Pyx_BEGIN_CRITICAL_SECTION Py_BEGIN_CRITICAL_SECTION
#define __Pyx_END_CRITICAL_SECTION Py_END_CRITICAL_SECTION
#endif

/* IncludeStructmemberH.proto (used by FixUpExtensionType) */
#include <structmember.h>

/* #### Code section: numeric_typedefs ### */
/* #### Code section: complex_type_declarations ### */
/* #### Code section: type_declarations ### */

/*--- Type declarations ---*/
struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet;
struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop;
struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable__FakeNotifier;
struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable;
struct __pyx_obj_6gevent_19_gevent_c_semaphore__LockReleaseLink;
struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore;
struct __pyx_obj_6gevent_19_gevent_c_semaphore_BoundedSemaphore;
struct __pyx_opt_args_6gevent_27_gevent_c_abstract_linkable_16AbstractLinkable__wait_core;
struct __pyx_opt_args_6gevent_27_gevent_c_abstract_linkable_16AbstractLinkable__wait;

/* "gevent/_gevent_c_abstract_linkable.pxd":79
 *    cpdef _acquire_lock_for_switch_in(self)
 * 
 *    cdef _wait_core(self, timeout, catch=*)             # <<<<<<<<<<<<<<
 *    cdef _wait_return_value(self, bint waited, bint wait_success)
 *    cdef _wait(self, timeout=*)
*/
struct __pyx_opt_args_6gevent_27_gevent_c_abstract_linkable_16AbstractLinkable__wait_core {
  int __pyx_n;
  PyObject *__pyx_catch;
};

/* "gevent/_gevent_c_abstract_linkable.pxd":81
 *    cdef _wait_core(self, timeout, catch=*)
 *    cdef _wait_return_value(self, bint waited, bint wait_success)
 *    cdef _wait(self, timeout=*)             # <<<<<<<<<<<<<<
 * 
 *    # Unreleated utilities
*/
struct __pyx_opt_args_6gevent_27_gevent_c_abstract_linkable_16AbstractLinkable__wait {
  int __pyx_n;
  PyObject *timeout;
};
struct __pyx_opt_args_6gevent_19_gevent_c_semaphore_9Semaphore_wait;
struct __pyx_opt_args_6gevent_19_gevent_c_semaphore_9Semaphore_acquire;

/* "gevent/_gevent_c_semaphore.pxd":40
 *     # threadpool uses it
 *     cpdef _start_notify(self)
 *     cpdef int wait(self, object timeout=*) except -1000             # <<<<<<<<<<<<<<
 *     @cython.locals(
 *         success=bint,
*/
struct __pyx_opt_args_6gevent_19_gevent_c_semaphore_9Semaphore_wait {
  int __pyx_n;
  PyObject *timeout;
};

/* "gevent/_gevent_c_semaphore.pxd":47
 *         args=tuple,
 *     )
 *     cpdef bint acquire(self, bint blocking=*, object timeout=*) except -1000             # <<<<<<<<<<<<<<
 *     cpdef __enter__(self)
 *     cpdef __exit__(self, object t, object v, object tb)
*/
struct __pyx_opt_args_6gevent_19_gevent_c_semaphore_9Semaphore_acquire {
  int __pyx_n;
  int blocking;
  PyObject *timeout;
};

/* "gevent/_gevent_c_greenlet_primitives.pxd":37
 *     return PyGreenlet_Switch(self, NULL, NULL)
 * 
 * cdef class TrackedRawGreenlet(greenlet):             # <<<<<<<<<<<<<<
 *     pass
 * 
*/
struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet {
  PyGreenlet __pyx_base;
};


/* "gevent/_gevent_c_greenlet_primitives.pxd":40
 *     pass
 * 
 * cdef class SwitchOutGreenletWithLoop(TrackedRawGreenlet):             # <<<<<<<<<<<<<<
 *     cdef public loop
 * 
*/
struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop {
  struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet __pyx_base;
  struct __pyx_vtabstruct_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *__pyx_vtab;
  PyObject *loop;
};


/* "gevent/_gevent_c_abstract_linkable.pxd":38
 * cdef dict get_roots_and_hubs()
 * 
 * cdef class _FakeNotifier(object):             # <<<<<<<<<<<<<<
 *     cdef bint pending
 * 
*/
struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable__FakeNotifier {
  PyObject_HEAD
  int pending;
};


/* "gevent/_gevent_c_abstract_linkable.pxd":41
 *     cdef bint pending
 * 
 * cdef class AbstractLinkable(object):             # <<<<<<<<<<<<<<
 *    # We declare the __weakref__ here in the base (even though
 *    # that's not really what we want) as a workaround for a Cython
*/
struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable {
  PyObject_HEAD
  struct __pyx_vtabstruct_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *__pyx_vtab;
  PyObject *__weakref__;
  struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *hub;
  PyObject *_notifier;
  PyObject *_links;
  int _notify_all;
};


/* "gevent/_gevent_c_semaphore.pxd":18
 * cdef _MULTI
 * 
 * cdef class _LockReleaseLink(object):             # <<<<<<<<<<<<<<
 *     cdef object lock
 * 
*/
struct __pyx_obj_6gevent_19_gevent_c_semaphore__LockReleaseLink {
  PyObject_HEAD
  PyObject *lock;
};


/* "gevent/_gevent_c_semaphore.pxd":22
 * 
 * 
 * cdef class Semaphore(AbstractLinkable):             # <<<<<<<<<<<<<<
 *     cdef public int counter
 *     # On Python 3, thread.get_ident() returns a ``unsigned long``; on
*/
struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore {
  struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable __pyx_base;
  int counter;
  PyObject *_multithreaded;
};


/* "gevent/_gevent_c_semaphore.pxd":67
 *     cdef bint __spin_on_native_lock(self, thread_lock, timeout)
 * 
 * cdef class BoundedSemaphore(Semaphore):             # <<<<<<<<<<<<<<
 *     cdef readonly int _initial_value
 * 
*/
struct __pyx_obj_6gevent_19_gevent_c_semaphore_BoundedSemaphore {
  struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore __pyx_base;
  int _initial_value;
};



/* "gevent/_gevent_c_greenlet_primitives.pxd":40
 *     pass
 * 
 * cdef class SwitchOutGreenletWithLoop(TrackedRawGreenlet):             # <<<<<<<<<<<<<<
 *     cdef public loop
 * 
*/

struct __pyx_vtabstruct_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop {
  PyObject *(*__pyx_switch)(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *, int __pyx_skip_dispatch);
  PyObject *(*switch_out)(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *__pyx_vtabptr_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop;


/* "gevent/_gevent_c_abstract_linkable.pxd":41
 *     cdef bint pending
 * 
 * cdef class AbstractLinkable(object):             # <<<<<<<<<<<<<<
 *    # We declare the __weakref__ here in the base (even though
 *    # that's not really what we want) as a workaround for a Cython
*/

struct __pyx_vtabstruct_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable {
  PyObject *(*linkcount)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *, int __pyx_skip_dispatch);
  PyObject *(*rawlink)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *, PyObject *, int __pyx_skip_dispatch);
  int (*ready)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *, int __pyx_skip_dispatch);
  PyObject *(*unlink)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*_check_and_notify)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *);
  struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *(*_capture_hub)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *, int);
  PyObject *(*_AbstractLinkable__wait_to_be_notified)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *, int);
  void (*_quiet_unlink_all)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *, PyObject *);
  int (*_switch_to_hub)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *, PyObject *);
  PyObject *(*_notify_link_list)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *, PyObject *);
  PyObject *(*_notify_links)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*_handle_unswitched_notifications)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *, PyObject *);
  PyObject *(*_AbstractLinkable__print_unswitched_warning)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *, PyObject *, int);
  PyObject *(*_drop_lock_for_switch_out)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *, int __pyx_skip_dispatch);
  PyObject *(*_acquire_lock_for_switch_in)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *, int __pyx_skip_dispatch);
  PyObject *(*_wait_core)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *, PyObject *, struct __pyx_opt_args_6gevent_27_gevent_c_abstract_linkable_16AbstractLinkable__wait_core *__pyx_optional_args);
  PyObject *(*_wait_return_value)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *, int, int);
  PyObject *(*_wait)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *, struct __pyx_opt_args_6gevent_27_gevent_c_abstract_linkable_16AbstractLinkable__wait *__pyx_optional_args);
  PyObject *(*_allocate_lock)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *);
  PyGreenlet *(*_getcurrent)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *);
  PyObject *(*_get_thread_ident)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *);
};
static struct __pyx_vtabstruct_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *__pyx_vtabptr_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable;


/* "src/gevent/_semaphore.py":48
 * _MULTI = object()
 * 
 * class Semaphore(AbstractLinkable): # pylint:disable=undefined-variable             # <<<<<<<<<<<<<<
 *     """
 *     Semaphore(value=1) -> Semaphore
*/

struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore {
  struct __pyx_vtabstruct_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable __pyx_base;
  int (*locked)(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *, int __pyx_skip_dispatch);
  int (*release)(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *, int __pyx_skip_dispatch);
  PyObject *(*_start_notify)(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *, int __pyx_skip_dispatch);
  int (*wait)(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *, int __pyx_skip_dispatch, struct __pyx_opt_args_6gevent_19_gevent_c_semaphore_9Semaphore_wait *__pyx_optional_args);
  int (*acquire)(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *, int __pyx_skip_dispatch, struct __pyx_opt_args_6gevent_19_gevent_c_semaphore_9Semaphore_acquire *__pyx_optional_args);
  PyObject *(*__pyx___enter__)(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *, int __pyx_skip_dispatch);
  PyObject *(*__pyx___exit__)(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *, PyObject *, PyObject *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*_Semaphore__acquire_from_other_thread)(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *, PyObject *, int, PyObject *);
  PyObject *(*_Semaphore__acquire_from_other_thread_cb)(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *, PyObject *, int, PyObject *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*_Semaphore__add_link)(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *, PyObject *);
  PyObject *(*_Semaphore__acquire_using_two_hubs)(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *, struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *, PyObject *, PyObject *);
  PyObject *(*_Semaphore__acquire_using_other_hub)(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *, struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *, PyObject *);
  int (*_Semaphore__acquire_without_hubs)(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *, PyObject *);
  int (*_Semaphore__spin_on_native_lock)(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *, PyObject *, PyObject *);
};
static struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_vtabptr_6gevent_19_gevent_c_semaphore_Semaphore;


/* "src/gevent/_semaphore.py":470
 * 
 * 
 * class BoundedSemaphore(Semaphore):             # <<<<<<<<<<<<<<
 *     """
 *     BoundedSemaphore(value=1) -> BoundedSemaphore
*/

struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_BoundedSemaphore {
  struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore __pyx_base;
};
static struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_BoundedSemaphore *__pyx_vtabptr_6gevent_19_gevent_c_semaphore_BoundedSemaphore;
/* #### Code section: utility_code_proto ### */

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#include "src/gevent/_generated_include/Refnanny_proto_00d2ab1aa529311d487a88a16574063b4d3b8ffa11a25109d76165964b208920.h"
/* PyErrExceptionMatches.proto (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* PyThreadStateGet.proto (used by PyErrFetchRestore) */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#if PY_VERSION_HEX >= 0x030C00A6
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->current_exception != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->current_exception ? (PyObject*) Py_TYPE(__pyx_tstate->current_exception) : (PyObject*) NULL)
#else
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->curexc_type != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->curexc_type)
#endif
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  (PyErr_Occurred() != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto (used by PyObjectGetAttrStrNoError) */
#include "src/gevent/_generated_include/PyErrFetchRestore_proto_b219ba96ee79f73e7240a9715dc835e7e817ccd9f4f99ab4145b09780817bd8a.h"
/* PyObjectGetAttrStr.proto (used by PyObjectGetAttrStrNoError) */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* PyObjectGetAttrStrNoError.proto (used by GetBuiltinName) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name);

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* TupleAndListFromArray.proto (used by fastcall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n);
#endif
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject* __Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n);
#endif

/* IncludeStringH.proto (used by BytesEquals) */
#include <string.h>

/* BytesEquals.proto (used by UnicodeEquals) */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto (used by fastcall) */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* fastcall.proto */
#include "src/gevent/_generated_include/fastcall_proto_66690a1464eb22fa574c56237a11be9953f14c69fdee2df9c4141aa9c5e2a76d.h"
/* PyObjectCall.proto (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyObjectCallMethO.proto (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectFastCall.proto */
#define __Pyx_PyObject_FastCall(func, args, nargs)  __Pyx_PyObject_FastCallDict(func, args, (size_t)(nargs), NULL)
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject * const*args, size_t nargs, PyObject *kwargs);

/* py_dict_items.proto (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Items(PyObject* d);

/* CallCFunction.proto (used by CallUnboundCMethod0) */
#define __Pyx_CallCFunction(cfunc, self, args)\
    ((PyCFunction)(void(*)(void))(cfunc)->func)(self, args)
#define __Pyx_CallCFunctionWithKeywords(cfunc, self, args, kwargs)\
    ((PyCFunctionWithKeywords)(void(*)(void))(cfunc)->func)(self, args, kwargs)
#define __Pyx_CallCFunctionFast(cfunc, self, args, nargs)\
    ((__Pyx_PyCFunctionFast)(void(*)(void))(PyCFunction)(cfunc)->func)(self, args, nargs)
#define __Pyx_CallCFunctionFastWithKeywords(cfunc, self, args, nargs, kwnames)\
    ((__Pyx_PyCFunctionFastWithKeywords)(void(*)(void))(PyCFunction)(cfunc)->func)(self, args, nargs, kwnames)

/* PyObjectCallOneArg.proto (used by CallUnboundCMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* UnpackUnboundCMethod.proto (used by CallUnboundCMethod0) */
typedef struct {
    PyObject *type;
    PyObject **method_name;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && CYTHON_ATOMICS
    __pyx_atomic_int_type initialized;
#endif
    PyCFunction func;
    PyObject *method;
    int flag;
} __Pyx_CachedCFunction;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
static CYTHON_INLINE int __Pyx_CachedCFunction_GetAndSetInitializing(__Pyx_CachedCFunction *cfunc) {
#if !CYTHON_ATOMICS
    return 1;
#else
    __pyx_nonatomic_int_type expected = 0;
    if (__pyx_atomic_int_cmp_exchange(&cfunc->initialized, &expected, 1)) {
        return 0;
    }
    return expected;
#endif
}
static CYTHON_INLINE void __Pyx_CachedCFunction_SetFinishedInitializing(__Pyx_CachedCFunction *cfunc) {
#if CYTHON_ATOMICS
    __pyx_atomic_store(&cfunc->initialized, 2);
#endif
}
#else
#define __Pyx_CachedCFunction_GetAndSetInitializing(cfunc) 2
#define __Pyx_CachedCFunction_SetFinishedInitializing(cfunc)
#endif

/* CallUnboundCMethod0.proto */
CYTHON_UNUSED
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#else
#define __Pyx_CallUnboundCMethod0(cfunc, self)  __Pyx__CallUnboundCMethod0(cfunc, self)
#endif

/* py_dict_values.proto (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Values(PyObject* d);

/* OwnedDictNext.proto (used by ParseKeywordsImpl) */
#if CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, PyObject **ppos, PyObject **pkey, PyObject **pvalue);
#else
CYTHON_INLINE
static int __Pyx_PyDict_NextRef(PyObject *p, Py_ssize_t *ppos, PyObject **pkey, PyObject **pvalue);
#endif

/* RaiseDoubleKeywords.proto (used by ParseKeywordsImpl) */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywordsImpl.export */
static int __Pyx_ParseKeywordsTuple(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);
static int __Pyx_ParseKeywordDictToDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name
);
static int __Pyx_ParseKeywordDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);

/* CallUnboundCMethod2.proto */
CYTHON_UNUSED
static PyObject* __Pyx__CallUnboundCMethod2(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg1, PyObject* arg2);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject *__Pyx_CallUnboundCMethod2(__Pyx_CachedCFunction *cfunc, PyObject *self, PyObject *arg1, PyObject *arg2);
#else
#define __Pyx_CallUnboundCMethod2(cfunc, self, arg1, arg2)  __Pyx__CallUnboundCMethod2(cfunc, self, arg1, arg2)
#endif

/* ParseKeywords.proto */
static CYTHON_INLINE int __Pyx_ParseKeywords(
    PyObject *kwds, PyObject *const *kwvalues, PyObject ** const argnames[],
    PyObject *kwds2, PyObject *values[],
    Py_ssize_t num_pos_args, Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* PyObjectFastCallMethod.proto */
#if CYTHON_VECTORCALL && PY_VERSION_HEX >= 0x03090000
#define __Pyx_PyObject_FastCallMethod(name, args, nargsf) PyObject_VectorcallMethod(name, args, nargsf, NULL)
#else
static PyObject *__Pyx_PyObject_FastCallMethod(PyObject *name, PyObject *const *args, size_t nargsf);
#endif

/* PyValueError_Check.proto */
#define __Pyx_PyExc_ValueError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_ValueError)

/* RaiseException.export */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* PyObjectFormatAndDecref.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatSimpleAndDecref(PyObject* s, PyObject* f);
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatAndDecref(PyObject* s, PyObject* f);

/* PyObjectFormat.proto */
#if CYTHON_USE_UNICODE_WRITER
static PyObject* __Pyx_PyObject_Format(PyObject* s, PyObject* f);
#else
#define __Pyx_PyObject_Format(s, f) PyObject_Format(s, f)
#endif

/* BuildPyUnicode.proto (used by COrdinalToPyUnicode) */
static PyObject* __Pyx_PyUnicode_BuildFromAscii(Py_ssize_t ulength, const char* chars, int clength,
                                                int prepend_sign, char padding_char);

/* COrdinalToPyUnicode.proto (used by CIntToPyUnicode) */
static CYTHON_INLINE int __Pyx_CheckUnicodeValue(int value);
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromOrdinal_Padded(int value, Py_ssize_t width, char padding_char);

/* GCCDiagnostics.proto (used by CIntToPyUnicode) */
#if !defined(__INTEL_COMPILER) && defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6))
#define __Pyx_HAS_GCC_DIAGNOSTIC
#endif

/* IncludeStdlibH.proto (used by CIntToPyUnicode) */
#include <stdlib.h>

/* CIntToPyUnicode.proto */
#define __Pyx_PyUnicode_From_int(value, width, padding_char, format_char) (\
    ((format_char) == ('c')) ?\
        __Pyx_uchar___Pyx_PyUnicode_From_int(value, width, padding_char) :\
        __Pyx____Pyx_PyUnicode_From_int(value, width, padding_char, format_char)\
    )
static CYTHON_INLINE PyObject* __Pyx_uchar___Pyx_PyUnicode_From_int(int value, Py_ssize_t width, char padding_char);
static CYTHON_INLINE PyObject* __Pyx____Pyx_PyUnicode_From_int(int value, Py_ssize_t width, char padding_char, char format_char);

/* JoinPyUnicode.export */
static PyObject* __Pyx_PyUnicode_Join(PyObject** values, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char);

/* PyDictVersioning.proto */
#include "src/gevent/_generated_include/PyDictVersioning_proto_fc9ab32633f390bb88d05edfc7599e60bc4df8ea122afe432e3adec504912045.h"
/* GetTopmostException.proto (used by SaveResetException) */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem * __Pyx_PyErr_GetTopmostException(PyThreadState *tstate);
#endif

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* GetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_GetException(type, value, tb)  __Pyx__GetException(__pyx_tstate, type, value, tb)
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* RaiseUnexpectedTypeError.proto */
static int __Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj);

/* SwapException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSwap(type, value, tb)  __Pyx__ExceptionSwap(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* GetItemInt.proto */
#include "src/gevent/_generated_include/GetItemInt_proto_3b42f7f7de85b71eab2f8b6ae51ddc7168a53d31d56dd1f1e34c94c36c959f55.h"
/* AssertionsEnabled.proto */
#if CYTHON_COMPILING_IN_LIMITED_API  ||  PY_VERSION_HEX >= 0x030C0000
  static int __pyx_assertions_enabled_flag;
  #define __pyx_assertions_enabled() (__pyx_assertions_enabled_flag)
  #if __clang__ || __GNUC__
  __attribute__((no_sanitize("thread")))
  #endif
  static int __Pyx_init_assertions_enabled(void) {
    PyObject *builtins, *debug, *debug_str;
    int flag;
    builtins = PyEval_GetBuiltins();
    if (!builtins) goto bad;
    debug_str = PyUnicode_FromStringAndSize("__debug__", 9);
    if (!debug_str) goto bad;
    debug = PyObject_GetItem(builtins, debug_str);
    Py_DECREF(debug_str);
    if (!debug) goto bad;
    flag = PyObject_IsTrue(debug);
    Py_DECREF(debug);
    if (flag == -1) goto bad;
    __pyx_assertions_enabled_flag = flag;
    return 0;
  bad:
    __pyx_assertions_enabled_flag = 1;
    return -1;
  }
#else
  #define __Pyx_init_assertions_enabled()  (0)
  #define __pyx_assertions_enabled()  (!Py_OptimizeFlag)
#endif

/* PyAssertionError_Check.proto */
#define __Pyx_PyExc_AssertionError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_AssertionError)

/* ListExtend.proto */
static CYTHON_INLINE int __Pyx_PyList_Extend(PyObject* L, PyObject* v) {
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00a2
    return PyList_Extend(L, v);
#elif CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000
    PyObject* none = _PyList_Extend((PyListObject*)L, v);
    if (unlikely(!none))
        return -1;
    Py_DECREF(none);
    return 0;
#else
    return PyList_SetSlice(L, PY_SSIZE_T_MAX, PY_SSIZE_T_MAX, v);
#endif
}

/* ListAppend.proto (used by append) */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
        L->ob_item[len] = x;
        #else
        PyList_SET_ITEM(list, len, x);
        #endif
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

/* PyObjectCall2Args.proto (used by PyObjectCallMethod1) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2);

/* PyObjectGetMethod.proto (used by PyObjectCallMethod1) */
#if !(CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000)))
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method);
#endif

/* PyObjectCallMethod1.proto (used by append) */
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg);

/* append.proto */
static CYTHON_INLINE int __Pyx_PyObject_Append(PyObject* L, PyObject* x);

/* ExtTypeTest.proto */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type);

/* PyObjectLookupSpecial.proto */
#if CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_LookupSpecialNoError(obj, attr_name)  __Pyx__PyObject_LookupSpecial(obj, attr_name, 0)
#define __Pyx_PyObject_LookupSpecial(obj, attr_name)  __Pyx__PyObject_LookupSpecial(obj, attr_name, 1)
static CYTHON_INLINE PyObject* __Pyx__PyObject_LookupSpecial(PyObject* obj, PyObject* attr_name, int with_error);
#else
#define __Pyx_PyObject_LookupSpecialNoError(o,n) __Pyx_PyObject_GetAttrStrNoError(o,n)
#define __Pyx_PyObject_LookupSpecial(o,n) __Pyx_PyObject_GetAttrStr(o,n)
#endif

/* ArgTypeTestFunc.export */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact);

/* ArgTypeTest.proto */
#define __Pyx_ArgTypeTest(obj, type, none_allowed, name, exact)\
    ((likely(__Pyx_IS_TYPE(obj, type) | (none_allowed && (obj == Py_None)))) ? 1 :\
        __Pyx__ArgTypeTest(obj, type, name, exact))

/* KeywordStringCheck.proto */
static CYTHON_INLINE int __Pyx_CheckKeywordStrings(const char* function_name, PyObject *kw);

/* AllocateExtensionType.proto */
static PyObject *__Pyx_AllocateExtensionType(PyTypeObject *t, int is_final);

/* CallTypeTraverse.proto */
#if !CYTHON_USE_TYPE_SPECS || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x03090000)
#define __Pyx_call_type_traverse(o, always_call, visit, arg) 0
#else
static int __Pyx_call_type_traverse(PyObject *o, int always_call, visitproc visit, void *arg);
#endif

/* CallNextTpDealloc.proto */
static void __Pyx_call_next_tp_dealloc(PyObject* obj, destructor current_tp_dealloc);

/* CallNextTpTraverse.proto */
static int __Pyx_call_next_tp_traverse(PyObject* obj, visitproc v, void *a, traverseproc current_tp_traverse);

/* CallNextTpClear.proto */
static void __Pyx_call_next_tp_clear(PyObject* obj, inquiry current_tp_clear);

/* VoidPtrExport.proto */
static int __Pyx_ExportVoidPtr(PyObject *api_dict, const char *name, void *p, const char *sig);

/* GetApiDict.proto */
static PyObject *__Pyx_ApiExport_GetApiDict(void);

/* LimitedApiGetTypeDict.proto (used by SetItemOnTypeDict) */
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_GetTypeDict(PyTypeObject *tp);
#endif

/* SetItemOnTypeDict.proto (used by FixUpExtensionType) */
static int __Pyx__SetItemOnTypeDict(PyTypeObject *tp, PyObject *k, PyObject *v);
#define __Pyx_SetItemOnTypeDict(tp, k, v) __Pyx__SetItemOnTypeDict((PyTypeObject*)tp, k, v)

/* FixUpExtensionType.proto */
static CYTHON_INLINE int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type);

/* PyObjectCallNoArg.proto (used by PyObjectCallMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);

/* PyObjectCallMethod0.proto (used by PyType_Ready) */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name);

/* ValidateBasesTuple.proto (used by PyType_Ready) */
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_USE_TYPE_SPECS
static int __Pyx_validate_bases_tuple(const char *type_name, Py_ssize_t dictoffset, PyObject *bases);
#endif

/* PyType_Ready.proto */
CYTHON_UNUSED static int __Pyx_PyType_Ready(PyTypeObject *t);

/* TypeImport.proto */
#ifndef __PYX_HAVE_RT_ImportType_proto_3_2_4
#define __PYX_HAVE_RT_ImportType_proto_3_2_4
#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#include <stdalign.h>
#endif
#if (defined (__STDC_VERSION__) && __STDC_VERSION__ >= 201112L) || __cplusplus >= 201103L
#define __PYX_GET_STRUCT_ALIGNMENT_3_2_4(s) alignof(s)
#else
#define __PYX_GET_STRUCT_ALIGNMENT_3_2_4(s) sizeof(void*)
#endif
enum __Pyx_ImportType_CheckSize_3_2_4 {
   __Pyx_ImportType_CheckSize_Error_3_2_4 = 0,
   __Pyx_ImportType_CheckSize_Warn_3_2_4 = 1,
   __Pyx_ImportType_CheckSize_Ignore_3_2_4 = 2
};
static PyTypeObject *__Pyx_ImportType_3_2_4(PyObject* module, const char *module_name, const char *class_name, size_t size, size_t alignment, enum __Pyx_ImportType_CheckSize_3_2_4 check_size);
#endif

/* GetVTable.proto */
static void* __Pyx_GetVtable(PyTypeObject *type);

/* SetVTable.proto */
static int __Pyx_SetVtable(PyTypeObject* typeptr , void* vtable);

/* MergeVTables.proto */
static int __Pyx_MergeVtables(PyTypeObject *type);

/* VoidPtrImport.proto */
static int __Pyx_ImportVoidPtr_3_2_4(PyObject *module, const char *name, void **p, const char *sig);

/* FunctionImport.proto */
static int __Pyx_ImportFunction_3_2_4(PyObject *module, const char *funcname, void (**f)(void), const char *sig);

/* ListPack.proto */
static PyObject *__Pyx_PyList_Pack(Py_ssize_t n, ...);

/* HasAttr.proto (used by ImportImpl) */
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
#define __Pyx_HasAttr(o, n)  PyObject_HasAttrWithError(o, n)
#else
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *, PyObject *);
#endif

/* ImportImpl.export */
static PyObject *__Pyx__Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, PyObject *moddict, int level);

/* Import.proto */
static CYTHON_INLINE PyObject *__Pyx_Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, int level);

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* dict_setdefault.proto (used by FetchCommonType) */
static CYTHON_INLINE PyObject *__Pyx_PyDict_SetDefault(PyObject *d, PyObject *key, PyObject *default_value);

/* AddModuleRef.proto (used by FetchSharedCythonModule) */
#if ((CYTHON_COMPILING_IN_CPYTHON_FREETHREADING ) ||\
     __PYX_LIMITED_VERSION_HEX < 0x030d0000)
  static PyObject *__Pyx_PyImport_AddModuleRef(const char *name);
#else
  #define __Pyx_PyImport_AddModuleRef(name) PyImport_AddModuleRef(name)
#endif

/* FetchSharedCythonModule.proto (used by FetchCommonType) */
static PyObject *__Pyx_FetchSharedCythonABIModule(void);

/* FetchCommonType.proto (used by CommonTypesMetaclass) */
static PyTypeObject* __Pyx_FetchCommonTypeFromSpec(PyTypeObject *metaclass, PyObject *module, PyType_Spec *spec, PyObject *bases);

/* CommonTypesMetaclass.proto (used by CythonFunctionShared) */
static int __pyx_CommonTypesMetaclass_init(PyObject *module);
#define __Pyx_CommonTypesMetaclass_USED

/* PyMethodNew.proto (used by CythonFunctionShared) */
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ);

/* PyVectorcallFastCallDict.proto (used by CythonFunctionShared) */
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw);
#endif

/* CythonFunctionShared.proto (used by CythonFunction) */
#include "src/gevent/_generated_include/CythonFunctionShared_proto_cfd16e7b1cdcce8e6454094d94c7459b788326000c3b790f09af3662926ca152.h"
/* CythonFunction.proto */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);

/* GetModuleGlobalName.proto */
#include "src/gevent/_generated_include/GetModuleGlobalName_proto_35020a92d25e00989051b6cce92e00e13fc50c1cb05740bd074404c24babc545.h"
/* PyObjectDelAttr.proto (used by PyObjectSetAttrStr) */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030d0000
#define __Pyx_PyObject_DelAttr(o, n) PyObject_SetAttr(o, n, NULL)
#else
#define __Pyx_PyObject_DelAttr(o, n) PyObject_DelAttr(o, n)
#endif

/* PyObjectSetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o, n, NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value);
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   __Pyx_PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

/* GetNameInClass.proto */
#define __Pyx_GetNameInClass(var, nmspace, name)  (var) = __Pyx__GetNameInClass(nmspace, name)
static PyObject *__Pyx__GetNameInClass(PyObject *nmspace, PyObject *name);

/* GetAttr.proto (used by Globals) */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *, PyObject *);

/* Globals.proto */
static PyObject* __Pyx_Globals(void);

/* CLineInTraceback.proto (used by AddTraceback) */
#if CYTHON_CLINE_IN_TRACEBACK && CYTHON_CLINE_IN_TRACEBACK_RUNTIME
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#else
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#endif

/* CodeObjectCache.proto (used by AddTraceback) */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject __Pyx_CachedCodeObjectType;
#else
typedef PyCodeObject __Pyx_CachedCodeObjectType;
#endif
typedef struct {
    __Pyx_CachedCodeObjectType* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_atomic_int_type accessor_count;
  #endif
};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static __Pyx_CachedCodeObjectType *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, __Pyx_CachedCodeObjectType* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyLong_As_int(PyObject *);

/* PyObjectVectorCallKwBuilder.proto (used by CIntToPy) */
CYTHON_UNUSED static int __Pyx_VectorcallBuilder_AddArg_Check(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n);
#if CYTHON_VECTORCALL
#if PY_VERSION_HEX >= 0x03090000
#define __Pyx_Object_Vectorcall_CallFromBuilder PyObject_Vectorcall
#else
#define __Pyx_Object_Vectorcall_CallFromBuilder _PyObject_Vectorcall
#endif
#define __Pyx_MakeVectorcallBuilderKwds(n) PyTuple_New(n)
static int __Pyx_VectorcallBuilder_AddArg(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n);
static int __Pyx_VectorcallBuilder_AddArgStr(const char *key, PyObject *value, PyObject *builder, PyObject **args, int n);
#else
#define __Pyx_Object_Vectorcall_CallFromBuilder __Pyx_PyObject_FastCallDict
#define __Pyx_MakeVectorcallBuilderKwds(n) __Pyx_PyDict_NewPresized(n)
#define __Pyx_VectorcallBuilder_AddArg(key, value, builder, args, n) PyDict_SetItem(builder, key, value)
#define __Pyx_VectorcallBuilder_AddArgStr(key, value, builder, args, n) PyDict_SetItemString(builder, key, value)
#endif

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_int(int value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_long(long value);

/* FormatTypeName.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%U"
#define __Pyx_DECREF_TypeName(obj) Py_XDECREF(obj)
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
#define __Pyx_PyType_GetFullyQualifiedName PyType_GetFullyQualifiedName
#else
static __Pyx_TypeName __Pyx_PyType_GetFullyQualifiedName(PyTypeObject* tp);
#endif
#else  // !LIMITED_API
typedef const char *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%.200s"
#define __Pyx_PyType_GetFullyQualifiedName(tp) ((tp)->tp_name)
#define __Pyx_DECREF_TypeName(obj)
#endif

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyLong_As_long(PyObject *);

/* FastTypeChecks.proto */
#include "src/gevent/_generated_include/FastTypeChecks_proto_b6a1eb5ffa2a3fc9ebedcc671e034de99427399b8e4cbe35bbcd118ac87e0e6e.h"
/* GetRuntimeVersion.proto */
#if __PYX_LIMITED_VERSION_HEX < 0x030b0000
static unsigned long __Pyx_cached_runtime_version = 0;
static void __Pyx_init_runtime_version(void);
#else
#define __Pyx_init_runtime_version()
#endif
static unsigned long __Pyx_get_runtime_version(void);

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer);

/* DecompressString.proto */
static PyObject *__Pyx_DecompressString(const char *s, Py_ssize_t length, int algo);

/* MultiPhaseInitModuleState.proto */
#if CYTHON_PEP489_MULTI_PHASE_INIT && CYTHON_USE_MODULE_STATE
static PyObject *__Pyx_State_FindModule(void*);
static int __Pyx_State_AddModule(PyObject* module, void*);
static int __Pyx_State_RemoveModule(void*);
#elif CYTHON_USE_MODULE_STATE
#define __Pyx_State_FindModule PyState_FindModule
#define __Pyx_State_AddModule PyState_AddModule
#define __Pyx_State_RemoveModule PyState_RemoveModule
#endif

/* #### Code section: module_declarations ### */
/* CythonABIVersion.proto */
#include "src/gevent/_generated_include/CythonABIVersion_proto_6de230514e3c249dc5d32a29298796e6371a56c148e74d1832d78a4b882841b1.h"
static int __pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore_locked(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore_release(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore_ready(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore__start_notify(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore__wait_return_value(CYTHON_UNUSED struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, int __pyx_v_waited, int __pyx_v_wait_success); /* proto*/
static int __pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore_wait(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, int __pyx_skip_dispatch, struct __pyx_opt_args_6gevent_19_gevent_c_semaphore_9Semaphore_wait *__pyx_optional_args); /* proto*/
static int __pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore_acquire(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, int __pyx_skip_dispatch, struct __pyx_opt_args_6gevent_19_gevent_c_semaphore_9Semaphore_acquire *__pyx_optional_args); /* proto*/
static PyObject *__pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore___enter__(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore___exit__(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_t, CYTHON_UNUSED PyObject *__pyx_v_v, CYTHON_UNUSED PyObject *__pyx_v_tb, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore__handle_unswitched_notifications(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, PyObject *__pyx_v_unswitched); /* proto*/
static PyObject *__pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore__Semaphore__add_link(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, PyObject *__pyx_v_link); /* proto*/
static PyObject *__pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore__Semaphore__acquire_from_other_thread(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, PyObject *__pyx_v_ex_args, int __pyx_v_blocking, PyObject *__pyx_v_timeout); /* proto*/
static PyObject *__pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore__Semaphore__acquire_using_two_hubs(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *__pyx_v_hub_for_this_thread, PyObject *__pyx_v_current_greenlet, PyObject *__pyx_v_timeout); /* proto*/
static PyObject *__pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore__Semaphore__acquire_from_other_thread_cb(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, PyObject *__pyx_v_results, int __pyx_v_blocking, PyObject *__pyx_v_timeout, PyObject *__pyx_v_thread_lock, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore__Semaphore__acquire_using_other_hub(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *__pyx_v_owning_hub, PyObject *__pyx_v_timeout); /* proto*/
static int __pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore__Semaphore__acquire_without_hubs(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, PyObject *__pyx_v_timeout); /* proto*/
static int __pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore__Semaphore__spin_on_native_lock(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, PyObject *__pyx_v_thread_lock, PyObject *__pyx_v_timeout); /* proto*/
static int __pyx_f_6gevent_19_gevent_c_semaphore_16BoundedSemaphore_release(struct __pyx_obj_6gevent_19_gevent_c_semaphore_BoundedSemaphore *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/

/* Module declarations from "cython" */

/* Module declarations from "greenlet" */

/* Module declarations from "gevent._gevent_c_greenlet_primitives" */
static PyObject **__pyx_vp_6gevent_29_gevent_c_greenlet_primitives_get_objects = 0;
#define __pyx_v_6gevent_29_gevent_c_greenlet_primitives_get_objects (*__pyx_vp_6gevent_29_gevent_c_greenlet_primitives_get_objects)
static PyObject **__pyx_vp_6gevent_29_gevent_c_greenlet_primitives_wref = 0;
#define __pyx_v_6gevent_29_gevent_c_greenlet_primitives_wref (*__pyx_vp_6gevent_29_gevent_c_greenlet_primitives_wref)
static PyObject **__pyx_vp_6gevent_29_gevent_c_greenlet_primitives_BlockingSwitchOutError = 0;
#define __pyx_v_6gevent_29_gevent_c_greenlet_primitives_BlockingSwitchOutError (*__pyx_vp_6gevent_29_gevent_c_greenlet_primitives_BlockingSwitchOutError)
static int *__pyx_vp_6gevent_29_gevent_c_greenlet_primitives__greenlet_imported = 0;
#define __pyx_v_6gevent_29_gevent_c_greenlet_primitives__greenlet_imported (*__pyx_vp_6gevent_29_gevent_c_greenlet_primitives__greenlet_imported)
static PyTypeObject **__pyx_vp_6gevent_29_gevent_c_greenlet_primitives__memoryview = 0;
#define __pyx_v_6gevent_29_gevent_c_greenlet_primitives__memoryview (*__pyx_vp_6gevent_29_gevent_c_greenlet_primitives__memoryview)
static PyTypeObject **__pyx_vp_6gevent_29_gevent_c_greenlet_primitives__buffer = 0;
#define __pyx_v_6gevent_29_gevent_c_greenlet_primitives__buffer (*__pyx_vp_6gevent_29_gevent_c_greenlet_primitives__buffer)

/* Module declarations from "gevent._gevent_c_hub_local" */
static PyObject **__pyx_vp_6gevent_19_gevent_c_hub_local__threadlocal = 0;
#define __pyx_v_6gevent_19_gevent_c_hub_local__threadlocal (*__pyx_vp_6gevent_19_gevent_c_hub_local__threadlocal)
static struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *(*__pyx_f_6gevent_19_gevent_c_hub_local_get_hub_if_exists)(int __pyx_skip_dispatch); /*proto*/
static struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *(*__pyx_f_6gevent_19_gevent_c_hub_local_get_hub_noargs)(int __pyx_skip_dispatch); /*proto*/

/* Module declarations from "gevent._gevent_c_abstract_linkable" */
static PyObject **__pyx_vp_6gevent_27_gevent_c_abstract_linkable_InvalidSwitchError = 0;
#define __pyx_v_6gevent_27_gevent_c_abstract_linkable_InvalidSwitchError (*__pyx_vp_6gevent_27_gevent_c_abstract_linkable_InvalidSwitchError)
static PyObject **__pyx_vp_6gevent_27_gevent_c_abstract_linkable_InvalidThreadUseError = 0;
#define __pyx_v_6gevent_27_gevent_c_abstract_linkable_InvalidThreadUseError (*__pyx_vp_6gevent_27_gevent_c_abstract_linkable_InvalidThreadUseError)
static PyObject **__pyx_vp_6gevent_27_gevent_c_abstract_linkable_Timeout = 0;
#define __pyx_v_6gevent_27_gevent_c_abstract_linkable_Timeout (*__pyx_vp_6gevent_27_gevent_c_abstract_linkable_Timeout)
static PyObject **__pyx_vp_6gevent_27_gevent_c_abstract_linkable__get_thread_ident = 0;
#define __pyx_v_6gevent_27_gevent_c_abstract_linkable__get_thread_ident (*__pyx_vp_6gevent_27_gevent_c_abstract_linkable__get_thread_ident)
static int *__pyx_vp_6gevent_27_gevent_c_abstract_linkable__greenlet_imported = 0;
#define __pyx_v_6gevent_27_gevent_c_abstract_linkable__greenlet_imported (*__pyx_vp_6gevent_27_gevent_c_abstract_linkable__greenlet_imported)
static PyObject **__pyx_vp_6gevent_27_gevent_c_abstract_linkable_get_objects = 0;
#define __pyx_v_6gevent_27_gevent_c_abstract_linkable_get_objects (*__pyx_vp_6gevent_27_gevent_c_abstract_linkable_get_objects)

/* Module declarations from "gevent._gevent_c_semaphore" */
static PyObject *__pyx_v_6gevent_19_gevent_c_semaphore_InvalidThreadUseError = 0;
static PyObject *__pyx_v_6gevent_19_gevent_c_semaphore_LoopExit = 0;
static PyObject *__pyx_v_6gevent_19_gevent_c_semaphore_Timeout = 0;
static PyObject *__pyx_v_6gevent_19_gevent_c_semaphore__native_sleep = 0;
static PyObject *__pyx_v_6gevent_19_gevent_c_semaphore_monotonic = 0;
static PyObject *__pyx_v_6gevent_19_gevent_c_semaphore_spawn_raw = 0;
static PyObject *__pyx_v_6gevent_19_gevent_c_semaphore__UNSET = 0;
static PyObject *__pyx_v_6gevent_19_gevent_c_semaphore__MULTI = 0;
/* #### Code section: typeinfo ### */
/* #### Code section: before_global_var ### */
#define __Pyx_MODULE_NAME "gevent._gevent_c_semaphore"
extern int __pyx_module_is_main_gevent___gevent_c_semaphore;
int __pyx_module_is_main_gevent___gevent_c_semaphore = 0;

/* Implementation of "gevent._gevent_c_semaphore" */
/* #### Code section: global_var ### */
static PyObject *__pyx_builtin_object;
static PyObject *__pyx_builtin___import__;
static PyObject *__pyx_builtin_super;
static PyObject *__pyx_builtin_id;
/* #### Code section: string_decls ### */
/* #### Code section: decls ### */
static PyObject *__pyx_pf_6gevent_19_gevent_c_semaphore__get_linkable(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static int __pyx_pf_6gevent_19_gevent_c_semaphore_16_LockReleaseLink___init__(struct __pyx_obj_6gevent_19_gevent_c_semaphore__LockReleaseLink *__pyx_v_self, PyObject *__pyx_v_lock); /* proto */
static PyObject *__pyx_pf_6gevent_19_gevent_c_semaphore_16_LockReleaseLink_2__call__(struct __pyx_obj_6gevent_19_gevent_c_semaphore__LockReleaseLink *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v__); /* proto */
static int __pyx_pf_6gevent_19_gevent_c_semaphore_9Semaphore___init__(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, PyObject *__pyx_v_value, PyObject *__pyx_v_hub); /* proto */
static PyObject *__pyx_pf_6gevent_19_gevent_c_semaphore_9Semaphore_2__str__(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_19_gevent_c_semaphore_9Semaphore_4locked(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_19_gevent_c_semaphore_9Semaphore_6release(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_19_gevent_c_semaphore_9Semaphore_8ready(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_19_gevent_c_semaphore_9Semaphore_10_start_notify(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_19_gevent_c_semaphore_9Semaphore_12wait(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, PyObject *__pyx_v_timeout); /* proto */
static PyObject *__pyx_pf_6gevent_19_gevent_c_semaphore_9Semaphore_14acquire(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, int __pyx_v_blocking, PyObject *__pyx_v_timeout); /* proto */
static PyObject *__pyx_pf_6gevent_19_gevent_c_semaphore_9Semaphore_16__enter__(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_19_gevent_c_semaphore_9Semaphore_18__exit__(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, PyObject *__pyx_v_t, PyObject *__pyx_v_v, PyObject *__pyx_v_tb); /* proto */
static PyObject *__pyx_pf_6gevent_19_gevent_c_semaphore_9Semaphore_20_Semaphore__acquire_from_other_thread_cb(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, PyObject *__pyx_v_results, int __pyx_v_blocking, PyObject *__pyx_v_timeout, PyObject *__pyx_v_thread_lock); /* proto */
static PyObject *__pyx_pf_6gevent_19_gevent_c_semaphore_9Semaphore_7counter___get__(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self); /* proto */
static int __pyx_pf_6gevent_19_gevent_c_semaphore_9Semaphore_7counter_2__set__(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6gevent_19_gevent_c_semaphore_16BoundedSemaphore___init__(struct __pyx_obj_6gevent_19_gevent_c_semaphore_BoundedSemaphore *__pyx_v_self, PyObject *__pyx_v_args, PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_6gevent_19_gevent_c_semaphore_16BoundedSemaphore_2release(struct __pyx_obj_6gevent_19_gevent_c_semaphore_BoundedSemaphore *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_19_gevent_c_semaphore_16BoundedSemaphore_4_at_fork_reinit(struct __pyx_obj_6gevent_19_gevent_c_semaphore_BoundedSemaphore *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_19_gevent_c_semaphore_16BoundedSemaphore_14_initial_value___get__(struct __pyx_obj_6gevent_19_gevent_c_semaphore_BoundedSemaphore *__pyx_v_self); /* proto */
static PyObject *__pyx_tp_new_6gevent_19_gevent_c_semaphore__LockReleaseLink(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6gevent_19_gevent_c_semaphore_Semaphore(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6gevent_19_gevent_c_semaphore_BoundedSemaphore(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
/* #### Code section: late_includes ### */
/* #### Code section: module_state ### */
/* SmallCodeConfig */
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif

typedef struct {
  PyObject *__pyx_d;
  PyObject *__pyx_b;
  PyObject *__pyx_cython_runtime;
  PyObject *__pyx_empty_tuple;
  PyObject *__pyx_empty_bytes;
  PyObject *__pyx_empty_unicode;
  PyTypeObject *__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_greenlet;
  PyTypeObject *__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet;
  PyTypeObject *__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop;
  PyTypeObject *__pyx_ptype_6gevent_27_gevent_c_abstract_linkable_greenlet;
  PyTypeObject *__pyx_ptype_6gevent_27_gevent_c_abstract_linkable__FakeNotifier;
  PyTypeObject *__pyx_ptype_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable;
  PyObject *__pyx_type_6gevent_19_gevent_c_semaphore__LockReleaseLink;
  PyObject *__pyx_type_6gevent_19_gevent_c_semaphore_Semaphore;
  PyObject *__pyx_type_6gevent_19_gevent_c_semaphore_BoundedSemaphore;
  PyTypeObject *__pyx_ptype_6gevent_19_gevent_c_semaphore__LockReleaseLink;
  PyTypeObject *__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore;
  PyTypeObject *__pyx_ptype_6gevent_19_gevent_c_semaphore_BoundedSemaphore;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_items;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_pop;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_values;
  PyObject *__pyx_tuple[6];
  PyObject *__pyx_codeobj_tab[12];
  PyObject *__pyx_string_tab[134];
  PyObject *__pyx_number_tab[2];
/* #### Code section: module_state_contents ### */
/* CommonTypesMetaclass.module_state_decls */
PyTypeObject *__pyx_CommonTypesMetaclassType;

/* CachedMethodType.module_state_decls */
#if CYTHON_COMPILING_IN_LIMITED_API
PyObject *__Pyx_CachedMethodType;
#endif

/* CythonFunctionShared.module_state_decls */
PyTypeObject *__pyx_CyFunctionType;

/* CodeObjectCache.module_state_decls */
struct __Pyx_CodeObjectCache __pyx_code_cache;

/* #### Code section: module_state_end ### */
} __pyx_mstatetype;

#if CYTHON_USE_MODULE_STATE
#ifdef __cplusplus
namespace {
extern struct PyModuleDef __pyx_moduledef;
} /* anonymous namespace */
#else
static struct PyModuleDef __pyx_moduledef;
#endif

#define __pyx_mstate_global (__Pyx_PyModule_GetState(__Pyx_State_FindModule(&__pyx_moduledef)))

#define __pyx_m (__Pyx_State_FindModule(&__pyx_moduledef))
#else
static __pyx_mstatetype __pyx_mstate_global_static =
#ifdef __cplusplus
    {};
#else
    {0};
#endif
static __pyx_mstatetype * const __pyx_mstate_global = &__pyx_mstate_global_static;
#endif
/* #### Code section: constant_name_defines ### */
#define __pyx_kp_u_Note_that_Cython_is_deliberately __pyx_string_tab[0]
#define __pyx_kp_u_Semaphore_released_too_many_time __pyx_string_tab[1]
#define __pyx_kp_u__2 __pyx_string_tab[2]
#define __pyx_kp_u__3 __pyx_string_tab[3]
#define __pyx_kp_u__4 __pyx_string_tab[4]
#define __pyx_kp_u__5 __pyx_string_tab[5]
#define __pyx_kp_u_add_note __pyx_string_tab[6]
#define __pyx_kp_u_at_0x __pyx_string_tab[7]
#define __pyx_kp_u_counter __pyx_string_tab[8]
#define __pyx_kp_u_disable __pyx_string_tab[9]
#define __pyx_kp_u_enable __pyx_string_tab[10]
#define __pyx_kp_u_gc __pyx_string_tab[11]
#define __pyx_kp_u_gevent___semaphore __pyx_string_tab[12]
#define __pyx_kp_u_gevent__abstract_linkable __pyx_string_tab[13]
#define __pyx_kp_u_isenabled __pyx_string_tab[14]
#define __pyx_kp_u_links __pyx_string_tab[15]
#define __pyx_kp_u_semaphore_initial_value_must_be __pyx_string_tab[16]
#define __pyx_kp_u_src_gevent__semaphore_py __pyx_string_tab[17]
#define __pyx_n_u_ __pyx_string_tab[18]
#define __pyx_n_u_AbstractLinkable __pyx_string_tab[19]
#define __pyx_n_u_BoundedSemaphore __pyx_string_tab[20]
#define __pyx_n_u_BoundedSemaphore__at_fork_reinit __pyx_string_tab[21]
#define __pyx_n_u_BoundedSemaphore_release __pyx_string_tab[22]
#define __pyx_n_u_InvalidThreadUseError __pyx_string_tab[23]
#define __pyx_n_u_LockReleaseLink __pyx_string_tab[24]
#define __pyx_n_u_LoopExit __pyx_string_tab[25]
#define __pyx_n_u_NoHubs __pyx_string_tab[26]
#define __pyx_n_u_OVER_RELEASE_ERROR __pyx_string_tab[27]
#define __pyx_n_u_Pyx_PyDict_NextRef __pyx_string_tab[28]
#define __pyx_n_u_Semaphore __pyx_string_tab[29]
#define __pyx_n_u_Semaphore__Semaphore__acquire_fr __pyx_string_tab[30]
#define __pyx_n_u_Semaphore___enter __pyx_string_tab[31]
#define __pyx_n_u_Semaphore___exit __pyx_string_tab[32]
#define __pyx_n_u_Semaphore__acquire_from_other_t __pyx_string_tab[33]
#define __pyx_n_u_Semaphore__start_notify __pyx_string_tab[34]
#define __pyx_n_u_Semaphore_acquire __pyx_string_tab[35]
#define __pyx_n_u_Semaphore_locked __pyx_string_tab[36]
#define __pyx_n_u_Semaphore_ready __pyx_string_tab[37]
#define __pyx_n_u_Semaphore_release __pyx_string_tab[38]
#define __pyx_n_u_Semaphore_wait __pyx_string_tab[39]
#define __pyx_n_u_Timeout __pyx_string_tab[40]
#define __pyx_n_u_abstract_linkable __pyx_string_tab[41]
#define __pyx_n_u_acquire __pyx_string_tab[42]
#define __pyx_n_u_all __pyx_string_tab[43]
#define __pyx_n_u_append __pyx_string_tab[44]
#define __pyx_n_u_args __pyx_string_tab[45]
#define __pyx_n_u_async __pyx_string_tab[46]
#define __pyx_n_u_asyncio_coroutines __pyx_string_tab[47]
#define __pyx_n_u_at_fork_reinit __pyx_string_tab[48]
#define __pyx_n_u_blocking __pyx_string_tab[49]
#define __pyx_n_u_class __pyx_string_tab[50]
#define __pyx_n_u_cline_in_traceback __pyx_string_tab[51]
#define __pyx_n_u_close __pyx_string_tab[52]
#define __pyx_n_u_counter_2 __pyx_string_tab[53]
#define __pyx_n_u_dict __pyx_string_tab[54]
#define __pyx_n_u_enter __pyx_string_tab[55]
#define __pyx_n_u_exit __pyx_string_tab[56]
#define __pyx_n_u_func __pyx_string_tab[57]
#define __pyx_n_u_get_hub __pyx_string_tab[58]
#define __pyx_n_u_get_hub_if_exists __pyx_string_tab[59]
#define __pyx_n_u_get_linkable __pyx_string_tab[60]
#define __pyx_n_u_gevent__compat __pyx_string_tab[61]
#define __pyx_n_u_gevent__gevent_c_semaphore __pyx_string_tab[62]
#define __pyx_n_u_gevent__hub_local __pyx_string_tab[63]
#define __pyx_n_u_gevent__util __pyx_string_tab[64]
#define __pyx_n_u_gevent_exceptions __pyx_string_tab[65]
#define __pyx_n_u_gevent_hub __pyx_string_tab[66]
#define __pyx_n_u_gevent_timeout __pyx_string_tab[67]
#define __pyx_n_u_hub __pyx_string_tab[68]
#define __pyx_n_u_id __pyx_string_tab[69]
#define __pyx_n_u_import __pyx_string_tab[70]
#define __pyx_n_u_import_c_accel __pyx_string_tab[71]
#define __pyx_n_u_init __pyx_string_tab[72]
#define __pyx_n_u_initial_value __pyx_string_tab[73]
#define __pyx_n_u_is_coroutine __pyx_string_tab[74]
#define __pyx_n_u_items __pyx_string_tab[75]
#define __pyx_n_u_lock __pyx_string_tab[76]
#define __pyx_n_u_locked __pyx_string_tab[77]
#define __pyx_n_u_main __pyx_string_tab[78]
#define __pyx_n_u_main_hub __pyx_string_tab[79]
#define __pyx_n_u_module __pyx_string_tab[80]
#define __pyx_n_u_monotonic __pyx_string_tab[81]
#define __pyx_n_u_multithreaded __pyx_string_tab[82]
#define __pyx_n_u_name __pyx_string_tab[83]
#define __pyx_n_u_object __pyx_string_tab[84]
#define __pyx_n_u_pop __pyx_string_tab[85]
#define __pyx_n_u_py3k_acquire __pyx_string_tab[86]
#define __pyx_n_u_pyx_capi __pyx_string_tab[87]
#define __pyx_n_u_pyx_vtable __pyx_string_tab[88]
#define __pyx_n_u_qualname __pyx_string_tab[89]
#define __pyx_n_u_ready __pyx_string_tab[90]
#define __pyx_n_u_release __pyx_string_tab[91]
#define __pyx_n_u_results __pyx_string_tab[92]
#define __pyx_n_u_run_callback_threadsafe __pyx_string_tab[93]
#define __pyx_n_u_self __pyx_string_tab[94]
#define __pyx_n_u_send_ignoring_arg __pyx_string_tab[95]
#define __pyx_n_u_set_name __pyx_string_tab[96]
#define __pyx_n_u_setdefault __pyx_string_tab[97]
#define __pyx_n_u_sleep __pyx_string_tab[98]
#define __pyx_n_u_slots __pyx_string_tab[99]
#define __pyx_n_u_spawn_raw __pyx_string_tab[100]
#define __pyx_n_u_start __pyx_string_tab[101]
#define __pyx_n_u_start_new_or_dummy __pyx_string_tab[102]
#define __pyx_n_u_start_notify __pyx_string_tab[103]
#define __pyx_n_u_stop __pyx_string_tab[104]
#define __pyx_n_u_super __pyx_string_tab[105]
#define __pyx_n_u_switch __pyx_string_tab[106]
#define __pyx_n_u_t __pyx_string_tab[107]
#define __pyx_n_u_tb __pyx_string_tab[108]
#define __pyx_n_u_test __pyx_string_tab[109]
#define __pyx_n_u_thread_lock __pyx_string_tab[110]
#define __pyx_n_u_time __pyx_string_tab[111]
#define __pyx_n_u_timeout __pyx_string_tab[112]
#define __pyx_n_u_v __pyx_string_tab[113]
#define __pyx_n_u_value __pyx_string_tab[114]
#define __pyx_n_u_values __pyx_string_tab[115]
#define __pyx_n_u_wait __pyx_string_tab[116]
#define __pyx_n_u_x __pyx_string_tab[117]
#define __pyx_kp_b_PyObject_InvalidThreadUseError_L __pyx_string_tab[118]
#define __pyx_kp_b_PyObject_PyTypeObject_int_Blocki __pyx_string_tab[119]
#define __pyx_kp_b_PyObject__threadlocal __pyx_string_tab[120]
#define __pyx_kp_b_PyObject_int_InvalidSwitchError __pyx_string_tab[121]
#define __pyx_kp_b_iso88591_1_1_q __pyx_string_tab[122]
#define __pyx_kp_b_iso88591_1_4y_4q_F_1_t1 __pyx_string_tab[123]
#define __pyx_kp_b_iso88591_A_4y_4q_1_81A_83d_q_q __pyx_string_tab[124]
#define __pyx_kp_b_iso88591_A_HA __pyx_string_tab[125]
#define __pyx_kp_b_iso88591_A_L_a_t1 __pyx_string_tab[126]
#define __pyx_kp_b_iso88591_A_Q_5Q_Kt1 __pyx_string_tab[127]
#define __pyx_kp_b_iso88591_A_T_A_7_1_xq_q __pyx_string_tab[128]
#define __pyx_kp_b_iso88591_A_a __pyx_string_tab[129]
#define __pyx_kp_b_iso88591_A_t9Ba __pyx_string_tab[130]
#define __pyx_kp_b_iso88591_A_t9Cq __pyx_string_tab[131]
#define __pyx_kp_b_iso88591_Q0_4_s_8_D_Q_Qa_t4y_A_t_7q8LJVW __pyx_string_tab[132]
#define __pyx_kp_b_struct___pyx_obj_6gevent_29_geve __pyx_string_tab[133]
#define __pyx_int_0 __pyx_number_tab[0]
#define __pyx_int_1 __pyx_number_tab[1]
/* #### Code section: module_state_clear ### */
#if CYTHON_USE_MODULE_STATE
static CYTHON_SMALL_CODE int __pyx_m_clear(PyObject *m) {
  __pyx_mstatetype *clear_module_state = __Pyx_PyModule_GetState(m);
  if (!clear_module_state) return 0;
  Py_CLEAR(clear_module_state->__pyx_d);
  Py_CLEAR(clear_module_state->__pyx_b);
  Py_CLEAR(clear_module_state->__pyx_cython_runtime);
  Py_CLEAR(clear_module_state->__pyx_empty_tuple);
  Py_CLEAR(clear_module_state->__pyx_empty_bytes);
  Py_CLEAR(clear_module_state->__pyx_empty_unicode);
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __Pyx_State_RemoveModule(NULL);
  #endif
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_greenlet);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_27_gevent_c_abstract_linkable_greenlet);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_27_gevent_c_abstract_linkable__FakeNotifier);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_19_gevent_c_semaphore__LockReleaseLink);
  Py_CLEAR(clear_module_state->__pyx_type_6gevent_19_gevent_c_semaphore__LockReleaseLink);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore);
  Py_CLEAR(clear_module_state->__pyx_type_6gevent_19_gevent_c_semaphore_Semaphore);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_19_gevent_c_semaphore_BoundedSemaphore);
  Py_CLEAR(clear_module_state->__pyx_type_6gevent_19_gevent_c_semaphore_BoundedSemaphore);
  for (int i=0; i<6; ++i) { Py_CLEAR(clear_module_state->__pyx_tuple[i]); }
  for (int i=0; i<12; ++i) { Py_CLEAR(clear_module_state->__pyx_codeobj_tab[i]); }
  for (int i=0; i<134; ++i) { Py_CLEAR(clear_module_state->__pyx_string_tab[i]); }
  for (int i=0; i<2; ++i) { Py_CLEAR(clear_module_state->__pyx_number_tab[i]); }
/* #### Code section: module_state_clear_contents ### */
/* CommonTypesMetaclass.module_state_clear */
Py_CLEAR(clear_module_state->__pyx_CommonTypesMetaclassType);

/* CythonFunctionShared.module_state_clear */
Py_CLEAR(clear_module_state->__pyx_CyFunctionType);

/* #### Code section: module_state_clear_end ### */
return 0;
}
#endif
/* #### Code section: module_state_traverse ### */
#if CYTHON_USE_MODULE_STATE
static CYTHON_SMALL_CODE int __pyx_m_traverse(PyObject *m, visitproc visit, void *arg) {
  __pyx_mstatetype *traverse_module_state = __Pyx_PyModule_GetState(m);
  if (!traverse_module_state) return 0;
  Py_VISIT(traverse_module_state->__pyx_d);
  Py_VISIT(traverse_module_state->__pyx_b);
  Py_VISIT(traverse_module_state->__pyx_cython_runtime);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_tuple);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_bytes);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_unicode);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_greenlet);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_27_gevent_c_abstract_linkable_greenlet);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_27_gevent_c_abstract_linkable__FakeNotifier);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_19_gevent_c_semaphore__LockReleaseLink);
  Py_VISIT(traverse_module_state->__pyx_type_6gevent_19_gevent_c_semaphore__LockReleaseLink);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore);
  Py_VISIT(traverse_module_state->__pyx_type_6gevent_19_gevent_c_semaphore_Semaphore);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_19_gevent_c_semaphore_BoundedSemaphore);
  Py_VISIT(traverse_module_state->__pyx_type_6gevent_19_gevent_c_semaphore_BoundedSemaphore);
  for (int i=0; i<6; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_tuple[i]); }
  for (int i=0; i<12; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_codeobj_tab[i]); }
  for (int i=0; i<134; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_string_tab[i]); }
  for (int i=0; i<2; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_number_tab[i]); }
/* #### Code section: module_state_traverse_contents ### */
/* CommonTypesMetaclass.module_state_traverse */
Py_VISIT(traverse_module_state->__pyx_CommonTypesMetaclassType);

/* CythonFunctionShared.module_state_traverse */
Py_VISIT(traverse_module_state->__pyx_CyFunctionType);

/* #### Code section: module_state_traverse_end ### */
return 0;
}
#endif
/* #### Code section: module_code ### */

/* "gevent/_gevent_c_greenlet_primitives.pxd":22
 *     void PyGreenlet_Import()
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef inline greenlet getcurrent():
 *     return PyGreenlet_GetCurrent()
*/

static CYTHON_INLINE PyGreenlet *__pyx_f_6gevent_29_gevent_c_greenlet_primitives_getcurrent(void) {
  PyGreenlet *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getcurrent", 0);

  /* "gevent/_gevent_c_greenlet_primitives.pxd":24
 * @cython.final
 * cdef inline greenlet getcurrent():
 *     return PyGreenlet_GetCurrent()             # <<<<<<<<<<<<<<
 * 
 * cdef bint _greenlet_imported
*/
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __pyx_t_1 = ((PyObject *)PyGreenlet_GetCurrent()); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = ((PyGreenlet *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "gevent/_gevent_c_greenlet_primitives.pxd":22
 *     void PyGreenlet_Import()
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef inline greenlet getcurrent():
 *     return PyGreenlet_GetCurrent()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_c_greenlet_primitives.getcurrent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/_gevent_c_greenlet_primitives.pxd":28
 * cdef bint _greenlet_imported
 * 
 * cdef inline void greenlet_init():             # <<<<<<<<<<<<<<
 *     global _greenlet_imported
 *     if not _greenlet_imported:
*/

static CYTHON_INLINE void __pyx_f_6gevent_29_gevent_c_greenlet_primitives_greenlet_init(void) {
  int __pyx_t_1;

  /* "gevent/_gevent_c_greenlet_primitives.pxd":30
 * cdef inline void greenlet_init():
 *     global _greenlet_imported
 *     if not _greenlet_imported:             # <<<<<<<<<<<<<<
 *         PyGreenlet_Import()
 *         _greenlet_imported = True
*/
  __pyx_t_1 = (!__pyx_v_6gevent_29_gevent_c_greenlet_primitives__greenlet_imported);
  if (__pyx_t_1) {

    /* "gevent/_gevent_c_greenlet_primitives.pxd":31
 *     global _greenlet_imported
 *     if not _greenlet_imported:
 *         PyGreenlet_Import()             # <<<<<<<<<<<<<<
 *         _greenlet_imported = True
 * 
*/
    PyGreenlet_Import();

    /* "gevent/_gevent_c_greenlet_primitives.pxd":32
 *     if not _greenlet_imported:
 *         PyGreenlet_Import()
 *         _greenlet_imported = True             # <<<<<<<<<<<<<<
 * 
 * cdef inline object _greenlet_switch(greenlet self):
*/
    __pyx_v_6gevent_29_gevent_c_greenlet_primitives__greenlet_imported = 1;

    /* "gevent/_gevent_c_greenlet_primitives.pxd":30
 * cdef inline void greenlet_init():
 *     global _greenlet_imported
 *     if not _greenlet_imported:             # <<<<<<<<<<<<<<
 *         PyGreenlet_Import()
 *         _greenlet_imported = True
*/
  }

  /* "gevent/_gevent_c_greenlet_primitives.pxd":28
 * cdef bint _greenlet_imported
 * 
 * cdef inline void greenlet_init():             # <<<<<<<<<<<<<<
 *     global _greenlet_imported
 *     if not _greenlet_imported:
*/

  /* function exit code */
}

/* "gevent/_gevent_c_greenlet_primitives.pxd":34
 *         _greenlet_imported = True
 * 
 * cdef inline object _greenlet_switch(greenlet self):             # <<<<<<<<<<<<<<
 *     return PyGreenlet_Switch(self, NULL, NULL)
 * 
*/

static CYTHON_INLINE PyObject *__pyx_f_6gevent_29_gevent_c_greenlet_primitives__greenlet_switch(PyGreenlet *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_greenlet_switch", 0);

  /* "gevent/_gevent_c_greenlet_primitives.pxd":35
 * 
 * cdef inline object _greenlet_switch(greenlet self):
 *     return PyGreenlet_Switch(self, NULL, NULL)             # <<<<<<<<<<<<<<
 * 
 * cdef class TrackedRawGreenlet(greenlet):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyGreenlet_Switch(__pyx_v_self, NULL, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 35, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "gevent/_gevent_c_greenlet_primitives.pxd":34
 *         _greenlet_imported = True
 * 
 * cdef inline object _greenlet_switch(greenlet self):             # <<<<<<<<<<<<<<
 *     return PyGreenlet_Switch(self, NULL, NULL)
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_c_greenlet_primitives._greenlet_switch", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/_gevent_c_abstract_linkable.pxd":25
 *     void PyGreenlet_Import()
 * 
 * cdef inline greenlet getcurrent():             # <<<<<<<<<<<<<<
 *     return PyGreenlet_GetCurrent()
 * 
*/

static CYTHON_INLINE PyGreenlet *__pyx_f_6gevent_27_gevent_c_abstract_linkable_getcurrent(void) {
  PyGreenlet *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getcurrent", 0);

  /* "gevent/_gevent_c_abstract_linkable.pxd":26
 * 
 * cdef inline greenlet getcurrent():
 *     return PyGreenlet_GetCurrent()             # <<<<<<<<<<<<<<
 * 
 * cdef inline void greenlet_init():
*/
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __pyx_t_1 = ((PyObject *)PyGreenlet_GetCurrent()); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = ((PyGreenlet *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "gevent/_gevent_c_abstract_linkable.pxd":25
 *     void PyGreenlet_Import()
 * 
 * cdef inline greenlet getcurrent():             # <<<<<<<<<<<<<<
 *     return PyGreenlet_GetCurrent()
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_c_abstract_linkable.getcurrent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/_gevent_c_abstract_linkable.pxd":28
 *     return PyGreenlet_GetCurrent()
 * 
 * cdef inline void greenlet_init():             # <<<<<<<<<<<<<<
 *     global _greenlet_imported
 *     if not _greenlet_imported:
*/

static CYTHON_INLINE void __pyx_f_6gevent_27_gevent_c_abstract_linkable_greenlet_init(void) {
  int __pyx_t_1;

  /* "gevent/_gevent_c_abstract_linkable.pxd":30
 * cdef inline void greenlet_init():
 *     global _greenlet_imported
 *     if not _greenlet_imported:             # <<<<<<<<<<<<<<
 *         PyGreenlet_Import()
 *         _greenlet_imported = True
*/
  __pyx_t_1 = (!__pyx_v_6gevent_27_gevent_c_abstract_linkable__greenlet_imported);
  if (__pyx_t_1) {

    /* "gevent/_gevent_c_abstract_linkable.pxd":31
 *     global _greenlet_imported
 *     if not _greenlet_imported:
 *         PyGreenlet_Import()             # <<<<<<<<<<<<<<
 *         _greenlet_imported = True
 * 
*/
    PyGreenlet_Import();

    /* "gevent/_gevent_c_abstract_linkable.pxd":32
 *     if not _greenlet_imported:
 *         PyGreenlet_Import()
 *         _greenlet_imported = True             # <<<<<<<<<<<<<<
 * 
 * cdef void _init()
*/
    __pyx_v_6gevent_27_gevent_c_abstract_linkable__greenlet_imported = 1;

    /* "gevent/_gevent_c_abstract_linkable.pxd":30
 * cdef inline void greenlet_init():
 *     global _greenlet_imported
 *     if not _greenlet_imported:             # <<<<<<<<<<<<<<
 *         PyGreenlet_Import()
 *         _greenlet_imported = True
*/
  }

  /* "gevent/_gevent_c_abstract_linkable.pxd":28
 *     return PyGreenlet_GetCurrent()
 * 
 * cdef inline void greenlet_init():             # <<<<<<<<<<<<<<
 *     global _greenlet_imported
 *     if not _greenlet_imported:
*/

  /* function exit code */
}

/* "src/gevent/_semaphore.py":24
 * from gevent.timeout import Timeout
 * 
 * def _get_linkable():             # <<<<<<<<<<<<<<
 *     x = __import__('gevent._abstract_linkable')
 *     return x._abstract_linkable.AbstractLinkable
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_19_gevent_c_semaphore_1_get_linkable(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_19_gevent_c_semaphore__get_linkable, "_get_linkable()");
static PyMethodDef __pyx_mdef_6gevent_19_gevent_c_semaphore_1_get_linkable = {"_get_linkable", (PyCFunction)__pyx_pw_6gevent_19_gevent_c_semaphore_1_get_linkable, METH_NOARGS, __pyx_doc_6gevent_19_gevent_c_semaphore__get_linkable};
static PyObject *__pyx_pw_6gevent_19_gevent_c_semaphore_1_get_linkable(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_get_linkable (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_19_gevent_c_semaphore__get_linkable(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_19_gevent_c_semaphore__get_linkable(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_v_x = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_get_linkable", 0);

  /* "src/gevent/_semaphore.py":25
 * 
 * def _get_linkable():
 *     x = __import__('gevent._abstract_linkable')             # <<<<<<<<<<<<<<
 *     return x._abstract_linkable.AbstractLinkable
 * locals()['AbstractLinkable'] = _get_linkable()
*/
  __pyx_t_2 = NULL;
  __pyx_t_3 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_gevent__abstract_linkable};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin___import__, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 25, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_x = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "src/gevent/_semaphore.py":26
 * def _get_linkable():
 *     x = __import__('gevent._abstract_linkable')
 *     return x._abstract_linkable.AbstractLinkable             # <<<<<<<<<<<<<<
 * locals()['AbstractLinkable'] = _get_linkable()
 * del _get_linkable
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_x, __pyx_mstate_global->__pyx_n_u_abstract_linkable); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_AbstractLinkable); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "src/gevent/_semaphore.py":24
 * from gevent.timeout import Timeout
 * 
 * def _get_linkable():             # <<<<<<<<<<<<<<
 *     x = __import__('gevent._abstract_linkable')
 *     return x._abstract_linkable.AbstractLinkable
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("gevent._gevent_c_semaphore._get_linkable", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_x);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/_semaphore.py":39
 *     )
 * 
 *     def __init__(self, lock):             # <<<<<<<<<<<<<<
 *         self.lock = lock
 * 
*/

/* Python wrapper */
static int __pyx_pw_6gevent_19_gevent_c_semaphore_16_LockReleaseLink_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6gevent_19_gevent_c_semaphore_16_LockReleaseLink_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_lock = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_lock,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 39, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 39, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__init__", 0) < (0)) __PYX_ERR(0, 39, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__init__", 1, 1, 1, i); __PYX_ERR(0, 39, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 39, __pyx_L3_error)
    }
    __pyx_v_lock = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 39, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("gevent._gevent_c_semaphore._LockReleaseLink.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6gevent_19_gevent_c_semaphore_16_LockReleaseLink___init__(((struct __pyx_obj_6gevent_19_gevent_c_semaphore__LockReleaseLink *)__pyx_v_self), __pyx_v_lock);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6gevent_19_gevent_c_semaphore_16_LockReleaseLink___init__(struct __pyx_obj_6gevent_19_gevent_c_semaphore__LockReleaseLink *__pyx_v_self, PyObject *__pyx_v_lock) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "src/gevent/_semaphore.py":40
 * 
 *     def __init__(self, lock):
 *         self.lock = lock             # <<<<<<<<<<<<<<
 * 
 *     def __call__(self, _):
*/
  __Pyx_INCREF(__pyx_v_lock);
  __Pyx_GIVEREF(__pyx_v_lock);
  __Pyx_GOTREF(__pyx_v_self->lock);
  __Pyx_DECREF(__pyx_v_self->lock);
  __pyx_v_self->lock = __pyx_v_lock;

  /* "src/gevent/_semaphore.py":39
 *     )
 * 
 *     def __init__(self, lock):             # <<<<<<<<<<<<<<
 *         self.lock = lock
 * 
*/

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/_semaphore.py":42
 *         self.lock = lock
 * 
 *     def __call__(self, _):             # <<<<<<<<<<<<<<
 *         self.lock.release()
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_19_gevent_c_semaphore_16_LockReleaseLink_3__call__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6gevent_19_gevent_c_semaphore_16_LockReleaseLink_3__call__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v__ = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__call__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 42, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 42, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__call__", 0) < (0)) __PYX_ERR(0, 42, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__call__", 1, 1, 1, i); __PYX_ERR(0, 42, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 42, __pyx_L3_error)
    }
    __pyx_v__ = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__call__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 42, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("gevent._gevent_c_semaphore._LockReleaseLink.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6gevent_19_gevent_c_semaphore_16_LockReleaseLink_2__call__(((struct __pyx_obj_6gevent_19_gevent_c_semaphore__LockReleaseLink *)__pyx_v_self), __pyx_v__);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_19_gevent_c_semaphore_16_LockReleaseLink_2__call__(struct __pyx_obj_6gevent_19_gevent_c_semaphore__LockReleaseLink *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v__) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__call__", 0);

  /* "src/gevent/_semaphore.py":43
 * 
 *     def __call__(self, _):
 *         self.lock.release()             # <<<<<<<<<<<<<<
 * 
 * _UNSET = object()
*/
  __pyx_t_2 = __pyx_v_self->lock;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_release, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 43, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "src/gevent/_semaphore.py":42
 *         self.lock = lock
 * 
 *     def __call__(self, _):             # <<<<<<<<<<<<<<
 *         self.lock.release()
 * 
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("gevent._gevent_c_semaphore._LockReleaseLink.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/_semaphore.py":96
 *     )
 * 
 *     def __init__(self, value=1, hub=None):             # <<<<<<<<<<<<<<
 *         self.counter = value
 *         if self.counter < 0: # Do the check after Cython native int conversion
*/

/* Python wrapper */
static int __pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_v_hub = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_value,&__pyx_mstate_global->__pyx_n_u_hub,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 96, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 96, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 96, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__init__", 0) < (0)) __PYX_ERR(0, 96, __pyx_L3_error)
      if (!values[0]) values[0] = __Pyx_NewRef(((PyObject *)__pyx_mstate_global->__pyx_int_1));
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
    } else {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 96, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 96, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[0]) values[0] = __Pyx_NewRef(((PyObject *)__pyx_mstate_global->__pyx_int_1));
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_value = values[0];
    __pyx_v_hub = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 0, 2, __pyx_nargs); __PYX_ERR(0, 96, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("gevent._gevent_c_semaphore.Semaphore.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6gevent_19_gevent_c_semaphore_9Semaphore___init__(((struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self), __pyx_v_value, __pyx_v_hub);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6gevent_19_gevent_c_semaphore_9Semaphore___init__(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, PyObject *__pyx_v_value, PyObject *__pyx_v_hub) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "src/gevent/_semaphore.py":97
 * 
 *     def __init__(self, value=1, hub=None):
 *         self.counter = value             # <<<<<<<<<<<<<<
 *         if self.counter < 0: # Do the check after Cython native int conversion
 *             raise ValueError("semaphore initial value must be >= 0")
*/
  __pyx_t_1 = __Pyx_PyLong_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 97, __pyx_L1_error)
  __pyx_v_self->counter = __pyx_t_1;

  /* "src/gevent/_semaphore.py":98
 *     def __init__(self, value=1, hub=None):
 *         self.counter = value
 *         if self.counter < 0: # Do the check after Cython native int conversion             # <<<<<<<<<<<<<<
 *             raise ValueError("semaphore initial value must be >= 0")
 *         super(Semaphore, self).__init__(hub)
*/
  __pyx_t_2 = (__pyx_v_self->counter < 0);
  if (unlikely(__pyx_t_2)) {

    /* "src/gevent/_semaphore.py":99
 *         self.counter = value
 *         if self.counter < 0: # Do the check after Cython native int conversion
 *             raise ValueError("semaphore initial value must be >= 0")             # <<<<<<<<<<<<<<
 *         super(Semaphore, self).__init__(hub)
 *         self._notify_all = False
*/
    __pyx_t_4 = NULL;
    __pyx_t_5 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_mstate_global->__pyx_kp_u_semaphore_initial_value_must_be};
      __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_ValueError)), __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 99, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 99, __pyx_L1_error)

    /* "src/gevent/_semaphore.py":98
 *     def __init__(self, value=1, hub=None):
 *         self.counter = value
 *         if self.counter < 0: # Do the check after Cython native int conversion             # <<<<<<<<<<<<<<
 *             raise ValueError("semaphore initial value must be >= 0")
 *         super(Semaphore, self).__init__(hub)
*/
  }

  /* "src/gevent/_semaphore.py":100
 *         if self.counter < 0: # Do the check after Cython native int conversion
 *             raise ValueError("semaphore initial value must be >= 0")
 *         super(Semaphore, self).__init__(hub)             # <<<<<<<<<<<<<<
 *         self._notify_all = False
 *         self._multithreaded = _UNSET
*/
  __pyx_t_7 = NULL;
  __pyx_t_5 = 1;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_7, ((PyObject *)__pyx_mstate_global->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore), ((PyObject *)__pyx_v_self)};
    __pyx_t_6 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_super, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 100, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
  }
  __pyx_t_4 = __pyx_t_6;
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_hub};
    __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_init, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 100, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "src/gevent/_semaphore.py":101
 *             raise ValueError("semaphore initial value must be >= 0")
 *         super(Semaphore, self).__init__(hub)
 *         self._notify_all = False             # <<<<<<<<<<<<<<
 *         self._multithreaded = _UNSET
 * 
*/
  __pyx_v_self->__pyx_base._notify_all = 0;

  /* "src/gevent/_semaphore.py":102
 *         super(Semaphore, self).__init__(hub)
 *         self._notify_all = False
 *         self._multithreaded = _UNSET             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
*/
  __Pyx_INCREF(__pyx_v_6gevent_19_gevent_c_semaphore__UNSET);
  __Pyx_GIVEREF(__pyx_v_6gevent_19_gevent_c_semaphore__UNSET);
  __Pyx_GOTREF(__pyx_v_self->_multithreaded);
  __Pyx_DECREF(__pyx_v_self->_multithreaded);
  __pyx_v_self->_multithreaded = __pyx_v_6gevent_19_gevent_c_semaphore__UNSET;

  /* "src/gevent/_semaphore.py":96
 *     )
 * 
 *     def __init__(self, value=1, hub=None):             # <<<<<<<<<<<<<<
 *         self.counter = value
 *         if self.counter < 0: # Do the check after Cython native int conversion
*/

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("gevent._gevent_c_semaphore.Semaphore.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/_semaphore.py":104
 *         self._multithreaded = _UNSET
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return '<%s at 0x%x counter=%s _links[%s]>' % (
 *             self.__class__.__name__,
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_3__str__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_3__str__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_19_gevent_c_semaphore_9Semaphore_2__str__(((struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_19_gevent_c_semaphore_9Semaphore_2__str__(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6[9];
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 0);

  /* "src/gevent/_semaphore.py":105
 * 
 *     def __str__(self):
 *         return '<%s at 0x%x counter=%s _links[%s]>' % (             # <<<<<<<<<<<<<<
 *             self.__class__.__name__,
 *             id(self),
*/
  __Pyx_XDECREF(__pyx_r);

  /* "src/gevent/_semaphore.py":106
 *     def __str__(self):
 *         return '<%s at 0x%x counter=%s _links[%s]>' % (
 *             self.__class__.__name__,             # <<<<<<<<<<<<<<
 *             id(self),
 *             self.counter,
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_class); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_2), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/_semaphore.py":107
 *         return '<%s at 0x%x counter=%s _links[%s]>' % (
 *             self.__class__.__name__,
 *             id(self),             # <<<<<<<<<<<<<<
 *             self.counter,
 *             self.linkcount()
*/
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_id, ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_Format(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_x); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/_semaphore.py":108
 *             self.__class__.__name__,
 *             id(self),
 *             self.counter,             # <<<<<<<<<<<<<<
 *             self.linkcount()
 *         )
*/
  __pyx_t_2 = __Pyx_PyUnicode_From_int(__pyx_v_self->counter, 0, ' ', 'd'); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 108, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "src/gevent/_semaphore.py":109
 *             id(self),
 *             self.counter,
 *             self.linkcount()             # <<<<<<<<<<<<<<
 *         )
 * 
*/
  __pyx_t_4 = ((struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.linkcount(((struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *)__pyx_v_self), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_4), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_6[0] = __pyx_mstate_global->__pyx_kp_u__2;
  __pyx_t_6[1] = __pyx_t_1;
  __pyx_t_6[2] = __pyx_mstate_global->__pyx_kp_u_at_0x;
  __pyx_t_6[3] = __pyx_t_3;
  __pyx_t_6[4] = __pyx_mstate_global->__pyx_kp_u_counter;
  __pyx_t_6[5] = __pyx_t_2;
  __pyx_t_6[6] = __pyx_mstate_global->__pyx_kp_u_links;
  __pyx_t_6[7] = __pyx_t_5;
  __pyx_t_6[8] = __pyx_mstate_global->__pyx_kp_u__3;

  /* "src/gevent/_semaphore.py":105
 * 
 *     def __str__(self):
 *         return '<%s at 0x%x counter=%s _links[%s]>' % (             # <<<<<<<<<<<<<<
 *             self.__class__.__name__,
 *             id(self),
*/
  __pyx_t_4 = __Pyx_PyUnicode_Join(__pyx_t_6, 9, 1 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1) + 6 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3) + 9 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2) + 8 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5) + 2, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5));
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "src/gevent/_semaphore.py":104
 *         self._multithreaded = _UNSET
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return '<%s at 0x%x counter=%s _links[%s]>' % (
 *             self.__class__.__name__,
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("gevent._gevent_c_semaphore.Semaphore.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/_semaphore.py":112
 *         )
 * 
 *     def locked(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return a boolean indicating whether the semaphore can be
*/

static PyObject *__pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_5locked(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore_locked(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("locked", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (
  #if !CYTHON_USE_TYPE_SLOTS
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore &&
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
  #else
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
  #endif
  ) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_locked); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 112, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_5locked)) {
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 112, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 112, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_6;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "src/gevent/_semaphore.py":120
 *         :rtype: bool
 *         """
 *         return self.counter <= 0             # <<<<<<<<<<<<<<
 * 
 *     def release(self):
*/
  __pyx_r = (__pyx_v_self->counter <= 0);
  goto __pyx_L0;

  /* "src/gevent/_semaphore.py":112
 *         )
 * 
 *     def locked(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return a boolean indicating whether the semaphore can be
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("gevent._gevent_c_semaphore.Semaphore.locked", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_5locked(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_19_gevent_c_semaphore_9Semaphore_4locked, "Semaphore.locked(self) -> bool\n\nReturn a boolean indicating whether the semaphore can be\nacquired (`False` if the semaphore *can* be acquired). Most\nuseful with binary semaphores (those with an initial value of 1).\n\n:rtype: bool");
static PyMethodDef __pyx_mdef_6gevent_19_gevent_c_semaphore_9Semaphore_5locked = {"locked", (PyCFunction)__pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_5locked, METH_NOARGS, __pyx_doc_6gevent_19_gevent_c_semaphore_9Semaphore_4locked};
static PyObject *__pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_5locked(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("locked (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_19_gevent_c_semaphore_9Semaphore_4locked(((struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_19_gevent_c_semaphore_9Semaphore_4locked(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("locked", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore_locked(__pyx_v_self, 1); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 112, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("gevent._gevent_c_semaphore.Semaphore.locked", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/_semaphore.py":122
 *         return self.counter <= 0
 * 
 *     def release(self):             # <<<<<<<<<<<<<<
 *         """
 *         Release the semaphore, notifying any waiters if needed. There
*/

static PyObject *__pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_7release(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore_release(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("release", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (
  #if !CYTHON_USE_TYPE_SLOTS
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore &&
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
  #else
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
  #endif
  ) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_release); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 122, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_7release)) {
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 122, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_t_6 = __Pyx_PyLong_As_int(__pyx_t_2); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 122, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_6;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "src/gevent/_semaphore.py":139
 *         :rtype: None
 *         """
 *         self.counter += 1             # <<<<<<<<<<<<<<
 *         self._check_and_notify()
 *         return self.counter
*/
  __pyx_v_self->counter = (__pyx_v_self->counter + 1);

  /* "src/gevent/_semaphore.py":140
 *         """
 *         self.counter += 1
 *         self._check_and_notify()             # <<<<<<<<<<<<<<
 *         return self.counter
 * 
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._check_and_notify(((struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "src/gevent/_semaphore.py":141
 *         self.counter += 1
 *         self._check_and_notify()
 *         return self.counter             # <<<<<<<<<<<<<<
 * 
 *     def ready(self):
*/
  __pyx_r = __pyx_v_self->counter;
  goto __pyx_L0;

  /* "src/gevent/_semaphore.py":122
 *         return self.counter <= 0
 * 
 *     def release(self):             # <<<<<<<<<<<<<<
 *         """
 *         Release the semaphore, notifying any waiters if needed. There
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("gevent._gevent_c_semaphore.Semaphore.release", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1000;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_7release(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_19_gevent_c_semaphore_9Semaphore_6release, "Semaphore.release(self) -> int\n\nRelease the semaphore, notifying any waiters if needed. There\nis no return value.\n\n.. note::\n\n    This can be used to over-release the semaphore.\n    (Release more times than it has been acquired or was initially\n    created with.)\n\n    This is usually a sign of a bug, but under some circumstances it can be\n    used deliberately, for example, to model the arrival of additional\n    resources.\n\n:rtype: None");
static PyMethodDef __pyx_mdef_6gevent_19_gevent_c_semaphore_9Semaphore_7release = {"release", (PyCFunction)__pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_7release, METH_NOARGS, __pyx_doc_6gevent_19_gevent_c_semaphore_9Semaphore_6release};
static PyObject *__pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_7release(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("release (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_19_gevent_c_semaphore_9Semaphore_6release(((struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_19_gevent_c_semaphore_9Semaphore_6release(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("release", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore_release(__pyx_v_self, 1); if (unlikely(__pyx_t_1 == ((int)-1000))) __PYX_ERR(0, 122, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyLong_From_int(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("gevent._gevent_c_semaphore.Semaphore.release", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/_semaphore.py":143
 *         return self.counter
 * 
 *     def ready(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return a boolean indicating whether the semaphore can be
*/

static PyObject *__pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_9ready(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore_ready(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ready", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (
  #if !CYTHON_USE_TYPE_SLOTS
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore &&
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
  #else
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
  #endif
  ) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_ready); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 143, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_9ready)) {
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 143, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 143, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_6;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "src/gevent/_semaphore.py":150
 *         :rtype: bool
 *         """
 *         return self.counter > 0             # <<<<<<<<<<<<<<
 * 
 *     def _start_notify(self):
*/
  __pyx_r = (__pyx_v_self->counter > 0);
  goto __pyx_L0;

  /* "src/gevent/_semaphore.py":143
 *         return self.counter
 * 
 *     def ready(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return a boolean indicating whether the semaphore can be
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("gevent._gevent_c_semaphore.Semaphore.ready", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_9ready(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_19_gevent_c_semaphore_9Semaphore_8ready, "Semaphore.ready(self) -> bool\n\nReturn a boolean indicating whether the semaphore can be\nacquired (`True` if the semaphore can be acquired).\n\n:rtype: bool");
static PyMethodDef __pyx_mdef_6gevent_19_gevent_c_semaphore_9Semaphore_9ready = {"ready", (PyCFunction)__pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_9ready, METH_NOARGS, __pyx_doc_6gevent_19_gevent_c_semaphore_9Semaphore_8ready};
static PyObject *__pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_9ready(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ready (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_19_gevent_c_semaphore_9Semaphore_8ready(((struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_19_gevent_c_semaphore_9Semaphore_8ready(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ready", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore_ready(__pyx_v_self, 1); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 143, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("gevent._gevent_c_semaphore.Semaphore.ready", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/_semaphore.py":152
 *         return self.counter > 0
 * 
 *     def _start_notify(self):             # <<<<<<<<<<<<<<
 *         self._check_and_notify()
 * 
*/

static PyObject *__pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_11_start_notify(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore__start_notify(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_start_notify", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (
  #if !CYTHON_USE_TYPE_SLOTS
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore &&
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
  #else
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
  #endif
  ) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_start_notify); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 152, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_11_start_notify)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 152, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "src/gevent/_semaphore.py":153
 * 
 *     def _start_notify(self):
 *         self._check_and_notify()             # <<<<<<<<<<<<<<
 * 
 *     def _wait_return_value(self, waited, wait_success):
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._check_and_notify(((struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "src/gevent/_semaphore.py":152
 *         return self.counter > 0
 * 
 *     def _start_notify(self):             # <<<<<<<<<<<<<<
 *         self._check_and_notify()
 * 
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("gevent._gevent_c_semaphore.Semaphore._start_notify", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_11_start_notify(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_19_gevent_c_semaphore_9Semaphore_10_start_notify, "Semaphore._start_notify(self)");
static PyMethodDef __pyx_mdef_6gevent_19_gevent_c_semaphore_9Semaphore_11_start_notify = {"_start_notify", (PyCFunction)__pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_11_start_notify, METH_NOARGS, __pyx_doc_6gevent_19_gevent_c_semaphore_9Semaphore_10_start_notify};
static PyObject *__pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_11_start_notify(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_start_notify (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_19_gevent_c_semaphore_9Semaphore_10_start_notify(((struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_19_gevent_c_semaphore_9Semaphore_10_start_notify(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_start_notify", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore__start_notify(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_c_semaphore.Semaphore._start_notify", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/_semaphore.py":155
 *         self._check_and_notify()
 * 
 *     def _wait_return_value(self, waited, wait_success):             # <<<<<<<<<<<<<<
 *         if waited:
 *             return wait_success
*/

static PyObject *__pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore__wait_return_value(CYTHON_UNUSED struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, int __pyx_v_waited, int __pyx_v_wait_success) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_wait_return_value", 0);

  /* "src/gevent/_semaphore.py":156
 * 
 *     def _wait_return_value(self, waited, wait_success):
 *         if waited:             # <<<<<<<<<<<<<<
 *             return wait_success
 *         # We didn't even wait, we must be good to go.
*/
  if (__pyx_v_waited) {

    /* "src/gevent/_semaphore.py":157
 *     def _wait_return_value(self, waited, wait_success):
 *         if waited:
 *             return wait_success             # <<<<<<<<<<<<<<
 *         # We didn't even wait, we must be good to go.
 *         # XXX: This is probably dead code, we're careful not to go into the wait
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_wait_success); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 157, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "src/gevent/_semaphore.py":156
 * 
 *     def _wait_return_value(self, waited, wait_success):
 *         if waited:             # <<<<<<<<<<<<<<
 *             return wait_success
 *         # We didn't even wait, we must be good to go.
*/
  }

  /* "src/gevent/_semaphore.py":161
 *         # XXX: This is probably dead code, we're careful not to go into the wait
 *         # state if we don't expect to need to
 *         return True             # <<<<<<<<<<<<<<
 * 
 *     def wait(self, timeout=None):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_True);
  __pyx_r = Py_True;
  goto __pyx_L0;

  /* "src/gevent/_semaphore.py":155
 *         self._check_and_notify()
 * 
 *     def _wait_return_value(self, waited, wait_success):             # <<<<<<<<<<<<<<
 *         if waited:
 *             return wait_success
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_c_semaphore.Semaphore._wait_return_value", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/_semaphore.py":163
 *         return True
 * 
 *     def wait(self, timeout=None):             # <<<<<<<<<<<<<<
 *         """
 *         Wait until it is possible to acquire this semaphore, or until the optional
*/

static PyObject *__pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_13wait(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static int __pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore_wait(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, int __pyx_skip_dispatch, struct __pyx_opt_args_6gevent_19_gevent_c_semaphore_9Semaphore_wait *__pyx_optional_args) {
  PyObject *__pyx_v_timeout = ((PyObject *)Py_None);
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  struct __pyx_opt_args_6gevent_27_gevent_c_abstract_linkable_16AbstractLinkable__wait __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("wait", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_timeout = __pyx_optional_args->timeout;
    }
  }
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (
  #if !CYTHON_USE_TYPE_SLOTS
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore &&
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
  #else
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
  #endif
  ) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_wait); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 163, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_13wait)) {
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_timeout};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 163, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_t_6 = __Pyx_PyLong_As_int(__pyx_t_2); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 163, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_6;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "src/gevent/_semaphore.py":178
 *         :rtype: int
 *         """
 *         if self.counter > 0:             # <<<<<<<<<<<<<<
 *             return self.counter
 * 
*/
  __pyx_t_7 = (__pyx_v_self->counter > 0);
  if (__pyx_t_7) {

    /* "src/gevent/_semaphore.py":179
 *         """
 *         if self.counter > 0:
 *             return self.counter             # <<<<<<<<<<<<<<
 * 
 *         self._wait(timeout) # return value irrelevant, whether we got it or got a timeout
*/
    __pyx_r = __pyx_v_self->counter;
    goto __pyx_L0;

    /* "src/gevent/_semaphore.py":178
 *         :rtype: int
 *         """
 *         if self.counter > 0:             # <<<<<<<<<<<<<<
 *             return self.counter
 * 
*/
  }

  /* "src/gevent/_semaphore.py":181
 *             return self.counter
 * 
 *         self._wait(timeout) # return value irrelevant, whether we got it or got a timeout             # <<<<<<<<<<<<<<
 *         return self.counter
 * 
*/
  __pyx_t_8.__pyx_n = 1;
  __pyx_t_8.timeout = __pyx_v_timeout;
  __pyx_t_1 = ((struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._wait(((struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *)__pyx_v_self), &__pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "src/gevent/_semaphore.py":182
 * 
 *         self._wait(timeout) # return value irrelevant, whether we got it or got a timeout
 *         return self.counter             # <<<<<<<<<<<<<<
 * 
 *     def acquire(self, blocking=True, timeout=None):
*/
  __pyx_r = __pyx_v_self->counter;
  goto __pyx_L0;

  /* "src/gevent/_semaphore.py":163
 *         return True
 * 
 *     def wait(self, timeout=None):             # <<<<<<<<<<<<<<
 *         """
 *         Wait until it is possible to acquire this semaphore, or until the optional
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("gevent._gevent_c_semaphore.Semaphore.wait", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1000;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_13wait(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_19_gevent_c_semaphore_9Semaphore_12wait, "Semaphore.wait(self, timeout=None) -> int\n\nWait until it is possible to acquire this semaphore, or until the optional\n*timeout* elapses.\n\n.. note:: If this semaphore was initialized with a *value* of 0,\n   this method will block forever if no timeout is given.\n\n:keyword float timeout: If given, specifies the maximum amount of seconds\n   this method will block.\n:return: A number indicating how many times the semaphore can be acquired\n    before blocking. *This could be 0,* if other waiters acquired\n    the semaphore.\n:rtype: int");
static PyMethodDef __pyx_mdef_6gevent_19_gevent_c_semaphore_9Semaphore_13wait = {"wait", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_13wait, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6gevent_19_gevent_c_semaphore_9Semaphore_12wait};
static PyObject *__pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_13wait(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_timeout = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("wait (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_timeout,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 163, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 163, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "wait", 0) < (0)) __PYX_ERR(0, 163, __pyx_L3_error)
      if (!values[0]) values[0] = __Pyx_NewRef(((PyObject *)Py_None));
    } else {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 163, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[0]) values[0] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_timeout = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("wait", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 163, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("gevent._gevent_c_semaphore.Semaphore.wait", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6gevent_19_gevent_c_semaphore_9Semaphore_12wait(((struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self), __pyx_v_timeout);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_19_gevent_c_semaphore_9Semaphore_12wait(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, PyObject *__pyx_v_timeout) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  struct __pyx_opt_args_6gevent_19_gevent_c_semaphore_9Semaphore_wait __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("wait", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.timeout = __pyx_v_timeout;
  __pyx_t_1 = __pyx_vtabptr_6gevent_19_gevent_c_semaphore_Semaphore->wait(__pyx_v_self, 1, &__pyx_t_2); if (unlikely(__pyx_t_1 == ((int)-1000))) __PYX_ERR(0, 163, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyLong_From_int(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("gevent._gevent_c_semaphore.Semaphore.wait", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/_semaphore.py":184
 *         return self.counter
 * 
 *     def acquire(self, blocking=True, timeout=None):             # <<<<<<<<<<<<<<
 *         """
 *         acquire(blocking=True, timeout=None) -> bool
*/

static PyObject *__pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_15acquire(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static int __pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore_acquire(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, int __pyx_skip_dispatch, struct __pyx_opt_args_6gevent_19_gevent_c_semaphore_9Semaphore_acquire *__pyx_optional_args) {
  int __pyx_v_blocking = ((int)1);
  PyObject *__pyx_v_timeout = ((PyObject *)Py_None);
  int __pyx_v_success;
  PyObject *__pyx_v_e = 0;
  PyObject *__pyx_v_ex = 0;
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_v_invalid_thread_use = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  int __pyx_t_12;
  int __pyx_t_13;
  char const *__pyx_t_14;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  int __pyx_t_21;
  struct __pyx_opt_args_6gevent_27_gevent_c_abstract_linkable_16AbstractLinkable__wait __pyx_t_22;
  Py_ssize_t __pyx_t_23;
  PyObject *__pyx_t_24 = NULL;
  char const *__pyx_t_25;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("acquire", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_blocking = __pyx_optional_args->blocking;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_timeout = __pyx_optional_args->timeout;
      }
    }
  }
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (
  #if !CYTHON_USE_TYPE_SLOTS
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore &&
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
  #else
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
  #endif
  ) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_acquire); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 184, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_15acquire)) {
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; 
        __pyx_t_5 = __Pyx_PyBool_FromLong(__pyx_v_blocking); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 184, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_6 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_6 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_t_5, __pyx_v_timeout};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_6, (3-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 184, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 184, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_7;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "src/gevent/_semaphore.py":208
 *         # pylint:disable=too-many-return-statements,too-many-branches
 *         # Sadly, the body of this method is rather complicated.
 *         if self._multithreaded is _UNSET:             # <<<<<<<<<<<<<<
 *             self._multithreaded = self._get_thread_ident()
 *         elif self._multithreaded != self._get_thread_ident():
*/
  __pyx_t_7 = (__pyx_v_self->_multithreaded == __pyx_v_6gevent_19_gevent_c_semaphore__UNSET);
  if (__pyx_t_7) {

    /* "src/gevent/_semaphore.py":209
 *         # Sadly, the body of this method is rather complicated.
 *         if self._multithreaded is _UNSET:
 *             self._multithreaded = self._get_thread_ident()             # <<<<<<<<<<<<<<
 *         elif self._multithreaded != self._get_thread_ident():
 *             self._multithreaded = _MULTI
*/
    __pyx_t_1 = ((struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._get_thread_ident(((struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 209, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_v_self->_multithreaded);
    __Pyx_DECREF(__pyx_v_self->_multithreaded);
    __pyx_v_self->_multithreaded = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "src/gevent/_semaphore.py":208
 *         # pylint:disable=too-many-return-statements,too-many-branches
 *         # Sadly, the body of this method is rather complicated.
 *         if self._multithreaded is _UNSET:             # <<<<<<<<<<<<<<
 *             self._multithreaded = self._get_thread_ident()
 *         elif self._multithreaded != self._get_thread_ident():
*/
    goto __pyx_L3;
  }

  /* "src/gevent/_semaphore.py":210
 *         if self._multithreaded is _UNSET:
 *             self._multithreaded = self._get_thread_ident()
 *         elif self._multithreaded != self._get_thread_ident():             # <<<<<<<<<<<<<<
 *             self._multithreaded = _MULTI
 * 
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._get_thread_ident(((struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_RichCompare(__pyx_v_self->_multithreaded, __pyx_t_1, Py_NE); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 210, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 210, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_7) {

    /* "src/gevent/_semaphore.py":211
 *             self._multithreaded = self._get_thread_ident()
 *         elif self._multithreaded != self._get_thread_ident():
 *             self._multithreaded = _MULTI             # <<<<<<<<<<<<<<
 * 
 *         # We conceptually now belong to the hub of the thread that
*/
    __Pyx_INCREF(__pyx_v_6gevent_19_gevent_c_semaphore__MULTI);
    __Pyx_GIVEREF(__pyx_v_6gevent_19_gevent_c_semaphore__MULTI);
    __Pyx_GOTREF(__pyx_v_self->_multithreaded);
    __Pyx_DECREF(__pyx_v_self->_multithreaded);
    __pyx_v_self->_multithreaded = __pyx_v_6gevent_19_gevent_c_semaphore__MULTI;

    /* "src/gevent/_semaphore.py":210
 *         if self._multithreaded is _UNSET:
 *             self._multithreaded = self._get_thread_ident()
 *         elif self._multithreaded != self._get_thread_ident():             # <<<<<<<<<<<<<<
 *             self._multithreaded = _MULTI
 * 
*/
  }
  __pyx_L3:;

  /* "src/gevent/_semaphore.py":218
 *         # by importlib.ModuleLock which is used when importing the hub
 *         # itself! This also checks for cross-thread issues.
 *         invalid_thread_use = None             # <<<<<<<<<<<<<<
 *         try:
 *             self._capture_hub(False)
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_invalid_thread_use = Py_None;

  /* "src/gevent/_semaphore.py":219
 *         # itself! This also checks for cross-thread issues.
 *         invalid_thread_use = None
 *         try:             # <<<<<<<<<<<<<<
 *             self._capture_hub(False)
 *         except InvalidThreadUseError as e:
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
    __Pyx_XGOTREF(__pyx_t_8);
    __Pyx_XGOTREF(__pyx_t_9);
    __Pyx_XGOTREF(__pyx_t_10);
    /*try:*/ {

      /* "src/gevent/_semaphore.py":220
 *         invalid_thread_use = None
 *         try:
 *             self._capture_hub(False)             # <<<<<<<<<<<<<<
 *         except InvalidThreadUseError as e:
 *             # My hub belongs to some other thread. We didn't release the GIL/object lock
*/
      __pyx_t_2 = ((PyObject *)((struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._capture_hub(((struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *)__pyx_v_self), 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 220, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "src/gevent/_semaphore.py":219
 *         # itself! This also checks for cross-thread issues.
 *         invalid_thread_use = None
 *         try:             # <<<<<<<<<<<<<<
 *             self._capture_hub(False)
 *         except InvalidThreadUseError as e:
*/
    }
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    goto __pyx_L9_try_end;
    __pyx_L4_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "src/gevent/_semaphore.py":221
 *         try:
 *             self._capture_hub(False)
 *         except InvalidThreadUseError as e:             # <<<<<<<<<<<<<<
 *             # My hub belongs to some other thread. We didn't release the GIL/object lock
 *             # by raising the exception, so we know this is still true.
*/
    __pyx_t_11 = __Pyx_PyErr_ExceptionMatches(__pyx_v_6gevent_19_gevent_c_semaphore_InvalidThreadUseError);
    if (__pyx_t_11) {
      __Pyx_AddTraceback("gevent._gevent_c_semaphore.Semaphore.acquire", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_1, &__pyx_t_4) < 0) __PYX_ERR(0, 221, __pyx_L6_except_error)
      __Pyx_XGOTREF(__pyx_t_2);
      __Pyx_XGOTREF(__pyx_t_1);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_1);
      __pyx_v_e = ((PyObject*)__pyx_t_1);
      /*try:*/ {

        /* "src/gevent/_semaphore.py":224
 *             # My hub belongs to some other thread. We didn't release the GIL/object lock
 *             # by raising the exception, so we know this is still true.
 *             invalid_thread_use = e.args             # <<<<<<<<<<<<<<
 *             e = None
 *             if not self.counter and blocking:
*/
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_mstate_global->__pyx_n_u_args); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 224, __pyx_L15_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF_SET(__pyx_v_invalid_thread_use, __pyx_t_5);
        __pyx_t_5 = 0;

        /* "src/gevent/_semaphore.py":225
 *             # by raising the exception, so we know this is still true.
 *             invalid_thread_use = e.args
 *             e = None             # <<<<<<<<<<<<<<
 *             if not self.counter and blocking:
 *                 # We would need to block. So coordinate with the main hub.
*/
        __Pyx_INCREF(Py_None);
        __Pyx_DECREF_SET(__pyx_v_e, ((PyObject*)Py_None));

        /* "src/gevent/_semaphore.py":226
 *             invalid_thread_use = e.args
 *             e = None
 *             if not self.counter and blocking:             # <<<<<<<<<<<<<<
 *                 # We would need to block. So coordinate with the main hub.
 *                 return self.__acquire_from_other_thread(invalid_thread_use, blocking, timeout)
*/
        __pyx_t_12 = (!(__pyx_v_self->counter != 0));
        if (__pyx_t_12) {
        } else {
          __pyx_t_7 = __pyx_t_12;
          goto __pyx_L18_bool_binop_done;
        }
        __pyx_t_7 = __pyx_v_blocking;
        __pyx_L18_bool_binop_done:;
        if (__pyx_t_7) {

          /* "src/gevent/_semaphore.py":228
 *             if not self.counter and blocking:
 *                 # We would need to block. So coordinate with the main hub.
 *                 return self.__acquire_from_other_thread(invalid_thread_use, blocking, timeout)             # <<<<<<<<<<<<<<
 * 
 *         if self.counter > 0:
*/
          __pyx_t_5 = __pyx_v_invalid_thread_use;
          __Pyx_INCREF(__pyx_t_5);
          if (!(likely(PyTuple_CheckExact(__pyx_t_5))||((__pyx_t_5) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_t_5))) __PYX_ERR(0, 228, __pyx_L15_error)
          __pyx_t_3 = ((struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self->__pyx_base.__pyx_vtab)->_Semaphore__acquire_from_other_thread(__pyx_v_self, ((PyObject*)__pyx_t_5), __pyx_v_blocking, __pyx_v_timeout); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 228, __pyx_L15_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 228, __pyx_L15_error)
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_r = __pyx_t_7;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          goto __pyx_L14_return;

          /* "src/gevent/_semaphore.py":226
 *             invalid_thread_use = e.args
 *             e = None
 *             if not self.counter and blocking:             # <<<<<<<<<<<<<<
 *                 # We would need to block. So coordinate with the main hub.
 *                 return self.__acquire_from_other_thread(invalid_thread_use, blocking, timeout)
*/
        }
      }

      /* "src/gevent/_semaphore.py":221
 *         try:
 *             self._capture_hub(False)
 *         except InvalidThreadUseError as e:             # <<<<<<<<<<<<<<
 *             # My hub belongs to some other thread. We didn't release the GIL/object lock
 *             # by raising the exception, so we know this is still true.
*/
      /*finally:*/ {
        /*normal exit:*/{
          __Pyx_DECREF(__pyx_v_e); __pyx_v_e = 0;
          goto __pyx_L16;
        }
        __pyx_L15_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0;
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
           __Pyx_ExceptionSwap(&__pyx_t_18, &__pyx_t_19, &__pyx_t_20);
          if ( unlikely(__Pyx_GetException(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17) < 0)) __Pyx_ErrFetch(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_15);
          __Pyx_XGOTREF(__pyx_t_16);
          __Pyx_XGOTREF(__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_20);
          __pyx_t_11 = __pyx_lineno; __pyx_t_13 = __pyx_clineno; __pyx_t_14 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_e); __pyx_v_e = 0;
          }
          __Pyx_XGIVEREF(__pyx_t_18);
          __Pyx_XGIVEREF(__pyx_t_19);
          __Pyx_XGIVEREF(__pyx_t_20);
          __Pyx_ExceptionReset(__pyx_t_18, __pyx_t_19, __pyx_t_20);
          __Pyx_XGIVEREF(__pyx_t_15);
          __Pyx_XGIVEREF(__pyx_t_16);
          __Pyx_XGIVEREF(__pyx_t_17);
          __Pyx_ErrRestore(__pyx_t_15, __pyx_t_16, __pyx_t_17);
          __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0;
          __pyx_lineno = __pyx_t_11; __pyx_clineno = __pyx_t_13; __pyx_filename = __pyx_t_14;
          goto __pyx_L6_except_error;
        }
        __pyx_L14_return: {
          __pyx_t_7 = __pyx_r;
          __Pyx_DECREF(__pyx_v_e); __pyx_v_e = 0;
          __pyx_r = __pyx_t_7;
          goto __pyx_L7_except_return;
        }
        __pyx_L16:;
      }
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      goto __pyx_L5_exception_handled;
    }
    goto __pyx_L6_except_error;

    /* "src/gevent/_semaphore.py":219
 *         # itself! This also checks for cross-thread issues.
 *         invalid_thread_use = None
 *         try:             # <<<<<<<<<<<<<<
 *             self._capture_hub(False)
 *         except InvalidThreadUseError as e:
*/
    __pyx_L6_except_error:;
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
    goto __pyx_L1_error;
    __pyx_L7_except_return:;
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
    goto __pyx_L0;
    __pyx_L5_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
    __pyx_L9_try_end:;
  }

  /* "src/gevent/_semaphore.py":230
 *                 return self.__acquire_from_other_thread(invalid_thread_use, blocking, timeout)
 * 
 *         if self.counter > 0:             # <<<<<<<<<<<<<<
 *             self.counter -= 1
 *             return True
*/
  __pyx_t_7 = (__pyx_v_self->counter > 0);
  if (__pyx_t_7) {

    /* "src/gevent/_semaphore.py":231
 * 
 *         if self.counter > 0:
 *             self.counter -= 1             # <<<<<<<<<<<<<<
 *             return True
 * 
*/
    __pyx_v_self->counter = (__pyx_v_self->counter - 1);

    /* "src/gevent/_semaphore.py":232
 *         if self.counter > 0:
 *             self.counter -= 1
 *             return True             # <<<<<<<<<<<<<<
 * 
 *         if not blocking:
*/
    __pyx_r = 1;
    goto __pyx_L0;

    /* "src/gevent/_semaphore.py":230
 *                 return self.__acquire_from_other_thread(invalid_thread_use, blocking, timeout)
 * 
 *         if self.counter > 0:             # <<<<<<<<<<<<<<
 *             self.counter -= 1
 *             return True
*/
  }

  /* "src/gevent/_semaphore.py":234
 *             return True
 * 
 *         if not blocking:             # <<<<<<<<<<<<<<
 *             return False
 * 
*/
  __pyx_t_7 = (!__pyx_v_blocking);
  if (__pyx_t_7) {

    /* "src/gevent/_semaphore.py":235
 * 
 *         if not blocking:
 *             return False             # <<<<<<<<<<<<<<
 * 
 *         if self._multithreaded is not _MULTI and self.hub is None: # pylint:disable=access-member-before-definition
*/
    __pyx_r = 0;
    goto __pyx_L0;

    /* "src/gevent/_semaphore.py":234
 *             return True
 * 
 *         if not blocking:             # <<<<<<<<<<<<<<
 *             return False
 * 
*/
  }

  /* "src/gevent/_semaphore.py":237
 *             return False
 * 
 *         if self._multithreaded is not _MULTI and self.hub is None: # pylint:disable=access-member-before-definition             # <<<<<<<<<<<<<<
 *             self.hub = get_hub() # pylint:disable=attribute-defined-outside-init
 * 
*/
  __pyx_t_12 = (__pyx_v_self->_multithreaded != __pyx_v_6gevent_19_gevent_c_semaphore__MULTI);
  if (__pyx_t_12) {
  } else {
    __pyx_t_7 = __pyx_t_12;
    goto __pyx_L27_bool_binop_done;
  }
  __pyx_t_12 = (((PyObject *)__pyx_v_self->__pyx_base.hub) == Py_None);
  __pyx_t_7 = __pyx_t_12;
  __pyx_L27_bool_binop_done:;
  if (__pyx_t_7) {

    /* "src/gevent/_semaphore.py":238
 * 
 *         if self._multithreaded is not _MULTI and self.hub is None: # pylint:disable=access-member-before-definition
 *             self.hub = get_hub() # pylint:disable=attribute-defined-outside-init             # <<<<<<<<<<<<<<
 * 
 *         if self.hub is None and not invalid_thread_use:
*/
    __pyx_t_4 = ((PyObject *)__pyx_f_6gevent_19_gevent_c_hub_local_get_hub_noargs(0)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 238, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->__pyx_base.hub);
    __Pyx_DECREF((PyObject *)__pyx_v_self->__pyx_base.hub);
    __pyx_v_self->__pyx_base.hub = ((struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *)__pyx_t_4);
    __pyx_t_4 = 0;

    /* "src/gevent/_semaphore.py":237
 *             return False
 * 
 *         if self._multithreaded is not _MULTI and self.hub is None: # pylint:disable=access-member-before-definition             # <<<<<<<<<<<<<<
 *             self.hub = get_hub() # pylint:disable=attribute-defined-outside-init
 * 
*/
  }

  /* "src/gevent/_semaphore.py":240
 *             self.hub = get_hub() # pylint:disable=attribute-defined-outside-init
 * 
 *         if self.hub is None and not invalid_thread_use:             # <<<<<<<<<<<<<<
 *             # Someone else is holding us. There's not a hub here,
 *             # nor is there a hub in that thread. We'll need to use regular locks.
*/
  __pyx_t_12 = (((PyObject *)__pyx_v_self->__pyx_base.hub) == Py_None);
  if (__pyx_t_12) {
  } else {
    __pyx_t_7 = __pyx_t_12;
    goto __pyx_L30_bool_binop_done;
  }
  __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_v_invalid_thread_use); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 240, __pyx_L1_error)
  __pyx_t_21 = (!__pyx_t_12);
  __pyx_t_7 = __pyx_t_21;
  __pyx_L30_bool_binop_done:;
  if (__pyx_t_7) {

    /* "src/gevent/_semaphore.py":245
 *             # This will be unfair to yet a third thread that tries to use us with greenlets.
 *             return self.__acquire_from_other_thread(
 *                 (None, None, self._getcurrent(), "NoHubs"),             # <<<<<<<<<<<<<<
 *                 blocking,
 *                 timeout
*/
    __pyx_t_4 = ((PyObject *)((struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._getcurrent(((struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *)__pyx_v_self))); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 245, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyTuple_New(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 245, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, Py_None) != (0)) __PYX_ERR(0, 245, __pyx_L1_error);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None) != (0)) __PYX_ERR(0, 245, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_t_4) != (0)) __PYX_ERR(0, 245, __pyx_L1_error);
    __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_NoHubs);
    __Pyx_GIVEREF(__pyx_mstate_global->__pyx_n_u_NoHubs);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_mstate_global->__pyx_n_u_NoHubs) != (0)) __PYX_ERR(0, 245, __pyx_L1_error);
    __pyx_t_4 = 0;

    /* "src/gevent/_semaphore.py":244
 *             # nor is there a hub in that thread. We'll need to use regular locks.
 *             # This will be unfair to yet a third thread that tries to use us with greenlets.
 *             return self.__acquire_from_other_thread(             # <<<<<<<<<<<<<<
 *                 (None, None, self._getcurrent(), "NoHubs"),
 *                 blocking,
*/
    __pyx_t_4 = ((struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self->__pyx_base.__pyx_vtab)->_Semaphore__acquire_from_other_thread(__pyx_v_self, ((PyObject*)__pyx_t_1), __pyx_v_blocking, __pyx_v_timeout); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 244, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 244, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_r = __pyx_t_7;
    goto __pyx_L0;

    /* "src/gevent/_semaphore.py":240
 *             self.hub = get_hub() # pylint:disable=attribute-defined-outside-init
 * 
 *         if self.hub is None and not invalid_thread_use:             # <<<<<<<<<<<<<<
 *             # Someone else is holding us. There's not a hub here,
 *             # nor is there a hub in that thread. We'll need to use regular locks.
*/
  }

  /* "src/gevent/_semaphore.py":252
 *         # self._wait may drop both the GIL and the _lock_lock.
 *         # By the time we regain control, both have been reacquired.
 *         try:             # <<<<<<<<<<<<<<
 *             success = self._wait(timeout)
 *         except LoopExit as ex:
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_10, &__pyx_t_9, &__pyx_t_8);
    __Pyx_XGOTREF(__pyx_t_10);
    __Pyx_XGOTREF(__pyx_t_9);
    __Pyx_XGOTREF(__pyx_t_8);
    /*try:*/ {

      /* "src/gevent/_semaphore.py":253
 *         # By the time we regain control, both have been reacquired.
 *         try:
 *             success = self._wait(timeout)             # <<<<<<<<<<<<<<
 *         except LoopExit as ex:
 *             args = ex.args
*/
      __pyx_t_22.__pyx_n = 1;
      __pyx_t_22.timeout = __pyx_v_timeout;
      __pyx_t_4 = ((struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._wait(((struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *)__pyx_v_self), &__pyx_t_22); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 253, __pyx_L32_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 253, __pyx_L32_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_v_success = __pyx_t_7;

      /* "src/gevent/_semaphore.py":252
 *         # self._wait may drop both the GIL and the _lock_lock.
 *         # By the time we regain control, both have been reacquired.
 *         try:             # <<<<<<<<<<<<<<
 *             success = self._wait(timeout)
 *         except LoopExit as ex:
*/
    }
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    goto __pyx_L37_try_end;
    __pyx_L32_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "src/gevent/_semaphore.py":254
 *         try:
 *             success = self._wait(timeout)
 *         except LoopExit as ex:             # <<<<<<<<<<<<<<
 *             args = ex.args
 *             ex = None
*/
    __pyx_t_13 = __Pyx_PyErr_ExceptionMatches(__pyx_v_6gevent_19_gevent_c_semaphore_LoopExit);
    if (__pyx_t_13) {
      __Pyx_AddTraceback("gevent._gevent_c_semaphore.Semaphore.acquire", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_1, &__pyx_t_2) < 0) __PYX_ERR(0, 254, __pyx_L34_except_error)
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_1);
      __Pyx_XGOTREF(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_1);
      __pyx_v_ex = ((PyObject*)__pyx_t_1);
      /*try:*/ {

        /* "src/gevent/_semaphore.py":255
 *             success = self._wait(timeout)
 *         except LoopExit as ex:
 *             args = ex.args             # <<<<<<<<<<<<<<
 *             ex = None
 *             if self.counter:
*/
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_ex, __pyx_mstate_global->__pyx_n_u_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 255, __pyx_L43_error)
        __Pyx_GOTREF(__pyx_t_3);
        if (!(likely(PyTuple_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_t_3))) __PYX_ERR(0, 255, __pyx_L43_error)
        __pyx_v_args = ((PyObject*)__pyx_t_3);
        __pyx_t_3 = 0;

        /* "src/gevent/_semaphore.py":256
 *         except LoopExit as ex:
 *             args = ex.args
 *             ex = None             # <<<<<<<<<<<<<<
 *             if self.counter:
 *                 success = True
*/
        __Pyx_INCREF(Py_None);
        __Pyx_DECREF_SET(__pyx_v_ex, ((PyObject*)Py_None));

        /* "src/gevent/_semaphore.py":257
 *             args = ex.args
 *             ex = None
 *             if self.counter:             # <<<<<<<<<<<<<<
 *                 success = True
 *             else:
*/
        __pyx_t_7 = (__pyx_v_self->counter != 0);
        if (__pyx_t_7) {

          /* "src/gevent/_semaphore.py":258
 *             ex = None
 *             if self.counter:
 *                 success = True             # <<<<<<<<<<<<<<
 *             else:
 *                 # Avoid using ex.hub property to keep holding the GIL
*/
          __pyx_v_success = 1;

          /* "src/gevent/_semaphore.py":257
 *             args = ex.args
 *             ex = None
 *             if self.counter:             # <<<<<<<<<<<<<<
 *                 success = True
 *             else:
*/
          goto __pyx_L45;
        }

        /* "src/gevent/_semaphore.py":261
 *             else:
 *                 # Avoid using ex.hub property to keep holding the GIL
 *                 if len(args) == 3 and args[1].main_hub:             # <<<<<<<<<<<<<<
 *                     # The main hub, meaning the main thread. We probably can do nothing with this.
 *                     raise
*/
        /*else*/ {
          if (unlikely(__pyx_v_args == Py_None)) {
            PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
            __PYX_ERR(0, 261, __pyx_L43_error)
          }
          __pyx_t_23 = __Pyx_PyTuple_GET_SIZE(__pyx_v_args); if (unlikely(__pyx_t_23 == ((Py_ssize_t)-1))) __PYX_ERR(0, 261, __pyx_L43_error)
          __pyx_t_21 = (__pyx_t_23 == 3);
          if (__pyx_t_21) {
          } else {
            __pyx_t_7 = __pyx_t_21;
            goto __pyx_L47_bool_binop_done;
          }
          if (unlikely(__pyx_v_args == Py_None)) {
            PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
            __PYX_ERR(0, 261, __pyx_L43_error)
          }
          __pyx_t_3 = __Pyx_GetItemInt_Tuple(__pyx_v_args, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 261, __pyx_L43_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_main_hub); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 261, __pyx_L43_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_21 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_21 < 0))) __PYX_ERR(0, 261, __pyx_L43_error)
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_7 = __pyx_t_21;
          __pyx_L47_bool_binop_done:;
          if (unlikely(__pyx_t_7)) {

            /* "src/gevent/_semaphore.py":263
 *                 if len(args) == 3 and args[1].main_hub:
 *                     # The main hub, meaning the main thread. We probably can do nothing with this.
 *                     raise             # <<<<<<<<<<<<<<
 *                 return self.__acquire_from_other_thread(
 *                     (self.hub, get_hub_if_exists(), self._getcurrent(), "LoopExit"),
*/
            __Pyx_GIVEREF(__pyx_t_4);
            __Pyx_GIVEREF(__pyx_t_1);
            __Pyx_XGIVEREF(__pyx_t_2);
            __Pyx_ErrRestoreWithState(__pyx_t_4, __pyx_t_1, __pyx_t_2);
            __pyx_t_4 = 0;  __pyx_t_1 = 0;  __pyx_t_2 = 0; 
            __PYX_ERR(0, 263, __pyx_L43_error)

            /* "src/gevent/_semaphore.py":261
 *             else:
 *                 # Avoid using ex.hub property to keep holding the GIL
 *                 if len(args) == 3 and args[1].main_hub:             # <<<<<<<<<<<<<<
 *                     # The main hub, meaning the main thread. We probably can do nothing with this.
 *                     raise
*/
          }

          /* "src/gevent/_semaphore.py":265
 *                     raise
 *                 return self.__acquire_from_other_thread(
 *                     (self.hub, get_hub_if_exists(), self._getcurrent(), "LoopExit"),             # <<<<<<<<<<<<<<
 *                     blocking,
 *                     timeout)
*/
          __pyx_t_5 = ((PyObject *)__pyx_f_6gevent_19_gevent_c_hub_local_get_hub_if_exists(0)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 265, __pyx_L43_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_3 = ((PyObject *)((struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._getcurrent(((struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *)__pyx_v_self))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 265, __pyx_L43_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_24 = PyTuple_New(4); if (unlikely(!__pyx_t_24)) __PYX_ERR(0, 265, __pyx_L43_error)
          __Pyx_GOTREF(__pyx_t_24);
          __Pyx_INCREF((PyObject *)__pyx_v_self->__pyx_base.hub);
          __Pyx_GIVEREF((PyObject *)__pyx_v_self->__pyx_base.hub);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_24, 0, ((PyObject *)__pyx_v_self->__pyx_base.hub)) != (0)) __PYX_ERR(0, 265, __pyx_L43_error);
          __Pyx_GIVEREF(__pyx_t_5);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_24, 1, __pyx_t_5) != (0)) __PYX_ERR(0, 265, __pyx_L43_error);
          __Pyx_GIVEREF(__pyx_t_3);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_24, 2, __pyx_t_3) != (0)) __PYX_ERR(0, 265, __pyx_L43_error);
          __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_LoopExit);
          __Pyx_GIVEREF(__pyx_mstate_global->__pyx_n_u_LoopExit);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_24, 3, __pyx_mstate_global->__pyx_n_u_LoopExit) != (0)) __PYX_ERR(0, 265, __pyx_L43_error);
          __pyx_t_5 = 0;
          __pyx_t_3 = 0;

          /* "src/gevent/_semaphore.py":264
 *                     # The main hub, meaning the main thread. We probably can do nothing with this.
 *                     raise
 *                 return self.__acquire_from_other_thread(             # <<<<<<<<<<<<<<
 *                     (self.hub, get_hub_if_exists(), self._getcurrent(), "LoopExit"),
 *                     blocking,
*/
          __pyx_t_3 = ((struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self->__pyx_base.__pyx_vtab)->_Semaphore__acquire_from_other_thread(__pyx_v_self, ((PyObject*)__pyx_t_24), __pyx_v_blocking, __pyx_v_timeout); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 264, __pyx_L43_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_24); __pyx_t_24 = 0;
          __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 264, __pyx_L43_error)
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_r = __pyx_t_7;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          goto __pyx_L42_return;
        }
        __pyx_L45:;
      }

      /* "src/gevent/_semaphore.py":254
 *         try:
 *             success = self._wait(timeout)
 *         except LoopExit as ex:             # <<<<<<<<<<<<<<
 *             args = ex.args
 *             ex = None
*/
      /*finally:*/ {
        /*normal exit:*/{
          __Pyx_DECREF(__pyx_v_ex); __pyx_v_ex = 0;
          goto __pyx_L44;
        }
        __pyx_L43_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_20 = 0; __pyx_t_19 = 0; __pyx_t_18 = 0; __pyx_t_17 = 0; __pyx_t_16 = 0; __pyx_t_15 = 0;
          __Pyx_XDECREF(__pyx_t_24); __pyx_t_24 = 0;
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
           __Pyx_ExceptionSwap(&__pyx_t_17, &__pyx_t_16, &__pyx_t_15);
          if ( unlikely(__Pyx_GetException(&__pyx_t_20, &__pyx_t_19, &__pyx_t_18) < 0)) __Pyx_ErrFetch(&__pyx_t_20, &__pyx_t_19, &__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_20);
          __Pyx_XGOTREF(__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_16);
          __Pyx_XGOTREF(__pyx_t_15);
          __pyx_t_13 = __pyx_lineno; __pyx_t_11 = __pyx_clineno; __pyx_t_25 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_ex); __pyx_v_ex = 0;
          }
          __Pyx_XGIVEREF(__pyx_t_17);
          __Pyx_XGIVEREF(__pyx_t_16);
          __Pyx_XGIVEREF(__pyx_t_15);
          __Pyx_ExceptionReset(__pyx_t_17, __pyx_t_16, __pyx_t_15);
          __Pyx_XGIVEREF(__pyx_t_20);
          __Pyx_XGIVEREF(__pyx_t_19);
          __Pyx_XGIVEREF(__pyx_t_18);
          __Pyx_ErrRestore(__pyx_t_20, __pyx_t_19, __pyx_t_18);
          __pyx_t_20 = 0; __pyx_t_19 = 0; __pyx_t_18 = 0; __pyx_t_17 = 0; __pyx_t_16 = 0; __pyx_t_15 = 0;
          __pyx_lineno = __pyx_t_13; __pyx_clineno = __pyx_t_11; __pyx_filename = __pyx_t_25;
          goto __pyx_L34_except_error;
        }
        __pyx_L42_return: {
          __pyx_t_7 = __pyx_r;
          __Pyx_DECREF(__pyx_v_ex); __pyx_v_ex = 0;
          __pyx_r = __pyx_t_7;
          goto __pyx_L35_except_return;
        }
        __pyx_L44:;
      }
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      goto __pyx_L33_exception_handled;
    }
    goto __pyx_L34_except_error;

    /* "src/gevent/_semaphore.py":252
 *         # self._wait may drop both the GIL and the _lock_lock.
 *         # By the time we regain control, both have been reacquired.
 *         try:             # <<<<<<<<<<<<<<
 *             success = self._wait(timeout)
 *         except LoopExit as ex:
*/
    __pyx_L34_except_error:;
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_9, __pyx_t_8);
    goto __pyx_L1_error;
    __pyx_L35_except_return:;
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_9, __pyx_t_8);
    goto __pyx_L0;
    __pyx_L33_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_9, __pyx_t_8);
    __pyx_L37_try_end:;
  }

  /* "src/gevent/_semaphore.py":269
 *                     timeout)
 * 
 *         if not success:             # <<<<<<<<<<<<<<
 *             assert timeout is not None
 *             # Our timer expired.
*/
  __pyx_t_7 = (!__pyx_v_success);
  if (__pyx_t_7) {

    /* "src/gevent/_semaphore.py":270
 * 
 *         if not success:
 *             assert timeout is not None             # <<<<<<<<<<<<<<
 *             # Our timer expired.
 *             return False
*/
    #ifndef CYTHON_WITHOUT_ASSERTIONS
    if (unlikely(__pyx_assertions_enabled())) {
      __pyx_t_7 = (__pyx_v_timeout != Py_None);
      if (unlikely(!__pyx_t_7)) {
        __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_AssertionError))), 0, 0, 0);
        __PYX_ERR(0, 270, __pyx_L1_error)
      }
    }
    #else
    if ((1)); else __PYX_ERR(0, 270, __pyx_L1_error)
    #endif

    /* "src/gevent/_semaphore.py":272
 *             assert timeout is not None
 *             # Our timer expired.
 *             return False             # <<<<<<<<<<<<<<
 * 
 *         # Neither our timer or another one expired, so we blocked until
*/
    __pyx_r = 0;
    goto __pyx_L0;

    /* "src/gevent/_semaphore.py":269
 *                     timeout)
 * 
 *         if not success:             # <<<<<<<<<<<<<<
 *             assert timeout is not None
 *             # Our timer expired.
*/
  }

  /* "src/gevent/_semaphore.py":276
 *         # Neither our timer or another one expired, so we blocked until
 *         # awoke. Therefore, the counter is ours
 *         assert self.counter > 0, (self.counter, blocking, timeout, success,)             # <<<<<<<<<<<<<<
 *         self.counter -= 1
 *         return True
*/
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(__pyx_assertions_enabled())) {
    __pyx_t_7 = (__pyx_v_self->counter > 0);
    if (unlikely(!__pyx_t_7)) {
      __pyx_t_2 = __Pyx_PyLong_From_int(__pyx_v_self->counter); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 276, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_blocking); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 276, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_4 = __Pyx_PyBool_FromLong(__pyx_v_success); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 276, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyTuple_New(4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 276, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_2);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2) != (0)) __PYX_ERR(0, 276, __pyx_L1_error);
      __Pyx_GIVEREF(__pyx_t_1);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_1) != (0)) __PYX_ERR(0, 276, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_timeout);
      __Pyx_GIVEREF(__pyx_v_timeout);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_v_timeout) != (0)) __PYX_ERR(0, 276, __pyx_L1_error);
      __Pyx_GIVEREF(__pyx_t_4);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 3, __pyx_t_4) != (0)) __PYX_ERR(0, 276, __pyx_L1_error);
      __pyx_t_2 = 0;
      __pyx_t_1 = 0;
      __pyx_t_4 = 0;
      __pyx_t_4 = PyTuple_Pack(1, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 276, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_AssertionError))), __pyx_t_4, 0, 0);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __PYX_ERR(0, 276, __pyx_L1_error)
    }
  }
  #else
  if ((1)); else __PYX_ERR(0, 276, __pyx_L1_error)
  #endif

  /* "src/gevent/_semaphore.py":277
 *         # awoke. Therefore, the counter is ours
 *         assert self.counter > 0, (self.counter, blocking, timeout, success,)
 *         self.counter -= 1             # <<<<<<<<<<<<<<
 *         return True
 * 
*/
  __pyx_v_self->counter = (__pyx_v_self->counter - 1);

  /* "src/gevent/_semaphore.py":278
 *         assert self.counter > 0, (self.counter, blocking, timeout, success,)
 *         self.counter -= 1
 *         return True             # <<<<<<<<<<<<<<
 * 
 *     _py3k_acquire = acquire # PyPy needs this; it must be static for Cython
*/
  __pyx_r = 1;
  goto __pyx_L0;

  /* "src/gevent/_semaphore.py":184
 *         return self.counter
 * 
 *     def acquire(self, blocking=True, timeout=None):             # <<<<<<<<<<<<<<
 *         """
 *         acquire(blocking=True, timeout=None) -> bool
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_24);
  __Pyx_AddTraceback("gevent._gevent_c_semaphore.Semaphore.acquire", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1000;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XDECREF(__pyx_v_ex);
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_v_invalid_thread_use);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_15acquire(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_19_gevent_c_semaphore_9Semaphore_14acquire, "Semaphore.acquire(self, bool blocking=True, timeout=None) -> bool\n\nacquire(blocking=True, timeout=None) -> bool\n\nAcquire the semaphore.\n\n.. note:: If this semaphore was initialized with a *value* of 0,\n   this method will block forever (unless a timeout is given or blocking is\n   set to false).\n\n:keyword bool blocking: If True (the default), this function will block\n   until the semaphore is acquired.\n:keyword float timeout: If given, and *blocking* is true,\n   specifies the maximum amount of seconds\n   this method will block.\n:return: A `bool` indicating whether the semaphore was acquired.\n   If ``blocking`` is True and ``timeout`` is None (the default), then\n   (so long as this semaphore was initialized with a size greater than 0)\n   this will always return True. If a timeout was given, and it expired before\n   the semaphore was acquired, False will be returned. (Note that this can still\n   raise a ``Timeout`` exception, if some other caller had already started a timer.)");
static PyMethodDef __pyx_mdef_6gevent_19_gevent_c_semaphore_9Semaphore_15acquire = {"acquire", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_15acquire, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6gevent_19_gevent_c_semaphore_9Semaphore_14acquire};
static PyObject *__pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_15acquire(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  int __pyx_v_blocking;
  PyObject *__pyx_v_timeout = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("acquire (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_blocking,&__pyx_mstate_global->__pyx_n_u_timeout,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 184, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 184, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 184, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "acquire", 0) < (0)) __PYX_ERR(0, 184, __pyx_L3_error)
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
    } else {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 184, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 184, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    if (values[0]) {
      __pyx_v_blocking = __Pyx_PyObject_IsTrue(values[0]); if (unlikely((__pyx_v_blocking == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 184, __pyx_L3_error)
    } else {
      __pyx_v_blocking = ((int)1);
    }
    __pyx_v_timeout = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("acquire", 0, 0, 2, __pyx_nargs); __PYX_ERR(0, 184, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("gevent._gevent_c_semaphore.Semaphore.acquire", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6gevent_19_gevent_c_semaphore_9Semaphore_14acquire(((struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self), __pyx_v_blocking, __pyx_v_timeout);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_19_gevent_c_semaphore_9Semaphore_14acquire(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, int __pyx_v_blocking, PyObject *__pyx_v_timeout) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  struct __pyx_opt_args_6gevent_19_gevent_c_semaphore_9Semaphore_acquire __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("acquire", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 2;
  __pyx_t_2.blocking = __pyx_v_blocking;
  __pyx_t_2.timeout = __pyx_v_timeout;
  __pyx_t_1 = __pyx_vtabptr_6gevent_19_gevent_c_semaphore_Semaphore->acquire(__pyx_v_self, 1, &__pyx_t_2); if (unlikely(__pyx_t_1 == ((int)-1000))) __PYX_ERR(0, 184, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 184, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("gevent._gevent_c_semaphore.Semaphore.acquire", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/_semaphore.py":282
 *     _py3k_acquire = acquire # PyPy needs this; it must be static for Cython
 * 
 *     def __enter__(self):             # <<<<<<<<<<<<<<
 *         self.acquire()
 * 
*/

static PyObject *__pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_17__enter__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore___enter__(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__enter__", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (
  #if !CYTHON_USE_TYPE_SLOTS
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore &&
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
  #else
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
  #endif
  ) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_enter); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 282, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_17__enter__)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 282, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "src/gevent/_semaphore.py":283
 * 
 *     def __enter__(self):
 *         self.acquire()             # <<<<<<<<<<<<<<
 * 
 *     def __exit__(self, t, v, tb):
*/
  __pyx_t_6 = ((struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self->__pyx_base.__pyx_vtab)->acquire(__pyx_v_self, 0, NULL); if (unlikely(__pyx_t_6 == ((int)-1000))) __PYX_ERR(0, 283, __pyx_L1_error)

  /* "src/gevent/_semaphore.py":282
 *     _py3k_acquire = acquire # PyPy needs this; it must be static for Cython
 * 
 *     def __enter__(self):             # <<<<<<<<<<<<<<
 *         self.acquire()
 * 
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("gevent._gevent_c_semaphore.Semaphore.__enter__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_17__enter__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_19_gevent_c_semaphore_9Semaphore_16__enter__, "Semaphore.__enter__(self)");
static PyMethodDef __pyx_mdef_6gevent_19_gevent_c_semaphore_9Semaphore_17__enter__ = {"__enter__", (PyCFunction)__pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_17__enter__, METH_NOARGS, __pyx_doc_6gevent_19_gevent_c_semaphore_9Semaphore_16__enter__};
static PyObject *__pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_17__enter__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__enter__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_19_gevent_c_semaphore_9Semaphore_16__enter__(((struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_19_gevent_c_semaphore_9Semaphore_16__enter__(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__enter__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore___enter__(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_c_semaphore.Semaphore.__enter__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/_semaphore.py":285
 *         self.acquire()
 * 
 *     def __exit__(self, t, v, tb):             # <<<<<<<<<<<<<<
 *         self.release()
 * 
*/

static PyObject *__pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_19__exit__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore___exit__(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_t, CYTHON_UNUSED PyObject *__pyx_v_v, CYTHON_UNUSED PyObject *__pyx_v_tb, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__exit__", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (
  #if !CYTHON_USE_TYPE_SLOTS
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore &&
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
  #else
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
  #endif
  ) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_exit); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 285, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_19__exit__)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[4] = {__pyx_t_3, __pyx_v_t, __pyx_v_v, __pyx_v_tb};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (4-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 285, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "src/gevent/_semaphore.py":286
 * 
 *     def __exit__(self, t, v, tb):
 *         self.release()             # <<<<<<<<<<<<<<
 * 
 *     def _handle_unswitched_notifications(self, unswitched):
*/
  __pyx_t_6 = ((struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self->__pyx_base.__pyx_vtab)->release(__pyx_v_self, 0); if (unlikely(__pyx_t_6 == ((int)-1000))) __PYX_ERR(0, 286, __pyx_L1_error)

  /* "src/gevent/_semaphore.py":285
 *         self.acquire()
 * 
 *     def __exit__(self, t, v, tb):             # <<<<<<<<<<<<<<
 *         self.release()
 * 
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("gevent._gevent_c_semaphore.Semaphore.__exit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_19__exit__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_19_gevent_c_semaphore_9Semaphore_18__exit__, "Semaphore.__exit__(self, t, v, tb)");
static PyMethodDef __pyx_mdef_6gevent_19_gevent_c_semaphore_9Semaphore_19__exit__ = {"__exit__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_19__exit__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6gevent_19_gevent_c_semaphore_9Semaphore_18__exit__};
static PyObject *__pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_19__exit__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_t = 0;
  PyObject *__pyx_v_v = 0;
  PyObject *__pyx_v_tb = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__exit__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_t,&__pyx_mstate_global->__pyx_n_u_v,&__pyx_mstate_global->__pyx_n_u_tb,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 285, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 285, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 285, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 285, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__exit__", 0) < (0)) __PYX_ERR(0, 285, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__exit__", 1, 3, 3, i); __PYX_ERR(0, 285, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 285, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 285, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 285, __pyx_L3_error)
    }
    __pyx_v_t = values[0];
    __pyx_v_v = values[1];
    __pyx_v_tb = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__exit__", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 285, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("gevent._gevent_c_semaphore.Semaphore.__exit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6gevent_19_gevent_c_semaphore_9Semaphore_18__exit__(((struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self), __pyx_v_t, __pyx_v_v, __pyx_v_tb);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_19_gevent_c_semaphore_9Semaphore_18__exit__(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, PyObject *__pyx_v_t, PyObject *__pyx_v_v, PyObject *__pyx_v_tb) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__exit__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore___exit__(__pyx_v_self, __pyx_v_t, __pyx_v_v, __pyx_v_tb, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 285, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_c_semaphore.Semaphore.__exit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/_semaphore.py":288
 *         self.release()
 * 
 *     def _handle_unswitched_notifications(self, unswitched):             # <<<<<<<<<<<<<<
 *         # If we fail to switch to a greenlet in another thread to send
 *         # a notification, just re-queue it, in the hopes that the
*/

static PyObject *__pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore__handle_unswitched_notifications(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, PyObject *__pyx_v_unswitched) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_handle_unswitched_notifications", 0);

  /* "src/gevent/_semaphore.py":311
 *         # TODO: Maybe we can rewrite that part of the algorithm to be friendly to
 *         # running the callbacks?
 *         self._links.extend(unswitched)             # <<<<<<<<<<<<<<
 * 
 *     def __add_link(self, link):
*/
  if (unlikely(__pyx_v_self->__pyx_base._links == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "extend");
    __PYX_ERR(0, 311, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyList_Extend(__pyx_v_self->__pyx_base._links, __pyx_v_unswitched); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 311, __pyx_L1_error)

  /* "src/gevent/_semaphore.py":288
 *         self.release()
 * 
 *     def _handle_unswitched_notifications(self, unswitched):             # <<<<<<<<<<<<<<
 *         # If we fail to switch to a greenlet in another thread to send
 *         # a notification, just re-queue it, in the hopes that the
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("gevent._gevent_c_semaphore.Semaphore._handle_unswitched_notifications", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/_semaphore.py":313
 *         self._links.extend(unswitched)
 * 
 *     def __add_link(self, link):             # <<<<<<<<<<<<<<
 *         if not self._notifier:
 *             self.rawlink(link)
*/

static PyObject *__pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore__Semaphore__add_link(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, PyObject *__pyx_v_link) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_Semaphore__add_link", 0);

  /* "src/gevent/_semaphore.py":314
 * 
 *     def __add_link(self, link):
 *         if not self._notifier:             # <<<<<<<<<<<<<<
 *             self.rawlink(link)
 *         else:
*/
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_self->__pyx_base._notifier); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 314, __pyx_L1_error)
  __pyx_t_2 = (!__pyx_t_1);
  if (__pyx_t_2) {

    /* "src/gevent/_semaphore.py":315
 *     def __add_link(self, link):
 *         if not self._notifier:
 *             self.rawlink(link)             # <<<<<<<<<<<<<<
 *         else:
 *             self._notifier.args[0].append(link)
*/
    __pyx_t_3 = ((struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.rawlink(((struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *)__pyx_v_self), __pyx_v_link, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 315, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "src/gevent/_semaphore.py":314
 * 
 *     def __add_link(self, link):
 *         if not self._notifier:             # <<<<<<<<<<<<<<
 *             self.rawlink(link)
 *         else:
*/
    goto __pyx_L3;
  }

  /* "src/gevent/_semaphore.py":317
 *             self.rawlink(link)
 *         else:
 *             self._notifier.args[0].append(link)             # <<<<<<<<<<<<<<
 * 
 *     def __acquire_from_other_thread(self, ex_args, blocking, timeout):
*/
  /*else*/ {
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->__pyx_base._notifier, __pyx_mstate_global->__pyx_n_u_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 317, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_GetItemInt(__pyx_t_3, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 317, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_5 = __Pyx_PyObject_Append(__pyx_t_4, __pyx_v_link); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 317, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_L3:;

  /* "src/gevent/_semaphore.py":313
 *         self._links.extend(unswitched)
 * 
 *     def __add_link(self, link):             # <<<<<<<<<<<<<<
 *         if not self._notifier:
 *             self.rawlink(link)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("gevent._gevent_c_semaphore.Semaphore._Semaphore__add_link", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/_semaphore.py":319
 *             self._notifier.args[0].append(link)
 * 
 *     def __acquire_from_other_thread(self, ex_args, blocking, timeout):             # <<<<<<<<<<<<<<
 *         assert blocking
 *         # Some other hub owns this object. We must ask it to wake us
*/

static PyObject *__pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore__Semaphore__acquire_from_other_thread(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, PyObject *__pyx_v_ex_args, int __pyx_v_blocking, PyObject *__pyx_v_timeout) {
  struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *__pyx_v_hub_for_this_thread = 0;
  struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *__pyx_v_owning_hub = 0;
  PyObject *__pyx_v_current_greenlet = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_Semaphore__acquire_from_other_thread", 0);

  /* "src/gevent/_semaphore.py":320
 * 
 *     def __acquire_from_other_thread(self, ex_args, blocking, timeout):
 *         assert blocking             # <<<<<<<<<<<<<<
 *         # Some other hub owns this object. We must ask it to wake us
 *         # up. In general, we can't use a Python-level ``Lock`` because
*/
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(__pyx_assertions_enabled())) {
    if (unlikely(!__pyx_v_blocking)) {
      __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_AssertionError))), 0, 0, 0);
      __PYX_ERR(0, 320, __pyx_L1_error)
    }
  }
  #else
  if ((1)); else __PYX_ERR(0, 320, __pyx_L1_error)
  #endif

  /* "src/gevent/_semaphore.py":335
 *         # We have to take an action that drops the GIL and drops the object lock
 *         # to allow the main thread (the thread for our hub) to advance.
 *         owning_hub = ex_args[0]             # <<<<<<<<<<<<<<
 *         hub_for_this_thread = ex_args[1]
 *         current_greenlet = ex_args[2]
*/
  if (unlikely(__pyx_v_ex_args == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 335, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v_ex_args, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 335, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_mstate_global->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop))))) __PYX_ERR(0, 335, __pyx_L1_error)
  __pyx_v_owning_hub = ((struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "src/gevent/_semaphore.py":336
 *         # to allow the main thread (the thread for our hub) to advance.
 *         owning_hub = ex_args[0]
 *         hub_for_this_thread = ex_args[1]             # <<<<<<<<<<<<<<
 *         current_greenlet = ex_args[2]
 * 
*/
  if (unlikely(__pyx_v_ex_args == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 336, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v_ex_args, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_mstate_global->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop))))) __PYX_ERR(0, 336, __pyx_L1_error)
  __pyx_v_hub_for_this_thread = ((struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "src/gevent/_semaphore.py":337
 *         owning_hub = ex_args[0]
 *         hub_for_this_thread = ex_args[1]
 *         current_greenlet = ex_args[2]             # <<<<<<<<<<<<<<
 * 
 *         if owning_hub is None and hub_for_this_thread is None:
*/
  if (unlikely(__pyx_v_ex_args == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 337, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v_ex_args, 2, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 337, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_current_greenlet = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "src/gevent/_semaphore.py":339
 *         current_greenlet = ex_args[2]
 * 
 *         if owning_hub is None and hub_for_this_thread is None:             # <<<<<<<<<<<<<<
 *             return self.__acquire_without_hubs(timeout)
 * 
*/
  __pyx_t_3 = (((PyObject *)__pyx_v_owning_hub) == Py_None);
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = (((PyObject *)__pyx_v_hub_for_this_thread) == Py_None);
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "src/gevent/_semaphore.py":340
 * 
 *         if owning_hub is None and hub_for_this_thread is None:
 *             return self.__acquire_without_hubs(timeout)             # <<<<<<<<<<<<<<
 * 
 *         if hub_for_this_thread is None:
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = ((struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self->__pyx_base.__pyx_vtab)->_Semaphore__acquire_without_hubs(__pyx_v_self, __pyx_v_timeout); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 340, __pyx_L1_error)
    __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 340, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "src/gevent/_semaphore.py":339
 *         current_greenlet = ex_args[2]
 * 
 *         if owning_hub is None and hub_for_this_thread is None:             # <<<<<<<<<<<<<<
 *             return self.__acquire_without_hubs(timeout)
 * 
*/
  }

  /* "src/gevent/_semaphore.py":342
 *             return self.__acquire_without_hubs(timeout)
 * 
 *         if hub_for_this_thread is None:             # <<<<<<<<<<<<<<
 *             # Probably a background worker thread. We don't want to create
 *             # the hub if not needed, and since it didn't exist there are no
*/
  __pyx_t_2 = (((PyObject *)__pyx_v_hub_for_this_thread) == Py_None);
  if (__pyx_t_2) {

    /* "src/gevent/_semaphore.py":348
 *             # to block and no reason to try to avoid blocking, so using a native
 *             # lock is the simplest way to go.
 *             return self.__acquire_using_other_hub(owning_hub, timeout)             # <<<<<<<<<<<<<<
 * 
 *         # We have a hub we don't want to block. Use an async watcher
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = ((struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self->__pyx_base.__pyx_vtab)->_Semaphore__acquire_using_other_hub(__pyx_v_self, __pyx_v_owning_hub, __pyx_v_timeout); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 348, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "src/gevent/_semaphore.py":342
 *             return self.__acquire_without_hubs(timeout)
 * 
 *         if hub_for_this_thread is None:             # <<<<<<<<<<<<<<
 *             # Probably a background worker thread. We don't want to create
 *             # the hub if not needed, and since it didn't exist there are no
*/
  }

  /* "src/gevent/_semaphore.py":352
 *         # We have a hub we don't want to block. Use an async watcher
 *         # and ask the next releaser of this object to wake us up.
 *         return self.__acquire_using_two_hubs(hub_for_this_thread,             # <<<<<<<<<<<<<<
 *                                              current_greenlet,
 *                                              timeout)
*/
  __Pyx_XDECREF(__pyx_r);

  /* "src/gevent/_semaphore.py":354
 *         return self.__acquire_using_two_hubs(hub_for_this_thread,
 *                                              current_greenlet,
 *                                              timeout)             # <<<<<<<<<<<<<<
 * 
 *     def __acquire_using_two_hubs(self,
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self->__pyx_base.__pyx_vtab)->_Semaphore__acquire_using_two_hubs(__pyx_v_self, __pyx_v_hub_for_this_thread, __pyx_v_current_greenlet, __pyx_v_timeout); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 352, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "src/gevent/_semaphore.py":319
 *             self._notifier.args[0].append(link)
 * 
 *     def __acquire_from_other_thread(self, ex_args, blocking, timeout):             # <<<<<<<<<<<<<<
 *         assert blocking
 *         # Some other hub owns this object. We must ask it to wake us
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_c_semaphore.Semaphore._Semaphore__acquire_from_other_thread", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_hub_for_this_thread);
  __Pyx_XDECREF((PyObject *)__pyx_v_owning_hub);
  __Pyx_XDECREF(__pyx_v_current_greenlet);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/_semaphore.py":356
 *                                              timeout)
 * 
 *     def __acquire_using_two_hubs(self,             # <<<<<<<<<<<<<<
 *                                  hub_for_this_thread,
 *                                  current_greenlet,
*/

static PyObject *__pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore__Semaphore__acquire_using_two_hubs(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *__pyx_v_hub_for_this_thread, PyObject *__pyx_v_current_greenlet, PyObject *__pyx_v_timeout) {
  PyObject *__pyx_v_watcher = NULL;
  PyObject *__pyx_v_send = NULL;
  PyObject *__pyx_v_timer = NULL;
  int __pyx_v_result;
  PyObject *__pyx_v_tex = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_t_13;
  int __pyx_t_14;
  struct __pyx_opt_args_6gevent_19_gevent_c_semaphore_9Semaphore_acquire __pyx_t_15;
  int __pyx_t_16;
  char const *__pyx_t_17;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  PyObject *__pyx_t_23 = NULL;
  int __pyx_t_24;
  char const *__pyx_t_25;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_Semaphore__acquire_using_two_hubs", 0);

  /* "src/gevent/_semaphore.py":364
 *         # With other backends, allocating might, and starting might also.
 *         # So...
 *         watcher = hub_for_this_thread.loop.async_()             # <<<<<<<<<<<<<<
 *         send = watcher.send_ignoring_arg
 *         watcher.start(current_greenlet.switch, self)
*/
  __pyx_t_2 = __pyx_v_hub_for_this_thread->loop;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_async, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 364, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_watcher = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "src/gevent/_semaphore.py":365
 *         # So...
 *         watcher = hub_for_this_thread.loop.async_()
 *         send = watcher.send_ignoring_arg             # <<<<<<<<<<<<<<
 *         watcher.start(current_greenlet.switch, self)
 *         try:
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_watcher, __pyx_mstate_global->__pyx_n_u_send_ignoring_arg); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 365, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_send = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "src/gevent/_semaphore.py":366
 *         watcher = hub_for_this_thread.loop.async_()
 *         send = watcher.send_ignoring_arg
 *         watcher.start(current_greenlet.switch, self)             # <<<<<<<<<<<<<<
 *         try:
 *             with Timeout._start_new_or_dummy(timeout) as timer:
*/
  __pyx_t_2 = __pyx_v_watcher;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_current_greenlet, __pyx_mstate_global->__pyx_n_u_switch); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_t_4, ((PyObject *)__pyx_v_self)};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_start, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 366, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "src/gevent/_semaphore.py":367
 *         send = watcher.send_ignoring_arg
 *         watcher.start(current_greenlet.switch, self)
 *         try:             # <<<<<<<<<<<<<<
 *             with Timeout._start_new_or_dummy(timeout) as timer:
 *                 # ... now that we're back holding the GIL, we need to verify our
*/
  /*try:*/ {

    /* "src/gevent/_semaphore.py":368
 *         watcher.start(current_greenlet.switch, self)
 *         try:
 *             with Timeout._start_new_or_dummy(timeout) as timer:             # <<<<<<<<<<<<<<
 *                 # ... now that we're back holding the GIL, we need to verify our
 *                 # state.
*/
    /*with:*/ {
      __pyx_t_4 = __pyx_v_6gevent_19_gevent_c_semaphore_Timeout;
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_timeout};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_start_new_or_dummy, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 368, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __pyx_t_5 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_exit); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 368, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_2 = NULL;
      __pyx_t_6 = __Pyx_PyObject_LookupSpecial(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_enter); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 368, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_3 = 1;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_6);
        assert(__pyx_t_2);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
        __pyx_t_3 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
        __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 368, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_4);
      }
      __pyx_t_6 = __pyx_t_4;
      __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      /*try:*/ {
        {
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __Pyx_ExceptionSave(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
          __Pyx_XGOTREF(__pyx_t_7);
          __Pyx_XGOTREF(__pyx_t_8);
          __Pyx_XGOTREF(__pyx_t_9);
          /*try:*/ {
            __pyx_v_timer = __pyx_t_6;
            __pyx_t_6 = 0;

            /* "src/gevent/_semaphore.py":371
 *                 # ... now that we're back holding the GIL, we need to verify our
 *                 # state.
 *                 try:             # <<<<<<<<<<<<<<
 *                     while 1:
 *                         if self.counter > 0:
*/
            {
              __Pyx_PyThreadState_declare
              __Pyx_PyThreadState_assign
              __Pyx_ExceptionSave(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
              __Pyx_XGOTREF(__pyx_t_10);
              __Pyx_XGOTREF(__pyx_t_11);
              __Pyx_XGOTREF(__pyx_t_12);
              /*try:*/ {

                /* "src/gevent/_semaphore.py":372
 *                 # state.
 *                 try:
 *                     while 1:             # <<<<<<<<<<<<<<
 *                         if self.counter > 0:
 *                             self.counter -= 1
*/
                while (1) {

                  /* "src/gevent/_semaphore.py":373
 *                 try:
 *                     while 1:
 *                         if self.counter > 0:             # <<<<<<<<<<<<<<
 *                             self.counter -= 1
 *                             assert self.counter >= 0, (self,)
*/
                  __pyx_t_13 = (__pyx_v_self->counter > 0);
                  if (__pyx_t_13) {

                    /* "src/gevent/_semaphore.py":374
 *                     while 1:
 *                         if self.counter > 0:
 *                             self.counter -= 1             # <<<<<<<<<<<<<<
 *                             assert self.counter >= 0, (self,)
 *                             return True
*/
                    __pyx_v_self->counter = (__pyx_v_self->counter - 1);

                    /* "src/gevent/_semaphore.py":375
 *                         if self.counter > 0:
 *                             self.counter -= 1
 *                             assert self.counter >= 0, (self,)             # <<<<<<<<<<<<<<
 *                             return True
 * 
*/
                    #ifndef CYTHON_WITHOUT_ASSERTIONS
                    if (unlikely(__pyx_assertions_enabled())) {
                      __pyx_t_13 = (__pyx_v_self->counter >= 0);
                      if (unlikely(!__pyx_t_13)) {
                        __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 375, __pyx_L16_error)
                        __Pyx_GOTREF(__pyx_t_6);
                        __Pyx_INCREF((PyObject *)__pyx_v_self);
                        __Pyx_GIVEREF((PyObject *)__pyx_v_self);
                        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, ((PyObject *)__pyx_v_self)) != (0)) __PYX_ERR(0, 375, __pyx_L16_error);
                        __pyx_t_1 = PyTuple_Pack(1, __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 375, __pyx_L16_error)
                        __Pyx_GOTREF(__pyx_t_1);
                        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                        __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_AssertionError))), __pyx_t_1, 0, 0);
                        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                        __PYX_ERR(0, 375, __pyx_L16_error)
                      }
                    }
                    #else
                    if ((1)); else __PYX_ERR(0, 375, __pyx_L16_error)
                    #endif

                    /* "src/gevent/_semaphore.py":376
 *                             self.counter -= 1
 *                             assert self.counter >= 0, (self,)
 *                             return True             # <<<<<<<<<<<<<<
 * 
 *                         self.__add_link(send)
*/
                    __Pyx_XDECREF(__pyx_r);
                    __Pyx_INCREF(Py_True);
                    __pyx_r = Py_True;
                    goto __pyx_L20_try_return;

                    /* "src/gevent/_semaphore.py":373
 *                 try:
 *                     while 1:
 *                         if self.counter > 0:             # <<<<<<<<<<<<<<
 *                             self.counter -= 1
 *                             assert self.counter >= 0, (self,)
*/
                  }

                  /* "src/gevent/_semaphore.py":378
 *                             return True
 * 
 *                         self.__add_link(send)             # <<<<<<<<<<<<<<
 * 
 *                         # Releases the object lock
*/
                  __pyx_t_1 = ((struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self->__pyx_base.__pyx_vtab)->_Semaphore__add_link(__pyx_v_self, __pyx_v_send); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 378, __pyx_L16_error)
                  __Pyx_GOTREF(__pyx_t_1);
                  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

                  /* "src/gevent/_semaphore.py":381
 * 
 *                         # Releases the object lock
 *                         self._switch_to_hub(hub_for_this_thread)             # <<<<<<<<<<<<<<
 *                         # We waited and got notified. We should be ready now, so a non-blocking
 *                         # acquire() should succeed. But sometimes we get spurious notifications?
*/
                  __pyx_t_14 = ((struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._switch_to_hub(((struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *)__pyx_v_self), ((PyObject *)__pyx_v_hub_for_this_thread)); if (unlikely(__pyx_t_14 == ((int)-1))) __PYX_ERR(0, 381, __pyx_L16_error)

                  /* "src/gevent/_semaphore.py":386
 *                         # It's not entirely clear how. So we need to loop until we get it, or until
 *                         # the timer expires
 *                         result = self.acquire(0)             # <<<<<<<<<<<<<<
 *                         if result:
 *                             return result
*/
                  __pyx_t_15.__pyx_n = 1;
                  __pyx_t_15.blocking = 0;
                  __pyx_t_13 = ((struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self->__pyx_base.__pyx_vtab)->acquire(__pyx_v_self, 0, &__pyx_t_15); if (unlikely(__pyx_t_13 == ((int)-1000))) __PYX_ERR(0, 386, __pyx_L16_error)
                  __pyx_v_result = __pyx_t_13;

                  /* "src/gevent/_semaphore.py":387
 *                         # the timer expires
 *                         result = self.acquire(0)
 *                         if result:             # <<<<<<<<<<<<<<
 *                             return result
 *                 except Timeout as tex:
*/
                  if (__pyx_v_result) {

                    /* "src/gevent/_semaphore.py":388
 *                         result = self.acquire(0)
 *                         if result:
 *                             return result             # <<<<<<<<<<<<<<
 *                 except Timeout as tex:
 *                     if tex is not timer:
*/
                    __Pyx_XDECREF(__pyx_r);
                    __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_result); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 388, __pyx_L16_error)
                    __Pyx_GOTREF(__pyx_t_1);
                    __pyx_r = __pyx_t_1;
                    __pyx_t_1 = 0;
                    goto __pyx_L20_try_return;

                    /* "src/gevent/_semaphore.py":387
 *                         # the timer expires
 *                         result = self.acquire(0)
 *                         if result:             # <<<<<<<<<<<<<<
 *                             return result
 *                 except Timeout as tex:
*/
                  }
                }

                /* "src/gevent/_semaphore.py":371
 *                 # ... now that we're back holding the GIL, we need to verify our
 *                 # state.
 *                 try:             # <<<<<<<<<<<<<<
 *                     while 1:
 *                         if self.counter > 0:
*/
              }
              __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
              __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
              __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
              goto __pyx_L21_try_end;
              __pyx_L16_error:;
              __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
              __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
              __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
              __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

              /* "src/gevent/_semaphore.py":389
 *                         if result:
 *                             return result
 *                 except Timeout as tex:             # <<<<<<<<<<<<<<
 *                     if tex is not timer:
 *                         raise
*/
              __pyx_t_14 = __Pyx_PyErr_ExceptionMatches(__pyx_v_6gevent_19_gevent_c_semaphore_Timeout);
              if (__pyx_t_14) {
                __Pyx_AddTraceback("gevent._gevent_c_semaphore.Semaphore._Semaphore__acquire_using_two_hubs", __pyx_clineno, __pyx_lineno, __pyx_filename);
                if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_6, &__pyx_t_4) < 0) __PYX_ERR(0, 389, __pyx_L18_except_error)
                __Pyx_XGOTREF(__pyx_t_1);
                __Pyx_XGOTREF(__pyx_t_6);
                __Pyx_XGOTREF(__pyx_t_4);
                __Pyx_INCREF(__pyx_t_6);
                __pyx_v_tex = __pyx_t_6;
                /*try:*/ {

                  /* "src/gevent/_semaphore.py":390
 *                             return result
 *                 except Timeout as tex:
 *                     if tex is not timer:             # <<<<<<<<<<<<<<
 *                         raise
 *                     return False
*/
                  __pyx_t_13 = (__pyx_v_tex != ((PyObject*)__pyx_v_timer));
                  if (unlikely(__pyx_t_13)) {

                    /* "src/gevent/_semaphore.py":391
 *                 except Timeout as tex:
 *                     if tex is not timer:
 *                         raise             # <<<<<<<<<<<<<<
 *                     return False
 *         finally:
*/
                    __Pyx_GIVEREF(__pyx_t_1);
                    __Pyx_GIVEREF(__pyx_t_6);
                    __Pyx_XGIVEREF(__pyx_t_4);
                    __Pyx_ErrRestoreWithState(__pyx_t_1, __pyx_t_6, __pyx_t_4);
                    __pyx_t_1 = 0;  __pyx_t_6 = 0;  __pyx_t_4 = 0; 
                    __PYX_ERR(0, 391, __pyx_L31_error)

                    /* "src/gevent/_semaphore.py":390
 *                             return result
 *                 except Timeout as tex:
 *                     if tex is not timer:             # <<<<<<<<<<<<<<
 *                         raise
 *                     return False
*/
                  }

                  /* "src/gevent/_semaphore.py":392
 *                     if tex is not timer:
 *                         raise
 *                     return False             # <<<<<<<<<<<<<<
 *         finally:
 *             self._quiet_unlink_all(send)
*/
                  __Pyx_XDECREF(__pyx_r);
                  __Pyx_INCREF(Py_False);
                  __pyx_r = Py_False;
                  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
                  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                  goto __pyx_L30_return;
                }

                /* "src/gevent/_semaphore.py":389
 *                         if result:
 *                             return result
 *                 except Timeout as tex:             # <<<<<<<<<<<<<<
 *                     if tex is not timer:
 *                         raise
*/
                /*finally:*/ {
                  __pyx_L31_error:;
                  /*exception exit:*/{
                    __Pyx_PyThreadState_declare
                    __Pyx_PyThreadState_assign
                    __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0;
                    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
                     __Pyx_ExceptionSwap(&__pyx_t_21, &__pyx_t_22, &__pyx_t_23);
                    if ( unlikely(__Pyx_GetException(&__pyx_t_18, &__pyx_t_19, &__pyx_t_20) < 0)) __Pyx_ErrFetch(&__pyx_t_18, &__pyx_t_19, &__pyx_t_20);
                    __Pyx_XGOTREF(__pyx_t_18);
                    __Pyx_XGOTREF(__pyx_t_19);
                    __Pyx_XGOTREF(__pyx_t_20);
                    __Pyx_XGOTREF(__pyx_t_21);
                    __Pyx_XGOTREF(__pyx_t_22);
                    __Pyx_XGOTREF(__pyx_t_23);
                    __pyx_t_14 = __pyx_lineno; __pyx_t_16 = __pyx_clineno; __pyx_t_17 = __pyx_filename;
                    {
                      __Pyx_DECREF(__pyx_v_tex); __pyx_v_tex = 0;
                    }
                    __Pyx_XGIVEREF(__pyx_t_21);
                    __Pyx_XGIVEREF(__pyx_t_22);
                    __Pyx_XGIVEREF(__pyx_t_23);
                    __Pyx_ExceptionReset(__pyx_t_21, __pyx_t_22, __pyx_t_23);
                    __Pyx_XGIVEREF(__pyx_t_18);
                    __Pyx_XGIVEREF(__pyx_t_19);
                    __Pyx_XGIVEREF(__pyx_t_20);
                    __Pyx_ErrRestore(__pyx_t_18, __pyx_t_19, __pyx_t_20);
                    __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0;
                    __pyx_lineno = __pyx_t_14; __pyx_clineno = __pyx_t_16; __pyx_filename = __pyx_t_17;
                    goto __pyx_L18_except_error;
                  }
                  __pyx_L30_return: {
                    __pyx_t_23 = __pyx_r;
                    __pyx_r = 0;
                    __Pyx_DECREF(__pyx_v_tex); __pyx_v_tex = 0;
                    __pyx_r = __pyx_t_23;
                    __pyx_t_23 = 0;
                    goto __pyx_L19_except_return;
                  }
                }
              }
              goto __pyx_L18_except_error;

              /* "src/gevent/_semaphore.py":371
 *                 # ... now that we're back holding the GIL, we need to verify our
 *                 # state.
 *                 try:             # <<<<<<<<<<<<<<
 *                     while 1:
 *                         if self.counter > 0:
*/
              __pyx_L18_except_error:;
              __Pyx_XGIVEREF(__pyx_t_10);
              __Pyx_XGIVEREF(__pyx_t_11);
              __Pyx_XGIVEREF(__pyx_t_12);
              __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
              goto __pyx_L10_error;
              __pyx_L20_try_return:;
              __Pyx_XGIVEREF(__pyx_t_10);
              __Pyx_XGIVEREF(__pyx_t_11);
              __Pyx_XGIVEREF(__pyx_t_12);
              __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
              goto __pyx_L14_try_return;
              __pyx_L19_except_return:;
              __Pyx_XGIVEREF(__pyx_t_10);
              __Pyx_XGIVEREF(__pyx_t_11);
              __Pyx_XGIVEREF(__pyx_t_12);
              __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
              goto __pyx_L14_try_return;
              __pyx_L21_try_end:;
            }

            /* "src/gevent/_semaphore.py":368
 *         watcher.start(current_greenlet.switch, self)
 *         try:
 *             with Timeout._start_new_or_dummy(timeout) as timer:             # <<<<<<<<<<<<<<
 *                 # ... now that we're back holding the GIL, we need to verify our
 *                 # state.
*/
          }
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          goto __pyx_L15_try_end;
          __pyx_L10_error:;
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          /*except:*/ {
            __Pyx_AddTraceback("gevent._gevent_c_semaphore.Semaphore._Semaphore__acquire_using_two_hubs", __pyx_clineno, __pyx_lineno, __pyx_filename);
            if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_6, &__pyx_t_1) < 0) __PYX_ERR(0, 368, __pyx_L12_except_error)
            __Pyx_XGOTREF(__pyx_t_4);
            __Pyx_XGOTREF(__pyx_t_6);
            __Pyx_XGOTREF(__pyx_t_1);
            __pyx_t_2 = PyTuple_Pack(3, __pyx_t_4, __pyx_t_6, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 368, __pyx_L12_except_error)
            __Pyx_GOTREF(__pyx_t_2);
            __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_2, NULL);
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 368, __pyx_L12_except_error)
            __Pyx_GOTREF(__pyx_t_12);
            __pyx_t_13 = __Pyx_PyObject_IsTrue(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            if (__pyx_t_13 < (0)) __PYX_ERR(0, 368, __pyx_L12_except_error)
            __pyx_t_24 = (!__pyx_t_13);
            if (unlikely(__pyx_t_24)) {
              __Pyx_GIVEREF(__pyx_t_4);
              __Pyx_GIVEREF(__pyx_t_6);
              __Pyx_XGIVEREF(__pyx_t_1);
              __Pyx_ErrRestoreWithState(__pyx_t_4, __pyx_t_6, __pyx_t_1);
              __pyx_t_4 = 0;  __pyx_t_6 = 0;  __pyx_t_1 = 0; 
              __PYX_ERR(0, 368, __pyx_L12_except_error)
            }
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
            goto __pyx_L11_exception_handled;
          }
          __pyx_L12_except_error:;
          __Pyx_XGIVEREF(__pyx_t_7);
          __Pyx_XGIVEREF(__pyx_t_8);
          __Pyx_XGIVEREF(__pyx_t_9);
          __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
          goto __pyx_L4_error;
          __pyx_L14_try_return:;
          __Pyx_XGIVEREF(__pyx_t_7);
          __Pyx_XGIVEREF(__pyx_t_8);
          __Pyx_XGIVEREF(__pyx_t_9);
          __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
          goto __pyx_L7_return;
          __pyx_L11_exception_handled:;
          __Pyx_XGIVEREF(__pyx_t_7);
          __Pyx_XGIVEREF(__pyx_t_8);
          __Pyx_XGIVEREF(__pyx_t_9);
          __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
          __pyx_L15_try_end:;
        }
      }
      /*finally:*/ {
        /*normal exit:*/{
          if (__pyx_t_5) {
            __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_mstate_global->__pyx_tuple[0], NULL);
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 368, __pyx_L4_error)
            __Pyx_GOTREF(__pyx_t_9);
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          }
          goto __pyx_L9;
        }
        __pyx_L7_return: {
          __pyx_t_9 = __pyx_r;
          __pyx_r = 0;
          if (__pyx_t_5) {
            __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_mstate_global->__pyx_tuple[0], NULL);
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 368, __pyx_L4_error)
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          }
          __pyx_r = __pyx_t_9;
          __pyx_t_9 = 0;
          goto __pyx_L3_return;
        }
        __pyx_L9:;
      }
      goto __pyx_L41;
      __pyx_L6_error:;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      goto __pyx_L4_error;
      __pyx_L41:;
    }
  }

  /* "src/gevent/_semaphore.py":394
 *                     return False
 *         finally:
 *             self._quiet_unlink_all(send)             # <<<<<<<<<<<<<<
 *             watcher.stop()
 *             watcher.close()
*/
  /*finally:*/ {
    /*normal exit:*/{
      ((struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._quiet_unlink_all(((struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *)__pyx_v_self), __pyx_v_send); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 394, __pyx_L1_error)

      /* "src/gevent/_semaphore.py":395
 *         finally:
 *             self._quiet_unlink_all(send)
 *             watcher.stop()             # <<<<<<<<<<<<<<
 *             watcher.close()
 * 
*/
      __pyx_t_6 = __pyx_v_watcher;
      __Pyx_INCREF(__pyx_t_6);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_stop, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 395, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "src/gevent/_semaphore.py":396
 *             self._quiet_unlink_all(send)
 *             watcher.stop()
 *             watcher.close()             # <<<<<<<<<<<<<<
 * 
 *     def __acquire_from_other_thread_cb(self, results, blocking, timeout, thread_lock):
*/
      __pyx_t_6 = __pyx_v_watcher;
      __Pyx_INCREF(__pyx_t_6);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_close, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 396, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L5;
    }
    __pyx_L4_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_5 = 0; __pyx_t_9 = 0; __pyx_t_8 = 0; __pyx_t_7 = 0; __pyx_t_12 = 0; __pyx_t_11 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
       __Pyx_ExceptionSwap(&__pyx_t_7, &__pyx_t_12, &__pyx_t_11);
      if ( unlikely(__Pyx_GetException(&__pyx_t_5, &__pyx_t_9, &__pyx_t_8) < 0)) __Pyx_ErrFetch(&__pyx_t_5, &__pyx_t_9, &__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_11);
      __pyx_t_16 = __pyx_lineno; __pyx_t_14 = __pyx_clineno; __pyx_t_25 = __pyx_filename;
      {

        /* "src/gevent/_semaphore.py":394
 *                     return False
 *         finally:
 *             self._quiet_unlink_all(send)             # <<<<<<<<<<<<<<
 *             watcher.stop()
 *             watcher.close()
*/
        ((struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._quiet_unlink_all(((struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *)__pyx_v_self), __pyx_v_send); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 394, __pyx_L43_error)

        /* "src/gevent/_semaphore.py":395
 *         finally:
 *             self._quiet_unlink_all(send)
 *             watcher.stop()             # <<<<<<<<<<<<<<
 *             watcher.close()
 * 
*/
        __pyx_t_6 = __pyx_v_watcher;
        __Pyx_INCREF(__pyx_t_6);
        __pyx_t_3 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
          __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_stop, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 395, __pyx_L43_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "src/gevent/_semaphore.py":396
 *             self._quiet_unlink_all(send)
 *             watcher.stop()
 *             watcher.close()             # <<<<<<<<<<<<<<
 * 
 *     def __acquire_from_other_thread_cb(self, results, blocking, timeout, thread_lock):
*/
        __pyx_t_6 = __pyx_v_watcher;
        __Pyx_INCREF(__pyx_t_6);
        __pyx_t_3 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
          __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_close, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 396, __pyx_L43_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_12);
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_12, __pyx_t_11);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_ErrRestore(__pyx_t_5, __pyx_t_9, __pyx_t_8);
      __pyx_t_5 = 0; __pyx_t_9 = 0; __pyx_t_8 = 0; __pyx_t_7 = 0; __pyx_t_12 = 0; __pyx_t_11 = 0;
      __pyx_lineno = __pyx_t_16; __pyx_clineno = __pyx_t_14; __pyx_filename = __pyx_t_25;
      goto __pyx_L1_error;
      __pyx_L43_error:;
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_12);
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_12, __pyx_t_11);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_7 = 0; __pyx_t_12 = 0; __pyx_t_11 = 0;
      goto __pyx_L1_error;
    }
    __pyx_L3_return: {
      __pyx_t_11 = __pyx_r;
      __pyx_r = 0;

      /* "src/gevent/_semaphore.py":394
 *                     return False
 *         finally:
 *             self._quiet_unlink_all(send)             # <<<<<<<<<<<<<<
 *             watcher.stop()
 *             watcher.close()
*/
      ((struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._quiet_unlink_all(((struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *)__pyx_v_self), __pyx_v_send); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 394, __pyx_L1_error)

      /* "src/gevent/_semaphore.py":395
 *         finally:
 *             self._quiet_unlink_all(send)
 *             watcher.stop()             # <<<<<<<<<<<<<<
 *             watcher.close()
 * 
*/
      __pyx_t_6 = __pyx_v_watcher;
      __Pyx_INCREF(__pyx_t_6);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_stop, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 395, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "src/gevent/_semaphore.py":396
 *             self._quiet_unlink_all(send)
 *             watcher.stop()
 *             watcher.close()             # <<<<<<<<<<<<<<
 * 
 *     def __acquire_from_other_thread_cb(self, results, blocking, timeout, thread_lock):
*/
      __pyx_t_6 = __pyx_v_watcher;
      __Pyx_INCREF(__pyx_t_6);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_close, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 396, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_r = __pyx_t_11;
      __pyx_t_11 = 0;
      goto __pyx_L0;
    }
    __pyx_L5:;
  }

  /* "src/gevent/_semaphore.py":356
 *                                              timeout)
 * 
 *     def __acquire_using_two_hubs(self,             # <<<<<<<<<<<<<<
 *                                  hub_for_this_thread,
 *                                  current_greenlet,
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("gevent._gevent_c_semaphore.Semaphore._Semaphore__acquire_using_two_hubs", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_watcher);
  __Pyx_XDECREF(__pyx_v_send);
  __Pyx_XDECREF(__pyx_v_timer);
  __Pyx_XDECREF(__pyx_v_tex);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/_semaphore.py":398
 *             watcher.close()
 * 
 *     def __acquire_from_other_thread_cb(self, results, blocking, timeout, thread_lock):             # <<<<<<<<<<<<<<
 *         try:
 *             result = self.acquire(blocking, timeout)
*/

static PyObject *__pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_21_Semaphore__acquire_from_other_thread_cb(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore__Semaphore__acquire_from_other_thread_cb(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, PyObject *__pyx_v_results, int __pyx_v_blocking, PyObject *__pyx_v_timeout, PyObject *__pyx_v_thread_lock, int __pyx_skip_dispatch) {
  int __pyx_v_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_t_7;
  struct __pyx_opt_args_6gevent_19_gevent_c_semaphore_9Semaphore_acquire __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  int __pyx_t_11;
  char const *__pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_Semaphore__acquire_from_other_thread_cb", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (
  #if !CYTHON_USE_TYPE_SLOTS
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore &&
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
  #else
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
  #endif
  ) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_Semaphore__acquire_from_other_t); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 398, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_21_Semaphore__acquire_from_other_thread_cb)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; 
        __pyx_t_5 = __Pyx_PyBool_FromLong(__pyx_v_blocking); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 398, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_6 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_6 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[5] = {__pyx_t_3, __pyx_v_results, __pyx_t_5, __pyx_v_timeout, __pyx_v_thread_lock};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_6, (5-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 398, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "src/gevent/_semaphore.py":399
 * 
 *     def __acquire_from_other_thread_cb(self, results, blocking, timeout, thread_lock):
 *         try:             # <<<<<<<<<<<<<<
 *             result = self.acquire(blocking, timeout)
 *             results.append(result)
*/
  /*try:*/ {

    /* "src/gevent/_semaphore.py":400
 *     def __acquire_from_other_thread_cb(self, results, blocking, timeout, thread_lock):
 *         try:
 *             result = self.acquire(blocking, timeout)             # <<<<<<<<<<<<<<
 *             results.append(result)
 *         finally:
*/
    __pyx_t_8.__pyx_n = 2;
    __pyx_t_8.blocking = __pyx_v_blocking;
    __pyx_t_8.timeout = __pyx_v_timeout;
    __pyx_t_7 = ((struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self->__pyx_base.__pyx_vtab)->acquire(__pyx_v_self, 0, &__pyx_t_8); if (unlikely(__pyx_t_7 == ((int)-1000))) __PYX_ERR(0, 400, __pyx_L4_error)
    __pyx_v_result = __pyx_t_7;

    /* "src/gevent/_semaphore.py":401
 *         try:
 *             result = self.acquire(blocking, timeout)
 *             results.append(result)             # <<<<<<<<<<<<<<
 *         finally:
 *             thread_lock.release()
*/
    if (unlikely(__pyx_v_results == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
      __PYX_ERR(0, 401, __pyx_L4_error)
    }
    __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_result); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 401, __pyx_L4_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_results, __pyx_t_1); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 401, __pyx_L4_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "src/gevent/_semaphore.py":403
 *             results.append(result)
 *         finally:
 *             thread_lock.release()             # <<<<<<<<<<<<<<
 *         return result
 * 
*/
  /*finally:*/ {
    /*normal exit:*/{
      __pyx_t_2 = __pyx_v_thread_lock;
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_release, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 403, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L5;
    }
    __pyx_L4_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
       __Pyx_ExceptionSwap(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18);
      if ( unlikely(__Pyx_GetException(&__pyx_t_13, &__pyx_t_14, &__pyx_t_15) < 0)) __Pyx_ErrFetch(&__pyx_t_13, &__pyx_t_14, &__pyx_t_15);
      __Pyx_XGOTREF(__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_14);
      __Pyx_XGOTREF(__pyx_t_15);
      __Pyx_XGOTREF(__pyx_t_16);
      __Pyx_XGOTREF(__pyx_t_17);
      __Pyx_XGOTREF(__pyx_t_18);
      __pyx_t_10 = __pyx_lineno; __pyx_t_11 = __pyx_clineno; __pyx_t_12 = __pyx_filename;
      {
        __pyx_t_2 = __pyx_v_thread_lock;
        __Pyx_INCREF(__pyx_t_2);
        __pyx_t_6 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
          __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_release, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 403, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __Pyx_XGIVEREF(__pyx_t_16);
      __Pyx_XGIVEREF(__pyx_t_17);
      __Pyx_XGIVEREF(__pyx_t_18);
      __Pyx_ExceptionReset(__pyx_t_16, __pyx_t_17, __pyx_t_18);
      __Pyx_XGIVEREF(__pyx_t_13);
      __Pyx_XGIVEREF(__pyx_t_14);
      __Pyx_XGIVEREF(__pyx_t_15);
      __Pyx_ErrRestore(__pyx_t_13, __pyx_t_14, __pyx_t_15);
      __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0;
      __pyx_lineno = __pyx_t_10; __pyx_clineno = __pyx_t_11; __pyx_filename = __pyx_t_12;
      goto __pyx_L1_error;
      __pyx_L7_error:;
      __Pyx_XGIVEREF(__pyx_t_16);
      __Pyx_XGIVEREF(__pyx_t_17);
      __Pyx_XGIVEREF(__pyx_t_18);
      __Pyx_ExceptionReset(__pyx_t_16, __pyx_t_17, __pyx_t_18);
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
      __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
      __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0;
      goto __pyx_L1_error;
    }
    __pyx_L5:;
  }

  /* "src/gevent/_semaphore.py":404
 *         finally:
 *             thread_lock.release()
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def __acquire_using_other_hub(self, owning_hub, timeout):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_result); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "src/gevent/_semaphore.py":398
 *             watcher.close()
 * 
 *     def __acquire_from_other_thread_cb(self, results, blocking, timeout, thread_lock):             # <<<<<<<<<<<<<<
 *         try:
 *             result = self.acquire(blocking, timeout)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("gevent._gevent_c_semaphore.Semaphore._Semaphore__acquire_from_other_thread_cb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_21_Semaphore__acquire_from_other_thread_cb(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_19_gevent_c_semaphore_9Semaphore_20_Semaphore__acquire_from_other_thread_cb, "Semaphore.__acquire_from_other_thread_cb(self, list results, bool blocking, timeout, thread_lock)");
static PyMethodDef __pyx_mdef_6gevent_19_gevent_c_semaphore_9Semaphore_21_Semaphore__acquire_from_other_thread_cb = {"_Semaphore__acquire_from_other_thread_cb", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_21_Semaphore__acquire_from_other_thread_cb, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6gevent_19_gevent_c_semaphore_9Semaphore_20_Semaphore__acquire_from_other_thread_cb};
static PyObject *__pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_21_Semaphore__acquire_from_other_thread_cb(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_results = 0;
  int __pyx_v_blocking;
  PyObject *__pyx_v_timeout = 0;
  PyObject *__pyx_v_thread_lock = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_Semaphore__acquire_from_other_thread_cb (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_results,&__pyx_mstate_global->__pyx_n_u_blocking,&__pyx_mstate_global->__pyx_n_u_timeout,&__pyx_mstate_global->__pyx_n_u_thread_lock,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 398, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 398, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 398, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 398, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 398, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_Semaphore__acquire_from_other_thread_cb", 0) < (0)) __PYX_ERR(0, 398, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 4; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_Semaphore__acquire_from_other_thread_cb", 1, 4, 4, i); __PYX_ERR(0, 398, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 4)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 398, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 398, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 398, __pyx_L3_error)
      values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 398, __pyx_L3_error)
    }
    __pyx_v_results = ((PyObject*)values[0]);
    __pyx_v_blocking = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_blocking == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 398, __pyx_L3_error)
    __pyx_v_timeout = values[2];
    __pyx_v_thread_lock = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_Semaphore__acquire_from_other_thread_cb", 1, 4, 4, __pyx_nargs); __PYX_ERR(0, 398, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("gevent._gevent_c_semaphore.Semaphore._Semaphore__acquire_from_other_thread_cb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_results), (&PyList_Type), 1, "results", 1))) __PYX_ERR(0, 398, __pyx_L1_error)
  __pyx_r = __pyx_pf_6gevent_19_gevent_c_semaphore_9Semaphore_20_Semaphore__acquire_from_other_thread_cb(((struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self), __pyx_v_results, __pyx_v_blocking, __pyx_v_timeout, __pyx_v_thread_lock);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_19_gevent_c_semaphore_9Semaphore_20_Semaphore__acquire_from_other_thread_cb(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, PyObject *__pyx_v_results, int __pyx_v_blocking, PyObject *__pyx_v_timeout, PyObject *__pyx_v_thread_lock) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_Semaphore__acquire_from_other_thread_cb", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore__Semaphore__acquire_from_other_thread_cb(__pyx_v_self, __pyx_v_results, __pyx_v_blocking, __pyx_v_timeout, __pyx_v_thread_lock, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 398, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_c_semaphore.Semaphore._Semaphore__acquire_from_other_thread_cb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/_semaphore.py":406
 *         return result
 * 
 *     def __acquire_using_other_hub(self, owning_hub, timeout):             # <<<<<<<<<<<<<<
 *         assert owning_hub is not get_hub_if_exists()
 *         thread_lock = self._allocate_lock()
*/

static PyObject *__pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore__Semaphore__acquire_using_other_hub(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *__pyx_v_owning_hub, PyObject *__pyx_v_timeout) {
  PyObject *__pyx_v_thread_lock = NULL;
  PyObject *__pyx_v_results = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_Semaphore__acquire_using_other_hub", 0);

  /* "src/gevent/_semaphore.py":407
 * 
 *     def __acquire_using_other_hub(self, owning_hub, timeout):
 *         assert owning_hub is not get_hub_if_exists()             # <<<<<<<<<<<<<<
 *         thread_lock = self._allocate_lock()
 *         thread_lock.acquire()
*/
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(__pyx_assertions_enabled())) {
    __pyx_t_1 = ((PyObject *)__pyx_f_6gevent_19_gevent_c_hub_local_get_hub_if_exists(0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 407, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = (__pyx_v_owning_hub != ((struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *)__pyx_t_1));
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) {
      __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_AssertionError))), 0, 0, 0);
      __PYX_ERR(0, 407, __pyx_L1_error)
    }
  }
  #else
  if ((1)); else __PYX_ERR(0, 407, __pyx_L1_error)
  #endif

  /* "src/gevent/_semaphore.py":408
 *     def __acquire_using_other_hub(self, owning_hub, timeout):
 *         assert owning_hub is not get_hub_if_exists()
 *         thread_lock = self._allocate_lock()             # <<<<<<<<<<<<<<
 *         thread_lock.acquire()
 *         results = []
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._allocate_lock(((struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_thread_lock = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "src/gevent/_semaphore.py":409
 *         assert owning_hub is not get_hub_if_exists()
 *         thread_lock = self._allocate_lock()
 *         thread_lock.acquire()             # <<<<<<<<<<<<<<
 *         results = []
 * 
*/
  __pyx_t_3 = __pyx_v_thread_lock;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_acquire, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 409, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "src/gevent/_semaphore.py":410
 *         thread_lock = self._allocate_lock()
 *         thread_lock.acquire()
 *         results = []             # <<<<<<<<<<<<<<
 * 
 *         owning_hub.loop.run_callback_threadsafe(
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 410, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_results = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "src/gevent/_semaphore.py":412
 *         results = []
 * 
 *         owning_hub.loop.run_callback_threadsafe(             # <<<<<<<<<<<<<<
 *             spawn_raw,
 *             self.__acquire_from_other_thread_cb,
*/
  __pyx_t_3 = __pyx_v_owning_hub->loop;
  __Pyx_INCREF(__pyx_t_3);

  /* "src/gevent/_semaphore.py":414
 *         owning_hub.loop.run_callback_threadsafe(
 *             spawn_raw,
 *             self.__acquire_from_other_thread_cb,             # <<<<<<<<<<<<<<
 *             results,
 *             1,       # blocking,
*/
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_Semaphore__acquire_from_other_t); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 414, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);

  /* "src/gevent/_semaphore.py":418
 *             1,       # blocking,
 *             timeout, # timeout,
 *             thread_lock)             # <<<<<<<<<<<<<<
 * 
 *         # We MUST use a blocking acquire here, or at least be sure we keep going
*/
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[7] = {__pyx_t_3, __pyx_v_6gevent_19_gevent_c_semaphore_spawn_raw, __pyx_t_5, __pyx_v_results, __pyx_mstate_global->__pyx_int_1, __pyx_v_timeout, __pyx_v_thread_lock};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_run_callback_threadsafe, __pyx_callargs+__pyx_t_4, (7-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 412, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "src/gevent/_semaphore.py":423
 *         # until we acquire it. If we timed out waiting here,
 *         # just before the callback runs, then we would be out of sync.
 *         self.__spin_on_native_lock(thread_lock, None)             # <<<<<<<<<<<<<<
 *         return results[0]
 * 
*/
  ((struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self->__pyx_base.__pyx_vtab)->_Semaphore__spin_on_native_lock(__pyx_v_self, __pyx_v_thread_lock, Py_None); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 423, __pyx_L1_error)

  /* "src/gevent/_semaphore.py":424
 *         # just before the callback runs, then we would be out of sync.
 *         self.__spin_on_native_lock(thread_lock, None)
 *         return results[0]             # <<<<<<<<<<<<<<
 * 
 *     def __acquire_without_hubs(self, timeout):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_results, 0, long, 1, __Pyx_PyLong_From_long, 1, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "src/gevent/_semaphore.py":406
 *         return result
 * 
 *     def __acquire_using_other_hub(self, owning_hub, timeout):             # <<<<<<<<<<<<<<
 *         assert owning_hub is not get_hub_if_exists()
 *         thread_lock = self._allocate_lock()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("gevent._gevent_c_semaphore.Semaphore._Semaphore__acquire_using_other_hub", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_thread_lock);
  __Pyx_XDECREF(__pyx_v_results);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/_semaphore.py":426
 *         return results[0]
 * 
 *     def __acquire_without_hubs(self, timeout):             # <<<<<<<<<<<<<<
 *         thread_lock = self._allocate_lock()
 *         thread_lock.acquire()
*/

static int __pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore__Semaphore__acquire_without_hubs(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, PyObject *__pyx_v_timeout) {
  PyObject *__pyx_v_thread_lock = NULL;
  PyObject *__pyx_v_absolute_expiration = NULL;
  PyObject *__pyx_v_begin = NULL;
  struct __pyx_obj_6gevent_19_gevent_c_semaphore__LockReleaseLink *__pyx_v_link = NULL;
  int __pyx_v_got_native;
  PyObject *__pyx_v_now = NULL;
  PyObject *__pyx_v_duration = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  struct __pyx_opt_args_6gevent_19_gevent_c_semaphore_9Semaphore_acquire __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_Semaphore__acquire_without_hubs", 0);
  __Pyx_INCREF(__pyx_v_timeout);

  /* "src/gevent/_semaphore.py":427
 * 
 *     def __acquire_without_hubs(self, timeout):
 *         thread_lock = self._allocate_lock()             # <<<<<<<<<<<<<<
 *         thread_lock.acquire()
 *         absolute_expiration = 0
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._allocate_lock(((struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 427, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_thread_lock = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "src/gevent/_semaphore.py":428
 *     def __acquire_without_hubs(self, timeout):
 *         thread_lock = self._allocate_lock()
 *         thread_lock.acquire()             # <<<<<<<<<<<<<<
 *         absolute_expiration = 0
 *         begin = 0
*/
  __pyx_t_2 = __pyx_v_thread_lock;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_acquire, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 428, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "src/gevent/_semaphore.py":429
 *         thread_lock = self._allocate_lock()
 *         thread_lock.acquire()
 *         absolute_expiration = 0             # <<<<<<<<<<<<<<
 *         begin = 0
 *         if timeout:
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_int_0);
  __pyx_v_absolute_expiration = __pyx_mstate_global->__pyx_int_0;

  /* "src/gevent/_semaphore.py":430
 *         thread_lock.acquire()
 *         absolute_expiration = 0
 *         begin = 0             # <<<<<<<<<<<<<<
 *         if timeout:
 *             absolute_expiration = monotonic() + timeout
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_int_0);
  __pyx_v_begin = __pyx_mstate_global->__pyx_int_0;

  /* "src/gevent/_semaphore.py":431
 *         absolute_expiration = 0
 *         begin = 0
 *         if timeout:             # <<<<<<<<<<<<<<
 *             absolute_expiration = monotonic() + timeout
 * 
*/
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_timeout); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 431, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "src/gevent/_semaphore.py":432
 *         begin = 0
 *         if timeout:
 *             absolute_expiration = monotonic() + timeout             # <<<<<<<<<<<<<<
 * 
 *         # Cython won't compile a lambda here
*/
    __pyx_t_2 = NULL;
    __Pyx_INCREF(__pyx_v_6gevent_19_gevent_c_semaphore_monotonic);
    __pyx_t_5 = __pyx_v_6gevent_19_gevent_c_semaphore_monotonic; 
    __pyx_t_3 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_5);
      assert(__pyx_t_2);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
      __pyx_t_3 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 432, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_t_5 = PyNumber_Add(__pyx_t_1, __pyx_v_timeout); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 432, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_absolute_expiration, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "src/gevent/_semaphore.py":431
 *         absolute_expiration = 0
 *         begin = 0
 *         if timeout:             # <<<<<<<<<<<<<<
 *             absolute_expiration = monotonic() + timeout
 * 
*/
  }

  /* "src/gevent/_semaphore.py":435
 * 
 *         # Cython won't compile a lambda here
 *         link = _LockReleaseLink(thread_lock)             # <<<<<<<<<<<<<<
 *         while 1:
 *             self.__add_link(link)
*/
  __pyx_t_1 = NULL;
  __pyx_t_3 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_thread_lock};
    __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6gevent_19_gevent_c_semaphore__LockReleaseLink, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 435, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_5);
  }
  __pyx_v_link = ((struct __pyx_obj_6gevent_19_gevent_c_semaphore__LockReleaseLink *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "src/gevent/_semaphore.py":436
 *         # Cython won't compile a lambda here
 *         link = _LockReleaseLink(thread_lock)
 *         while 1:             # <<<<<<<<<<<<<<
 *             self.__add_link(link)
 *             if absolute_expiration:
*/
  while (1) {

    /* "src/gevent/_semaphore.py":437
 *         link = _LockReleaseLink(thread_lock)
 *         while 1:
 *             self.__add_link(link)             # <<<<<<<<<<<<<<
 *             if absolute_expiration:
 *                 begin = monotonic()
*/
    __pyx_t_5 = ((struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self->__pyx_base.__pyx_vtab)->_Semaphore__add_link(__pyx_v_self, ((PyObject *)__pyx_v_link)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 437, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "src/gevent/_semaphore.py":438
 *         while 1:
 *             self.__add_link(link)
 *             if absolute_expiration:             # <<<<<<<<<<<<<<
 *                 begin = monotonic()
 * 
*/
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_absolute_expiration); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 438, __pyx_L1_error)
    if (__pyx_t_4) {

      /* "src/gevent/_semaphore.py":439
 *             self.__add_link(link)
 *             if absolute_expiration:
 *                 begin = monotonic()             # <<<<<<<<<<<<<<
 * 
 *             got_native = self.__spin_on_native_lock(thread_lock, timeout)
*/
      __pyx_t_1 = NULL;
      __Pyx_INCREF(__pyx_v_6gevent_19_gevent_c_semaphore_monotonic);
      __pyx_t_2 = __pyx_v_6gevent_19_gevent_c_semaphore_monotonic; 
      __pyx_t_3 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
        assert(__pyx_t_1);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
        __pyx_t_3 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
        __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 439, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
      }
      __Pyx_DECREF_SET(__pyx_v_begin, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "src/gevent/_semaphore.py":438
 *         while 1:
 *             self.__add_link(link)
 *             if absolute_expiration:             # <<<<<<<<<<<<<<
 *                 begin = monotonic()
 * 
*/
    }

    /* "src/gevent/_semaphore.py":441
 *                 begin = monotonic()
 * 
 *             got_native = self.__spin_on_native_lock(thread_lock, timeout)             # <<<<<<<<<<<<<<
 *             self._quiet_unlink_all(link)
 *             if got_native:
*/
    __pyx_t_4 = ((struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self->__pyx_base.__pyx_vtab)->_Semaphore__spin_on_native_lock(__pyx_v_self, __pyx_v_thread_lock, __pyx_v_timeout); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 441, __pyx_L1_error)
    __pyx_v_got_native = __pyx_t_4;

    /* "src/gevent/_semaphore.py":442
 * 
 *             got_native = self.__spin_on_native_lock(thread_lock, timeout)
 *             self._quiet_unlink_all(link)             # <<<<<<<<<<<<<<
 *             if got_native:
 *                 if self.acquire(0):
*/
    ((struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._quiet_unlink_all(((struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *)__pyx_v_self), ((PyObject *)__pyx_v_link)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 442, __pyx_L1_error)

    /* "src/gevent/_semaphore.py":443
 *             got_native = self.__spin_on_native_lock(thread_lock, timeout)
 *             self._quiet_unlink_all(link)
 *             if got_native:             # <<<<<<<<<<<<<<
 *                 if self.acquire(0):
 *                     return True
*/
    if (__pyx_v_got_native) {

      /* "src/gevent/_semaphore.py":444
 *             self._quiet_unlink_all(link)
 *             if got_native:
 *                 if self.acquire(0):             # <<<<<<<<<<<<<<
 *                     return True
 *             if absolute_expiration:
*/
      __pyx_t_6.__pyx_n = 1;
      __pyx_t_6.blocking = 0;
      __pyx_t_4 = ((struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self->__pyx_base.__pyx_vtab)->acquire(__pyx_v_self, 0, &__pyx_t_6); if (unlikely(__pyx_t_4 == ((int)-1000))) __PYX_ERR(0, 444, __pyx_L1_error)
      if (__pyx_t_4) {

        /* "src/gevent/_semaphore.py":445
 *             if got_native:
 *                 if self.acquire(0):
 *                     return True             # <<<<<<<<<<<<<<
 *             if absolute_expiration:
 *                 now = monotonic()
*/
        __pyx_r = 1;
        goto __pyx_L0;

        /* "src/gevent/_semaphore.py":444
 *             self._quiet_unlink_all(link)
 *             if got_native:
 *                 if self.acquire(0):             # <<<<<<<<<<<<<<
 *                     return True
 *             if absolute_expiration:
*/
      }

      /* "src/gevent/_semaphore.py":443
 *             got_native = self.__spin_on_native_lock(thread_lock, timeout)
 *             self._quiet_unlink_all(link)
 *             if got_native:             # <<<<<<<<<<<<<<
 *                 if self.acquire(0):
 *                     return True
*/
    }

    /* "src/gevent/_semaphore.py":446
 *                 if self.acquire(0):
 *                     return True
 *             if absolute_expiration:             # <<<<<<<<<<<<<<
 *                 now = monotonic()
 *                 if now >= absolute_expiration:
*/
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_absolute_expiration); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 446, __pyx_L1_error)
    if (__pyx_t_4) {

      /* "src/gevent/_semaphore.py":447
 *                     return True
 *             if absolute_expiration:
 *                 now = monotonic()             # <<<<<<<<<<<<<<
 *                 if now >= absolute_expiration:
 *                     return False
*/
      __pyx_t_2 = NULL;
      __Pyx_INCREF(__pyx_v_6gevent_19_gevent_c_semaphore_monotonic);
      __pyx_t_1 = __pyx_v_6gevent_19_gevent_c_semaphore_monotonic; 
      __pyx_t_3 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
        assert(__pyx_t_2);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_1, __pyx__function);
        __pyx_t_3 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
        __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_1, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 447, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
      }
      __Pyx_XDECREF_SET(__pyx_v_now, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "src/gevent/_semaphore.py":448
 *             if absolute_expiration:
 *                 now = monotonic()
 *                 if now >= absolute_expiration:             # <<<<<<<<<<<<<<
 *                     return False
 *                 duration = now - begin
*/
      __pyx_t_5 = PyObject_RichCompare(__pyx_v_now, __pyx_v_absolute_expiration, Py_GE); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 448, __pyx_L1_error)
      __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 448, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_4) {

        /* "src/gevent/_semaphore.py":449
 *                 now = monotonic()
 *                 if now >= absolute_expiration:
 *                     return False             # <<<<<<<<<<<<<<
 *                 duration = now - begin
 *                 timeout -= duration
*/
        __pyx_r = 0;
        goto __pyx_L0;

        /* "src/gevent/_semaphore.py":448
 *             if absolute_expiration:
 *                 now = monotonic()
 *                 if now >= absolute_expiration:             # <<<<<<<<<<<<<<
 *                     return False
 *                 duration = now - begin
*/
      }

      /* "src/gevent/_semaphore.py":450
 *                 if now >= absolute_expiration:
 *                     return False
 *                 duration = now - begin             # <<<<<<<<<<<<<<
 *                 timeout -= duration
 *                 if timeout <= 0:
*/
      __pyx_t_5 = PyNumber_Subtract(__pyx_v_now, __pyx_v_begin); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 450, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_XDECREF_SET(__pyx_v_duration, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "src/gevent/_semaphore.py":451
 *                     return False
 *                 duration = now - begin
 *                 timeout -= duration             # <<<<<<<<<<<<<<
 *                 if timeout <= 0:
 *                     return False
*/
      __pyx_t_5 = PyNumber_InPlaceSubtract(__pyx_v_timeout, __pyx_v_duration); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 451, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF_SET(__pyx_v_timeout, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "src/gevent/_semaphore.py":452
 *                 duration = now - begin
 *                 timeout -= duration
 *                 if timeout <= 0:             # <<<<<<<<<<<<<<
 *                     return False
 * 
*/
      __pyx_t_5 = PyObject_RichCompare(__pyx_v_timeout, __pyx_mstate_global->__pyx_int_0, Py_LE); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 452, __pyx_L1_error)
      __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 452, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_4) {

        /* "src/gevent/_semaphore.py":453
 *                 timeout -= duration
 *                 if timeout <= 0:
 *                     return False             # <<<<<<<<<<<<<<
 * 
 *     def __spin_on_native_lock(self, thread_lock, timeout):
*/
        __pyx_r = 0;
        goto __pyx_L0;

        /* "src/gevent/_semaphore.py":452
 *                 duration = now - begin
 *                 timeout -= duration
 *                 if timeout <= 0:             # <<<<<<<<<<<<<<
 *                     return False
 * 
*/
      }

      /* "src/gevent/_semaphore.py":446
 *                 if self.acquire(0):
 *                     return True
 *             if absolute_expiration:             # <<<<<<<<<<<<<<
 *                 now = monotonic()
 *                 if now >= absolute_expiration:
*/
    }
  }

  /* "src/gevent/_semaphore.py":426
 *         return results[0]
 * 
 *     def __acquire_without_hubs(self, timeout):             # <<<<<<<<<<<<<<
 *         thread_lock = self._allocate_lock()
 *         thread_lock.acquire()
*/

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("gevent._gevent_c_semaphore.Semaphore._Semaphore__acquire_without_hubs", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_thread_lock);
  __Pyx_XDECREF(__pyx_v_absolute_expiration);
  __Pyx_XDECREF(__pyx_v_begin);
  __Pyx_XDECREF((PyObject *)__pyx_v_link);
  __Pyx_XDECREF(__pyx_v_now);
  __Pyx_XDECREF(__pyx_v_duration);
  __Pyx_XDECREF(__pyx_v_timeout);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/_semaphore.py":455
 *                     return False
 * 
 *     def __spin_on_native_lock(self, thread_lock, timeout):             # <<<<<<<<<<<<<<
 *         self._drop_lock_for_switch_out()
 *         try:
*/

static int __pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore__Semaphore__spin_on_native_lock(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, PyObject *__pyx_v_thread_lock, PyObject *__pyx_v_timeout) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  char const *__pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_Semaphore__spin_on_native_lock", 0);

  /* "src/gevent/_semaphore.py":456
 * 
 *     def __spin_on_native_lock(self, thread_lock, timeout):
 *         self._drop_lock_for_switch_out()             # <<<<<<<<<<<<<<
 *         try:
 *             # Unlike Python 2, Python 3 thread locks
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._drop_lock_for_switch_out(((struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *)__pyx_v_self), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "src/gevent/_semaphore.py":457
 *     def __spin_on_native_lock(self, thread_lock, timeout):
 *         self._drop_lock_for_switch_out()
 *         try:             # <<<<<<<<<<<<<<
 *             # Unlike Python 2, Python 3 thread locks
 *             # can be interrupted when blocking, with or
*/
  /*try:*/ {

    /* "src/gevent/_semaphore.py":462
 *             # without a timeout. Python 2 didn't even
 *             # support a timeout for non -blocking.
 *             if timeout:             # <<<<<<<<<<<<<<
 *                 return thread_lock.acquire(True, timeout)
 * 
*/
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_timeout); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 462, __pyx_L4_error)
    if (__pyx_t_2) {

      /* "src/gevent/_semaphore.py":463
 *             # support a timeout for non -blocking.
 *             if timeout:
 *                 return thread_lock.acquire(True, timeout)             # <<<<<<<<<<<<<<
 * 
 *             return thread_lock.acquire()
*/
      __pyx_t_3 = __pyx_v_thread_lock;
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_3, Py_True, __pyx_v_timeout};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_acquire, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 463, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 463, __pyx_L4_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_r = __pyx_t_2;
      goto __pyx_L3_return;

      /* "src/gevent/_semaphore.py":462
 *             # without a timeout. Python 2 didn't even
 *             # support a timeout for non -blocking.
 *             if timeout:             # <<<<<<<<<<<<<<
 *                 return thread_lock.acquire(True, timeout)
 * 
*/
    }

    /* "src/gevent/_semaphore.py":465
 *                 return thread_lock.acquire(True, timeout)
 * 
 *             return thread_lock.acquire()             # <<<<<<<<<<<<<<
 *         finally:
 *             self._acquire_lock_for_switch_in()
*/
    __pyx_t_3 = __pyx_v_thread_lock;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_acquire, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 465, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 465, __pyx_L4_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_2;
    goto __pyx_L3_return;
  }

  /* "src/gevent/_semaphore.py":467
 *             return thread_lock.acquire()
 *         finally:
 *             self._acquire_lock_for_switch_in()             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*finally:*/ {
    __pyx_L4_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_8 = 0; __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
       __Pyx_ExceptionSwap(&__pyx_t_11, &__pyx_t_12, &__pyx_t_13);
      if ( unlikely(__Pyx_GetException(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10) < 0)) __Pyx_ErrFetch(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_13);
      __pyx_t_5 = __pyx_lineno; __pyx_t_6 = __pyx_clineno; __pyx_t_7 = __pyx_filename;
      {
        __pyx_t_1 = ((struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._acquire_lock_for_switch_in(((struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *)__pyx_v_self), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 467, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_XGIVEREF(__pyx_t_12);
      __Pyx_XGIVEREF(__pyx_t_13);
      __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_ErrRestore(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      __pyx_t_8 = 0; __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0;
      __pyx_lineno = __pyx_t_5; __pyx_clineno = __pyx_t_6; __pyx_filename = __pyx_t_7;
      goto __pyx_L1_error;
      __pyx_L8_error:;
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_XGIVEREF(__pyx_t_12);
      __Pyx_XGIVEREF(__pyx_t_13);
      __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0;
      goto __pyx_L1_error;
    }
    __pyx_L3_return: {
      __pyx_t_2 = __pyx_r;
      __pyx_t_1 = ((struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._acquire_lock_for_switch_in(((struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *)__pyx_v_self), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 467, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_r = __pyx_t_2;
      goto __pyx_L0;
    }
  }

  /* "src/gevent/_semaphore.py":455
 *                     return False
 * 
 *     def __spin_on_native_lock(self, thread_lock, timeout):             # <<<<<<<<<<<<<<
 *         self._drop_lock_for_switch_out()
 *         try:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("gevent._gevent_c_semaphore.Semaphore._Semaphore__spin_on_native_lock", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/_gevent_c_semaphore.pxd":23
 * 
 * cdef class Semaphore(AbstractLinkable):
 *     cdef public int counter             # <<<<<<<<<<<<<<
 *     # On Python 3, thread.get_ident() returns a ``unsigned long``; on
 *     # Python 2, it's a plain ``long``. We can conditionally change
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_7counter_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_7counter_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_19_gevent_c_semaphore_9Semaphore_7counter___get__(((struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_19_gevent_c_semaphore_9Semaphore_7counter___get__(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyLong_From_int(__pyx_v_self->counter); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 23, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_c_semaphore.Semaphore.counter.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_7counter_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_7counter_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_19_gevent_c_semaphore_9Semaphore_7counter_2__set__(((struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6gevent_19_gevent_c_semaphore_9Semaphore_7counter_2__set__(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __pyx_t_1 = __Pyx_PyLong_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(3, 23, __pyx_L1_error)
  __pyx_v_self->counter = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("gevent._gevent_c_semaphore.Semaphore.counter.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  return __pyx_r;
}

/* "src/gevent/_semaphore.py":490
 *     _OVER_RELEASE_ERROR = ValueError
 * 
 *     def __init__(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         Semaphore.__init__(self, *args, **kwargs)
 *         self._initial_value = self.counter
*/

/* Python wrapper */
static int __pyx_pw_6gevent_19_gevent_c_semaphore_16BoundedSemaphore_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6gevent_19_gevent_c_semaphore_16BoundedSemaphore_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_v_kwargs = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return -1;
  if (__pyx_kwds_len > 0) {
    if (unlikely(__Pyx_CheckKeywordStrings("__init__", __pyx_kwds) == -1)) return -1;
    __pyx_v_kwargs = __Pyx_KwargsAsDict_VARARGS(__pyx_kwds, __pyx_kwvalues);
    if (unlikely(!__pyx_v_kwargs)) return -1;
    __Pyx_GOTREF(__pyx_v_kwargs);
  } else {
    __pyx_v_kwargs = PyDict_New();
    if (unlikely(!__pyx_v_kwargs)) return -1;
    __Pyx_GOTREF(__pyx_v_kwargs);
  }
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6gevent_19_gevent_c_semaphore_16BoundedSemaphore___init__(((struct __pyx_obj_6gevent_19_gevent_c_semaphore_BoundedSemaphore *)__pyx_v_self), __pyx_v_args, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_DECREF(__pyx_v_kwargs);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6gevent_19_gevent_c_semaphore_16BoundedSemaphore___init__(struct __pyx_obj_6gevent_19_gevent_c_semaphore_BoundedSemaphore *__pyx_v_self, PyObject *__pyx_v_args, PyObject *__pyx_v_kwargs) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "src/gevent/_semaphore.py":491
 * 
 *     def __init__(self, *args, **kwargs):
 *         Semaphore.__init__(self, *args, **kwargs)             # <<<<<<<<<<<<<<
 *         self._initial_value = self.counter
 * 
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_mstate_global->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore), __pyx_mstate_global->__pyx_n_u_init); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_self)) != (0)) __PYX_ERR(0, 491, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_2, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyDict_Copy(__pyx_v_kwargs); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/_semaphore.py":492
 *     def __init__(self, *args, **kwargs):
 *         Semaphore.__init__(self, *args, **kwargs)
 *         self._initial_value = self.counter             # <<<<<<<<<<<<<<
 * 
 *     def release(self):
*/
  __pyx_t_5 = __pyx_v_self->__pyx_base.counter;
  __pyx_v_self->_initial_value = __pyx_t_5;

  /* "src/gevent/_semaphore.py":490
 *     _OVER_RELEASE_ERROR = ValueError
 * 
 *     def __init__(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         Semaphore.__init__(self, *args, **kwargs)
 *         self._initial_value = self.counter
*/

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("gevent._gevent_c_semaphore.BoundedSemaphore.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/_semaphore.py":494
 *         self._initial_value = self.counter
 * 
 *     def release(self):             # <<<<<<<<<<<<<<
 *         """
 *         Like :meth:`Semaphore.release`, but raises :class:`ValueError`
*/

static PyObject *__pyx_pw_6gevent_19_gevent_c_semaphore_16BoundedSemaphore_3release(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_6gevent_19_gevent_c_semaphore_16BoundedSemaphore_release(struct __pyx_obj_6gevent_19_gevent_c_semaphore_BoundedSemaphore *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_v_counter;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("release", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (
  #if !CYTHON_USE_TYPE_SLOTS
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_6gevent_19_gevent_c_semaphore_BoundedSemaphore &&
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
  #else
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
  #endif
  ) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_release); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 494, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_6gevent_19_gevent_c_semaphore_16BoundedSemaphore_3release)) {
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 494, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_t_6 = __Pyx_PyLong_As_int(__pyx_t_2); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 494, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_6;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "src/gevent/_semaphore.py":499
 *         if the semaphore is being over-released.
 *         """
 *         if self.counter >= self._initial_value:             # <<<<<<<<<<<<<<
 *             raise self._OVER_RELEASE_ERROR("Semaphore released too many times")
 *         counter = Semaphore.release(self)
*/
  __pyx_t_7 = (__pyx_v_self->__pyx_base.counter >= __pyx_v_self->_initial_value);
  if (unlikely(__pyx_t_7)) {

    /* "src/gevent/_semaphore.py":500
 *         """
 *         if self.counter >= self._initial_value:
 *             raise self._OVER_RELEASE_ERROR("Semaphore released too many times")             # <<<<<<<<<<<<<<
 *         counter = Semaphore.release(self)
 *         # When we are absolutely certain that no one holds this semaphore,
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_self);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_Semaphore_released_too_many_time};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_OVER_RELEASE_ERROR, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 500, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 500, __pyx_L1_error)

    /* "src/gevent/_semaphore.py":499
 *         if the semaphore is being over-released.
 *         """
 *         if self.counter >= self._initial_value:             # <<<<<<<<<<<<<<
 *             raise self._OVER_RELEASE_ERROR("Semaphore released too many times")
 *         counter = Semaphore.release(self)
*/
  }

  /* "src/gevent/_semaphore.py":501
 *         if self.counter >= self._initial_value:
 *             raise self._OVER_RELEASE_ERROR("Semaphore released too many times")
 *         counter = Semaphore.release(self)             # <<<<<<<<<<<<<<
 *         # When we are absolutely certain that no one holds this semaphore,
 *         # release our hub and go back to floating. This assists in cross-thread
*/
  __pyx_t_6 = __pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore_release(((struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *)__pyx_v_self), 1); if (unlikely(__pyx_t_6 == ((int)-1000))) __PYX_ERR(0, 501, __pyx_L1_error)
  __pyx_v_counter = __pyx_t_6;

  /* "src/gevent/_semaphore.py":505
 *         # release our hub and go back to floating. This assists in cross-thread
 *         # uses.
 *         if counter == self._initial_value:             # <<<<<<<<<<<<<<
 *             self.hub = None # pylint:disable=attribute-defined-outside-init
 *         return counter
*/
  __pyx_t_7 = (__pyx_v_counter == __pyx_v_self->_initial_value);
  if (__pyx_t_7) {

    /* "src/gevent/_semaphore.py":506
 *         # uses.
 *         if counter == self._initial_value:
 *             self.hub = None # pylint:disable=attribute-defined-outside-init             # <<<<<<<<<<<<<<
 *         return counter
 * 
*/
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->__pyx_base.__pyx_base.hub);
    __Pyx_DECREF((PyObject *)__pyx_v_self->__pyx_base.__pyx_base.hub);
    __pyx_v_self->__pyx_base.__pyx_base.hub = ((struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *)Py_None);

    /* "src/gevent/_semaphore.py":505
 *         # release our hub and go back to floating. This assists in cross-thread
 *         # uses.
 *         if counter == self._initial_value:             # <<<<<<<<<<<<<<
 *             self.hub = None # pylint:disable=attribute-defined-outside-init
 *         return counter
*/
  }

  /* "src/gevent/_semaphore.py":507
 *         if counter == self._initial_value:
 *             self.hub = None # pylint:disable=attribute-defined-outside-init
 *         return counter             # <<<<<<<<<<<<<<
 * 
 *     def _at_fork_reinit(self):
*/
  __pyx_r = __pyx_v_counter;
  goto __pyx_L0;

  /* "src/gevent/_semaphore.py":494
 *         self._initial_value = self.counter
 * 
 *     def release(self):             # <<<<<<<<<<<<<<
 *         """
 *         Like :meth:`Semaphore.release`, but raises :class:`ValueError`
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("gevent._gevent_c_semaphore.BoundedSemaphore.release", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1000;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_19_gevent_c_semaphore_16BoundedSemaphore_3release(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_19_gevent_c_semaphore_16BoundedSemaphore_2release, "BoundedSemaphore.release(self) -> int\n\nLike :meth:`Semaphore.release`, but raises :class:`ValueError`\nif the semaphore is being over-released.");
static PyMethodDef __pyx_mdef_6gevent_19_gevent_c_semaphore_16BoundedSemaphore_3release = {"release", (PyCFunction)__pyx_pw_6gevent_19_gevent_c_semaphore_16BoundedSemaphore_3release, METH_NOARGS, __pyx_doc_6gevent_19_gevent_c_semaphore_16BoundedSemaphore_2release};
static PyObject *__pyx_pw_6gevent_19_gevent_c_semaphore_16BoundedSemaphore_3release(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("release (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_19_gevent_c_semaphore_16BoundedSemaphore_2release(((struct __pyx_obj_6gevent_19_gevent_c_semaphore_BoundedSemaphore *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_19_gevent_c_semaphore_16BoundedSemaphore_2release(struct __pyx_obj_6gevent_19_gevent_c_semaphore_BoundedSemaphore *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("release", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6gevent_19_gevent_c_semaphore_16BoundedSemaphore_release(__pyx_v_self, 1); if (unlikely(__pyx_t_1 == ((int)-1000))) __PYX_ERR(0, 494, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyLong_From_int(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 494, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("gevent._gevent_c_semaphore.BoundedSemaphore.release", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/_semaphore.py":509
 *         return counter
 * 
 *     def _at_fork_reinit(self):             # <<<<<<<<<<<<<<
 *         super(BoundedSemaphore, self)._at_fork_reinit()
 *         self.counter = self._initial_value
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_19_gevent_c_semaphore_16BoundedSemaphore_5_at_fork_reinit(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_19_gevent_c_semaphore_16BoundedSemaphore_4_at_fork_reinit, "BoundedSemaphore._at_fork_reinit(self)");
static PyMethodDef __pyx_mdef_6gevent_19_gevent_c_semaphore_16BoundedSemaphore_5_at_fork_reinit = {"_at_fork_reinit", (PyCFunction)__pyx_pw_6gevent_19_gevent_c_semaphore_16BoundedSemaphore_5_at_fork_reinit, METH_NOARGS, __pyx_doc_6gevent_19_gevent_c_semaphore_16BoundedSemaphore_4_at_fork_reinit};
static PyObject *__pyx_pw_6gevent_19_gevent_c_semaphore_16BoundedSemaphore_5_at_fork_reinit(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_at_fork_reinit (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_19_gevent_c_semaphore_16BoundedSemaphore_4_at_fork_reinit(((struct __pyx_obj_6gevent_19_gevent_c_semaphore_BoundedSemaphore *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_19_gevent_c_semaphore_16BoundedSemaphore_4_at_fork_reinit(struct __pyx_obj_6gevent_19_gevent_c_semaphore_BoundedSemaphore *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_at_fork_reinit", 0);

  /* "src/gevent/_semaphore.py":510
 * 
 *     def _at_fork_reinit(self):
 *         super(BoundedSemaphore, self)._at_fork_reinit()             # <<<<<<<<<<<<<<
 *         self.counter = self._initial_value
 * 
*/
  __pyx_t_4 = NULL;
  __pyx_t_5 = 1;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, ((PyObject *)__pyx_mstate_global->__pyx_ptype_6gevent_19_gevent_c_semaphore_BoundedSemaphore), ((PyObject *)__pyx_v_self)};
    __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_super, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 510, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_t_2 = __pyx_t_3;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_at_fork_reinit, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 510, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "src/gevent/_semaphore.py":511
 *     def _at_fork_reinit(self):
 *         super(BoundedSemaphore, self)._at_fork_reinit()
 *         self.counter = self._initial_value             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_6 = __pyx_v_self->_initial_value;
  __pyx_v_self->__pyx_base.counter = __pyx_t_6;

  /* "src/gevent/_semaphore.py":509
 *         return counter
 * 
 *     def _at_fork_reinit(self):             # <<<<<<<<<<<<<<
 *         super(BoundedSemaphore, self)._at_fork_reinit()
 *         self.counter = self._initial_value
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("gevent._gevent_c_semaphore.BoundedSemaphore._at_fork_reinit", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/_gevent_c_semaphore.pxd":68
 * 
 * cdef class BoundedSemaphore(Semaphore):
 *     cdef readonly int _initial_value             # <<<<<<<<<<<<<<
 * 
 *     cpdef int release(self) except -1000
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_19_gevent_c_semaphore_16BoundedSemaphore_14_initial_value_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6gevent_19_gevent_c_semaphore_16BoundedSemaphore_14_initial_value_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_19_gevent_c_semaphore_16BoundedSemaphore_14_initial_value___get__(((struct __pyx_obj_6gevent_19_gevent_c_semaphore_BoundedSemaphore *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_19_gevent_c_semaphore_16BoundedSemaphore_14_initial_value___get__(struct __pyx_obj_6gevent_19_gevent_c_semaphore_BoundedSemaphore *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyLong_From_int(__pyx_v_self->_initial_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 68, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_c_semaphore.BoundedSemaphore._initial_value.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
/* #### Code section: module_exttypes ### */

static PyObject *__pyx_tp_new_6gevent_19_gevent_c_semaphore__LockReleaseLink(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_6gevent_19_gevent_c_semaphore__LockReleaseLink *p;
  PyObject *o;
  o = __Pyx_AllocateExtensionType(t, 0);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6gevent_19_gevent_c_semaphore__LockReleaseLink *)o);
  p->lock = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6gevent_19_gevent_c_semaphore__LockReleaseLink(PyObject *o) {
  struct __pyx_obj_6gevent_19_gevent_c_semaphore__LockReleaseLink *p = (struct __pyx_obj_6gevent_19_gevent_c_semaphore__LockReleaseLink *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6gevent_19_gevent_c_semaphore__LockReleaseLink) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->lock);
  PyTypeObject *tp = Py_TYPE(o);
  #if CYTHON_USE_TYPE_SLOTS
  (*tp->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  Py_DECREF(tp);
  #endif
}

static int __pyx_tp_traverse_6gevent_19_gevent_c_semaphore__LockReleaseLink(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6gevent_19_gevent_c_semaphore__LockReleaseLink *p = (struct __pyx_obj_6gevent_19_gevent_c_semaphore__LockReleaseLink *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->lock) {
    e = (*v)(p->lock, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6gevent_19_gevent_c_semaphore__LockReleaseLink(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6gevent_19_gevent_c_semaphore__LockReleaseLink *p = (struct __pyx_obj_6gevent_19_gevent_c_semaphore__LockReleaseLink *)o;
  tmp = ((PyObject*)p->lock);
  p->lock = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_6gevent_19_gevent_c_semaphore__LockReleaseLink[] = {
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6gevent_19_gevent_c_semaphore__LockReleaseLink_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6gevent_19_gevent_c_semaphore__LockReleaseLink},
  {Py_tp_call, (void *)__pyx_pw_6gevent_19_gevent_c_semaphore_16_LockReleaseLink_3__call__},
  {Py_tp_doc, (void *)PyDoc_STR("_LockReleaseLink(lock)")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6gevent_19_gevent_c_semaphore__LockReleaseLink},
  {Py_tp_clear, (void *)__pyx_tp_clear_6gevent_19_gevent_c_semaphore__LockReleaseLink},
  {Py_tp_methods, (void *)__pyx_methods_6gevent_19_gevent_c_semaphore__LockReleaseLink},
  {Py_tp_init, (void *)__pyx_pw_6gevent_19_gevent_c_semaphore_16_LockReleaseLink_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6gevent_19_gevent_c_semaphore__LockReleaseLink},
  {0, 0},
};
static PyType_Spec __pyx_type_6gevent_19_gevent_c_semaphore__LockReleaseLink_spec = {
  "gevent._gevent_c_semaphore._LockReleaseLink",
  sizeof(struct __pyx_obj_6gevent_19_gevent_c_semaphore__LockReleaseLink),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6gevent_19_gevent_c_semaphore__LockReleaseLink_slots,
};
#else

static PyTypeObject __pyx_type_6gevent_19_gevent_c_semaphore__LockReleaseLink = {
  PyVarObject_HEAD_INIT(0, 0)
  "gevent._gevent_c_semaphore.""_LockReleaseLink", /*tp_name*/
  sizeof(struct __pyx_obj_6gevent_19_gevent_c_semaphore__LockReleaseLink), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6gevent_19_gevent_c_semaphore__LockReleaseLink, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  __pyx_pw_6gevent_19_gevent_c_semaphore_16_LockReleaseLink_3__call__, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("_LockReleaseLink(lock)"), /*tp_doc*/
  __pyx_tp_traverse_6gevent_19_gevent_c_semaphore__LockReleaseLink, /*tp_traverse*/
  __pyx_tp_clear_6gevent_19_gevent_c_semaphore__LockReleaseLink, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6gevent_19_gevent_c_semaphore__LockReleaseLink, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6gevent_19_gevent_c_semaphore_16_LockReleaseLink_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6gevent_19_gevent_c_semaphore__LockReleaseLink, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_Semaphore __pyx_vtable_6gevent_19_gevent_c_semaphore_Semaphore;

static PyObject *__pyx_tp_new_6gevent_19_gevent_c_semaphore_Semaphore(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *p;
  PyObject *o = __Pyx_PyType_GetSlot(__pyx_mstate_global->__pyx_ptype_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable, tp_new, newfunc)(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable*)__pyx_vtabptr_6gevent_19_gevent_c_semaphore_Semaphore;
  p->_multithreaded = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6gevent_19_gevent_c_semaphore_Semaphore(PyObject *o) {
  struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *p = (struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6gevent_19_gevent_c_semaphore_Semaphore) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->_multithreaded);
  if (PyType_IS_GC(__pyx_mstate_global->__pyx_ptype_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable)) PyObject_GC_Track(o);
  #if !CYTHON_USE_MODULE_STATE
  if (likely(__pyx_mstate_global->__pyx_ptype_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable)) __Pyx_PyType_GetSlot(__pyx_mstate_global->__pyx_ptype_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable, tp_dealloc, destructor)(o); else
  #endif
  __Pyx_call_next_tp_dealloc(o, __pyx_tp_dealloc_6gevent_19_gevent_c_semaphore_Semaphore);
}

static int __pyx_tp_traverse_6gevent_19_gevent_c_semaphore_Semaphore(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *p = (struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *)o;
  #if !CYTHON_USE_MODULE_STATE
  e = 0;
  if (likely(__pyx_mstate_global->__pyx_ptype_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable)) {
    traverseproc traverse = __Pyx_PyType_GetSlot(__pyx_mstate_global->__pyx_ptype_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable, tp_traverse, traverseproc);
    if (traverse) { e = traverse(o, v, a); }
  } else
  #endif
  { e = __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_6gevent_19_gevent_c_semaphore_Semaphore); }
  if (e) return e;
  {
    e = __Pyx_call_type_traverse(o, 0, v, a);
    if (e) return e;
  }
  if (p->_multithreaded) {
    e = (*v)(p->_multithreaded, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6gevent_19_gevent_c_semaphore_Semaphore(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *p = (struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *)o;
  #if !CYTHON_USE_MODULE_STATE
  if (likely(__pyx_mstate_global->__pyx_ptype_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable)) {
    inquiry clear = __Pyx_PyType_GetSlot(__pyx_mstate_global->__pyx_ptype_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable, tp_clear, inquiry);
    if (clear) clear(o);
  } else
  #endif
  { __Pyx_call_next_tp_clear(o, __pyx_tp_clear_6gevent_19_gevent_c_semaphore_Semaphore); }
  tmp = ((PyObject*)p->_multithreaded);
  p->_multithreaded = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6gevent_19_gevent_c_semaphore_9Semaphore_counter(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_7counter_1__get__(o);
}

static int __pyx_setprop_6gevent_19_gevent_c_semaphore_9Semaphore_counter(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_7counter_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyMethodDef __pyx_methods_6gevent_19_gevent_c_semaphore_Semaphore[] = {
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6gevent_19_gevent_c_semaphore_Semaphore[] = {
  {"counter", __pyx_getprop_6gevent_19_gevent_c_semaphore_9Semaphore_counter, __pyx_setprop_6gevent_19_gevent_c_semaphore_9Semaphore_counter, PyDoc_STR("counter: 'int'"), 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6gevent_19_gevent_c_semaphore_Semaphore_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6gevent_19_gevent_c_semaphore_Semaphore},
  {Py_tp_str, (void *)__pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_3__str__},
  {Py_tp_doc, (void *)PyDoc_STR("Semaphore(value=1, hub=None)\n\nSemaphore(value=1) -> Semaphore\n\n.. seealso:: :class:`BoundedSemaphore` for a safer version that prevents\n   some classes of bugs. If unsure, most users should opt for `BoundedSemaphore`.\n\nA semaphore manages a counter representing the number of `release`\ncalls minus the number of `acquire` calls, plus an initial value.\nThe `acquire` method blocks if necessary until it can return\nwithout making the counter negative. A semaphore does not track ownership\nby greenlets; any greenlet can call `release`, whether or not it has previously\ncalled `acquire`.\n\nIf not given, ``value`` defaults to 1.\n\nThe semaphore is a context manager and can be used in ``with`` statements.\n\nThis Semaphore's ``__exit__`` method does not call the trace function\non CPython, but does under PyPy.\n\n.. versionchanged:: 1.4.0\n    Document that the order in which waiters are awakened is not specified. It was not\n    specified previously, but due to CPython implementation quirks usually went in FIFO order.\n.. versionchanged:: 1.5a3\n   Waiting greenlets are now awakened in the order in which they waited.\n.. versionchanged:: 1.5a3\n   The low-level ``rawlink`` method (most users won't use this) now automatically\n   unlinks waiters before calling them.\n.. versionchanged:: 20.12.0\n   Improved support for multi-threaded usage. When multi-threaded usage is detected,\n   instances will no longer create the thread's hub if it's not present.\n\n.. versionchanged:: 24.2.1\n   Uses Python 3 native lock timeouts for cross-thread operations instead\n   of spinning.")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6gevent_19_gevent_c_semaphore_Semaphore},
  {Py_tp_clear, (void *)__pyx_tp_clear_6gevent_19_gevent_c_semaphore_Semaphore},
  {Py_tp_methods, (void *)__pyx_methods_6gevent_19_gevent_c_semaphore_Semaphore},
  {Py_tp_getset, (void *)__pyx_getsets_6gevent_19_gevent_c_semaphore_Semaphore},
  {Py_tp_init, (void *)__pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6gevent_19_gevent_c_semaphore_Semaphore},
  {0, 0},
};
static PyType_Spec __pyx_type_6gevent_19_gevent_c_semaphore_Semaphore_spec = {
  "gevent._gevent_c_semaphore.Semaphore",
  sizeof(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6gevent_19_gevent_c_semaphore_Semaphore_slots,
};
#else

static PyTypeObject __pyx_type_6gevent_19_gevent_c_semaphore_Semaphore = {
  PyVarObject_HEAD_INIT(0, 0)
  "gevent._gevent_c_semaphore.""Semaphore", /*tp_name*/
  sizeof(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6gevent_19_gevent_c_semaphore_Semaphore, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  __pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_3__str__, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("Semaphore(value=1, hub=None)\n\nSemaphore(value=1) -> Semaphore\n\n.. seealso:: :class:`BoundedSemaphore` for a safer version that prevents\n   some classes of bugs. If unsure, most users should opt for `BoundedSemaphore`.\n\nA semaphore manages a counter representing the number of `release`\ncalls minus the number of `acquire` calls, plus an initial value.\nThe `acquire` method blocks if necessary until it can return\nwithout making the counter negative. A semaphore does not track ownership\nby greenlets; any greenlet can call `release`, whether or not it has previously\ncalled `acquire`.\n\nIf not given, ``value`` defaults to 1.\n\nThe semaphore is a context manager and can be used in ``with`` statements.\n\nThis Semaphore's ``__exit__`` method does not call the trace function\non CPython, but does under PyPy.\n\n.. versionchanged:: 1.4.0\n    Document that the order in which waiters are awakened is not specified. It was not\n    specified previously, but due to CPython implementation quirks usually went in FIFO order.\n.. versionchanged:: 1.5a3\n   Waiting greenlets are now awakened in the order in which they waited.\n.. versionchanged:: 1.5a3\n   The low-level ``rawlink`` method (most users won't use this) now automatically\n   unlinks waiters before calling them.\n.. versionchanged:: 20.12.0\n   Improved support for multi-threaded usage. When multi-threaded usage is detected,\n   instances will no longer create the thread's hub if it's not present.\n\n.. versionchanged:: 24.2.1\n   Uses Python 3 native lock timeouts for cross-thread operations instead\n   of spinning."), /*tp_doc*/
  __pyx_tp_traverse_6gevent_19_gevent_c_semaphore_Semaphore, /*tp_traverse*/
  __pyx_tp_clear_6gevent_19_gevent_c_semaphore_Semaphore, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6gevent_19_gevent_c_semaphore_Semaphore, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6gevent_19_gevent_c_semaphore_Semaphore, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6gevent_19_gevent_c_semaphore_Semaphore, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6gevent_19_gevent_c_semaphore_BoundedSemaphore __pyx_vtable_6gevent_19_gevent_c_semaphore_BoundedSemaphore;

static PyObject *__pyx_tp_new_6gevent_19_gevent_c_semaphore_BoundedSemaphore(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6gevent_19_gevent_c_semaphore_BoundedSemaphore *p;
  PyObject *o = __pyx_tp_new_6gevent_19_gevent_c_semaphore_Semaphore(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6gevent_19_gevent_c_semaphore_BoundedSemaphore *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable*)__pyx_vtabptr_6gevent_19_gevent_c_semaphore_BoundedSemaphore;
  return o;
}

static PyObject *__pyx_getprop_6gevent_19_gevent_c_semaphore_16BoundedSemaphore__initial_value(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6gevent_19_gevent_c_semaphore_16BoundedSemaphore_14_initial_value_1__get__(o);
}

static PyMethodDef __pyx_methods_6gevent_19_gevent_c_semaphore_BoundedSemaphore[] = {
  {"_at_fork_reinit", (PyCFunction)__pyx_pw_6gevent_19_gevent_c_semaphore_16BoundedSemaphore_5_at_fork_reinit, METH_NOARGS, __pyx_doc_6gevent_19_gevent_c_semaphore_16BoundedSemaphore_4_at_fork_reinit},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6gevent_19_gevent_c_semaphore_BoundedSemaphore[] = {
  {"_initial_value", __pyx_getprop_6gevent_19_gevent_c_semaphore_16BoundedSemaphore__initial_value, 0, 0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6gevent_19_gevent_c_semaphore_BoundedSemaphore_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6gevent_19_gevent_c_semaphore_Semaphore},
  {Py_tp_doc, (void *)PyDoc_STR("BoundedSemaphore(*args, **kwargs)\n\nBoundedSemaphore(value=1) -> BoundedSemaphore\n\nA bounded semaphore checks to make sure its current value doesn't\nexceed its initial value. If it does, :class:`ValueError` is\nraised. In most situations semaphores are used to guard resources\nwith limited capacity. If the semaphore is released too many times\nit's a sign of a bug.\n\nIf not given, *value* defaults to 1.")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6gevent_19_gevent_c_semaphore_Semaphore},
  {Py_tp_clear, (void *)__pyx_tp_clear_6gevent_19_gevent_c_semaphore_Semaphore},
  {Py_tp_methods, (void *)__pyx_methods_6gevent_19_gevent_c_semaphore_BoundedSemaphore},
  {Py_tp_getset, (void *)__pyx_getsets_6gevent_19_gevent_c_semaphore_BoundedSemaphore},
  {Py_tp_init, (void *)__pyx_pw_6gevent_19_gevent_c_semaphore_16BoundedSemaphore_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6gevent_19_gevent_c_semaphore_BoundedSemaphore},
  {0, 0},
};
static PyType_Spec __pyx_type_6gevent_19_gevent_c_semaphore_BoundedSemaphore_spec = {
  "gevent._gevent_c_semaphore.BoundedSemaphore",
  sizeof(struct __pyx_obj_6gevent_19_gevent_c_semaphore_BoundedSemaphore),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6gevent_19_gevent_c_semaphore_BoundedSemaphore_slots,
};
#else

static PyTypeObject __pyx_type_6gevent_19_gevent_c_semaphore_BoundedSemaphore = {
  PyVarObject_HEAD_INIT(0, 0)
  "gevent._gevent_c_semaphore.""BoundedSemaphore", /*tp_name*/
  sizeof(struct __pyx_obj_6gevent_19_gevent_c_semaphore_BoundedSemaphore), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6gevent_19_gevent_c_semaphore_Semaphore, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6gevent_19_gevent_c_semaphore_9Semaphore_3__str__, /*tp_str*/
  #else
  0, /*tp_str*/
  #endif
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("BoundedSemaphore(*args, **kwargs)\n\nBoundedSemaphore(value=1) -> BoundedSemaphore\n\nA bounded semaphore checks to make sure its current value doesn't\nexceed its initial value. If it does, :class:`ValueError` is\nraised. In most situations semaphores are used to guard resources\nwith limited capacity. If the semaphore is released too many times\nit's a sign of a bug.\n\nIf not given, *value* defaults to 1."), /*tp_doc*/
  __pyx_tp_traverse_6gevent_19_gevent_c_semaphore_Semaphore, /*tp_traverse*/
  __pyx_tp_clear_6gevent_19_gevent_c_semaphore_Semaphore, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6gevent_19_gevent_c_semaphore_BoundedSemaphore, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6gevent_19_gevent_c_semaphore_BoundedSemaphore, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6gevent_19_gevent_c_semaphore_16BoundedSemaphore_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6gevent_19_gevent_c_semaphore_BoundedSemaphore, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};
/* #### Code section: initfunc_declarations ### */
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitConstants(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_CreateCodeObjects(__pyx_mstatetype *__pyx_mstate); /*proto*/
/* #### Code section: init_module ### */

static int __Pyx_modinit_global_init_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __pyx_v_6gevent_19_gevent_c_semaphore_InvalidThreadUseError = Py_None; Py_INCREF(Py_None);
  __pyx_v_6gevent_19_gevent_c_semaphore_LoopExit = Py_None; Py_INCREF(Py_None);
  __pyx_v_6gevent_19_gevent_c_semaphore_Timeout = Py_None; Py_INCREF(Py_None);
  __pyx_v_6gevent_19_gevent_c_semaphore__native_sleep = Py_None; Py_INCREF(Py_None);
  __pyx_v_6gevent_19_gevent_c_semaphore_monotonic = Py_None; Py_INCREF(Py_None);
  __pyx_v_6gevent_19_gevent_c_semaphore_spawn_raw = Py_None; Py_INCREF(Py_None);
  __pyx_v_6gevent_19_gevent_c_semaphore__UNSET = Py_None; Py_INCREF(Py_None);
  __pyx_v_6gevent_19_gevent_c_semaphore__MULTI = Py_None; Py_INCREF(Py_None);
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  {
    __pyx_t_1 = __Pyx_ApiExport_GetApiDict(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_export_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_PyObject_InvalidThreadUseError_L);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_export_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_export_name = __pyx_export_signature + 18;
    void *const __pyx_export_pointers[] = {(void *)&__pyx_v_6gevent_19_gevent_c_semaphore_InvalidThreadUseError, (void *)&__pyx_v_6gevent_19_gevent_c_semaphore_LoopExit, (void *)&__pyx_v_6gevent_19_gevent_c_semaphore_Timeout, (void *)&__pyx_v_6gevent_19_gevent_c_semaphore__MULTI, (void *)&__pyx_v_6gevent_19_gevent_c_semaphore__UNSET, (void *)&__pyx_v_6gevent_19_gevent_c_semaphore__native_sleep, (void *)&__pyx_v_6gevent_19_gevent_c_semaphore_monotonic, (void *)&__pyx_v_6gevent_19_gevent_c_semaphore_spawn_raw, (void *) NULL};
    void *const *__pyx_export_pointer = __pyx_export_pointers;
    const char *__pyx_export_current_signature = __pyx_export_signature;
    while (*__pyx_export_pointer) {
      if (__Pyx_ExportVoidPtr(__pyx_t_1, __pyx_export_name, *__pyx_export_pointer, __pyx_export_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_export_pointer;
      __pyx_export_name = strchr(__pyx_export_name, '\0') + 1;
      __pyx_export_signature = strchr(__pyx_export_signature, '\0') + 1;
      if (*__pyx_export_signature != '\0') __pyx_export_current_signature = __pyx_export_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_function_export_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_init_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore__LockReleaseLink = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6gevent_19_gevent_c_semaphore__LockReleaseLink_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore__LockReleaseLink)) __PYX_ERR(0, 34, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6gevent_19_gevent_c_semaphore__LockReleaseLink_spec, __pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore__LockReleaseLink) < (0)) __PYX_ERR(0, 34, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore__LockReleaseLink = &__pyx_type_6gevent_19_gevent_c_semaphore__LockReleaseLink;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore__LockReleaseLink) < (0)) __PYX_ERR(0, 34, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore__LockReleaseLink);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore__LockReleaseLink->tp_dictoffset && __pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore__LockReleaseLink->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore__LockReleaseLink->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_LockReleaseLink, (PyObject *) __pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore__LockReleaseLink) < (0)) __PYX_ERR(0, 34, __pyx_L1_error)
  __pyx_t_1 = PyImport_ImportModule("gevent._gevent_c_abstract_linkable"); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable = __Pyx_ImportType_3_2_4(__pyx_t_1, "gevent._gevent_c_abstract_linkable", "AbstractLinkable",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable),
  #else
  sizeof(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_vtabptr_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable = (struct __pyx_vtabstruct_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable); if (unlikely(!__pyx_vtabptr_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_vtabptr_6gevent_19_gevent_c_semaphore_Semaphore = &__pyx_vtable_6gevent_19_gevent_c_semaphore_Semaphore;
  __pyx_vtable_6gevent_19_gevent_c_semaphore_Semaphore.__pyx_base = *__pyx_vtabptr_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable;
  __pyx_vtable_6gevent_19_gevent_c_semaphore_Semaphore.__pyx_base.ready = (int (*)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *, int __pyx_skip_dispatch))__pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore_ready;
  __pyx_vtable_6gevent_19_gevent_c_semaphore_Semaphore.__pyx_base._handle_unswitched_notifications = (PyObject *(*)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *, PyObject *))__pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore__handle_unswitched_notifications;
  __pyx_vtable_6gevent_19_gevent_c_semaphore_Semaphore.__pyx_base._wait_return_value = (PyObject *(*)(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable *, int, int))__pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore__wait_return_value;
  __pyx_vtable_6gevent_19_gevent_c_semaphore_Semaphore.locked = (int (*)(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *, int __pyx_skip_dispatch))__pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore_locked;
  __pyx_vtable_6gevent_19_gevent_c_semaphore_Semaphore.release = (int (*)(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *, int __pyx_skip_dispatch))__pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore_release;
  __pyx_vtable_6gevent_19_gevent_c_semaphore_Semaphore._start_notify = (PyObject *(*)(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *, int __pyx_skip_dispatch))__pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore__start_notify;
  __pyx_vtable_6gevent_19_gevent_c_semaphore_Semaphore.wait = (int (*)(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *, int __pyx_skip_dispatch, struct __pyx_opt_args_6gevent_19_gevent_c_semaphore_9Semaphore_wait *__pyx_optional_args))__pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore_wait;
  __pyx_vtable_6gevent_19_gevent_c_semaphore_Semaphore.acquire = (int (*)(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *, int __pyx_skip_dispatch, struct __pyx_opt_args_6gevent_19_gevent_c_semaphore_9Semaphore_acquire *__pyx_optional_args))__pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore_acquire;
  __pyx_vtable_6gevent_19_gevent_c_semaphore_Semaphore.__pyx___enter__ = (PyObject *(*)(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *, int __pyx_skip_dispatch))__pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore___enter__;
  __pyx_vtable_6gevent_19_gevent_c_semaphore_Semaphore.__pyx___exit__ = (PyObject *(*)(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *, PyObject *, PyObject *, PyObject *, int __pyx_skip_dispatch))__pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore___exit__;
  __pyx_vtable_6gevent_19_gevent_c_semaphore_Semaphore._Semaphore__acquire_from_other_thread = (PyObject *(*)(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *, PyObject *, int, PyObject *))__pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore__Semaphore__acquire_from_other_thread;
  __pyx_vtable_6gevent_19_gevent_c_semaphore_Semaphore._Semaphore__acquire_from_other_thread_cb = (PyObject *(*)(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *, PyObject *, int, PyObject *, PyObject *, int __pyx_skip_dispatch))__pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore__Semaphore__acquire_from_other_thread_cb;
  __pyx_vtable_6gevent_19_gevent_c_semaphore_Semaphore._Semaphore__add_link = (PyObject *(*)(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *, PyObject *))__pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore__Semaphore__add_link;
  __pyx_vtable_6gevent_19_gevent_c_semaphore_Semaphore._Semaphore__acquire_using_two_hubs = (PyObject *(*)(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *, struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *, PyObject *, PyObject *))__pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore__Semaphore__acquire_using_two_hubs;
  __pyx_vtable_6gevent_19_gevent_c_semaphore_Semaphore._Semaphore__acquire_using_other_hub = (PyObject *(*)(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *, struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *, PyObject *))__pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore__Semaphore__acquire_using_other_hub;
  __pyx_vtable_6gevent_19_gevent_c_semaphore_Semaphore._Semaphore__acquire_without_hubs = (int (*)(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *, PyObject *))__pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore__Semaphore__acquire_without_hubs;
  __pyx_vtable_6gevent_19_gevent_c_semaphore_Semaphore._Semaphore__spin_on_native_lock = (int (*)(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *, PyObject *, PyObject *))__pyx_f_6gevent_19_gevent_c_semaphore_9Semaphore__Semaphore__spin_on_native_lock;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_2 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 48, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6gevent_19_gevent_c_semaphore_Semaphore_spec, __pyx_t_2);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore)) __PYX_ERR(0, 48, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6gevent_19_gevent_c_semaphore_Semaphore_spec, __pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore) < (0)) __PYX_ERR(0, 48, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore = &__pyx_type_6gevent_19_gevent_c_semaphore_Semaphore;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore->tp_base = __pyx_mstate_global->__pyx_ptype_6gevent_27_gevent_c_abstract_linkable_AbstractLinkable;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore) < (0)) __PYX_ERR(0, 48, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore->tp_dictoffset && __pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore, __pyx_vtabptr_6gevent_19_gevent_c_semaphore_Semaphore) < (0)) __PYX_ERR(0, 48, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore) < (0)) __PYX_ERR(0, 48, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_Semaphore, (PyObject *) __pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore) < (0)) __PYX_ERR(0, 48, __pyx_L1_error)
  #if CYTHON_USE_TYPE_SLOTS
  if (__pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore->tp_weaklistoffset == 0) __pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore->tp_weaklistoffset = offsetof(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore, __pyx_base.__weakref__);
  #endif
  __pyx_vtabptr_6gevent_19_gevent_c_semaphore_BoundedSemaphore = &__pyx_vtable_6gevent_19_gevent_c_semaphore_BoundedSemaphore;
  __pyx_vtable_6gevent_19_gevent_c_semaphore_BoundedSemaphore.__pyx_base = *__pyx_vtabptr_6gevent_19_gevent_c_semaphore_Semaphore;
  __pyx_vtable_6gevent_19_gevent_c_semaphore_BoundedSemaphore.__pyx_base.release = (int (*)(struct __pyx_obj_6gevent_19_gevent_c_semaphore_Semaphore *, int __pyx_skip_dispatch))__pyx_f_6gevent_19_gevent_c_semaphore_16BoundedSemaphore_release;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_2 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 470, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore_BoundedSemaphore = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6gevent_19_gevent_c_semaphore_BoundedSemaphore_spec, __pyx_t_2);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore_BoundedSemaphore)) __PYX_ERR(0, 470, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6gevent_19_gevent_c_semaphore_BoundedSemaphore_spec, __pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore_BoundedSemaphore) < (0)) __PYX_ERR(0, 470, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore_BoundedSemaphore = &__pyx_type_6gevent_19_gevent_c_semaphore_BoundedSemaphore;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_6gevent_19_gevent_c_semaphore_BoundedSemaphore->tp_base = __pyx_mstate_global->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore_BoundedSemaphore) < (0)) __PYX_ERR(0, 470, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore_BoundedSemaphore);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore_BoundedSemaphore->tp_dictoffset && __pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore_BoundedSemaphore->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore_BoundedSemaphore->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore_BoundedSemaphore, __pyx_vtabptr_6gevent_19_gevent_c_semaphore_BoundedSemaphore) < (0)) __PYX_ERR(0, 470, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore_BoundedSemaphore) < (0)) __PYX_ERR(0, 470, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_BoundedSemaphore, (PyObject *) __pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore_BoundedSemaphore) < (0)) __PYX_ERR(0, 470, __pyx_L1_error)
  #if CYTHON_USE_TYPE_SLOTS
  if (__pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore_BoundedSemaphore->tp_weaklistoffset == 0) __pyx_mstate->__pyx_ptype_6gevent_19_gevent_c_semaphore_BoundedSemaphore->tp_weaklistoffset = offsetof(struct __pyx_obj_6gevent_19_gevent_c_semaphore_BoundedSemaphore, __pyx_base.__pyx_base.__weakref__);
  #endif
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __pyx_t_1 = PyImport_ImportModule("greenlet"); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_greenlet = __Pyx_ImportType_3_2_4(__pyx_t_1, "greenlet", "greenlet",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyGreenlet),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(PyGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyGreenlet),
  #else
  sizeof(PyGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyGreenlet),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_greenlet) __PYX_ERR(1, 12, __pyx_L1_error)
  __pyx_t_2 = PyImport_ImportModule("gevent._gevent_c_greenlet_primitives"); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_mstate->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet = __Pyx_ImportType_3_2_4(__pyx_t_2, "gevent._gevent_c_greenlet_primitives", "TrackedRawGreenlet",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet),
  #else
  sizeof(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet) __PYX_ERR(1, 37, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop = __Pyx_ImportType_3_2_4(__pyx_t_2, "gevent._gevent_c_greenlet_primitives", "SwitchOutGreenletWithLoop",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop),
  #else
  sizeof(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop) __PYX_ERR(1, 40, __pyx_L1_error)
  __pyx_vtabptr_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop = (struct __pyx_vtabstruct_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop); if (unlikely(!__pyx_vtabptr_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop)) __PYX_ERR(1, 40, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyImport_ImportModule("greenlet"); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_mstate->__pyx_ptype_6gevent_27_gevent_c_abstract_linkable_greenlet = __Pyx_ImportType_3_2_4(__pyx_t_2, "greenlet", "greenlet",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyGreenlet),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(PyGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyGreenlet),
  #else
  sizeof(PyGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyGreenlet),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_27_gevent_c_abstract_linkable_greenlet) __PYX_ERR(2, 16, __pyx_L1_error)
  __pyx_t_1 = PyImport_ImportModule("gevent._gevent_c_abstract_linkable"); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 38, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_6gevent_27_gevent_c_abstract_linkable__FakeNotifier = __Pyx_ImportType_3_2_4(__pyx_t_1, "gevent._gevent_c_abstract_linkable", "_FakeNotifier",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable__FakeNotifier), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable__FakeNotifier),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable__FakeNotifier), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable__FakeNotifier),
  #else
  sizeof(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable__FakeNotifier), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_27_gevent_c_abstract_linkable__FakeNotifier),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_27_gevent_c_abstract_linkable__FakeNotifier) __PYX_ERR(2, 38, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_variable_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  {
    __pyx_t_1 = PyImport_ImportModule("gevent._gevent_c_greenlet_primitives"); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_import_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_PyObject_PyTypeObject_int_Blocki);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_import_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_import_name = __pyx_import_signature + 33;
    void **const __pyx_import_pointers[] = {(void **)&__pyx_vp_6gevent_29_gevent_c_greenlet_primitives_BlockingSwitchOutError, (void **)&__pyx_vp_6gevent_29_gevent_c_greenlet_primitives_get_objects, (void **)&__pyx_vp_6gevent_29_gevent_c_greenlet_primitives_wref, (void **)&__pyx_vp_6gevent_29_gevent_c_greenlet_primitives__buffer, (void **)&__pyx_vp_6gevent_29_gevent_c_greenlet_primitives__memoryview, (void **)&__pyx_vp_6gevent_29_gevent_c_greenlet_primitives__greenlet_imported, (void **) NULL};
    void **const *__pyx_import_pointer = __pyx_import_pointers;
    const char *__pyx_import_current_signature = __pyx_import_signature;
    while (*__pyx_import_pointer) {
      if (__Pyx_ImportVoidPtr_3_2_4(__pyx_t_1, __pyx_import_name, *__pyx_import_pointer, __pyx_import_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_import_pointer;
      __pyx_import_name = strchr(__pyx_import_name, '\0') + 1;
      __pyx_import_signature = strchr(__pyx_import_signature, '\0') + 1;
      if (*__pyx_import_signature != '\0') __pyx_import_current_signature = __pyx_import_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  {
    __pyx_t_1 = PyImport_ImportModule("gevent._gevent_c_hub_local"); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_import_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_PyObject__threadlocal);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_import_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_import_name = __pyx_import_signature + 11;
    void **const __pyx_import_pointers[] = {(void **)&__pyx_vp_6gevent_19_gevent_c_hub_local__threadlocal, (void **) NULL};
    void **const *__pyx_import_pointer = __pyx_import_pointers;
    const char *__pyx_import_current_signature = __pyx_import_signature;
    while (*__pyx_import_pointer) {
      if (__Pyx_ImportVoidPtr_3_2_4(__pyx_t_1, __pyx_import_name, *__pyx_import_pointer, __pyx_import_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_import_pointer;
      __pyx_import_name = strchr(__pyx_import_name, '\0') + 1;
      __pyx_import_signature = strchr(__pyx_import_signature, '\0') + 1;
      if (*__pyx_import_signature != '\0') __pyx_import_current_signature = __pyx_import_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  {
    __pyx_t_1 = PyImport_ImportModule("gevent._gevent_c_abstract_linkable"); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_import_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_PyObject_int_InvalidSwitchError);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_import_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_import_name = __pyx_import_signature + 19;
    void **const __pyx_import_pointers[] = {(void **)&__pyx_vp_6gevent_27_gevent_c_abstract_linkable_InvalidSwitchError, (void **)&__pyx_vp_6gevent_27_gevent_c_abstract_linkable_InvalidThreadUseError, (void **)&__pyx_vp_6gevent_27_gevent_c_abstract_linkable_Timeout, (void **)&__pyx_vp_6gevent_27_gevent_c_abstract_linkable__get_thread_ident, (void **)&__pyx_vp_6gevent_27_gevent_c_abstract_linkable_get_objects, (void **)&__pyx_vp_6gevent_27_gevent_c_abstract_linkable__greenlet_imported, (void **) NULL};
    void **const *__pyx_import_pointer = __pyx_import_pointers;
    const char *__pyx_import_current_signature = __pyx_import_signature;
    while (*__pyx_import_pointer) {
      if (__Pyx_ImportVoidPtr_3_2_4(__pyx_t_1, __pyx_import_name, *__pyx_import_pointer, __pyx_import_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_import_pointer;
      __pyx_import_name = strchr(__pyx_import_name, '\0') + 1;
      __pyx_import_signature = strchr(__pyx_import_signature, '\0') + 1;
      if (*__pyx_import_signature != '\0') __pyx_import_current_signature = __pyx_import_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_function_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  {
    __pyx_t_1 = PyImport_ImportModule("gevent._gevent_c_hub_local"); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_import_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_struct___pyx_obj_6gevent_29_geve);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_import_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_import_name = __pyx_import_signature + 111;
    void (**const __pyx_import_pointers[])(void) = {(void (**)(void))&__pyx_f_6gevent_19_gevent_c_hub_local_get_hub_if_exists, (void (**)(void))&__pyx_f_6gevent_19_gevent_c_hub_local_get_hub_noargs, (void (**)(void)) NULL};
    void (**const *__pyx_import_pointer)(void) = __pyx_import_pointers;
    const char *__pyx_import_current_signature = __pyx_import_signature;
    while (*__pyx_import_pointer) {
      if (__Pyx_ImportFunction_3_2_4(__pyx_t_1, __pyx_import_name, *__pyx_import_pointer, __pyx_import_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_import_pointer;
      __pyx_import_name = strchr(__pyx_import_name, '\0') + 1;
      __pyx_import_signature = strchr(__pyx_import_signature, '\0') + 1;
      if (*__pyx_import_signature != '\0') __pyx_import_current_signature = __pyx_import_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec__gevent_c_semaphore(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec__gevent_c_semaphore},
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
  {Py_mod_gil, __Pyx_FREETHREADING_COMPATIBLE},
  #endif
  #if PY_VERSION_HEX >= 0x030C0000 && CYTHON_USE_MODULE_STATE
  {Py_mod_multiple_interpreters, Py_MOD_MULTIPLE_INTERPRETERS_NOT_SUPPORTED},
  #endif
  {0, NULL}
};
#endif

#ifdef __cplusplus
namespace {
  struct PyModuleDef __pyx_moduledef =
  #else
  static struct PyModuleDef __pyx_moduledef =
  #endif
  {
      PyModuleDef_HEAD_INIT,
      "_gevent_c_semaphore",
      0, /* m_doc */
    #if CYTHON_USE_MODULE_STATE
      sizeof(__pyx_mstatetype), /* m_size */
    #else
      (CYTHON_PEP489_MULTI_PHASE_INIT) ? 0 : -1, /* m_size */
    #endif
      __pyx_methods /* m_methods */,
    #if CYTHON_PEP489_MULTI_PHASE_INIT
      __pyx_moduledef_slots, /* m_slots */
    #else
      NULL, /* m_reload */
    #endif
    #if CYTHON_USE_MODULE_STATE
      __pyx_m_traverse, /* m_traverse */
      __pyx_m_clear, /* m_clear */
      NULL /* m_free */
    #else
      NULL, /* m_traverse */
      NULL, /* m_clear */
      NULL /* m_free */
    #endif
  };
  #ifdef __cplusplus
} /* anonymous namespace */
#endif

/* PyModInitFuncType */
#ifndef CYTHON_NO_PYINIT_EXPORT
  #define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#else
  #ifdef __cplusplus
  #define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
  #else
  #define __Pyx_PyMODINIT_FUNC PyObject *
  #endif
#endif

__Pyx_PyMODINIT_FUNC PyInit__gevent_c_semaphore(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit__gevent_c_semaphore(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
/* ModuleCreationPEP489 */
#include "src/gevent/_generated_include/ModuleCreationPEP489_impl_e8e48a7033664eca332c0112edbc6a62057c1d998b2c8eee547bdd9088e6ab4c.h"

static CYTHON_SMALL_CODE int __pyx_pymod_exec__gevent_c_semaphore(PyObject *__pyx_pyinit_module)
#endif
{
  int stringtab_initialized = 0;
  #if CYTHON_USE_MODULE_STATE
  int pystate_addmodule_run = 0;
  #endif
  __pyx_mstatetype *__pyx_mstate = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module '_gevent_c_semaphore' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #else
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_t_1 = __pyx_pyinit_module;
  Py_INCREF(__pyx_t_1);
  #else
  __pyx_t_1 = PyModule_Create(&__pyx_moduledef); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #if CYTHON_USE_MODULE_STATE
  {
    int add_module_result = __Pyx_State_AddModule(__pyx_t_1, &__pyx_moduledef);
    __pyx_t_1 = 0; /* transfer ownership from __pyx_t_1 to "_gevent_c_semaphore" pseudovariable */
    if (unlikely((add_module_result < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    pystate_addmodule_run = 1;
  }
  #else
  __pyx_m = __pyx_t_1;
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
  PyUnstable_Module_SetGIL(__pyx_m, Py_MOD_GIL_USED);
  #endif
  __pyx_mstate = __pyx_mstate_global;
  CYTHON_UNUSED_VAR(__pyx_t_1);
  __pyx_mstate->__pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_mstate->__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_mstate->__pyx_d);
  __pyx_mstate->__pyx_b = __Pyx_PyImport_AddModuleRef(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_mstate->__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_cython_runtime = __Pyx_PyImport_AddModuleRef("cython_runtime"); if (unlikely(!__pyx_mstate->__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_mstate->__pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /* ImportRefnannyAPI */
  #if CYTHON_REFNANNY
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
  if (!__Pyx_RefNanny) {
    PyErr_Clear();
    __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
    if (!__Pyx_RefNanny)
        Py_FatalError("failed to import 'refnanny' module");
  }
  #endif
  
__Pyx_RefNannySetupContext("PyInit__gevent_c_semaphore", 0);
  __Pyx_init_runtime_version();
  if (__Pyx_check_binary_version(__PYX_LIMITED_VERSION_HEX, __Pyx_get_runtime_version(), CYTHON_COMPILING_IN_LIMITED_API) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_mstate->__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_mstate->__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_mstate->__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Library function declarations ---*/
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitConstants(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  stringtab_initialized = 1;
  if (__Pyx_InitGlobals() < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__pyx_module_is_main_gevent___gevent_c_semaphore) {
    if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_name, __pyx_mstate_global->__pyx_n_u_main) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "gevent._gevent_c_semaphore")) {
      if (unlikely((PyDict_SetItemString(modules, "gevent._gevent_c_semaphore", __pyx_m) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_CreateCodeObjects(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code(__pyx_mstate);
  if (unlikely((__Pyx_modinit_variable_export_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  (void)__Pyx_modinit_function_export_code(__pyx_mstate);
  if (unlikely((__Pyx_modinit_type_init_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely((__Pyx_modinit_type_import_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely((__Pyx_modinit_variable_import_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely((__Pyx_modinit_function_import_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Execution code ---*/

  /* "src/gevent/_semaphore.py":12
 * from __future__ import print_function, absolute_import, division
 * 
 * __all__ = [             # <<<<<<<<<<<<<<
 *     'Semaphore',
 *     'BoundedSemaphore',
*/
  __pyx_t_2 = __Pyx_PyList_Pack(2, __pyx_mstate_global->__pyx_n_u_Semaphore, __pyx_mstate_global->__pyx_n_u_BoundedSemaphore); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_all, __pyx_t_2) < (0)) __PYX_ERR(0, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/_semaphore.py":17
 * ]
 * 
 * from time import sleep as _native_sleep             # <<<<<<<<<<<<<<
 * 
 * from gevent._compat import monotonic
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_sleep};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_time, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 17, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_sleep};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 17, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6gevent_19_gevent_c_semaphore__native_sleep);
        __Pyx_DECREF_SET(__pyx_v_6gevent_19_gevent_c_semaphore__native_sleep, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/_semaphore.py":19
 * from time import sleep as _native_sleep
 * 
 * from gevent._compat import monotonic             # <<<<<<<<<<<<<<
 * from gevent.exceptions import InvalidThreadUseError
 * from gevent.exceptions import LoopExit
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_monotonic};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_gevent__compat, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 19, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_monotonic};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 19, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6gevent_19_gevent_c_semaphore_monotonic);
        __Pyx_DECREF_SET(__pyx_v_6gevent_19_gevent_c_semaphore_monotonic, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/_semaphore.py":20
 * 
 * from gevent._compat import monotonic
 * from gevent.exceptions import InvalidThreadUseError             # <<<<<<<<<<<<<<
 * from gevent.exceptions import LoopExit
 * from gevent.timeout import Timeout
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_InvalidThreadUseError};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_gevent_exceptions, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 20, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_InvalidThreadUseError};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 20, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6gevent_19_gevent_c_semaphore_InvalidThreadUseError);
        __Pyx_DECREF_SET(__pyx_v_6gevent_19_gevent_c_semaphore_InvalidThreadUseError, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/_semaphore.py":21
 * from gevent._compat import monotonic
 * from gevent.exceptions import InvalidThreadUseError
 * from gevent.exceptions import LoopExit             # <<<<<<<<<<<<<<
 * from gevent.timeout import Timeout
 * 
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_LoopExit};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_gevent_exceptions, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 21, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_LoopExit};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 21, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6gevent_19_gevent_c_semaphore_LoopExit);
        __Pyx_DECREF_SET(__pyx_v_6gevent_19_gevent_c_semaphore_LoopExit, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/_semaphore.py":22
 * from gevent.exceptions import InvalidThreadUseError
 * from gevent.exceptions import LoopExit
 * from gevent.timeout import Timeout             # <<<<<<<<<<<<<<
 * 
 * def _get_linkable():
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Timeout};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_gevent_timeout, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 22, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Timeout};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 22, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6gevent_19_gevent_c_semaphore_Timeout);
        __Pyx_DECREF_SET(__pyx_v_6gevent_19_gevent_c_semaphore_Timeout, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/_semaphore.py":24
 * from gevent.timeout import Timeout
 * 
 * def _get_linkable():             # <<<<<<<<<<<<<<
 *     x = __import__('gevent._abstract_linkable')
 *     return x._abstract_linkable.AbstractLinkable
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_19_gevent_c_semaphore_1_get_linkable, 0, __pyx_mstate_global->__pyx_n_u_get_linkable, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_c_semaphore, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[0])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_get_linkable, __pyx_t_2) < (0)) __PYX_ERR(0, 24, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/_semaphore.py":27
 *     x = __import__('gevent._abstract_linkable')
 *     return x._abstract_linkable.AbstractLinkable
 * locals()['AbstractLinkable'] = _get_linkable()             # <<<<<<<<<<<<<<
 * del _get_linkable
 * 
*/
  __pyx_t_4 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_get_linkable); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 27, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 27, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __pyx_t_5 = __Pyx_Globals(); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 27, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (unlikely((PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_AbstractLinkable, __pyx_t_2) < 0))) __PYX_ERR(0, 27, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/_semaphore.py":28
 *     return x._abstract_linkable.AbstractLinkable
 * locals()['AbstractLinkable'] = _get_linkable()
 * del _get_linkable             # <<<<<<<<<<<<<<
 * 
 * from gevent._hub_local import get_hub_if_exists
*/
  if (__Pyx_PyObject_DelAttrStr(__pyx_m, __pyx_mstate_global->__pyx_n_u_get_linkable) < (0)) __PYX_ERR(0, 28, __pyx_L1_error)

  /* "src/gevent/_semaphore.py":30
 * del _get_linkable
 * 
 * from gevent._hub_local import get_hub_if_exists             # <<<<<<<<<<<<<<
 * from gevent._hub_local import get_hub
 * from gevent.hub import spawn_raw
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_get_hub_if_exists};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_gevent__hub_local, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 30, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_get_hub_if_exists};
    __pyx_t_3 = 0; {
      __pyx_t_5 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 30, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_5) < (0)) __PYX_ERR(0, 30, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/_semaphore.py":31
 * 
 * from gevent._hub_local import get_hub_if_exists
 * from gevent._hub_local import get_hub             # <<<<<<<<<<<<<<
 * from gevent.hub import spawn_raw
 * 
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_get_hub};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_gevent__hub_local, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 31, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_get_hub};
    __pyx_t_3 = 0; {
      __pyx_t_5 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 31, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_5) < (0)) __PYX_ERR(0, 31, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/_semaphore.py":32
 * from gevent._hub_local import get_hub_if_exists
 * from gevent._hub_local import get_hub
 * from gevent.hub import spawn_raw             # <<<<<<<<<<<<<<
 * 
 * class _LockReleaseLink(object):
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_spawn_raw};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_gevent_hub, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 32, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_spawn_raw};
    __pyx_t_3 = 0; {
      __pyx_t_5 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 32, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      switch (__pyx_t_3) {
        case 0:
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_XGOTREF(__pyx_v_6gevent_19_gevent_c_semaphore_spawn_raw);
        __Pyx_DECREF_SET(__pyx_v_6gevent_19_gevent_c_semaphore_spawn_raw, __pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_5);
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/_semaphore.py":36
 * class _LockReleaseLink(object):
 *     __slots__ = (
 *         'lock',             # <<<<<<<<<<<<<<
 *     )
 * 
*/
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_19_gevent_c_semaphore__LockReleaseLink, __pyx_mstate_global->__pyx_n_u_slots, __pyx_mstate_global->__pyx_tuple[1]) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)

  /* "src/gevent/_semaphore.py":45
 *         self.lock.release()
 * 
 * _UNSET = object()             # <<<<<<<<<<<<<<
 * _MULTI = object()
 * 
*/
  __pyx_t_5 = NULL;
  __pyx_t_6 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_object, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 45, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __Pyx_XGOTREF(__pyx_v_6gevent_19_gevent_c_semaphore__UNSET);
  __Pyx_DECREF_SET(__pyx_v_6gevent_19_gevent_c_semaphore__UNSET, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "src/gevent/_semaphore.py":46
 * 
 * _UNSET = object()
 * _MULTI = object()             # <<<<<<<<<<<<<<
 * 
 * class Semaphore(AbstractLinkable): # pylint:disable=undefined-variable
*/
  __pyx_t_5 = NULL;
  __pyx_t_6 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_object, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 46, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __Pyx_XGOTREF(__pyx_v_6gevent_19_gevent_c_semaphore__MULTI);
  __Pyx_DECREF_SET(__pyx_v_6gevent_19_gevent_c_semaphore__MULTI, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "src/gevent/_semaphore.py":87
 * 
 *     __slots__ = (
 *         'counter',             # <<<<<<<<<<<<<<
 *         # long integer, signed (Py2) or unsigned (Py3); see comments
 *         # in the .pxd file for why we store as Python object. Set to ``_UNSET``
*/
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore, __pyx_mstate_global->__pyx_n_u_slots, __pyx_mstate_global->__pyx_tuple[2]) < (0)) __PYX_ERR(0, 86, __pyx_L1_error)

  /* "src/gevent/_semaphore.py":112
 *         )
 * 
 *     def locked(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return a boolean indicating whether the semaphore can be
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_19_gevent_c_semaphore_9Semaphore_5locked, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Semaphore_locked, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_c_semaphore, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[1])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore, __pyx_mstate_global->__pyx_n_u_locked, __pyx_t_2) < (0)) __PYX_ERR(0, 112, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/_semaphore.py":122
 *         return self.counter <= 0
 * 
 *     def release(self):             # <<<<<<<<<<<<<<
 *         """
 *         Release the semaphore, notifying any waiters if needed. There
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_19_gevent_c_semaphore_9Semaphore_7release, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Semaphore_release, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_c_semaphore, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[2])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore, __pyx_mstate_global->__pyx_n_u_release, __pyx_t_2) < (0)) __PYX_ERR(0, 122, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/_semaphore.py":143
 *         return self.counter
 * 
 *     def ready(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return a boolean indicating whether the semaphore can be
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_19_gevent_c_semaphore_9Semaphore_9ready, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Semaphore_ready, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_c_semaphore, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[3])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore, __pyx_mstate_global->__pyx_n_u_ready, __pyx_t_2) < (0)) __PYX_ERR(0, 143, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/_semaphore.py":152
 *         return self.counter > 0
 * 
 *     def _start_notify(self):             # <<<<<<<<<<<<<<
 *         self._check_and_notify()
 * 
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_19_gevent_c_semaphore_9Semaphore_11_start_notify, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Semaphore__start_notify, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_c_semaphore, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[4])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore, __pyx_mstate_global->__pyx_n_u_start_notify, __pyx_t_2) < (0)) __PYX_ERR(0, 152, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/_semaphore.py":163
 *         return True
 * 
 *     def wait(self, timeout=None):             # <<<<<<<<<<<<<<
 *         """
 *         Wait until it is possible to acquire this semaphore, or until the optional
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_19_gevent_c_semaphore_9Semaphore_13wait, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Semaphore_wait, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_c_semaphore, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[5])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_mstate_global->__pyx_tuple[3]);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore, __pyx_mstate_global->__pyx_n_u_wait, __pyx_t_2) < (0)) __PYX_ERR(0, 163, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/_semaphore.py":184
 *         return self.counter
 * 
 *     def acquire(self, blocking=True, timeout=None):             # <<<<<<<<<<<<<<
 *         """
 *         acquire(blocking=True, timeout=None) -> bool
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_19_gevent_c_semaphore_9Semaphore_15acquire, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Semaphore_acquire, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_c_semaphore, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[6])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 184, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_mstate_global->__pyx_tuple[4]);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore, __pyx_mstate_global->__pyx_n_u_acquire, __pyx_t_2) < (0)) __PYX_ERR(0, 184, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/_semaphore.py":280
 *         return True
 * 
 *     _py3k_acquire = acquire # PyPy needs this; it must be static for Cython             # <<<<<<<<<<<<<<
 * 
 *     def __enter__(self):
*/
  __Pyx_GetNameInClass(__pyx_t_2, (PyObject*)__pyx_mstate_global->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore, __pyx_mstate_global->__pyx_n_u_acquire); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 280, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore, __pyx_mstate_global->__pyx_n_u_py3k_acquire, __pyx_t_2) < (0)) __PYX_ERR(0, 280, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/_semaphore.py":282
 *     _py3k_acquire = acquire # PyPy needs this; it must be static for Cython
 * 
 *     def __enter__(self):             # <<<<<<<<<<<<<<
 *         self.acquire()
 * 
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_19_gevent_c_semaphore_9Semaphore_17__enter__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Semaphore___enter, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_c_semaphore, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[7])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore, __pyx_mstate_global->__pyx_n_u_enter, __pyx_t_2) < (0)) __PYX_ERR(0, 282, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/_semaphore.py":285
 *         self.acquire()
 * 
 *     def __exit__(self, t, v, tb):             # <<<<<<<<<<<<<<
 *         self.release()
 * 
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_19_gevent_c_semaphore_9Semaphore_19__exit__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Semaphore___exit, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_c_semaphore, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[8])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 285, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore, __pyx_mstate_global->__pyx_n_u_exit, __pyx_t_2) < (0)) __PYX_ERR(0, 285, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/_semaphore.py":398
 *             watcher.close()
 * 
 *     def __acquire_from_other_thread_cb(self, results, blocking, timeout, thread_lock):             # <<<<<<<<<<<<<<
 *         try:
 *             result = self.acquire(blocking, timeout)
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_19_gevent_c_semaphore_9Semaphore_21_Semaphore__acquire_from_other_thread_cb, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Semaphore__Semaphore__acquire_fr, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_c_semaphore, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[9])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 398, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_19_gevent_c_semaphore_Semaphore, __pyx_mstate_global->__pyx_n_u_Semaphore__acquire_from_other_t, __pyx_t_2) < (0)) __PYX_ERR(0, 398, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/_semaphore.py":484
 * 
 *     __slots__ = (
 *         '_initial_value',             # <<<<<<<<<<<<<<
 *     )
 * 
*/
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_19_gevent_c_semaphore_BoundedSemaphore, __pyx_mstate_global->__pyx_n_u_slots, __pyx_mstate_global->__pyx_tuple[5]) < (0)) __PYX_ERR(0, 483, __pyx_L1_error)

  /* "src/gevent/_semaphore.py":488
 * 
 *     #: For monkey-patching, allow changing the class of error we raise
 *     _OVER_RELEASE_ERROR = ValueError             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, *args, **kwargs):
*/
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_19_gevent_c_semaphore_BoundedSemaphore, __pyx_mstate_global->__pyx_n_u_OVER_RELEASE_ERROR, ((PyObject *)(((PyTypeObject*)PyExc_ValueError)))) < (0)) __PYX_ERR(0, 488, __pyx_L1_error)

  /* "src/gevent/_semaphore.py":494
 *         self._initial_value = self.counter
 * 
 *     def release(self):             # <<<<<<<<<<<<<<
 *         """
 *         Like :meth:`Semaphore.release`, but raises :class:`ValueError`
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_19_gevent_c_semaphore_16BoundedSemaphore_3release, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BoundedSemaphore_release, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_c_semaphore, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[10])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 494, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_19_gevent_c_semaphore_BoundedSemaphore, __pyx_mstate_global->__pyx_n_u_release, __pyx_t_2) < (0)) __PYX_ERR(0, 494, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/_semaphore.py":509
 *         return counter
 * 
 *     def _at_fork_reinit(self):             # <<<<<<<<<<<<<<
 *         super(BoundedSemaphore, self)._at_fork_reinit()
 *         self.counter = self._initial_value
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_19_gevent_c_semaphore_16BoundedSemaphore_5_at_fork_reinit, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BoundedSemaphore__at_fork_reinit, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_c_semaphore, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[11])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 509, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_19_gevent_c_semaphore_BoundedSemaphore, __pyx_mstate_global->__pyx_n_u_at_fork_reinit, __pyx_t_2) < (0)) __PYX_ERR(0, 509, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/_semaphore.py":526
 * # for PyPy in all cases anyway, so this does nothing.
 * 
 * from gevent._util import import_c_accel             # <<<<<<<<<<<<<<
 * import_c_accel(globals(), 'gevent.__semaphore')
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_import_c_accel};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_gevent__util, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 526, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_import_c_accel};
    __pyx_t_3 = 0; {
      __pyx_t_5 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 526, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_5) < (0)) __PYX_ERR(0, 526, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/_semaphore.py":527
 * 
 * from gevent._util import import_c_accel
 * import_c_accel(globals(), 'gevent.__semaphore')             # <<<<<<<<<<<<<<
*/
  __pyx_t_5 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_import_c_accel); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = __Pyx_Globals(); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = 1;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_t_7, __pyx_mstate_global->__pyx_kp_u_gevent___semaphore};
    __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_6, (3-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 527, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/_semaphore.py":1
 * # cython: auto_pickle=False,embedsignature=True,always_allow_keywords=False             # <<<<<<<<<<<<<<
 * ###
 * # This file is ``gevent._semaphore`` so that it can be compiled by Cython
*/
  __pyx_t_2 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_test, __pyx_t_2) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  if (__pyx_m) {
    if (__pyx_mstate->__pyx_d && stringtab_initialized) {
      __Pyx_AddTraceback("init gevent._gevent_c_semaphore", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    #if !CYTHON_USE_MODULE_STATE
    Py_CLEAR(__pyx_m);
    #else
    Py_DECREF(__pyx_m);
    if (pystate_addmodule_run) {
      PyObject *tp, *value, *tb;
      PyErr_Fetch(&tp, &value, &tb);
      PyState_RemoveModule(&__pyx_moduledef);
      PyErr_Restore(tp, value, tb);
    }
    #endif
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init gevent._gevent_c_semaphore");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #else
  return __pyx_m;
  #endif
}
/* #### Code section: pystring_table ### */
/* #### Code section: cached_builtins ### */

static int __Pyx_InitCachedBuiltins(__pyx_mstatetype *__pyx_mstate) {
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __pyx_builtin_object = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_object); if (!__pyx_builtin_object) __PYX_ERR(0, 45, __pyx_L1_error)
  __pyx_builtin___import__ = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_import); if (!__pyx_builtin___import__) __PYX_ERR(0, 25, __pyx_L1_error)
  __pyx_builtin_super = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_super); if (!__pyx_builtin_super) __PYX_ERR(0, 100, __pyx_L1_error)
  __pyx_builtin_id = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_id); if (!__pyx_builtin_id) __PYX_ERR(0, 107, __pyx_L1_error)

  /* Cached unbound methods */
  __pyx_mstate->__pyx_umethod_PyDict_Type_items.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_items.method_name = &__pyx_mstate->__pyx_n_u_items;
  __pyx_mstate->__pyx_umethod_PyDict_Type_pop.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_pop.method_name = &__pyx_mstate->__pyx_n_u_pop;
  __pyx_mstate->__pyx_umethod_PyDict_Type_values.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_values.method_name = &__pyx_mstate->__pyx_n_u_values;
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cached_constants ### */

static int __Pyx_InitCachedConstants(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "src/gevent/_semaphore.py":368
 *         watcher.start(current_greenlet.switch, self)
 *         try:
 *             with Timeout._start_new_or_dummy(timeout) as timer:             # <<<<<<<<<<<<<<
 *                 # ... now that we're back holding the GIL, we need to verify our
 *                 # state.
*/
  __pyx_mstate_global->__pyx_tuple[0] = PyTuple_Pack(3, Py_None, Py_None, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_tuple[0])) __PYX_ERR(0, 368, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[0]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[0]);

  /* "src/gevent/_semaphore.py":36
 * class _LockReleaseLink(object):
 *     __slots__ = (
 *         'lock',             # <<<<<<<<<<<<<<
 *     )
 * 
*/
  __pyx_mstate_global->__pyx_tuple[1] = PyTuple_Pack(1, __pyx_mstate_global->__pyx_n_u_lock); if (unlikely(!__pyx_mstate_global->__pyx_tuple[1])) __PYX_ERR(0, 36, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[1]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[1]);

  /* "src/gevent/_semaphore.py":87
 * 
 *     __slots__ = (
 *         'counter',             # <<<<<<<<<<<<<<
 *         # long integer, signed (Py2) or unsigned (Py3); see comments
 *         # in the .pxd file for why we store as Python object. Set to ``_UNSET``
*/
  __pyx_mstate_global->__pyx_tuple[2] = PyTuple_Pack(2, __pyx_mstate_global->__pyx_n_u_counter_2, __pyx_mstate_global->__pyx_n_u_multithreaded); if (unlikely(!__pyx_mstate_global->__pyx_tuple[2])) __PYX_ERR(0, 87, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[2]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[2]);

  /* "src/gevent/_semaphore.py":163
 *         return True
 * 
 *     def wait(self, timeout=None):             # <<<<<<<<<<<<<<
 *         """
 *         Wait until it is possible to acquire this semaphore, or until the optional
*/
  __pyx_mstate_global->__pyx_tuple[3] = PyTuple_Pack(1, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_tuple[3])) __PYX_ERR(0, 163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[3]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[3]);

  /* "src/gevent/_semaphore.py":184
 *         return self.counter
 * 
 *     def acquire(self, blocking=True, timeout=None):             # <<<<<<<<<<<<<<
 *         """
 *         acquire(blocking=True, timeout=None) -> bool
*/
  __pyx_mstate_global->__pyx_tuple[4] = PyTuple_Pack(2, Py_True, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_tuple[4])) __PYX_ERR(0, 184, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[4]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[4]);

  /* "src/gevent/_semaphore.py":484
 * 
 *     __slots__ = (
 *         '_initial_value',             # <<<<<<<<<<<<<<
 *     )
 * 
*/
  __pyx_mstate_global->__pyx_tuple[5] = PyTuple_Pack(1, __pyx_mstate_global->__pyx_n_u_initial_value); if (unlikely(!__pyx_mstate_global->__pyx_tuple[5])) __PYX_ERR(0, 484, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[5]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[5]);
  #if CYTHON_IMMORTAL_CONSTANTS
  {
    PyObject **table = __pyx_mstate->__pyx_tuple;
    for (Py_ssize_t i=0; i<6; ++i) {
      #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
      #if PY_VERSION_HEX < 0x030E0000
      if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
      #else
      if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
      #endif
      {
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
      }
      #else
      Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
      #endif
    }
  }
  #endif
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}
/* #### Code section: init_constants ### */

static int __Pyx_InitConstants(__pyx_mstatetype *__pyx_mstate) {
  CYTHON_UNUSED_VAR(__pyx_mstate);
  {
    const struct { const unsigned int length: 9; } index[] = {{179},{33},{1},{2},{1},{1},{8},{6},{9},{7},{6},{2},{18},{25},{9},{8},{36},{24},{1},{16},{16},{32},{24},{21},{16},{8},{6},{19},{20},{9},{50},{19},{18},{40},{23},{17},{16},{15},{17},{14},{7},{18},{7},{7},{6},{4},{6},{18},{15},{8},{9},{18},{5},{7},{8},{9},{8},{8},{7},{17},{13},{14},{26},{17},{12},{17},{10},{14},{3},{2},{10},{14},{8},{14},{13},{5},{4},{6},{8},{8},{10},{9},{14},{8},{6},{3},{13},{12},{14},{12},{5},{7},{7},{23},{4},{17},{12},{10},{5},{9},{9},{5},{19},{13},{4},{5},{6},{1},{2},{8},{11},{4},{7},{1},{5},{6},{4},{1},{104},{111},{23},{116},{21},{41},{63},{9},{26},{26},{39},{10},{15},{15},{408},{143}};
    #if (CYTHON_COMPRESS_STRINGS) == 3 && __PYX_LIMITED_VERSION_HEX >= 0x030e0000 /* compression: zstd (1508 bytes) */
const char* const cstring = "(\265/\375`{\t\325.\000\nJ4\017E\000\2218\007\374?\337\273\177\277\372_\256\357=\337{\215~\365[\311s\034k\177'\221\266EvhbmsIY8\373\267hU\370\317\305T\263\205\032\240\274Bl\030\322~\252\364?Q\000PU\024\024\2000\260;\314\000\310\000\346\000v\205\343~\301\227\353\337|31\nu\370\235h\320\240\341\2142G\220\230\236\315\317\2407\035\354\250jv\264~\2655\313\310s\313\365\305\326\256_\243\370sFs\367\311[W\371I;Y\367.\243\271n#\260\277\005\2576Y(\363\251\355m\243%NH\314\020\221\335\253?CK\275y3\365\316\361t|Q\037\365\334\345\304sGQ\270\252\276\346\270n\323\302\311\326\266\267>\375k-\2650\337\363\264\216\372L\277y\177n\356v\2027\234\334\212y\222\375\013\177\332\372]\005\263\311\335\231=g\332i\031\230g~\315i8\236\233\245\023\224\002\312\320\"j\231\026\373k\025\177\236a\347O\261g\265\363m\346:\355E}xb>E\375\364\277+\001Yk\013\342\234\035w\024L\275\252\273~Tk\326\013\207\360\353\357~\331\365\250\255\337\201^k\325\336\277\326;p\273\266R\257;{\376\265s\355\266\235k\032m\355\361\375\274\332\275\325\317\237k,\357\250\326O?\357j\3713W;\003Q\375~j\220\353\336\272=\337N{\321h\346mkwg\331m\305W;\271\2655\033f\232O\230n\326\277\257\353h?x\335\253\246\257t\025n\264\013\271\372\230~\356\356\366\316\264\376\306\216\372\333\336\305\\\005S\032\355\346\274\364,_\351\327\252\n+l\351.\261\224J\242\026\271\204D#Q\251K\"\030,\2353P\305]\371\312\022}\367\216J/\332\0355\276\030\213<\277\330\250c\224i\253\001\002\310i\240$\265B\350\010aSj\306Q+\344\003\213\020\022U\274B7R)\221\200\310\331D\016b\212\307L\210\374\220)\243\003\030\017\214\211\202r\202\210`\363J\215\2401\000\310L\350\306G\374\326\001\017\024\255\215\207LJ\004\211\t6/\317\010`\014[\240\326\346\003\2030\363\031\035t\224\251\261dS~Z\005:^\037\321#\202\264<:^\232\033o}\253\233\277w\326\035\237\032[yU\205\370z\3565\206\235\343\300\2541\316\361\n\313\017\262\270\230\300\336V\377BS\330\202a\355\252\372\3246f\022\271\254\274hl\205i\364\302Ec\030\206\231L\226\260\205\225U\375\331\277;\373Gi_W\031\373\007\346\357~\016=\017\334\032\337^\371\212\342""\266+\372\345\357\376\334;\312\371\366\236\273\361\265\247\332\233\365\314u\236\235\243\001\371\204\351\265\030\206\201~\271n\375\325\227l\353\005\223\211\372\032#E\347\352U\374\201\330\340\241\347k \376\374\301\201!\006\304Ec\223\361\220\037\306\224\021\221\227&\207\n\216M\214\212\253\303\205RR*\030\031\214\274^#\"2$\230\r\0339\201\004@\272P\221\216gl\300\351\210\035q\303g\254\321!5d\005\005\233\027\010\347\325y@\232F\225H\322y}\\\034HJ\220(\022\2422\202\342\t\021\244\343\212\024#!\346\205K\304e\2029\221\253\324g\334\024\360\220\211\001\243d\221c\224R\246\\\037\034\224/\222pdBd\007\031\212\240\315K\023!\004\0330\243\201\271p\240$\215!\244\021\202'&\304\205R\205L@z:e'\344\245\211I\251PN #pJ2\217%\007J\224\031\022\214\215\261\344\004\307\304\010\202\363\201\031\030Y\"\311F\3463z\306\017!\030\023\262C.\030M\342\310\346\3651\276\330\202\344\352@\241\014\200\353\250\001!sJ\231\031\021\021\021I\222$\035 \204 \204\352\314\003\262\0219\212K\212&\220\024\2662\354\377\006\025\010\\\032?\330\204*/,D\001]p\275\374\375\236\332v+\204\351``\276\254\255\313'g\030\341\240\205sHj\002%K\252\215z\371\222\245\325DR?\253\233\\x\221\223D\257\362\302\337^41\256\350\214\330\232\376o|\032\037\336\313g\000JG\316M\252\316<\007\177t\032yJ\220\355\2018\233\325\023\236\016\037\007\277\305\213\037\262\203\311\017\336<\254\033\323\311;\363b,\372\263\001:\243Z\204swT%w\262\353e\372V\346\242\222.Z)\261\204\350F\324@\245\363\220R\003\232'\240\003!\237\346aj\313\023\037\222\n\242\335l:/\371n7Q\234\030\257\262\006\234-/\035\2634\251\005\317j}?\210\331VA\261\215\002\271\312\214\222.\304\215\317v\005\245\355\203\004\302\205\364`\327\004\264i}\340\265\345\0261H\030\203\211\004qT\366\305I{&\001\311\004W\317/\036\203\256\201*\220\021\224\246;i$\211i\030\360\263E\036\016\252&\344\361\233py\022+_\025Jp\245\375Q\242\021M\352\035J\220\330\3106?\001g\344n\"\225x\333D\r\377&\242!`&In\2062\337(o\001~A\200M\257\371\322\t\216\224\254\330\315\334\374k8F\027\341\257\201\336@p\252\361*q\2373b\354\332I4\314\353Y\032T""\212\344\321F\006\205\335\224!\243bW\260AfL=\314\362\214\325\0240\034iD\017\034\273\240\004\340B\350\200|\320\250t9\021P\322\361)M@\021\327\324FA\234\206\203q\004\027d\340RM\357\241\267\027R\007q\362\360\317\303\006\262E\241\371\300\371{\031\301\017\271&2\324$\034V\214\\,1\375\340\316\203\366Jma\313\034>\001\237\223NM\201\316\0132r\314SP[\005\365\336\037";
    PyObject *data = __Pyx_DecompressString(cstring, 1508, 3);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #elif (CYTHON_COMPRESS_STRINGS) == 2 /* compression: bz2 (1609 bytes) */
const char* const cstring = "BZh91AY&SYR\375)w\000\001\002\377\377\377\377\377\375\377\363\377\367\277\377\377\212\277\377\377\345@@@@@@@@@@@@@\000@\000P\005\255\246\350\340\000\016\200\016\343\203S$\320!=\022~\244\366\2152\236\223j\232?T\323M\352\200zM3Q\265\036\2404\006\201\351\000\321\352l\246\206\311\352M0\324\tM!1\004\304h\214\206U?\324\r&\246\3220L\010\000\000\000\000\000\032\032\030C\320\200\324\323 \232\244\375S2\001\251\2012d\302a14\311\200ChL\002i\204i\2024\006L2\236\230\232\rOJ\243F\236\246F\231\014&\201\246\232\032\006L&#@\321\221\2404\032\003M\0324\001\240\006\231\002\014\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\004\200\201\022$3\023\362\313>\204|\203\3123p_\033A\2632\271\357=\274\n\327\243u\r)\205\323}C\205\2513\256`\231:|\344\r*\"\210\211\005\002\244 \tM\024\202\210)V\356\n\022\203\007|^\033$\304\330j!\225\315 \210[\213\226\\J\022\270\230A\217\020\210L\252\030\034\246\251OD8\305\341B;@\300\002A\343\320\367\033p\025\005\311\\\003\3210Q\202L\210\344H\2104\257\303\277\266J\026;\0132\233\357\232c\247Q\247\347\237m-\217\202\373\230pFP`\272JcC\\/\375\237-\201\004<\261Y#4\314\210\240\216 \245\203%\010bn\352y\361o4\240\216\323_\207\275\317\000\340\022\242K\224\010\240I\177j\260\226\315\240`\371?\213e\311\216B\023\005+oPI\342\334X!`\311\203\3634kk\014\350XR\274\376\244\243]\367\363\246z_\255\026\265\000\241N\252\022\006\234Q\022\342s&\371V\201\274\037\270\334\305\204I\220\034-\021F\005\271\207mgt\211\233k\324\304\263nPg\201\221\"\231&+\272\232\250\234S\204\367\025gN\347b\222\241\244P\364\242\314\013\322\310\030\235\247\212\376m=\366\362M\345\222\014\316\322\203\372\317\263W\202M\270\306\335\223\330{v\321\267i\346\333\333\313\330\243\021\362j\317\342g*r\247Z\336\243c\261\031\270\323\035y7\272n{\353e\247\257\266\223\266\037;\262\350#\274*\336\376^\023\270\262\376\345\341XFy\315\260\327\250\2519\275\371?\302\025LG\262\357\351W0\302\204Q~B\251\002\327\023\266r\224\212\242\252\310)I\314d\347\203\336\0378\266\002\330\177\027\275\025\324\3451\337\r\010\276V\334Ou\261\232\226""\211\3125u\225\276-\026voe1L\315gNi|\001W\372\236\334C\026\361\357\372\3270\305*z\035[C&:\272[\\\356\275\311h\251\253\2621\027\224x\223biD\030js\r\256\331\366\260\233\337\002\221\361\300\316\224\325\234R\202\250\202\303\016=\333\330\244\354\020\323\342.H\345\206sa1\223\352\020\2405\251\231\302\014\234v\202\336\356\231_;*\377a\344`\356Wq\273\324\341\235\373rO\307\256\0147\007c\252\003\301\331v:\021\245'(\203&8O\302\304PG(\335\321\275\t=\326P\020\273e\010$\312/j\222jY7\364\300H\004j\206p\275d\341<Xm\335\372\261#\016w1q\245\367\241R\354\251Lt\246\276 \204\350t\365\214\030n\312\361\326\332\374\335\235\237\201\350,\270\337P\306\331\227\266J\261\321LB\335\023b\251\262~W\367\241zk\3167\027!3t\203\036\253;4,\033t$\2142=\316\273\242\030\327\251\024\022\323\006p\234A\366\217H\027\362,\333b\357?\242P:\177O\314\333yv,k\272\347\275x[j\315\016x\302^\365\321;\263\203t0Y\302\314\177\306\341\340\t\216I\325M\324x4*kRa\023\023L!>\307p\246\260v\326\375\233}\313n\225\036\226\336\316\027wI\235\020\006\"\320\260\006\256Q1\314\001f\352\267\265\215\017*\320H\201\362H7\322\036\300jt\0104\200x%1 \262>\r\035\254k\013\022a\250\205\337\no\261Y\340\255C\003\222\033-[\315;m\270\260w\243^\334\341F.\2401\177iq0\273\t\032\2508CM\355C@\274F\246Y>}8\"\272\266\276\2140\266X\020\312\267?Rm\376\272\311\207<\263\324\363\034\201\010U\252\220\223$^\n\246Q\000\326\204\033\3060\224?\327cq\231#t\305\245\333\033\r\324n\263\245\207=&&\344\301\023\315\335\262\223\305\333\036|\341\031=\216\273\223\343\362\032\346\271S\337\321\253\224\2576H\346\215\\\236\234\237\365\312\241\317\t7\r\373[\017\202\361\311\360\\.9\346O\001\373\214HO\262\2161e\204\237\304\245(\301\"\263\233\310\2411\246\222\213&K\314\230t\354\266\210,\21121\245Cdc\210L\327 \2120r#\362\272|z\344[\262\030B\331\226\213)^\354:D^g;iJw\231\273\255^\2121h\233\311\245\341\274\261\216\347\034\353\t\362\271\210\330\347\246#\024\330\343\2743\227GV\203\260\313\204z\250K5\325\217\240\312'5g.u\271\213[\276&\263\206|\276\203\035<\036\033\3627y\332\211\323\355\312\313""\000\341VE\242\377\233\240E\270\312\237\342\241=D\2018\2365n\202\004\345 \010\212\034\277{\237\247\204\300\267\000\275\3504\244\301\242^\215\333\332\243gs'\213dF\371\250\225\334\032\010\335\223\202\306\021\274n\343\251zg\316\305\324U\217v\320-b\307\337N\335o\005T\243\006\253\376\275)\267\375\257e\313j\273\025\3425A\265d\2648j\026\306\026\334\007\320\377p\373<_L\241\324s\217F\230v\266=\215L|r\257\326\270\022 \317\346\213v\306dKY\026\273\322?\025+\270\343\226\tk2&\014\324\215kZy\203\212\201\005\271\344\3443ec\236=\257\006\266\232\341\3674\202\341L\3644(\210\031\0313\300]\311\024\341BAK\364\245\334";
    PyObject *data = __Pyx_DecompressString(cstring, 1609, 2);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #elif (CYTHON_COMPRESS_STRINGS) != 0 /* compression: zlib (1487 bytes) */
const char* const cstring = "x\332\235U\315s\323F\024W\332\264M\202\003vIH[:\260\246\224\217\3144\304\220\226\320)t\0141\2056\315w\340\320\351\354\254\245\265\263D\322\312\332Ul\315t:\034}\324QG\035s\3641G\216\034u\3241\177B\376\204\276\225d9!\234\232q\264\273o\367}\375\336o\337\256qI\221\334#\022=\363\345\036\267\021\023\310\240&kR\227Hj\372HH\227\351\222\272\352\220\2156\032\033?,-/!b\033\310\245o\250.\005\022^S7\211\020T \336BM\217\231\222\331H\372\016\025\013\350e\013\371\334C6\245\006\222\0349p\356\264\202\334\2436\022T\252\t\272Ml\233K\"\031\2671\2503\273}\033\031\314\005'\354\200*\355\347\304\024ta\233Z\304\331\343.\205\010LJDj\231#\213\330>\222\314\242\342\227\277\237,\374J\014\003\333*9Hm\261\207t\356\331\220\305c\203\t\3224)\265\325\267\255\267\351\001\265\345\002\306bht(!M\310\234\350\022\233\314\336W\207\231\310\224\014\224\212\304_\205\nb6\223\214\230\350\200\230\036E\226'$jR\364\3441Z\024\256~/\263xo\344b\301\361q=7\277\232[\177\n\361\031\324(r\373p\r\001I\334\342\356>v\251rwn?\307\342\245\rA0cg\317\245\304\330\025\264\341\272\334\305\253\\\337\337\312\016(\207\253\234;\215\036\223k\374\205\327\024x\375Uc\013o5V\033\365\355\006nlm\255oa\274\341\367\340\177\005J\217\327hOn\321V\341\352TL\305\024c\242w<\250\025n\271\334\302\034\312\351b\231\006\201\365\346)\rLU\0310>#\202P0\376\037\306\204$\256TUf-\177$\316\225G\002\023\262?\013\0251\374s\310\215\004]\302\344\016\020\211{\362<\r\206\241ab\232\360q\034j\033\304m\013\"|[\307\351\227\361\005\235\273\240\315l*>\250[S\005\003\314\3068\275\002j\200S\230\001\343\301\rm\022}_7\271\2409_16T\tp\201[\201\026ny\340\017\267\251\304{^3\0370k\251}!E\2721\214y\310i\235[\016\221\303U6b\375<\367\225%\210\223\230C\001\2442\234\323\236N\035uEE.H\275\2473\231a\006\002f`\314,\207Cu\206#`\243\353\024 S(\340l\200;\203\323;\203\231\300\005dLRK(\230\262\272al\021\200'\373\252\310\260\305\r\317\244j\204\322s\233\351\330\362\240\347d\014Q\n6\261`\2337U\177r\270\203\035\377\301~\301)X\365\260N\034\246@T\363\003\2510R\253\216G\314L7\245HN\014\227\n0/\\\317\0065""\323T%\312\331(H\213\nj\266\2403\030\230\265m\356\252\312\002\033T?\221y\03003h\213(\023\320w\034\020\230\034\352\203\205C\2726vI7cq\316e\332\305p_\r\317\262\3743\364\026\222;\302s\250+\272L\352{R\002\016\222\n@2\277\030\n,U\200\274\010\007)\256\351G(>\3676\374\365\024\0174\257\345\177\037m\025\332\2607h\371\r\320\360\237\273\253;/5\274\273\266\335\330\321 )\325\215q\232\213VT@+\2629\343g\303\337\201g`$`\266\324\236\3467`;Md\335\223\231_\305\327\254bB\353\272\264\245\341\246\327jQW\303\026\265\270\353\0370\332\325p\333\205\326m\302\321\214U\3248\345.G\"%\356\007\331*\277y\272\231\333\314\347\307\021(\022W!\345\3502\003\010~&\306\363\241\274\035K\306'\372SA5\250%\343\027\372\265\270t=\354\304\343W\303\332\3115m\262\324_\352\373\341'a5)]\016\226\202\316\361D\251\377<=;q\251/\203\332\333\372\311\324\360\324\247\341R\330IJ_\0067\343+\363\207\325C8s5\\\216jQ\375dB\235Y\016\036\004\206\262T\016\276\010:\312@\347m=\001\203/\202:\330\271\241MN\367W\3031\220\304\245k!)<$\023\323\375\315\370\"\212>\213\277\377q\260\2514\376\010d\230\356L&\245\331`'\374*\252D\363\207u\025\344\303\260\032\326\216KsA/<\345#\265\010N.j\223e\260\372(|\232.\313\303\3453\225\363\365\360\337\303\315\223\3054\237\370\322\365PD*\330\270|#\272\031\337Z>\032K\246+q\245\032]\216V\342;?\037\r\367\252\312\350\265p3\r\246\034L\207\233i\354\361\245;\207c'\237k\3237 \2664\351\261\244\2442Z\n\374h<\252\037\227\347\002\031_}8\350\304\313\253\357\177\217_\275>\236\2700B\273\034\224\3024\237Z&\356\214\346*\264n\324>\334\031\314\014v\217\276;\332\314\020\355\206$;\352\005\317\002/\\QN\000\370\351\231`)\236{0\250%\225\271\340 \334\211\276\005\305JRV?U\273\251\244t\005\312r+\032\213*\n\257\177\302\232ru?\000\263\225\240\222\305\\K\312\337\204U\310\2462\003E$`g;\372$\272\031\031P\346\373\207\233\3073\263I\221N2\373ux%\276\2768\030\037\254\034\225\336\255\274\037K`{f\366T\036\313\341\303\250z\254\022R\314\030\026\304\000\203o\006SGw\337\325T\215S*@\375\340%\363\340Jd]\017x\214\177\312\237\200\373\217F\217AAk\307e\026Sw""]\340\342\252\376\226o\276\206f\253\032\005\232\277\003W+\267(\366\231\003\317\025t\0028|W\323\316\275I\205\304\346\352\305\374\017^,\003\332";
    PyObject *data = __Pyx_DecompressString(cstring, 1487, 1);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #else /* compression: none (2683 bytes) */
const char* const bytes = "Note that Cython is deliberately stricter than PEP-484 and rejects subclasses of builtin types. If you need to pass subclasses then set the 'annotation_typing' directive to False.Semaphore released too many times<]>.?add_note at 0x counter=disableenablegcgevent.__semaphoregevent._abstract_linkableisenabled _links[semaphore initial value must be >= 0src/gevent/_semaphore.py_AbstractLinkableBoundedSemaphoreBoundedSemaphore._at_fork_reinitBoundedSemaphore.releaseInvalidThreadUseError_LockReleaseLinkLoopExitNoHubs_OVER_RELEASE_ERROR__Pyx_PyDict_NextRefSemaphoreSemaphore._Semaphore__acquire_from_other_thread_cbSemaphore.__enter__Semaphore.__exit___Semaphore__acquire_from_other_thread_cbSemaphore._start_notifySemaphore.acquireSemaphore.lockedSemaphore.readySemaphore.releaseSemaphore.waitTimeout_abstract_linkableacquire__all__appendargsasync_asyncio.coroutines_at_fork_reinitblocking__class__cline_in_tracebackclosecounter__dict____enter____exit____func__get_hubget_hub_if_exists_get_linkablegevent._compatgevent._gevent_c_semaphoregevent._hub_localgevent._utilgevent.exceptionsgevent.hubgevent.timeouthubid__import__import_c_accel__init___initial_value_is_coroutineitemslocklocked__main__main_hub__module__monotonic_multithreaded__name__objectpop_py3k_acquire__pyx_capi____pyx_vtable____qualname__readyreleaseresultsrun_callback_threadsafeselfsend_ignoring_arg__set_name__setdefaultsleep__slots__spawn_rawstart_start_new_or_dummy_start_notifystopsuperswitchttb__test__thread_locktimetimeoutvvaluevalueswaitxPyObject *\000\000\000\000\000\000\000\000InvalidThreadUseError\000LoopExit\000Timeout\000_MULTI\000_UNSET\000_native_sleep\000monotonic\000spawn_rawPyObject *\000\000\000PyTypeObject *\000\000int\000BlockingSwitchOutError\000get_objects\000wref\000_buffer\000_memoryview\000_greenlet_importedPyObject *\000_threadlocalPyObject *\000\000\000\000\000int\000InvalidSwitchError\000InvalidThreadUseError\000Timeout\000_get_thread_ident\000get_objects\000_greenlet_imported\200\001\330\004""\010\210\n\220!\2201\330\004\013\2101\320\014\037\230q\320\004\033\2301\360\036\000\t\014\2104\210y\230\002\230!\330\014\023\2204\220q\340\010\014\210F\220!\2201\330\010\017\210t\2201\200A\360\n\000\t\014\2104\210y\230\003\2304\230q\330\014\022\220$\320\026*\250!\2501\330\010\033\2308\2401\240A\360\010\000\t\014\2108\2203\220d\230!\330\014\020\220\007\220q\330\010\017\210q\200A\330\010\014\210H\220A\200A\360\"\000\t\r\210L\230\001\330\010\014\320\014\036\230a\330\010\017\210t\2201\200A\330\010\r\210Q\320\016 \240\005\320%5\260Q\330\010\014\210K\220t\2301\200A\330\010\t\330\014\025\220T\230\030\240\021\240*\250A\330\014\023\2207\230!\2301\340\014\027\220x\230q\330\010\017\210q\200A\330\010\014\320\014\036\230a\200A\360\016\000\t\020\210t\2209\230B\230a\200A\360\020\000\t\020\210t\2209\230C\230q\320\004\037\230~\250Q\3600\000\t\014\2104\320\017\037\230s\240!\330\014\020\320\020\"\240$\320&8\270\001\330\r\021\320\021!\240\023\240D\320(:\270!\330\014\020\320\020\"\240!\360\016\000\t\036\230Q\330\010\t\330\014\020\220\r\230Q\230a\330\010\017\320\017(\250\001\360\006\000\r\"\240\021\240!\330\014\020\220\001\330\014\017\210t\2204\220y\240\004\240A\340\020\027\220t\320\0337\260q\3208L\310J\320VW\340\010\013\2104\210y\230\002\230!\330\014\020\220\014\230A\330\014\023\2201\340\010\013\2104\210q\330\014\023\2201\340\010\013\2104\320\017\037\230w\240g\250T\260\024\260U\270#\270Q\330\014\020\220\007\220w\230a\340\010\013\2104\210u\220C\220u\230D\240\004\240A\360\010\000\r\024\2204\320\0273\2601\330\021\027\220v\230T\240\034\250T\260\021\330\020\021\330\020\021\360\n\000\t\n\330\014\026\220d\230&\240\001\240\021\330\010\017\210|\2301\330\014\023\2202\220Q\330\014\021\220\021\330\014\017\210t\2201\330\020\032\230!\360\006\000\021\024\2203\220a\220v\230S\240\002\240$\240d\250!\2502\250Q\340\024\025\330\020\027\220t\320\0337\260q\330\025\031\230\026\320\0370\260\004\260D\270\014\300D\310\001\330\024\025\330\024\025\340\010\013\2104\210q\330\014\023\2208\2307\240!\340\014\023\2201""\360\010\000\t\020\210t\2209\230B\230d\240$\240j\260\n\270)\3001\330\010\014\210L\230\001\330\010\017\210qstruct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *(int __pyx_skip_dispatch)\000\000get_hub_if_exists\000get_hub_noargs";
    PyObject *data = NULL;
    CYTHON_UNUSED_VAR(__Pyx_DecompressString);
    #endif
    PyObject **stringtab = __pyx_mstate->__pyx_string_tab;
    Py_ssize_t pos = 0;
    for (int i = 0; i < 118; i++) {
      Py_ssize_t bytes_length = index[i].length;
      PyObject *string = PyUnicode_DecodeUTF8(bytes + pos, bytes_length, NULL);
      if (likely(string) && i >= 18) PyUnicode_InternInPlace(&string);
      if (unlikely(!string)) {
        Py_XDECREF(data);
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
      stringtab[i] = string;
      pos += bytes_length;
    }
    for (int i = 118; i < 134; i++) {
      Py_ssize_t bytes_length = index[i].length;
      PyObject *string = PyBytes_FromStringAndSize(bytes + pos, bytes_length);
      stringtab[i] = string;
      pos += bytes_length;
      if (unlikely(!string)) {
        Py_XDECREF(data);
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
    }
    Py_XDECREF(data);
    for (Py_ssize_t i = 0; i < 134; i++) {
      if (unlikely(PyObject_Hash(stringtab[i]) == -1)) {
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
    }
    #if CYTHON_IMMORTAL_CONSTANTS
    {
      PyObject **table = stringtab + 118;
      for (Py_ssize_t i=0; i<16; ++i) {
        #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
        #if PY_VERSION_HEX < 0x030E0000
        if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
        #else
        if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
        #endif
        {
          Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
        }
        #else
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
        #endif
      }
    }
    #endif
  }
  {
    PyObject **numbertab = __pyx_mstate->__pyx_number_tab + 0;
    int8_t const cint_constants_1[] = {0,1};
    for (int i = 0; i < 2; i++) {
      numbertab[i] = PyLong_FromLong(cint_constants_1[i - 0]);
      if (unlikely(!numbertab[i])) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #if CYTHON_IMMORTAL_CONSTANTS
  {
    PyObject **table = __pyx_mstate->__pyx_number_tab;
    for (Py_ssize_t i=0; i<2; ++i) {
      #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
      #if PY_VERSION_HEX < 0x030E0000
      if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
      #else
      if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
      #endif
      {
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
      }
      #else
      Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
      #endif
    }
  }
  #endif
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: init_codeobjects ### */
typedef struct {
    unsigned int argcount : 3;
    unsigned int num_posonly_args : 1;
    unsigned int num_kwonly_args : 1;
    unsigned int nlocals : 3;
    unsigned int flags : 10;
    unsigned int first_line : 9;
} __Pyx_PyCode_New_function_description;
/* NewCodeObj.proto */
static PyObject* __Pyx_PyCode_New(
        const __Pyx_PyCode_New_function_description descr,
        PyObject * const *varnames,
        PyObject *filename,
        PyObject *funcname,
        PyObject *line_table,
        PyObject *tuple_dedup_map
);


static int __Pyx_CreateCodeObjects(__pyx_mstatetype *__pyx_mstate) {
  PyObject* tuple_dedup_map = PyDict_New();
  if (unlikely(!tuple_dedup_map)) return -1;
  {
    const __Pyx_PyCode_New_function_description descr = {0, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 24};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_x};
    __pyx_mstate_global->__pyx_codeobj_tab[0] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent__semaphore_py, __pyx_mstate->__pyx_n_u_get_linkable, __pyx_mstate->__pyx_kp_b_iso88591_1_1_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[0])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 112};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[1] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent__semaphore_py, __pyx_mstate->__pyx_n_u_locked, __pyx_mstate->__pyx_kp_b_iso88591_A_t9Cq, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[1])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 122};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[2] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent__semaphore_py, __pyx_mstate->__pyx_n_u_release, __pyx_mstate->__pyx_kp_b_iso88591_A_L_a_t1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[2])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 143};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[3] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent__semaphore_py, __pyx_mstate->__pyx_n_u_ready, __pyx_mstate->__pyx_kp_b_iso88591_A_t9Ba, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[3])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 152};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[4] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent__semaphore_py, __pyx_mstate->__pyx_n_u_start_notify, __pyx_mstate->__pyx_kp_b_iso88591_A_a, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[4])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 163};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_timeout};
    __pyx_mstate_global->__pyx_codeobj_tab[5] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent__semaphore_py, __pyx_mstate->__pyx_n_u_wait, __pyx_mstate->__pyx_kp_b_iso88591_1_4y_4q_F_1_t1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[5])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 184};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_blocking, __pyx_mstate->__pyx_n_u_timeout};
    __pyx_mstate_global->__pyx_codeobj_tab[6] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent__semaphore_py, __pyx_mstate->__pyx_n_u_acquire, __pyx_mstate->__pyx_kp_b_iso88591_Q0_4_s_8_D_Q_Qa_t4y_A_t_7q8LJVW, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[6])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 282};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[7] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent__semaphore_py, __pyx_mstate->__pyx_n_u_enter, __pyx_mstate->__pyx_kp_b_iso88591_A_HA, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[7])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {4, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 285};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_t, __pyx_mstate->__pyx_n_u_v, __pyx_mstate->__pyx_n_u_tb};
    __pyx_mstate_global->__pyx_codeobj_tab[8] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent__semaphore_py, __pyx_mstate->__pyx_n_u_exit, __pyx_mstate->__pyx_kp_b_iso88591_A_HA, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[8])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {5, 0, 0, 5, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 398};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_results, __pyx_mstate->__pyx_n_u_blocking, __pyx_mstate->__pyx_n_u_timeout, __pyx_mstate->__pyx_n_u_thread_lock};
    __pyx_mstate_global->__pyx_codeobj_tab[9] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent__semaphore_py, __pyx_mstate->__pyx_n_u_Semaphore__acquire_from_other_t, __pyx_mstate->__pyx_kp_b_iso88591_A_T_A_7_1_xq_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[9])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 494};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[10] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent__semaphore_py, __pyx_mstate->__pyx_n_u_release, __pyx_mstate->__pyx_kp_b_iso88591_A_4y_4q_1_81A_83d_q_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[10])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 509};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[11] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent__semaphore_py, __pyx_mstate->__pyx_n_u_at_fork_reinit, __pyx_mstate->__pyx_kp_b_iso88591_A_Q_5Q_Kt1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[11])) goto bad;
  }
  Py_DECREF(tuple_dedup_map);
  return 0;
  bad:
  Py_DECREF(tuple_dedup_map);
  return -1;
}
/* #### Code section: init_globals ### */

static int __Pyx_InitGlobals(void) {
  /* PythonCompatibility.init */
  if (likely(__Pyx_init_co_variables() == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* AssertionsEnabled.init */
  if (likely(__Pyx_init_assertions_enabled() == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CommonTypesMetaclass.init */
  if (likely(__pyx_CommonTypesMetaclass_init(__pyx_m) == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CachedMethodType.init */
  #if CYTHON_COMPILING_IN_LIMITED_API
  {
      PyObject *typesModule=NULL;
      typesModule = PyImport_ImportModule("types");
      if (typesModule) {
          __pyx_mstate_global->__Pyx_CachedMethodType = PyObject_GetAttrString(typesModule, "MethodType");
          Py_DECREF(typesModule);
      }
  } // error handling follows
  #endif
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CythonFunctionShared.init */
  if (likely(__pyx_CyFunction_init(__pyx_m) == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cleanup_globals ### */
/* #### Code section: cleanup_module ### */
/* #### Code section: main_method ### */
/* #### Code section: utility_code_pragmas ### */
#ifdef _MSC_VER
#pragma warning( push )
/* Warning 4127: conditional expression is constant
 * Cython uses constant conditional expressions to allow in inline functions to be optimized at
 * compile-time, so this warning is not useful
 */
#pragma warning( disable : 4127 )
#endif



/* #### Code section: utility_code_def ### */

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyErrExceptionMatches (used by PyObjectGetAttrStrNoError) */
#include "src/gevent/_generated_include/PyErrExceptionMatches_impl_7b4f377310190df92a521563db80ecc2f42d95506fc867b739186a972ce9c8f6.h"
/* PyErrFetchRestore (used by PyObjectGetAttrStrNoError) */
#include "src/gevent/_generated_include/PyErrFetchRestore_impl_83072c493b1583a48ff3aad9f8dc7ade3be268831a2ab8ada440fe395cf916ad.h"
/* PyObjectGetAttrStr (used by PyObjectGetAttrStrNoError) */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* PyObjectGetAttrStrNoError (used by GetBuiltinName) */
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
static void __Pyx_PyObject_GetAttrStr_ClearAttributeError(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (likely(__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        __Pyx_PyErr_Clear();
}
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name) {
    PyObject *result;
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    (void) PyObject_GetOptionalAttr(obj, attr_name, &result);
    return result;
#else
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_TYPE_SLOTS
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro == PyObject_GenericGetAttr)) {
        return _PyObject_GenericGetAttrWithDict(obj, attr_name, NULL, 1);
    }
#endif
    result = __Pyx_PyObject_GetAttrStr(obj, attr_name);
    if (unlikely(!result)) {
        __Pyx_PyObject_GetAttrStr_ClearAttributeError();
    }
    return result;
#endif
}

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStrNoError(__pyx_mstate_global->__pyx_b, name);
    if (unlikely(!result) && !PyErr_Occurred()) {
        PyErr_Format(PyExc_NameError,
            "name '%U' is not defined", name);
    }
    return result;
}

/* TupleAndListFromArray (used by fastcall) */
#include "src/gevent/_generated_include/TupleAndListFromArray_impl_d69ed499f68cd42feaee4b5942c18d0f8efd9989393e455f897298c58b9fa8dd.h"
/* BytesEquals (used by UnicodeEquals) */
#include "src/gevent/_generated_include/BytesEquals_impl_d48b3ef06490e9921f32936be4dcafdc3250ac7ef2252e904b8f20e24a665cc0.h"
/* UnicodeEquals (used by fastcall) */
#include "src/gevent/_generated_include/UnicodeEquals_impl_836cabebedcde255d7b2e14d2d3ec8ae093224d9992c111dd33f6f1ba2aecbef.h"
/* fastcall */
#include "src/gevent/_generated_include/fastcall_impl_2d371982e998467e5c3fa3d5d125a44afb3a07b23828be3d6b5d120f6be5ca37.h"
/* PyObjectCall (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = Py_TYPE(func)->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallMethO (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = __Pyx_CyOrPyCFunction_GET_FUNCTION(func);
    self = __Pyx_CyOrPyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectFastCall */
#include "src/gevent/_generated_include/PyObjectFastCall_impl_49781168209ae59e1c56f88d63362765f980ea90cc34bbbe49d64735688b114b.h"
/* PyObjectCallOneArg (used by CallUnboundCMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *args[2] = {NULL, arg};
    return __Pyx_PyObject_FastCall(func, args+1, 1 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* UnpackUnboundCMethod (used by CallUnboundCMethod0) */
#include "src/gevent/_generated_include/UnpackUnboundCMethod_impl_73fbc94f885e37a7810c861231fd30d7a9eae7cde8890c6786a4ce1f346a7810.h"
/* CallUnboundCMethod0 */
#include "src/gevent/_generated_include/CallUnboundCMethod0_impl_506503ba83409bc78d50e6c2a64d54ddd95a836cba396a015c59c17bbf915db5.h"
/* py_dict_items (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Items(PyObject* d) {
    return __Pyx_CallUnboundCMethod0(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_items, d);
}

/* py_dict_values (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Values(PyObject* d) {
    return __Pyx_CallUnboundCMethod0(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_values, d);
}

/* OwnedDictNext (used by ParseKeywordsImpl) */
#if CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, PyObject **ppos, PyObject **pkey, PyObject **pvalue) {
    PyObject *next = NULL;
    if (!*ppos) {
        if (pvalue) {
            PyObject *dictview = pkey ? __Pyx_PyDict_Items(p) : __Pyx_PyDict_Values(p);
            if (unlikely(!dictview)) goto bad;
            *ppos = PyObject_GetIter(dictview);
            Py_DECREF(dictview);
        } else {
            *ppos = PyObject_GetIter(p);
        }
        if (unlikely(!*ppos)) goto bad;
    }
    next = PyIter_Next(*ppos);
    if (!next) {
        if (PyErr_Occurred()) goto bad;
        return 0;
    }
    if (pkey && pvalue) {
        *pkey = __Pyx_PySequence_ITEM(next, 0);
        if (unlikely(*pkey)) goto bad;
        *pvalue = __Pyx_PySequence_ITEM(next, 1);
        if (unlikely(*pvalue)) goto bad;
        Py_DECREF(next);
    } else if (pkey) {
        *pkey = next;
    } else {
        assert(pvalue);
        *pvalue = next;
    }
    return 1;
  bad:
    Py_XDECREF(next);
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d0000
    PyErr_FormatUnraisable("Exception ignored in __Pyx_PyDict_NextRef");
#else
    PyErr_WriteUnraisable(__pyx_mstate_global->__pyx_n_u_Pyx_PyDict_NextRef);
#endif
    if (pkey) *pkey = NULL;
    if (pvalue) *pvalue = NULL;
    return 0;
}
#else // !CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, Py_ssize_t *ppos, PyObject **pkey, PyObject **pvalue) {
    int result = PyDict_Next(p, ppos, pkey, pvalue);
    if (likely(result == 1)) {
        if (pkey) Py_INCREF(*pkey);
        if (pvalue) Py_INCREF(*pvalue);
    }
    return result;
}
#endif

/* RaiseDoubleKeywords (used by ParseKeywordsImpl) */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
}

/* CallUnboundCMethod2 */
#include "src/gevent/_generated_include/CallUnboundCMethod2_impl_15aa7f0a5154a4d6051e84dd189b6dc929e7450de4be5cb5e9cc003766aec24d.h"
/* ParseKeywordsImpl (used by ParseKeywords) */
static int __Pyx_ValidateDuplicatePosArgs(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    const char* function_name)
{
    PyObject ** const *name = argnames;
    while (name != first_kw_arg) {
        PyObject *key = **name;
        int found = PyDict_Contains(kwds, key);
        if (unlikely(found)) {
            if (found == 1) __Pyx_RaiseDoubleKeywordsError(function_name, key);
            goto bad;
        }
        name++;
    }
    return 0;
bad:
    return -1;
}
#if CYTHON_USE_UNICODE_INTERNALS
static CYTHON_INLINE int __Pyx_UnicodeKeywordsEqual(PyObject *s1, PyObject *s2) {
    int kind;
    Py_ssize_t len = PyUnicode_GET_LENGTH(s1);
    if (len != PyUnicode_GET_LENGTH(s2)) return 0;
    kind = PyUnicode_KIND(s1);
    if (kind != PyUnicode_KIND(s2)) return 0;
    const void *data1 = PyUnicode_DATA(s1);
    const void *data2 = PyUnicode_DATA(s2);
    return (memcmp(data1, data2, (size_t) len * (size_t) kind) == 0);
}
#endif
static int __Pyx_MatchKeywordArg_str(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    PyObject ** const *name;
    #if CYTHON_USE_UNICODE_INTERNALS
    Py_hash_t key_hash = ((PyASCIIObject*)key)->hash;
    if (unlikely(key_hash == -1)) {
        key_hash = PyObject_Hash(key);
        if (unlikely(key_hash == -1))
            goto bad;
    }
    #endif
    name = first_kw_arg;
    while (*name) {
        PyObject *name_str = **name;
        #if CYTHON_USE_UNICODE_INTERNALS
        if (key_hash == ((PyASCIIObject*)name_str)->hash && __Pyx_UnicodeKeywordsEqual(name_str, key)) {
            *index_found = (size_t) (name - argnames);
            return 1;
        }
        #else
        #if CYTHON_ASSUME_SAFE_SIZE
        if (PyUnicode_GET_LENGTH(name_str) == PyUnicode_GET_LENGTH(key))
        #endif
        {
            int cmp = PyUnicode_Compare(name_str, key);
            if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
            if (cmp == 0) {
                *index_found = (size_t) (name - argnames);
                return 1;
            }
        }
        #endif
        name++;
    }
    name = argnames;
    while (name != first_kw_arg) {
        PyObject *name_str = **name;
        #if CYTHON_USE_UNICODE_INTERNALS
        if (unlikely(key_hash == ((PyASCIIObject*)name_str)->hash)) {
            if (__Pyx_UnicodeKeywordsEqual(name_str, key))
                goto arg_passed_twice;
        }
        #else
        #if CYTHON_ASSUME_SAFE_SIZE
        if (PyUnicode_GET_LENGTH(name_str) == PyUnicode_GET_LENGTH(key))
        #endif
        {
            if (unlikely(name_str == key)) goto arg_passed_twice;
            int cmp = PyUnicode_Compare(name_str, key);
            if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
            if (cmp == 0) goto arg_passed_twice;
        }
        #endif
        name++;
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
bad:
    return -1;
}
static int __Pyx_MatchKeywordArg_nostr(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    PyObject ** const *name;
    if (unlikely(!PyUnicode_Check(key))) goto invalid_keyword_type;
    name = first_kw_arg;
    while (*name) {
        int cmp = PyObject_RichCompareBool(**name, key, Py_EQ);
        if (cmp == 1) {
            *index_found = (size_t) (name - argnames);
            return 1;
        }
        if (unlikely(cmp == -1)) goto bad;
        name++;
    }
    name = argnames;
    while (name != first_kw_arg) {
        int cmp = PyObject_RichCompareBool(**name, key, Py_EQ);
        if (unlikely(cmp != 0)) {
            if (cmp == 1) goto arg_passed_twice;
            else goto bad;
        }
        name++;
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
bad:
    return -1;
}
static CYTHON_INLINE int __Pyx_MatchKeywordArg(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    return likely(PyUnicode_CheckExact(key)) ?
        __Pyx_MatchKeywordArg_str(key, argnames, first_kw_arg, index_found, function_name) :
        __Pyx_MatchKeywordArg_nostr(key, argnames, first_kw_arg, index_found, function_name);
}
static void __Pyx_RejectUnknownKeyword(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    const char *function_name)
{
    #if CYTHON_AVOID_BORROWED_REFS
    PyObject *pos = NULL;
    #else
    Py_ssize_t pos = 0;
    #endif
    PyObject *key = NULL;
    __Pyx_BEGIN_CRITICAL_SECTION(kwds);
    while (
        #if CYTHON_AVOID_BORROWED_REFS
        __Pyx_PyDict_NextRef(kwds, &pos, &key, NULL)
        #else
        PyDict_Next(kwds, &pos, &key, NULL)
        #endif
    ) {
        PyObject** const *name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (!*name) {
            size_t index_found = 0;
            int cmp = __Pyx_MatchKeywordArg(key, argnames, first_kw_arg, &index_found, function_name);
            if (cmp != 1) {
                if (cmp == 0) {
                    PyErr_Format(PyExc_TypeError,
                        "%s() got an unexpected keyword argument '%U'",
                        function_name, key);
                }
                #if CYTHON_AVOID_BORROWED_REFS
                Py_DECREF(key);
                #endif
                break;
            }
        }
        #if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(key);
        #endif
    }
    __Pyx_END_CRITICAL_SECTION();
    #if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(pos);
    #endif
    assert(PyErr_Occurred());
}
static int __Pyx_ParseKeywordDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    PyObject** const *name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    Py_ssize_t extracted = 0;
#if !CYTHON_COMPILING_IN_PYPY || defined(PyArg_ValidateKeywordArguments)
    if (unlikely(!PyArg_ValidateKeywordArguments(kwds))) return -1;
#endif
    name = first_kw_arg;
    while (*name && num_kwargs > extracted) {
        PyObject * key = **name;
        PyObject *value;
        int found = 0;
        #if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
        found = PyDict_GetItemRef(kwds, key, &value);
        #else
        value = PyDict_GetItemWithError(kwds, key);
        if (value) {
            Py_INCREF(value);
            found = 1;
        } else {
            if (unlikely(PyErr_Occurred())) goto bad;
        }
        #endif
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
            extracted++;
        }
        name++;
    }
    if (num_kwargs > extracted) {
        if (ignore_unknown_kwargs) {
            if (unlikely(__Pyx_ValidateDuplicatePosArgs(kwds, argnames, first_kw_arg, function_name) == -1))
                goto bad;
        } else {
            __Pyx_RejectUnknownKeyword(kwds, argnames, first_kw_arg, function_name);
            goto bad;
        }
    }
    return 0;
bad:
    return -1;
}
static int __Pyx_ParseKeywordDictToDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject** const *name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    Py_ssize_t len;
#if !CYTHON_COMPILING_IN_PYPY || defined(PyArg_ValidateKeywordArguments)
    if (unlikely(!PyArg_ValidateKeywordArguments(kwds))) return -1;
#endif
    if (PyDict_Update(kwds2, kwds) < 0) goto bad;
    name = first_kw_arg;
    while (*name) {
        PyObject *key = **name;
        PyObject *value;
#if !CYTHON_COMPILING_IN_LIMITED_API && (PY_VERSION_HEX >= 0x030d00A2 || defined(PyDict_Pop))
        int found = PyDict_Pop(kwds2, key, &value);
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
        }
#elif __PYX_LIMITED_VERSION_HEX >= 0x030d0000
        int found = PyDict_GetItemRef(kwds2, key, &value);
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
            if (unlikely(PyDict_DelItem(kwds2, key) < 0)) goto bad;
        }
#else
    #if CYTHON_COMPILING_IN_CPYTHON
        value = _PyDict_Pop(kwds2, key, kwds2);
    #else
        value = __Pyx_CallUnboundCMethod2(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_pop, kwds2, key, kwds2);
    #endif
        if (value == kwds2) {
            Py_DECREF(value);
        } else {
            if (unlikely(!value)) goto bad;
            values[name-argnames] = value;
        }
#endif
        name++;
    }
    len = PyDict_Size(kwds2);
    if (len > 0) {
        return __Pyx_ValidateDuplicatePosArgs(kwds, argnames, first_kw_arg, function_name);
    } else if (unlikely(len == -1)) {
        goto bad;
    }
    return 0;
bad:
    return -1;
}
static int __Pyx_ParseKeywordsTuple(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    PyObject *key = NULL;
    PyObject** const * name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    for (Py_ssize_t pos = 0; pos < num_kwargs; pos++) {
#if CYTHON_AVOID_BORROWED_REFS
        key = __Pyx_PySequence_ITEM(kwds, pos);
#else
        key = __Pyx_PyTuple_GET_ITEM(kwds, pos);
#endif
#if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(!key)) goto bad;
#endif
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            PyObject *value = kwvalues[pos];
            values[name-argnames] = __Pyx_NewRef(value);
        } else {
            size_t index_found = 0;
            int cmp = __Pyx_MatchKeywordArg(key, argnames, first_kw_arg, &index_found, function_name);
            if (cmp == 1) {
                PyObject *value = kwvalues[pos];
                values[index_found] = __Pyx_NewRef(value);
            } else {
                if (unlikely(cmp == -1)) goto bad;
                if (kwds2) {
                    PyObject *value = kwvalues[pos];
                    if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
                } else if (!ignore_unknown_kwargs) {
                    goto invalid_keyword;
                }
            }
        }
        #if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(key);
        key = NULL;
        #endif
    }
    return 0;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    goto bad;
bad:
    #if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(key);
    #endif
    return -1;
}

/* ParseKeywords */
static int __Pyx_ParseKeywords(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    if (CYTHON_METH_FASTCALL && likely(PyTuple_Check(kwds)))
        return __Pyx_ParseKeywordsTuple(kwds, kwvalues, argnames, kwds2, values, num_pos_args, num_kwargs, function_name, ignore_unknown_kwargs);
    else if (kwds2)
        return __Pyx_ParseKeywordDictToDict(kwds, argnames, kwds2, values, num_pos_args, function_name);
    else
        return __Pyx_ParseKeywordDict(kwds, argnames, values, num_pos_args, num_kwargs, function_name, ignore_unknown_kwargs);
}

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* PyObjectFastCallMethod */
#if !CYTHON_VECTORCALL || PY_VERSION_HEX < 0x03090000
static PyObject *__Pyx_PyObject_FastCallMethod(PyObject *name, PyObject *const *args, size_t nargsf) {
    PyObject *result;
    PyObject *attr = PyObject_GetAttr(args[0], name);
    if (unlikely(!attr))
        return NULL;
    result = __Pyx_PyObject_FastCall(attr, args+1, nargsf - 1);
    Py_DECREF(attr);
    return result;
}
#endif

/* RaiseException */
#include "src/gevent/_generated_include/RaiseException_impl_5214b4470ab1cce407ca930811cfafb701053719a58763807254160af0a39f69.h"
/* PyObjectFormatAndDecref */
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatSimpleAndDecref(PyObject* s, PyObject* f) {
    if (unlikely(!s)) return NULL;
    if (likely(PyUnicode_CheckExact(s))) return s;
    return __Pyx_PyObject_FormatAndDecref(s, f);
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatAndDecref(PyObject* s, PyObject* f) {
    PyObject *result;
    if (unlikely(!s)) return NULL;
    result = PyObject_Format(s, f);
    Py_DECREF(s);
    return result;
}

/* PyObjectFormat */
#if CYTHON_USE_UNICODE_WRITER
static PyObject* __Pyx_PyObject_Format(PyObject* obj, PyObject* format_spec) {
    int ret;
    _PyUnicodeWriter writer;
    if (likely(PyFloat_CheckExact(obj))) {
        _PyUnicodeWriter_Init(&writer);
        ret = _PyFloat_FormatAdvancedWriter(
            &writer,
            obj,
            format_spec, 0, PyUnicode_GET_LENGTH(format_spec));
    } else if (likely(PyLong_CheckExact(obj))) {
        _PyUnicodeWriter_Init(&writer);
        ret = _PyLong_FormatAdvancedWriter(
            &writer,
            obj,
            format_spec, 0, PyUnicode_GET_LENGTH(format_spec));
    } else {
        return PyObject_Format(obj, format_spec);
    }
    if (unlikely(ret == -1)) {
        _PyUnicodeWriter_Dealloc(&writer);
        return NULL;
    }
    return _PyUnicodeWriter_Finish(&writer);
}
#endif

/* CIntToDigits (used by CIntToPyUnicode) */
static const char DIGIT_PAIRS_10[2*10*10+1] = {
    "00010203040506070809"
    "10111213141516171819"
    "20212223242526272829"
    "30313233343536373839"
    "40414243444546474849"
    "50515253545556575859"
    "60616263646566676869"
    "70717273747576777879"
    "80818283848586878889"
    "90919293949596979899"
};
static const char DIGIT_PAIRS_8[2*8*8+1] = {
    "0001020304050607"
    "1011121314151617"
    "2021222324252627"
    "3031323334353637"
    "4041424344454647"
    "5051525354555657"
    "6061626364656667"
    "7071727374757677"
};
static const char DIGITS_HEX[2*16+1] = {
    "0123456789abcdef"
    "0123456789ABCDEF"
};

/* BuildPyUnicode (used by COrdinalToPyUnicode) */
#include "src/gevent/_generated_include/BuildPyUnicode_impl_39336659d3e7fa6e93f0316e0a04a30f8e9ee88a4ff7243bbd044712c15d9a95.h"
/* COrdinalToPyUnicode (used by CIntToPyUnicode) */
#include "src/gevent/_generated_include/COrdinalToPyUnicode_impl_b9a3dd9d59ba195a7026008f8d4ba59db46533309847ef8b2804b042630ea937.h"
/* CIntToPyUnicode */
#include "src/gevent/_generated_include/CIntToPyUnicode_impl_60c990d69b3109107516df669b0496ea3c683ef15a8523feac6c3440ce8fe308.h"
/* JoinPyUnicode */
#include "src/gevent/_generated_include/JoinPyUnicode_impl_199e5554049cf0e6f79c238bd653d59e48f3389f2b94c2dd9cad4227096f0038.h"
/* PyDictVersioning */
#include "src/gevent/_generated_include/PyDictVersioning_impl_f179ad268abce9726a76569141f76d5dcd0550225ef9a9e9f73d478d7be0c345.h"
/* GetTopmostException (used by SaveResetException) */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem *
__Pyx_PyErr_GetTopmostException(PyThreadState *tstate)
{
    _PyErr_StackItem *exc_info = tstate->exc_info;
    while ((exc_info->exc_value == NULL || exc_info->exc_value == Py_None) &&
           exc_info->previous_item != NULL)
    {
        exc_info = exc_info->previous_item;
    }
    return exc_info;
}
#endif

/* SaveResetException */
#include "src/gevent/_generated_include/SaveResetException_impl_b3e76ed9bc3819093e52b1558c2bbad485040cdc5a28b71844e50bfc92f51cf0.h"
/* GetException */
#include "src/gevent/_generated_include/GetException_impl_36bcd44414c3b1ebf6a1c0f320ee2c6e2baced19353f70d825d0fd0338e3c175.h"
/* RaiseUnexpectedTypeError */
static int
__Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj)
{
    __Pyx_TypeName obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError, "Expected %s, got " __Pyx_FMT_TYPENAME,
                 expected, obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* SwapException */
#include "src/gevent/_generated_include/SwapException_impl_3529c43002b85b6a88333a1994598a58e361312e8462c9c4553bcc16b799892a.h"
/* GetItemInt */
#include "src/gevent/_generated_include/GetItemInt_impl_057d6f270e739b86c6eeceee664d75d3caab665a9ec308b52b1fc08c260ccd28.h"
/* PyObjectCall2Args (used by PyObjectCallMethod1) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2) {
    PyObject *args[3] = {NULL, arg1, arg2};
    return __Pyx_PyObject_FastCall(function, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* PyObjectGetMethod (used by PyObjectCallMethod1) */
#include "src/gevent/_generated_include/PyObjectGetMethod_impl_e128eb9d3930413c3ed54abc40d4953c55ff9ea67a8c08ac7b5c2fd8494b6c00.h"
/* PyObjectCallMethod1 (used by append) */
#include "src/gevent/_generated_include/PyObjectCallMethod1_impl_a9fa2b3d12e0557b4699af9743eada81ea3325e239ce0b5c7a77ad1579669f5a.h"
/* append */
static CYTHON_INLINE int __Pyx_PyObject_Append(PyObject* L, PyObject* x) {
    if (likely(PyList_CheckExact(L))) {
        if (unlikely(__Pyx_PyList_Append(L, x) < 0)) return -1;
    } else {
        PyObject* retval = __Pyx_PyObject_CallMethod1(L, __pyx_mstate_global->__pyx_n_u_append, x);
        if (unlikely(!retval))
            return -1;
        Py_DECREF(retval);
    }
    return 0;
}

/* ExtTypeTest */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type) {
    __Pyx_TypeName obj_type_name;
    __Pyx_TypeName type_name;
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (likely(__Pyx_TypeCheck(obj, type)))
        return 1;
    obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    type_name = __Pyx_PyType_GetFullyQualifiedName(type);
    PyErr_Format(PyExc_TypeError,
                 "Cannot convert " __Pyx_FMT_TYPENAME " to " __Pyx_FMT_TYPENAME,
                 obj_type_name, type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    __Pyx_DECREF_TypeName(type_name);
    return 0;
}

/* PyObjectLookupSpecial */
#if CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx__PyObject_LookupSpecial(PyObject* obj, PyObject* attr_name, int with_error) {
    PyObject *res;
    PyTypeObject *tp = Py_TYPE(obj);
    res = _PyType_Lookup(tp, attr_name);
    if (likely(res)) {
        descrgetfunc f = Py_TYPE(res)->tp_descr_get;
        if (!f) {
            Py_INCREF(res);
        } else {
            res = f(res, obj, (PyObject *)tp);
        }
    } else if (with_error) {
        PyErr_SetObject(PyExc_AttributeError, attr_name);
    }
    return res;
}
#endif

/* ArgTypeTestFunc (used by ArgTypeTest) */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact)
{
    __Pyx_TypeName type_name;
    __Pyx_TypeName obj_type_name;
    PyObject *extra_info = __pyx_mstate_global->__pyx_empty_unicode;
    int from_annotation_subclass = 0;
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    else if (!exact) {
        if (likely(__Pyx_TypeCheck(obj, type))) return 1;
    } else if (exact == 2) {
        if (__Pyx_TypeCheck(obj, type)) {
            from_annotation_subclass = 1;
            extra_info = __pyx_mstate_global->__pyx_kp_u_Note_that_Cython_is_deliberately;
        }
    }
    type_name = __Pyx_PyType_GetFullyQualifiedName(type);
    obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "Argument '%.200s' has incorrect type (expected " __Pyx_FMT_TYPENAME
        ", got " __Pyx_FMT_TYPENAME ")"
#if __PYX_LIMITED_VERSION_HEX < 0x030C0000
        "%s%U"
#endif
        , name, type_name, obj_type_name
#if __PYX_LIMITED_VERSION_HEX < 0x030C0000
        , (from_annotation_subclass ? ". " : ""), extra_info
#endif
        );
#if __PYX_LIMITED_VERSION_HEX >= 0x030C0000
    if (exact == 2 && from_annotation_subclass) {
        PyObject *res;
        PyObject *vargs[2];
        vargs[0] = PyErr_GetRaisedException();
        vargs[1] = extra_info;
        res = PyObject_VectorcallMethod(__pyx_mstate_global->__pyx_kp_u_add_note, vargs, 2, NULL);
        Py_XDECREF(res);
        PyErr_SetRaisedException(vargs[0]);
    }
#endif
    __Pyx_DECREF_TypeName(type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* KeywordStringCheck */
#include "src/gevent/_generated_include/KeywordStringCheck_impl_ab906f68bdf90466d372bd85a39d7cf8593483145096621667739080797c0f42.h"
/* AllocateExtensionType */
static PyObject *__Pyx_AllocateExtensionType(PyTypeObject *t, int is_final) {
    if (is_final || likely(!__Pyx_PyType_HasFeature(t, Py_TPFLAGS_IS_ABSTRACT))) {
        allocfunc alloc_func = __Pyx_PyType_GetSlot(t, tp_alloc, allocfunc);
        return alloc_func(t, 0);
    } else {
        newfunc tp_new = __Pyx_PyType_TryGetSlot(&PyBaseObject_Type, tp_new, newfunc);
    #if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
        if (!tp_new) {
            PyObject *new_str = PyUnicode_FromString("__new__");
            if (likely(new_str)) {
                PyObject *o = PyObject_CallMethodObjArgs((PyObject *)&PyBaseObject_Type, new_str, t, NULL);
                Py_DECREF(new_str);
                return o;
            } else
                return NULL;
        } else
    #endif
        return tp_new(t, __pyx_mstate_global->__pyx_empty_tuple, 0);
    }
}

/* CallTypeTraverse */
#if !CYTHON_USE_TYPE_SPECS || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x03090000)
#else
static int __Pyx_call_type_traverse(PyObject *o, int always_call, visitproc visit, void *arg) {
    #if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x03090000
    if (__Pyx_get_runtime_version() < 0x03090000) return 0;
    #endif
    if (!always_call) {
        PyTypeObject *base = __Pyx_PyObject_GetSlot(o, tp_base, PyTypeObject*);
        unsigned long flags = PyType_GetFlags(base);
        if (flags & Py_TPFLAGS_HEAPTYPE) {
            return 0;
        }
    }
    Py_VISIT((PyObject*)Py_TYPE(o));
    return 0;
}
#endif

/* CallNextTpDealloc */
static void __Pyx_call_next_tp_dealloc(PyObject* obj, destructor current_tp_dealloc) {
    PyTypeObject* type = Py_TYPE(obj);
    destructor tp_dealloc = NULL;
    while (type && __Pyx_PyType_GetSlot(type, tp_dealloc, destructor) != current_tp_dealloc)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    while (type && (tp_dealloc = __Pyx_PyType_GetSlot(type, tp_dealloc, destructor)) == current_tp_dealloc)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    if (type)
        tp_dealloc(obj);
}

/* CallNextTpTraverse */
static int __Pyx_call_next_tp_traverse(PyObject* obj, visitproc v, void *a, traverseproc current_tp_traverse) {
    PyTypeObject* type = Py_TYPE(obj);
    traverseproc tp_traverse = NULL;
    while (type && __Pyx_PyType_GetSlot(type, tp_traverse, traverseproc) != current_tp_traverse)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    while (type && (tp_traverse = __Pyx_PyType_GetSlot(type, tp_traverse, traverseproc)) == current_tp_traverse)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    if (type && tp_traverse)
        return tp_traverse(obj, v, a);
    return 0;
}

/* CallNextTpClear */
static void __Pyx_call_next_tp_clear(PyObject* obj, inquiry current_tp_clear) {
    PyTypeObject* type = Py_TYPE(obj);
    inquiry tp_clear = NULL;
    while (type && __Pyx_PyType_GetSlot(type, tp_clear, inquiry) != current_tp_clear)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    while (type && (tp_clear = __Pyx_PyType_GetSlot(type, tp_clear, inquiry)) == current_tp_clear)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    if (type && tp_clear)
        tp_clear(obj);
}

/* VoidPtrExport */
static int __Pyx_ExportVoidPtr(PyObject *api_dict, const char *name, void *p, const char *sig) {
    PyObject *cobj;
    cobj = PyCapsule_New(p, sig, 0);
    if (!cobj)
        goto bad;
    if (PyDict_SetItemString(api_dict, name, cobj) < 0)
        goto bad;
    Py_DECREF(cobj);
    return 0;
bad:
    Py_XDECREF(cobj);
    return -1;
}

/* GetApiDict */
static PyObject *__Pyx_ApiExport_GetApiDict(void) {
    PyObject *d;
    if (__Pyx_PyDict_GetItemRef(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_pyx_capi, &d) == -1)
        return NULL;
    if (!d) {
        d = PyDict_New();
        if (!d)
            goto bad;
        if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_pyx_capi, d) < 0)
            goto bad;
    }
    return d;
bad:
    Py_XDECREF(d);
    return NULL;
}

/* LimitedApiGetTypeDict (used by SetItemOnTypeDict) */
#include "src/gevent/_generated_include/LimitedApiGetTypeDict_impl_fd5385b0b7d81c54e35b8e8be86f2a48fa376c140ad1a251d94cb50d5e2fb049.h"
/* SetItemOnTypeDict (used by FixUpExtensionType) */
static int __Pyx__SetItemOnTypeDict(PyTypeObject *tp, PyObject *k, PyObject *v) {
    int result;
    PyObject *tp_dict;
#if CYTHON_COMPILING_IN_LIMITED_API
    tp_dict = __Pyx_GetTypeDict(tp);
    if (unlikely(!tp_dict)) return -1;
#else
    tp_dict = tp->tp_dict;
#endif
    result = PyDict_SetItem(tp_dict, k, v);
    if (likely(!result)) {
        PyType_Modified(tp);
        if (unlikely(PyObject_HasAttr(v, __pyx_mstate_global->__pyx_n_u_set_name))) {
            PyObject *setNameResult = PyObject_CallMethodObjArgs(v, __pyx_mstate_global->__pyx_n_u_set_name,  (PyObject *) tp, k, NULL);
            if (!setNameResult) return -1;
            Py_DECREF(setNameResult);
        }
    }
    return result;
}

/* FixUpExtensionType */
#include "src/gevent/_generated_include/FixUpExtensionType_impl_968625585c074793d4236a363113043104c99af679f80b0b7d0ea5e03b43f419.h"
/* PyObjectCallNoArg (used by PyObjectCallMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
    PyObject *arg[2] = {NULL, NULL};
    return __Pyx_PyObject_FastCall(func, arg + 1, 0 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* PyObjectCallMethod0 (used by PyType_Ready) */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name) {
#if CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000))
    PyObject *args[1] = {obj};
    (void) __Pyx_PyObject_CallOneArg;
    (void) __Pyx_PyObject_CallNoArg;
    return PyObject_VectorcallMethod(method_name, args, 1 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#else
    PyObject *method = NULL, *result = NULL;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_CallOneArg(method, obj);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) goto bad;
    result = __Pyx_PyObject_CallNoArg(method);
    Py_DECREF(method);
bad:
    return result;
#endif
}

/* ValidateBasesTuple (used by PyType_Ready) */
#include "src/gevent/_generated_include/ValidateBasesTuple_impl_3b9fdcb5e55f23d97a6405040c32f85cd06688a92f7d1964c3b28bc807f560c9.h"
/* PyType_Ready */
CYTHON_UNUSED static int __Pyx_PyType_HasMultipleInheritance(PyTypeObject *t) {
    while (t) {
        PyObject *bases = __Pyx_PyType_GetSlot(t, tp_bases, PyObject*);
        if (bases) {
            return 1;
        }
        t = __Pyx_PyType_GetSlot(t, tp_base, PyTypeObject*);
    }
    return 0;
}
static int __Pyx_PyType_Ready(PyTypeObject *t) {
#if CYTHON_USE_TYPE_SPECS || !CYTHON_COMPILING_IN_CPYTHON || defined(PYSTON_MAJOR_VERSION)
    (void)__Pyx_PyObject_CallMethod0;
#if CYTHON_USE_TYPE_SPECS
    (void)__Pyx_validate_bases_tuple;
#endif
    return PyType_Ready(t);
#else
    int r;
    if (!__Pyx_PyType_HasMultipleInheritance(t)) {
        return PyType_Ready(t);
    }
    PyObject *bases = __Pyx_PyType_GetSlot(t, tp_bases, PyObject*);
    if (bases && unlikely(__Pyx_validate_bases_tuple(t->tp_name, t->tp_dictoffset, bases) == -1))
        return -1;
#if !defined(PYSTON_MAJOR_VERSION)
    {
        int gc_was_enabled;
    #if PY_VERSION_HEX >= 0x030A00b1
        gc_was_enabled = PyGC_Disable();
        (void)__Pyx_PyObject_CallMethod0;
    #else
        PyObject *ret, *py_status;
        PyObject *gc = NULL;
        #if (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM+0 >= 0x07030400) &&\
                !CYTHON_COMPILING_IN_GRAAL
        gc = PyImport_GetModule(__pyx_mstate_global->__pyx_kp_u_gc);
        #endif
        if (unlikely(!gc)) gc = PyImport_Import(__pyx_mstate_global->__pyx_kp_u_gc);
        if (unlikely(!gc)) return -1;
        py_status = __Pyx_PyObject_CallMethod0(gc, __pyx_mstate_global->__pyx_kp_u_isenabled);
        if (unlikely(!py_status)) {
            Py_DECREF(gc);
            return -1;
        }
        gc_was_enabled = __Pyx_PyObject_IsTrue(py_status);
        Py_DECREF(py_status);
        if (gc_was_enabled > 0) {
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_mstate_global->__pyx_kp_u_disable);
            if (unlikely(!ret)) {
                Py_DECREF(gc);
                return -1;
            }
            Py_DECREF(ret);
        } else if (unlikely(gc_was_enabled == -1)) {
            Py_DECREF(gc);
            return -1;
        }
    #endif
        t->tp_flags |= Py_TPFLAGS_HEAPTYPE;
#if PY_VERSION_HEX >= 0x030A0000
        t->tp_flags |= Py_TPFLAGS_IMMUTABLETYPE;
#endif
#else
        (void)__Pyx_PyObject_CallMethod0;
#endif
    r = PyType_Ready(t);
#if !defined(PYSTON_MAJOR_VERSION)
        t->tp_flags &= ~Py_TPFLAGS_HEAPTYPE;
    #if PY_VERSION_HEX >= 0x030A00b1
        if (gc_was_enabled)
            PyGC_Enable();
    #else
        if (gc_was_enabled) {
            PyObject *tp, *v, *tb;
            PyErr_Fetch(&tp, &v, &tb);
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_mstate_global->__pyx_kp_u_enable);
            if (likely(ret || r == -1)) {
                Py_XDECREF(ret);
                PyErr_Restore(tp, v, tb);
            } else {
                Py_XDECREF(tp);
                Py_XDECREF(v);
                Py_XDECREF(tb);
                r = -1;
            }
        }
        Py_DECREF(gc);
    #endif
    }
#endif
    return r;
#endif
}

/* TypeImport */
#include "src/gevent/_generated_include/TypeImport_impl_e30d056ae329ba5e94fee4709e4266a267c585bd5c229f7cd6121597afbfaa4e.h"
/* GetVTable */
static void* __Pyx_GetVtable(PyTypeObject *type) {
    void* ptr;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *ob = PyObject_GetAttr((PyObject *)type, __pyx_mstate_global->__pyx_n_u_pyx_vtable);
#else
    PyObject *ob = PyObject_GetItem(type->tp_dict, __pyx_mstate_global->__pyx_n_u_pyx_vtable);
#endif
    if (!ob)
        goto bad;
    ptr = PyCapsule_GetPointer(ob, 0);
    if (!ptr && !PyErr_Occurred())
        PyErr_SetString(PyExc_RuntimeError, "invalid vtable found for imported type");
    Py_DECREF(ob);
    return ptr;
bad:
    Py_XDECREF(ob);
    return NULL;
}

/* SetVTable */
static int __Pyx_SetVtable(PyTypeObject *type, void *vtable) {
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
    if (unlikely(!ob))
        goto bad;
#if CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(PyObject_SetAttr((PyObject *) type, __pyx_mstate_global->__pyx_n_u_pyx_vtable, ob) < 0))
#else
    if (unlikely(PyDict_SetItem(type->tp_dict, __pyx_mstate_global->__pyx_n_u_pyx_vtable, ob) < 0))
#endif
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

/* MergeVTables */
#include "src/gevent/_generated_include/MergeVTables_impl_cc0b823a0ed067bdca31ab6afca82ec940b10d68e9ecebbaec0a3d49b6244e8c.h"
/* PxdImportShared (used by VoidPtrImport) */
#include "src/gevent/_generated_include/PxdImportShared_impl_df92e4b607edac2b8480e2c8668970e8115d694234fa83cf1c26cb7dc602ab00.h"
/* VoidPtrImport */
#ifndef __PYX_HAVE_RT_ImportVoidPtr_3_2_4
#define __PYX_HAVE_RT_ImportVoidPtr_3_2_4
static int __Pyx_ImportVoidPtr_3_2_4(PyObject *module, const char *name, void **p, const char *sig) {
    return __Pyx_ImportFromPxd_3_2_4(module, name, p, sig, "variable");
}
#endif

/* FunctionImport */
#ifndef __PYX_HAVE_RT_ImportFunction_3_2_4
#define __PYX_HAVE_RT_ImportFunction_3_2_4
static int __Pyx_ImportFunction_3_2_4(PyObject *module, const char *funcname, void (**f)(void), const char *sig) {
    union {
        void (*fp)(void);
        void *p;
    } tmp;
    int result = __Pyx_ImportFromPxd_3_2_4(module, funcname, &tmp.p, sig, "function");
    if (result == 0) {
        *f = tmp.fp;
    }
    return result;
}
#endif

/* ListPack */
static PyObject *__Pyx_PyList_Pack(Py_ssize_t n, ...) {
    va_list va;
    PyObject *l = PyList_New(n);
    va_start(va, n);
    if (unlikely(!l)) goto end;
    for (Py_ssize_t i=0; i<n; ++i) {
        PyObject *arg = va_arg(va, PyObject*);
        Py_INCREF(arg);
        if (__Pyx_PyList_SET_ITEM(l, i, arg) != (0)) {
            Py_CLEAR(l);
            goto end;
        }
    }
    end:
    va_end(va);
    return l;
}

/* HasAttr (used by ImportImpl) */
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *o, PyObject *n) {
    PyObject *r;
    if (unlikely(!PyUnicode_Check(n))) {
        PyErr_SetString(PyExc_TypeError,
                        "hasattr(): attribute name must be string");
        return -1;
    }
    r = __Pyx_PyObject_GetAttrStrNoError(o, n);
    if (!r) {
        return (unlikely(PyErr_Occurred())) ? -1 : 0;
    } else {
        Py_DECREF(r);
        return 1;
    }
}
#endif

/* ImportImpl (used by Import) */
#include "src/gevent/_generated_include/ImportImpl_impl_54add44d3961eb3adfb567f9d1292a4ce092acafbf7b2d11f026c8e90ea281d3.h"
/* Import */
static PyObject *__Pyx_Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, int level) {
    return __Pyx__Import(name, imported_names, len_imported_names, qualname, __pyx_mstate_global->__pyx_d, level);
}

/* ImportFrom */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        const char* module_name_str = 0;
        PyObject* module_name = 0;
        PyObject* module_dot = 0;
        PyObject* full_name = 0;
        PyErr_Clear();
        module_name_str = PyModule_GetName(module);
        if (unlikely(!module_name_str)) { goto modbad; }
        module_name = PyUnicode_FromString(module_name_str);
        if (unlikely(!module_name)) { goto modbad; }
        module_dot = PyUnicode_Concat(module_name, __pyx_mstate_global->__pyx_kp_u__4);
        if (unlikely(!module_dot)) { goto modbad; }
        full_name = PyUnicode_Concat(module_dot, name);
        if (unlikely(!full_name)) { goto modbad; }
        #if (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM  < 0x07030400) ||\
                CYTHON_COMPILING_IN_GRAAL
        {
            PyObject *modules = PyImport_GetModuleDict();
            if (unlikely(!modules))
                goto modbad;
            value = PyObject_GetItem(modules, full_name);
        }
        #else
        value = PyImport_GetModule(full_name);
        #endif
      modbad:
        Py_XDECREF(full_name);
        Py_XDECREF(module_dot);
        Py_XDECREF(module_name);
    }
    if (unlikely(!value)) {
        PyErr_Format(PyExc_ImportError, "cannot import name %S", name);
    }
    return value;
}

/* dict_setdefault (used by FetchCommonType) */
static CYTHON_INLINE PyObject *__Pyx_PyDict_SetDefault(PyObject *d, PyObject *key, PyObject *default_value) {
    PyObject* value;
#if __PYX_LIMITED_VERSION_HEX >= 0x030F0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4)
    PyDict_SetDefaultRef(d, key, default_value, &value);
#elif CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX >= 0x030C0000
    PyObject *args[] = {d, key, default_value};
    value = PyObject_VectorcallMethod(__pyx_mstate_global->__pyx_n_u_setdefault, args, 3 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#elif CYTHON_COMPILING_IN_LIMITED_API
    value = PyObject_CallMethodObjArgs(d, __pyx_mstate_global->__pyx_n_u_setdefault, key, default_value, NULL);
#else
    value = PyDict_SetDefault(d, key, default_value);
    if (unlikely(!value)) return NULL;
    Py_INCREF(value);
#endif
    return value;
}

/* AddModuleRef (used by FetchSharedCythonModule) */
#include "src/gevent/_generated_include/AddModuleRef_impl_59efe7a55c2d1acdb632a2a6953f1ce31c634c9f98f262a8d338db6996845385.h"
/* FetchSharedCythonModule (used by FetchCommonType) */
static PyObject *__Pyx_FetchSharedCythonABIModule(void) {
    return __Pyx_PyImport_AddModuleRef(__PYX_ABI_MODULE_NAME);
}

/* FetchCommonType (used by CommonTypesMetaclass) */
#include "src/gevent/_generated_include/FetchCommonType_impl_8ddf5d6e0d45314935e4d87502d7fa32ec8f3d50d91ca9715a35d7f0fc2dda28.h"
/* CommonTypesMetaclass (used by CythonFunctionShared) */
#include "src/gevent/_generated_include/CommonTypesMetaclass_impl_5345023feb7cb35c8a99997be95973c1bfc904b959ef880ae7125f77d296af2b.h"
/* PyMethodNew (used by CythonFunctionShared) */
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    PyObject *result;
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    #if __PYX_LIMITED_VERSION_HEX >= 0x030C0000
    {
        PyObject *args[] = {func, self};
        result = PyObject_Vectorcall(__pyx_mstate_global->__Pyx_CachedMethodType, args, 2, NULL);
    }
    #else
    result = PyObject_CallFunctionObjArgs(__pyx_mstate_global->__Pyx_CachedMethodType, func, self, NULL);
    #endif
    return result;
}
#else
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    return PyMethod_New(func, self);
}
#endif

/* PyVectorcallFastCallDict (used by CythonFunctionShared) */
#include "src/gevent/_generated_include/PyVectorcallFastCallDict_impl_3616dfa798c1c336b0933a7ec9d88cb291d491f6315b48f846f69828df4619eb.h"
/* CythonFunctionShared (used by CythonFunction) */
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunctionNoMethod(PyObject *func, void (*cfunc)(void)) {
    if (__Pyx_CyFunction_Check(func)) {
        return PyCFunction_GetFunction(((__pyx_CyFunctionObject*)func)->func) == (PyCFunction) cfunc;
    } else if (PyCFunction_Check(func)) {
        return PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void (*cfunc)(void)) {
    if ((PyObject*)Py_TYPE(func) == __pyx_mstate_global->__Pyx_CachedMethodType) {
        int result;
        PyObject *newFunc = PyObject_GetAttr(func, __pyx_mstate_global->__pyx_n_u_func);
        if (unlikely(!newFunc)) {
            PyErr_Clear(); // It's only an optimization, so don't throw an error
            return 0;
        }
        result = __Pyx__IsSameCyOrCFunctionNoMethod(newFunc, cfunc);
        Py_DECREF(newFunc);
        return result;
    }
    return __Pyx__IsSameCyOrCFunctionNoMethod(func, cfunc);
}
#else
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void (*cfunc)(void)) {
    if (PyMethod_Check(func)) {
        func = PyMethod_GET_FUNCTION(func);
    }
    return __Pyx_CyOrPyCFunction_Check(func) && __Pyx_CyOrPyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
}
#endif
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj) {
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    __Pyx_Py_XDECREF_SET(
        __Pyx_CyFunction_GetClassObj(f),
            ((classobj) ? __Pyx_NewRef(classobj) : NULL));
#else
    __Pyx_Py_XDECREF_SET(
        ((PyCMethodObject *) (f))->mm_class,
        (PyTypeObject*)((classobj) ? __Pyx_NewRef(classobj) : NULL));
#endif
}
static PyObject *
__Pyx_CyFunction_get_doc_locked(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_doc == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_doc = PyObject_GetAttrString(op->func, "__doc__");
        if (unlikely(!op->func_doc)) return NULL;
#else
        if (((PyCFunctionObject*)op)->m_ml->ml_doc) {
            op->func_doc = PyUnicode_FromString(((PyCFunctionObject*)op)->m_ml->ml_doc);
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
#endif
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, void *closure) {
    PyObject *result;
    CYTHON_UNUSED_VAR(closure);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_doc_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (value == NULL) {
        value = Py_None;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_doc, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name_locked(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_name == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_name = PyObject_GetAttrString(op->func, "__name__");
#else
        op->func_name = PyUnicode_InternFromString(((PyCFunctionObject*)op)->m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op, void *context)
{
    PyObject *result = NULL;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_name_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_name, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    PyObject *result;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    Py_INCREF(op->func_qualname);
    result = op->func_qualname;
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_qualname, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
#endif
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(op);
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op, void *context)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    int result = 0;
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    #else
    op->defaults_tuple = __Pyx_PySequence_ITEM(res, 0);
    if (unlikely(!op->defaults_tuple)) result = -1;
    else {
        op->defaults_kwdict = __Pyx_PySequence_ITEM(res, 1);
        if (unlikely(!op->defaults_kwdict)) result = -1;
    }
    #endif
    Py_DECREF(res);
    return result;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyTuple_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__defaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->defaults_tuple, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_tuple;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = NULL;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_defaults_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__kwdefaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->defaults_kwdict, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_kwdict;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_kwdefaults_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value || value == Py_None) {
        value = NULL;
    } else if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_annotations, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->func_annotations;
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op, void *context) {
    PyObject *result;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_annotations_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static PyObject *
__Pyx_CyFunction_get_is_coroutine_value(__pyx_CyFunctionObject *op) {
    int is_coroutine = op->flags & __Pyx_CYFUNCTION_COROUTINE;
    if (is_coroutine) {
        PyObject *is_coroutine_value, *module, *fromlist, *marker = __pyx_mstate_global->__pyx_n_u_is_coroutine;
        fromlist = PyList_New(1);
        if (unlikely(!fromlist)) return NULL;
        Py_INCREF(marker);
#if CYTHON_ASSUME_SAFE_MACROS
        PyList_SET_ITEM(fromlist, 0, marker);
#else
        if (unlikely(PyList_SetItem(fromlist, 0, marker) < 0)) {
            Py_DECREF(marker);
            Py_DECREF(fromlist);
            return NULL;
        }
#endif
        module = PyImport_ImportModuleLevelObject(__pyx_mstate_global->__pyx_n_u_asyncio_coroutines, NULL, NULL, fromlist, 0);
        Py_DECREF(fromlist);
        if (unlikely(!module)) goto ignore;
        is_coroutine_value = __Pyx_PyObject_GetAttrStr(module, marker);
        Py_DECREF(module);
        if (likely(is_coroutine_value)) {
            return is_coroutine_value;
        }
ignore:
        PyErr_Clear();
    }
    return __Pyx_PyBool_FromLong(is_coroutine);
}
static PyObject *
__Pyx_CyFunction_get_is_coroutine(__pyx_CyFunctionObject *op, void *context) {
    PyObject *result;
    CYTHON_UNUSED_VAR(context);
    if (op->func_is_coroutine) {
        return __Pyx_NewRef(op->func_is_coroutine);
    }
    result = __Pyx_CyFunction_get_is_coroutine_value(op);
    if (unlikely(!result))
        return NULL;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    if (op->func_is_coroutine) {
        Py_DECREF(result);
        result = __Pyx_NewRef(op->func_is_coroutine);
    } else {
        op->func_is_coroutine = __Pyx_NewRef(result);
    }
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static void __Pyx_CyFunction_raise_argument_count_error(__pyx_CyFunctionObject *func, const char* message, Py_ssize_t size) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_name = __Pyx_CyFunction_get_name(func, NULL);
    if (!py_name) return;
    PyErr_Format(PyExc_TypeError,
        "%.200S() %s (%" CYTHON_FORMAT_SSIZE_T "d given)",
        py_name, message, size);
    Py_DECREF(py_name);
#else
    const char* name = ((PyCFunctionObject*)func)->m_ml->ml_name;
    PyErr_Format(PyExc_TypeError,
        "%.200s() %s (%" CYTHON_FORMAT_SSIZE_T "d given)",
        name, message, size);
#endif
}
static void __Pyx_CyFunction_raise_type_error(__pyx_CyFunctionObject *func, const char* message) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_name = __Pyx_CyFunction_get_name(func, NULL);
    if (!py_name) return;
    PyErr_Format(PyExc_TypeError,
        "%.200S() %s",
        py_name, message);
    Py_DECREF(py_name);
#else
    const char* name = ((PyCFunctionObject*)func)->m_ml->ml_name;
    PyErr_Format(PyExc_TypeError,
        "%.200s() %s",
        name, message);
#endif
}
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *
__Pyx_CyFunction_get_module(__pyx_CyFunctionObject *op, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_GetAttrString(op->func, "__module__");
}
static int
__Pyx_CyFunction_set_module(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_SetAttrString(op->func, "__module__", value);
}
#endif
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {"func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {"__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {"func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {"__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {"__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
    {"func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)PyObject_GenericSetDict, 0, 0},
    {"__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)PyObject_GenericSetDict, 0, 0},
#else
    {"func_dict", (getter)PyObject_GenericGetDict, (setter)PyObject_GenericSetDict, 0, 0},
    {"__dict__", (getter)PyObject_GenericGetDict, (setter)PyObject_GenericSetDict, 0, 0},
#endif
    {"func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {"__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {"func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {"__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {"func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {"__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {"func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {"__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {"__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {"__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {"_is_coroutine", (getter)__Pyx_CyFunction_get_is_coroutine, 0, 0, 0},
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__module__", (getter)__Pyx_CyFunction_get_module, (setter)__Pyx_CyFunction_set_module, 0, 0},
#endif
    {0, 0, 0, 0, 0}
};
static PyMemberDef __pyx_CyFunction_members[] = {
#if !CYTHON_COMPILING_IN_LIMITED_API
    {"__module__", T_OBJECT, offsetof(PyCFunctionObject, m_module), 0, 0},
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    {"__dictoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_dict), READONLY, 0},
#endif
#if CYTHON_METH_FASTCALL
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__vectorcalloffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_vectorcall), READONLY, 0},
#else
    {"__vectorcalloffset__", T_PYSSIZET, offsetof(PyCFunctionObject, vectorcall), READONLY, 0},
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__weaklistoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_weakreflist), READONLY, 0},
#else
    {"__weaklistoffset__", T_PYSSIZET, offsetof(PyCFunctionObject, m_weakreflist), READONLY, 0},
#endif
#endif
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, PyObject *args)
{
    PyObject *result = NULL;
    CYTHON_UNUSED_VAR(args);
    __Pyx_BEGIN_CRITICAL_SECTION(m);
    Py_INCREF(m->func_qualname);
    result = m->func_qualname;
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {"__reduce__", (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
#if CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func_weakreflist)
#else
#define __Pyx_CyFunction_weakreflist(cyfunc) (((PyCFunctionObject*)cyfunc)->m_weakreflist)
#endif
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject *op, PyMethodDef *ml, int flags, PyObject* qualname,
                                       PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
#if !CYTHON_COMPILING_IN_LIMITED_API
    PyCFunctionObject *cf = (PyCFunctionObject*) op;
#endif
    if (unlikely(op == NULL))
        return NULL;
#if CYTHON_COMPILING_IN_LIMITED_API
    op->func = PyCFunction_NewEx(ml, (PyObject*)op, module);
    if (unlikely(!op->func)) return NULL;
#endif
    op->flags = flags;
    __Pyx_CyFunction_weakreflist(op) = NULL;
#if !CYTHON_COMPILING_IN_LIMITED_API
    cf->m_ml = ml;
    cf->m_self = (PyObject *) op;
#endif
    Py_XINCREF(closure);
    op->func_closure = closure;
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_XINCREF(module);
    cf->m_module = module;
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    op->func_dict = NULL;
#endif
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    op->func_classobj = NULL;
#else
    ((PyCMethodObject*)op)->mm_class = NULL;
#endif
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    op->func_is_coroutine = NULL;
#if CYTHON_METH_FASTCALL
    switch (ml->ml_flags & (METH_VARARGS | METH_FASTCALL | METH_NOARGS | METH_O | METH_KEYWORDS | METH_METHOD)) {
    case METH_NOARGS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_NOARGS;
        break;
    case METH_O:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_O;
        break;
    case METH_METHOD | METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD;
        break;
    case METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS;
        break;
    case METH_VARARGS | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = NULL;
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        Py_DECREF(op);
        return NULL;
    }
#endif
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_CLEAR(m->func);
#else
    Py_CLEAR(((PyCFunctionObject*)m)->m_module);
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    Py_CLEAR(m->func_dict);
#elif PY_VERSION_HEX < 0x030d0000
    _PyObject_ClearManagedDict((PyObject*)m);
#else
    PyObject_ClearManagedDict((PyObject*)m);
#endif
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
#if PY_VERSION_HEX < 0x030900B1
    Py_CLEAR(__Pyx_CyFunction_GetClassObj(m));
#else
    {
        PyObject *cls = (PyObject*) ((PyCMethodObject *) (m))->mm_class;
        ((PyCMethodObject *) (m))->mm_class = NULL;
        Py_XDECREF(cls);
    }
#endif
#endif
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    Py_CLEAR(m->func_is_coroutine);
    Py_CLEAR(m->defaults);
    return 0;
}
static void __Pyx__CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    if (__Pyx_CyFunction_weakreflist(m) != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    __Pyx_PyHeapTypeObject_GC_Del(m);
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    __Pyx__CyFunction_dealloc(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    {
        int e = __Pyx_call_type_traverse((PyObject*)m, 1, visit, arg);
        if (e) return e;
    }
    Py_VISIT(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(m->func);
#else
    Py_VISIT(((PyCFunctionObject*)m)->m_module);
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(m->func_dict);
#else
    {
        int e =
#if PY_VERSION_HEX < 0x030d0000
            _PyObject_VisitManagedDict
#else
            PyObject_VisitManagedDict
#endif
                ((PyObject*)m, visit, arg);
        if (e != 0) return e;
    }
#endif
    __Pyx_VISIT_CONST(m->func_name);
    __Pyx_VISIT_CONST(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    __Pyx_VISIT_CONST(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(__Pyx_CyFunction_GetClassObj(m));
#endif
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    Py_VISIT(m->func_is_coroutine);
    Py_VISIT(m->defaults);
    return 0;
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
    PyObject *repr;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    repr = PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
    __Pyx_END_CRITICAL_SECTION();
    return repr;
}
static PyObject * __Pyx_CyFunction_CallMethod(PyObject *func, PyObject *self, PyObject *arg, PyObject *kw) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *f = ((__pyx_CyFunctionObject*)func)->func;
    PyCFunction meth;
    int flags;
    meth = PyCFunction_GetFunction(f);
    if (unlikely(!meth)) return NULL;
    flags = PyCFunction_GetFlags(f);
    if (unlikely(flags < 0)) return NULL;
#else
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = f->m_ml->ml_meth;
    int flags = f->m_ml->ml_flags;
#endif
    Py_ssize_t size;
    switch (flags & (METH_VARARGS | METH_KEYWORDS | METH_NOARGS | METH_O)) {
    case METH_VARARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0))
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)(void(*)(void))meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_SIZE
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 0))
                return (*meth)(self, NULL);
            __Pyx_CyFunction_raise_argument_count_error(
                (__pyx_CyFunctionObject*)func,
                "takes no arguments", size);
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_SIZE
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 1)) {
                PyObject *result, *arg0;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                arg0 = PyTuple_GET_ITEM(arg, 0);
                #else
                arg0 = __Pyx_PySequence_ITEM(arg, 0); if (unlikely(!arg0)) return NULL;
                #endif
                result = (*meth)(self, arg0);
                #if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
                Py_DECREF(arg0);
                #endif
                return result;
            }
            __Pyx_CyFunction_raise_argument_count_error(
                (__pyx_CyFunctionObject*)func,
                "takes exactly one argument", size);
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        return NULL;
    }
    __Pyx_CyFunction_raise_type_error(
        (__pyx_CyFunctionObject*)func, "takes no keyword arguments");
    return NULL;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *self, *result;
#if CYTHON_COMPILING_IN_LIMITED_API
    self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)func)->func);
    if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
    self = ((PyCFunctionObject*)func)->m_self;
#endif
    result = __Pyx_CyFunction_CallMethod(func, self, arg, kw);
    return result;
}
static PyObject *__Pyx_CyFunction_CallAsMethod(PyObject *func, PyObject *args, PyObject *kw) {
    PyObject *result;
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
     __pyx_vectorcallfunc vc = __Pyx_CyFunction_func_vectorcall(cyfunc);
    if (vc) {
#if CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE
        return __Pyx_PyVectorcall_FastCallDict(func, vc, &PyTuple_GET_ITEM(args, 0), (size_t)PyTuple_GET_SIZE(args), kw);
#else
        (void) &__Pyx_PyVectorcall_FastCallDict;
        return PyVectorcall_Call(func, args, kw);
#endif
    }
#endif
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        Py_ssize_t argc;
        PyObject *new_args;
        PyObject *self;
#if CYTHON_ASSUME_SAFE_SIZE
        argc = PyTuple_GET_SIZE(args);
#else
        argc = PyTuple_Size(args);
        if (unlikely(argc < 0)) return NULL;
#endif
        new_args = PyTuple_GetSlice(args, 1, argc);
        if (unlikely(!new_args))
            return NULL;
        self = PyTuple_GetItem(args, 0);
        if (unlikely(!self)) {
            Py_DECREF(new_args);
            PyErr_Format(PyExc_TypeError,
                         "unbound method %.200S() needs an argument",
                         cyfunc->func_qualname);
            return NULL;
        }
        result = __Pyx_CyFunction_CallMethod(func, self, new_args, kw);
        Py_DECREF(new_args);
    } else {
        result = __Pyx_CyFunction_Call(func, args, kw);
    }
    return result;
}
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
static CYTHON_INLINE int __Pyx_CyFunction_Vectorcall_CheckArgs(__pyx_CyFunctionObject *cyfunc, Py_ssize_t nargs, PyObject *kwnames)
{
    int ret = 0;
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        if (unlikely(nargs < 1)) {
            __Pyx_CyFunction_raise_type_error(
                cyfunc, "needs an argument");
            return -1;
        }
        ret = 1;
    }
    if (unlikely(kwnames) && unlikely(__Pyx_PyTuple_GET_SIZE(kwnames))) {
        __Pyx_CyFunction_raise_type_error(
            cyfunc, "takes no keyword arguments");
        return -1;
    }
    return ret;
}
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 0)) {
        __Pyx_CyFunction_raise_argument_count_error(
            cyfunc, "takes no arguments", nargs);
        return NULL;
    }
    return meth(self, NULL);
}
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 1)) {
        __Pyx_CyFunction_raise_argument_count_error(
            cyfunc, "takes exactly one argument", nargs);
        return NULL;
    }
    return meth(self, args[0]);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    return ((__Pyx_PyCFunctionFastWithKeywords)(void(*)(void))meth)(self, args, nargs, kwnames);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyTypeObject *cls = (PyTypeObject *) __Pyx_CyFunction_GetClassObj(cyfunc);
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    #if PY_VERSION_HEX < 0x030e00A6
    size_t nargs_value = (size_t) nargs;
    #else
    Py_ssize_t nargs_value = nargs;
    #endif
    return ((__Pyx_PyCMethod)(void(*)(void))meth)(self, cls, args, nargs_value, kwnames);
}
#endif
static PyType_Slot __pyx_CyFunctionType_slots[] = {
    {Py_tp_dealloc, (void *)__Pyx_CyFunction_dealloc},
    {Py_tp_repr, (void *)__Pyx_CyFunction_repr},
    {Py_tp_call, (void *)__Pyx_CyFunction_CallAsMethod},
    {Py_tp_traverse, (void *)__Pyx_CyFunction_traverse},
    {Py_tp_clear, (void *)__Pyx_CyFunction_clear},
    {Py_tp_methods, (void *)__pyx_CyFunction_methods},
    {Py_tp_members, (void *)__pyx_CyFunction_members},
    {Py_tp_getset, (void *)__pyx_CyFunction_getsets},
    {Py_tp_descr_get, (void *)__Pyx_PyMethod_New},
    {0, 0},
};
static PyType_Spec __pyx_CyFunctionType_spec = {
    __PYX_TYPE_MODULE_PREFIX "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
#ifdef Py_TPFLAGS_METHOD_DESCRIPTOR
    Py_TPFLAGS_METHOD_DESCRIPTOR |
#endif
#if CYTHON_METH_FASTCALL
#if defined(Py_TPFLAGS_HAVE_VECTORCALL)
    Py_TPFLAGS_HAVE_VECTORCALL |
#elif defined(_Py_TPFLAGS_HAVE_VECTORCALL)
    _Py_TPFLAGS_HAVE_VECTORCALL |
#endif
#endif // CYTHON_METH_FASTCALL
#if PY_VERSION_HEX >= 0x030C0000 && !CYTHON_COMPILING_IN_LIMITED_API
    Py_TPFLAGS_MANAGED_DICT |
#endif
    Py_TPFLAGS_IMMUTABLETYPE | Py_TPFLAGS_DISALLOW_INSTANTIATION |
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    __pyx_CyFunctionType_slots
};
static int __pyx_CyFunction_init(PyObject *module) {
    __pyx_mstatetype *mstate = __Pyx_PyModule_GetState(module);
    mstate->__pyx_CyFunctionType = __Pyx_FetchCommonTypeFromSpec(
        mstate->__pyx_CommonTypesMetaclassType, module, &__pyx_CyFunctionType_spec, NULL);
    if (unlikely(mstate->__pyx_CyFunctionType == NULL)) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_InitDefaults(PyObject *func, PyTypeObject *defaults_type) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyObject_CallObject((PyObject*)defaults_type, NULL); // _PyObject_New(defaults_type);
    if (unlikely(!m->defaults))
        return NULL;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

/* CythonFunction */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    PyObject *op = __Pyx_CyFunction_Init(
        PyObject_GC_New(__pyx_CyFunctionObject, __pyx_mstate_global->__pyx_CyFunctionType),
        ml, flags, qualname, closure, module, globals, code
    );
    if (likely(op)) {
        PyObject_GC_Track(op);
    }
    return op;
}

/* GetModuleGlobalName */
#include "src/gevent/_generated_include/GetModuleGlobalName_impl_b2394fa294c641220c991c48f5c953347ba392e1233755a6228b28d5e679fef0.h"
/* PyObjectSetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
    return PyObject_SetAttr(obj, attr_name, value);
}
#endif

/* GetNameInClass */
static PyObject *__Pyx__GetNameInClass(PyObject *nmspace, PyObject *name) {
    PyObject *result;
    PyObject *dict;
    assert(PyType_Check(nmspace));
#if CYTHON_USE_TYPE_SLOTS
    dict = ((PyTypeObject*)nmspace)->tp_dict;
    Py_XINCREF(dict);
#else
    dict = PyObject_GetAttr(nmspace, __pyx_mstate_global->__pyx_n_u_dict);
#endif
    if (likely(dict)) {
        result = PyObject_GetItem(dict, name);
        Py_DECREF(dict);
        if (result) {
            return result;
        }
    }
    PyErr_Clear();
    __Pyx_GetModuleGlobalNameUncached(result, name);
    return result;
}

/* GetAttr (used by Globals) */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *o, PyObject *n) {
#if CYTHON_USE_TYPE_SLOTS
    if (likely(PyUnicode_Check(n)))
        return __Pyx_PyObject_GetAttrStr(o, n);
#endif
    return PyObject_GetAttr(o, n);
}

/* Globals */
static PyObject* __Pyx_Globals(void) {
    return __Pyx_NewRef(__pyx_mstate_global->__pyx_d);
}

/* CLineInTraceback (used by AddTraceback) */
#if CYTHON_CLINE_IN_TRACEBACK && CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
#define __Pyx_PyProbablyModule_GetDict(o) __Pyx_XNewRef(PyModule_GetDict(o))
#elif !CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyProbablyModule_GetDict(o) PyObject_GenericGetDict(o, NULL);
#else
PyObject* __Pyx_PyProbablyModule_GetDict(PyObject *o) {
    PyObject **dict_ptr = _PyObject_GetDictPtr(o);
    return dict_ptr ? __Pyx_XNewRef(*dict_ptr) : NULL;
}
#endif
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line) {
    PyObject *use_cline = NULL;
    PyObject *ptype, *pvalue, *ptraceback;
    PyObject *cython_runtime_dict;
    CYTHON_MAYBE_UNUSED_VAR(tstate);
    if (unlikely(!__pyx_mstate_global->__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
    cython_runtime_dict = __Pyx_PyProbablyModule_GetDict(__pyx_mstate_global->__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, cython_runtime_dict,
            __Pyx_PyDict_SetDefault(cython_runtime_dict, __pyx_mstate_global->__pyx_n_u_cline_in_traceback, Py_False))
    }
    if (use_cline == NULL || use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    Py_XDECREF(use_cline);
    Py_XDECREF(cython_runtime_dict);
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache (used by AddTraceback) */
#include "src/gevent/_generated_include/CodeObjectCache_impl_ffc81bf87e547a82e6009d64a2466eb1a5f6677afcbab3333a029ea24e45c012.h"
/* AddTraceback */
#include "src/gevent/_generated_include/AddTraceback_impl_5c53b964023228d90bdfcfa91919f5c3c484446268d5ef056f29421d654f5af4.h"
/* CIntFromPyVerify */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntFromPy */
#include "src/gevent/_generated_include/CIntFromPy_impl_ceb8d340f976d387a193f777f2c34549caaafc1e59b58b253b09ec2b16efbddf.h"
/* PyObjectVectorCallKwBuilder (used by CIntToPy) */
#include "src/gevent/_generated_include/PyObjectVectorCallKwBuilder_impl_fd859cdb6cbc3b35f6b10f5733f06af41f621c00f218f3658f8b944bf821c5f8.h"
/* CIntToPy */
#include "src/gevent/_generated_include/CIntToPy_impl_04d273d7fd8d781e47c953336d9035c05b46b928eb9a876491735d34363bfe94.h"
/* CIntToPy */
#include "src/gevent/_generated_include/CIntToPy_impl_3a4503f42bed1a339a5a77cabbacbe22d845586eaf8fe2b8bf391ccbe75ae64a.h"
/* FormatTypeName */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030d0000
static __Pyx_TypeName
__Pyx_PyType_GetFullyQualifiedName(PyTypeObject* tp)
{
    PyObject *module = NULL, *name = NULL, *result = NULL;
    #if __PYX_LIMITED_VERSION_HEX < 0x030b0000
    name = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_mstate_global->__pyx_n_u_qualname);
    #else
    name = PyType_GetQualName(tp);
    #endif
    if (unlikely(name == NULL) || unlikely(!PyUnicode_Check(name))) goto bad;
    module = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_mstate_global->__pyx_n_u_module);
    if (unlikely(module == NULL) || unlikely(!PyUnicode_Check(module))) goto bad;
    if (PyUnicode_CompareWithASCIIString(module, "builtins") == 0) {
        result = name;
        name = NULL;
        goto done;
    }
    result = PyUnicode_FromFormat("%U.%U", module, name);
    if (unlikely(result == NULL)) goto bad;
  done:
    Py_XDECREF(name);
    Py_XDECREF(module);
    return result;
  bad:
    PyErr_Clear();
    if (name) {
        result = name;
        name = NULL;
    } else {
        result = __Pyx_NewRef(__pyx_mstate_global->__pyx_kp_u__5);
    }
    goto done;
}
#endif

/* CIntFromPy */
#include "src/gevent/_generated_include/CIntFromPy_impl_b91de55768d50878c1454209403f531c1ef9ecfc0f5cfff0eb0b925c62c994e2.h"
/* FastTypeChecks */
#include "src/gevent/_generated_include/FastTypeChecks_impl_f9d18941833a215bcf3276e2b6a57d81e032bd85ed1fb021b834da49989898c9.h"
/* GetRuntimeVersion */
#if __PYX_LIMITED_VERSION_HEX < 0x030b0000
void __Pyx_init_runtime_version(void) {
    if (__Pyx_cached_runtime_version == 0) {
        const char* rt_version = Py_GetVersion();
        unsigned long version = 0;
        unsigned long factor = 0x01000000UL;
        unsigned int digit = 0;
        int i = 0;
        while (factor) {
            while ('0' <= rt_version[i] && rt_version[i] <= '9') {
                digit = digit * 10 + (unsigned int) (rt_version[i] - '0');
                ++i;
            }
            version += factor * digit;
            if (rt_version[i] != '.')
                break;
            digit = 0;
            factor >>= 8;
            ++i;
        }
        __Pyx_cached_runtime_version = version;
    }
}
#endif
static unsigned long __Pyx_get_runtime_version(void) {
#if __PYX_LIMITED_VERSION_HEX >= 0x030b0000
    return Py_Version & ~0xFFUL;
#else
    return __Pyx_cached_runtime_version;
#endif
}

/* CheckBinaryVersion */
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer) {
    const unsigned long MAJOR_MINOR = 0xFFFF0000UL;
    if ((rt_version & MAJOR_MINOR) == (ct_version & MAJOR_MINOR))
        return 0;
    if (likely(allow_newer && (rt_version & MAJOR_MINOR) > (ct_version & MAJOR_MINOR)))
        return 1;
    {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compile time Python version %d.%d "
                      "of module '%.100s' "
                      "%s "
                      "runtime version %d.%d",
                       (int) (ct_version >> 24), (int) ((ct_version >> 16) & 0xFF),
                       __Pyx_MODULE_NAME,
                       (allow_newer) ? "was newer than" : "does not match",
                       (int) (rt_version >> 24), (int) ((rt_version >> 16) & 0xFF)
       );
        return PyErr_WarnEx(NULL, message, 1);
    }
}

/* NewCodeObj */
#include "src/gevent/_generated_include/NewCodeObj_impl_a437ae594518b78f515ea800eae13a23abf85c5a9a57d6d2c88c6b9b215ff54c.h"
/* DecompressString */
#include "src/gevent/_generated_include/DecompressString_impl_08916ce6b33dc899db1820b9329c4da53ddc4f977613e2296edf3d94850c4279.h"
#include <string.h>
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s) {
    size_t len = strlen(s);
    if (unlikely(len > (size_t) PY_SSIZE_T_MAX)) {
        PyErr_SetString(PyExc_OverflowError, "byte string is too long");
        return -1;
    }
    return (Py_ssize_t) len;
}
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return __Pyx_PyUnicode_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return PyByteArray_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if CYTHON_COMPILING_IN_LIMITED_API
    {
        const char* result;
        Py_ssize_t unicode_length;
        CYTHON_MAYBE_UNUSED_VAR(unicode_length); // only for __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        #if __PYX_LIMITED_VERSION_HEX < 0x030A0000
        if (unlikely(PyArg_Parse(o, "s#", &result, length) < 0)) return NULL;
        #else
        result = PyUnicode_AsUTF8AndSize(o, length);
        #endif
        #if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        unicode_length = PyUnicode_GetLength(o);
        if (unlikely(unicode_length < 0)) return NULL;
        if (unlikely(unicode_length != *length)) {
            PyUnicode_AsASCIIString(o);
            return NULL;
        }
        #endif
        return result;
    }
#else
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
#endif
}
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
    if (PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
    if (PyByteArray_Check(o)) {
#if (CYTHON_ASSUME_SAFE_SIZE && CYTHON_ASSUME_SAFE_MACROS) || (CYTHON_COMPILING_IN_PYPY && (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE)))
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
#else
        *length = PyByteArray_Size(o);
        if (*length == -1) return NULL;
        return PyByteArray_AsString(o);
#endif
    } else
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_LongWrongResultType(PyObject* result) {
    __Pyx_TypeName result_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(result));
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ").  "
                "The ability to return an instance of a strict subclass of int is deprecated, "
                "and may be removed in a future version of Python.",
                result_type_name)) {
            __Pyx_DECREF_TypeName(result_type_name);
            Py_DECREF(result);
            return NULL;
        }
        __Pyx_DECREF_TypeName(result_type_name);
        return result;
    }
    PyErr_Format(PyExc_TypeError,
                 "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ")",
                 result_type_name);
    __Pyx_DECREF_TypeName(result_type_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Long(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  PyObject *res = NULL;
  if (likely(PyLong_Check(x)))
      return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  if (likely(m && m->nb_int)) {
      res = m->nb_int(x);
  }
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
      res = PyNumber_Long(x);
  }
#endif
  if (likely(res)) {
      if (unlikely(!PyLong_CheckExact(res))) {
          return __Pyx_PyNumber_LongWrongResultType(res);
      }
  }
  else if (!PyErr_Occurred()) {
      PyErr_SetString(PyExc_TypeError,
                      "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(__Pyx_PyLong_IsCompact(b))) {
        return __Pyx_PyLong_CompactValue(b);
    } else {
      const digit* digits = __Pyx_PyLong_Digits(b);
      const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(b);
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyLong_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject* o) {
  if (sizeof(Py_hash_t) == sizeof(Py_ssize_t)) {
    return (Py_hash_t) __Pyx_PyIndex_AsSsize_t(o);
  } else {
    Py_ssize_t ival;
    PyObject *x;
    x = PyNumber_Index(o);
    if (!x) return -1;
    ival = PyLong_AsLong(x);
    Py_DECREF(x);
    return ival;
  }
}
static CYTHON_INLINE PyObject *__Pyx_Owned_Py_None(int b) {
    CYTHON_UNUSED_VAR(b);
    return __Pyx_NewRef(Py_None);
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return __Pyx_NewRef(b ? Py_True: Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyLong_FromSize_t(size_t ival) {
    return PyLong_FromSize_t(ival);
}


/* MultiPhaseInitModuleState */
#include "src/gevent/_generated_include/MultiPhaseInitModuleState_impl_41d512917574f55c289a94dba0e3ef9c60f8de37a71dd41f0dd086494a351cae.h"
/* #### Code section: utility_code_pragmas_end ### */
#ifdef _MSC_VER
#pragma warning( pop )
#endif



/* #### Code section: end ### */
#endif /* Py_PYTHON_H */
