/* Generated by Cython 3.2.4 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "define_macros": [
            [
                "CYTHON_FAST_THREAD_STATE",
                "0"
            ]
        ],
        "depends": [
            "src/gevent/_gevent_c_ident.pxd",
            "src/gevent/_gevent_cgreenlet.pxd",
            "src/gevent/_ident.py"
        ],
        "include_dirs": [
            "/usr/include/python3.14",
            "/usr/include/python3.14",
            "/build/python-gevent/src/python-gevent/deps"
        ],
        "name": "gevent._gevent_cgreenlet",
        "sources": [
            "src/gevent/greenlet.py"
        ]
    },
    "module_name": "gevent._gevent_cgreenlet"
}
END: Cython Metadata */

#ifndef PY_SSIZE_T_CLEAN
#define PY_SSIZE_T_CLEAN
#endif /* PY_SSIZE_T_CLEAN */
/* InitLimitedAPI */
#if defined(Py_LIMITED_API)
  #if !defined(CYTHON_LIMITED_API)
  #define CYTHON_LIMITED_API 1
  #endif
#elif defined(CYTHON_LIMITED_API)
  #ifdef _MSC_VER
  #pragma message ("Limited API usage is enabled with 'CYTHON_LIMITED_API' but 'Py_LIMITED_API' does not define a Python target version. Consider setting 'Py_LIMITED_API' instead.")
  #else
  #warning Limited API usage is enabled with 'CYTHON_LIMITED_API' but 'Py_LIMITED_API' does not define a Python target version. Consider setting 'Py_LIMITED_API' instead.
  #endif
#endif

#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x03080000
    #error Cython requires Python 3.8+.
#else
#define __PYX_ABI_VERSION "3_2_4"
#define CYTHON_HEX_VERSION 0x030204F0
#define CYTHON_FUTURE_DIVISION 1
/* CModulePreamble */
#include "src/gevent/_generated_include/CModulePreamble_impl_67ff8da3bafbaee898fb2680a081f9cf07617f9b80d936bf5254c02966774c38.h"
/* CInitCode */
#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

/* PythonCompatibility */
#include "src/gevent/_generated_include/PythonCompatibility_impl_9f6bc6a154e6d1f4d1d9250f48a0e6d407560d70233eabffbe0fccfe1f684e75.h"
/* MathInitCode */
#if defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)
  #ifndef _USE_MATH_DEFINES
    #define _USE_MATH_DEFINES
  #endif
#endif
#include <math.h>
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#ifndef CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#define CYTHON_CLINE_IN_TRACEBACK_RUNTIME 0
#endif
#ifndef CYTHON_CLINE_IN_TRACEBACK
#define CYTHON_CLINE_IN_TRACEBACK CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#endif
#if CYTHON_CLINE_IN_TRACEBACK
#define __PYX_MARK_ERR_POS(f_index, lineno)  { __pyx_filename = __pyx_f[f_index]; (void) __pyx_filename; __pyx_lineno = lineno; (void) __pyx_lineno; __pyx_clineno = __LINE__; (void) __pyx_clineno; }
#else
#define __PYX_MARK_ERR_POS(f_index, lineno)  { __pyx_filename = __pyx_f[f_index]; (void) __pyx_filename; __pyx_lineno = lineno; (void) __pyx_lineno; (void) __pyx_clineno; }
#endif
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifdef CYTHON_EXTERN_C
    #undef __PYX_EXTERN_C
    #define __PYX_EXTERN_C CYTHON_EXTERN_C
#elif defined(__PYX_EXTERN_C)
    #ifdef _MSC_VER
    #pragma message ("Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.")
    #else
    #warning Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.
    #endif
#else
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__gevent___gevent_cgreenlet
#define __PYX_HAVE_API__gevent___gevent_cgreenlet
/* Early includes */
#include <string.h>
#include <stdio.h>
#include "greenlet/greenlet.h"
#include "_compat.h"
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

#ifdef CYTHON_FREETHREADING_COMPATIBLE
#if CYTHON_FREETHREADING_COMPATIBLE
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_NOT_USED
#else
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_USED
#endif
#else
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_USED
#endif
#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s);
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char*);
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyByteArray_AsString(s) PyByteArray_AS_STRING(s)
#else
    #define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AsString(s))
    #define __Pyx_PyByteArray_AsString(s) PyByteArray_AsString(s)
#endif
#define __Pyx_PyObject_AsWritableString(s)    ((char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
#define __Pyx_PyUnicode_FromOrdinal(o)       PyUnicode_FromOrdinal((int)o)
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
static CYTHON_INLINE PyObject *__Pyx_NewRef(PyObject *obj) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030a0000 || defined(Py_NewRef)
    return Py_NewRef(obj);
#else
    Py_INCREF(obj);
    return obj;
#endif
}
static CYTHON_INLINE PyObject *__Pyx_XNewRef(PyObject *obj) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030a0000 || defined(Py_XNewRef)
    return Py_XNewRef(obj);
#else
    Py_XINCREF(obj);
    return obj;
#endif
}
static CYTHON_INLINE PyObject *__Pyx_Owned_Py_None(int b);
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Long(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyLong_FromSize_t(size_t);
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject*);
#if CYTHON_ASSUME_SAFE_MACROS
#define __Pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#define __Pyx_PyFloat_AS_DOUBLE(x) PyFloat_AS_DOUBLE(x)
#else
#define __Pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#define __Pyx_PyFloat_AS_DOUBLE(x) PyFloat_AsDouble(x)
#endif
#define __Pyx_PyFloat_AsFloat(x) ((float) __Pyx_PyFloat_AsDouble(x))
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_VERSION_HEX >= 0x030C00A7
  #ifndef _PyLong_SIGN_MASK
    #define _PyLong_SIGN_MASK 3
  #endif
  #ifndef _PyLong_NON_SIZE_BITS
    #define _PyLong_NON_SIZE_BITS 3
  #endif
  #define __Pyx_PyLong_Sign(x)  (((PyLongObject*)x)->long_value.lv_tag & _PyLong_SIGN_MASK)
  #define __Pyx_PyLong_IsNeg(x)  ((__Pyx_PyLong_Sign(x) & 2) != 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (!__Pyx_PyLong_IsNeg(x))
  #define __Pyx_PyLong_IsZero(x)  (__Pyx_PyLong_Sign(x) & 1)
  #define __Pyx_PyLong_IsPos(x)  (__Pyx_PyLong_Sign(x) == 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  (__Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  ((Py_ssize_t) (((PyLongObject*)x)->long_value.lv_tag >> _PyLong_NON_SIZE_BITS))
  #define __Pyx_PyLong_SignedDigitCount(x)\
        ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * __Pyx_PyLong_DigitCount(x))
  #if defined(PyUnstable_Long_IsCompact) && defined(PyUnstable_Long_CompactValue)
    #define __Pyx_PyLong_IsCompact(x)     PyUnstable_Long_IsCompact((PyLongObject*) x)
    #define __Pyx_PyLong_CompactValue(x)  PyUnstable_Long_CompactValue((PyLongObject*) x)
  #else
    #define __Pyx_PyLong_IsCompact(x)     (((PyLongObject*)x)->long_value.lv_tag < (2 << _PyLong_NON_SIZE_BITS))
    #define __Pyx_PyLong_CompactValue(x)  ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * (Py_ssize_t) __Pyx_PyLong_Digits(x)[0])
  #endif
  typedef Py_ssize_t  __Pyx_compact_pylong;
  typedef size_t  __Pyx_compact_upylong;
  #else
  #define __Pyx_PyLong_IsNeg(x)  (Py_SIZE(x) < 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (Py_SIZE(x) >= 0)
  #define __Pyx_PyLong_IsZero(x)  (Py_SIZE(x) == 0)
  #define __Pyx_PyLong_IsPos(x)  (Py_SIZE(x) > 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  ((Py_SIZE(x) == 0) ? 0 : __Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  __Pyx_sst_abs(Py_SIZE(x))
  #define __Pyx_PyLong_SignedDigitCount(x)  Py_SIZE(x)
  #define __Pyx_PyLong_IsCompact(x)  (Py_SIZE(x) == 0 || Py_SIZE(x) == 1 || Py_SIZE(x) == -1)
  #define __Pyx_PyLong_CompactValue(x)\
        ((Py_SIZE(x) == 0) ? (sdigit) 0 : ((Py_SIZE(x) < 0) ? -(sdigit)__Pyx_PyLong_Digits(x)[0] : (sdigit)__Pyx_PyLong_Digits(x)[0]))
  typedef sdigit  __Pyx_compact_pylong;
  typedef digit  __Pyx_compact_upylong;
  #endif
  #if PY_VERSION_HEX >= 0x030C00A5
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->long_value.ob_digit)
  #else
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->ob_digit)
  #endif
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#elif __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeASCII(c_str, size, NULL)
#else
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
/* PretendToInitialize */
#ifdef __cplusplus
#if __cplusplus > 201103L
#include <type_traits>
#endif
template <typename T>
static void __Pyx_pretend_to_initialize(T* ptr) {
#if __cplusplus > 201103L
    if ((std::is_trivially_default_constructible<T>::value))
#endif
        *ptr = T();
    (void)ptr;
}
#else
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }
#endif


#if !CYTHON_USE_MODULE_STATE
static PyObject *__pyx_m = NULL;
#endif
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * const __pyx_cfilenm = __FILE__;
static const char *__pyx_filename;

/* #### Code section: filename_table ### */

static const char* const __pyx_f[] = {
  "src/gevent/greenlet.py",
  "cfunc.to_py",
  "src/gevent/_gevent_c_greenlet_primitives.pxd",
  "src/gevent/_gevent_c_waiter.pxd",
  "src/gevent/_gevent_cgreenlet.pxd",
  "cpython/type.pxd",
  "src/gevent/_gevent_c_ident.pxd",
};
/* #### Code section: utility_code_proto_before_types ### */
/* Atomics.proto (used by UnpackUnboundCMethod) */
#include "src/gevent/_generated_include/Atomics_proto_3c6d386cad499e8bf66734864569013c6cb59adf2353bb94c6c6798eea3c07cc.h"
/* CriticalSectionsDefinition.proto (used by CriticalSections) */
#if !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyCriticalSection void*
#define __Pyx_PyCriticalSection2 void*
#define __Pyx_PyCriticalSection_End(cs)
#define __Pyx_PyCriticalSection2_End(cs)
#else
#define __Pyx_PyCriticalSection PyCriticalSection
#define __Pyx_PyCriticalSection2 PyCriticalSection2
#define __Pyx_PyCriticalSection_End PyCriticalSection_End
#define __Pyx_PyCriticalSection2_End PyCriticalSection2_End
#endif

/* CriticalSections.proto (used by ParseKeywordsImpl) */
#if !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyCriticalSection_Begin(cs, arg) (void)(cs)
#define __Pyx_PyCriticalSection2_Begin(cs, arg1, arg2) (void)(cs)
#else
#define __Pyx_PyCriticalSection_Begin PyCriticalSection_Begin
#define __Pyx_PyCriticalSection2_Begin PyCriticalSection2_Begin
#endif
#if PY_VERSION_HEX < 0x030d0000 || CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_BEGIN_CRITICAL_SECTION(o) {
#define __Pyx_END_CRITICAL_SECTION() }
#else
#define __Pyx_BEGIN_CRITICAL_SECTION Py_BEGIN_CRITICAL_SECTION
#define __Pyx_END_CRITICAL_SECTION Py_END_CRITICAL_SECTION
#endif

/* IncludeStructmemberH.proto (used by FixUpExtensionType) */
#include <structmember.h>

/* #### Code section: numeric_typedefs ### */
/* #### Code section: complex_type_declarations ### */
/* #### Code section: type_declarations ### */

/*--- Type declarations ---*/
struct __pyx_obj_6gevent_15_gevent_c_ident_ValuedWeakRef;
struct __pyx_obj_6gevent_15_gevent_c_ident_IdentRegistry;
struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet;
struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop;
struct __pyx_obj_6gevent_16_gevent_c_waiter_Waiter;
struct __pyx_obj_6gevent_16_gevent_c_waiter_MultipleWaiter;
struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink;
struct __pyx_obj_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink;
struct __pyx_obj_6gevent_17_gevent_cgreenlet_FailureSpawnedLink;
struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame;
struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet;
struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event;
struct __pyx_defaults;
struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter;
struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception;
struct __pyx_opt_args_6gevent_17_gevent_cgreenlet_8Greenlet_join;
struct __pyx_opt_args_6gevent_17_gevent_cgreenlet_8Greenlet_kill;
struct __pyx_opt_args_6gevent_17_gevent_cgreenlet_joinall;

/* "gevent/_gevent_cgreenlet.pxd":72
 *         _greenlet_imported = True
 * 
 * ctypedef object CodeType             # <<<<<<<<<<<<<<
 * ctypedef object FrameType
 * 
*/
typedef PyObject *__pyx_t_6gevent_17_gevent_cgreenlet_CodeType;

/* "gevent/_gevent_cgreenlet.pxd":73
 * 
 * ctypedef object CodeType
 * ctypedef object FrameType             # <<<<<<<<<<<<<<
 * 
 * cdef extern from "_compat.h":
*/
typedef PyObject *__pyx_t_6gevent_17_gevent_cgreenlet_FrameType;

/* "gevent/_gevent_cgreenlet.pxd":144
 * 
 *     cpdef bint has_links(self)
 *     cpdef join(self, timeout=*)             # <<<<<<<<<<<<<<
 *     cpdef kill(self, exception=*, block=*, timeout=*)
 *     cpdef bint ready(self)
*/
struct __pyx_opt_args_6gevent_17_gevent_cgreenlet_8Greenlet_join {
  int __pyx_n;
  PyObject *timeout;
};

/* "gevent/_gevent_cgreenlet.pxd":145
 *     cpdef bint has_links(self)
 *     cpdef join(self, timeout=*)
 *     cpdef kill(self, exception=*, block=*, timeout=*)             # <<<<<<<<<<<<<<
 *     cpdef bint ready(self)
 *     cpdef bint successful(self)
*/
struct __pyx_opt_args_6gevent_17_gevent_cgreenlet_8Greenlet_kill {
  int __pyx_n;
  PyObject *exception;
  PyObject *block;
  PyObject *timeout;
};

/* "gevent/_gevent_cgreenlet.pxd":219
 * 
 * @cython.locals(done=list)
 * cpdef joinall(greenlets, timeout=*, raise_error=*, count=*)             # <<<<<<<<<<<<<<
 * 
 * cdef set _spawn_callbacks
*/
struct __pyx_opt_args_6gevent_17_gevent_cgreenlet_joinall {
  int __pyx_n;
  PyObject *timeout;
  PyObject *raise_error;
  PyObject *count;
};

/* "gevent/_gevent_c_ident.pxd":13
 * cdef type ref
 * 
 * @cython.internal             # <<<<<<<<<<<<<<
 * @cython.final
 * cdef class ValuedWeakRef(ref):
*/
struct __pyx_obj_6gevent_15_gevent_c_ident_ValuedWeakRef {
  PyWeakReference __pyx_base;
  PyObject *value;
};


/* "gevent/_gevent_c_ident.pxd":18
 *     cdef object value
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class IdentRegistry:
 *     cdef object _registry
*/
struct __pyx_obj_6gevent_15_gevent_c_ident_IdentRegistry {
  PyObject_HEAD
  struct __pyx_vtabstruct_6gevent_15_gevent_c_ident_IdentRegistry *__pyx_vtab;
  PyObject *_registry;
  PyObject *_available_idents;
};


/* "gevent/_gevent_c_greenlet_primitives.pxd":37
 *     return PyGreenlet_Switch(self, NULL, NULL)
 * 
 * cdef class TrackedRawGreenlet(greenlet):             # <<<<<<<<<<<<<<
 *     pass
 * 
*/
struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet {
  PyGreenlet __pyx_base;
};


/* "gevent/_gevent_c_greenlet_primitives.pxd":40
 *     pass
 * 
 * cdef class SwitchOutGreenletWithLoop(TrackedRawGreenlet):             # <<<<<<<<<<<<<<
 *     cdef public loop
 * 
*/
struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop {
  struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet __pyx_base;
  struct __pyx_vtabstruct_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *__pyx_vtab;
  PyObject *loop;
};


/* "gevent/_gevent_c_waiter.pxd":33
 *         _greenlet_imported = True
 * 
 * cdef class Waiter:             # <<<<<<<<<<<<<<
 *     cdef readonly SwitchOutGreenletWithLoop hub
 *     cdef readonly greenlet greenlet
*/
struct __pyx_obj_6gevent_16_gevent_c_waiter_Waiter {
  PyObject_HEAD
  struct __pyx_vtabstruct_6gevent_16_gevent_c_waiter_Waiter *__pyx_vtab;
  struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *hub;
  PyGreenlet *greenlet;
  PyObject *value;
  PyObject *_exception;
};


/* "gevent/_gevent_c_waiter.pxd":45
 *     #cpdef switch(self, value)
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * @cython.internal
 * cdef class MultipleWaiter(Waiter):
*/
struct __pyx_obj_6gevent_16_gevent_c_waiter_MultipleWaiter {
  struct __pyx_obj_6gevent_16_gevent_c_waiter_Waiter __pyx_base;
  PyObject *_values;
};


/* "gevent/_gevent_cgreenlet.pxd":100
 * cdef void _init()
 * 
 * cdef class SpawnedLink:             # <<<<<<<<<<<<<<
 *     cdef public object callback
 * 
*/
struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink {
  PyObject_HEAD
  PyObject *callback;
};


/* "gevent/_gevent_cgreenlet.pxd":104
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class SuccessSpawnedLink(SpawnedLink):
 *     pass
*/
struct __pyx_obj_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink {
  struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink __pyx_base;
};


/* "gevent/_gevent_cgreenlet.pxd":108
 *     pass
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class FailureSpawnedLink(SpawnedLink):
 *     pass
*/
struct __pyx_obj_6gevent_17_gevent_cgreenlet_FailureSpawnedLink {
  struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink __pyx_base;
};


/* "gevent/_gevent_cgreenlet.pxd":112
 *     pass
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * @cython.internal
 * @cython.freelist(1000)
*/
struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame {
  PyObject_HEAD
  __pyx_t_6gevent_17_gevent_cgreenlet_CodeType f_code;
  int f_lineno;
  struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *f_back;
};


/* "gevent/_gevent_cgreenlet.pxd":128
 * cdef _Frame _extract_stack(int limit)
 * 
 * cdef class Greenlet(greenlet):             # <<<<<<<<<<<<<<
 *     cdef readonly object value
 *     cdef readonly tuple args
*/
struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet {
  PyGreenlet __pyx_base;
  struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_vtab;
  PyObject *value;
  PyObject *args;
  PyObject *kwargs;
  PyObject *spawning_greenlet;
  struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *spawning_stack;
  PyObject *spawn_tree_locals;
  PyObject *_links;
  PyObject *_exc_info;
  PyObject *_notifier;
  PyObject *_start_event;
  PyObject *_formatted_info;
  PyObject *_ident;
};


/* "gevent/_gevent_cgreenlet.pxd":199
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * @cython.internal
 * cdef class _dummy_event:
*/
struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event {
  PyObject_HEAD
  struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet__dummy_event *__pyx_vtab;
  int pending;
  int active;
};


/* "src/gevent/greenlet.py":1129
 * 
 * 
 * def killall(greenlets, exception=GreenletExit, block=True, timeout=None):             # <<<<<<<<<<<<<<
 *     """
 *     Forceably terminate all the *greenlets* by causing them to raise *exception*.
*/
struct __pyx_defaults {
  PyObject_HEAD
  PyObject *arg0;
};


/* "cfunc.to_py":65
 * 
 * 
 * @cname("__Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter")             # <<<<<<<<<<<<<<
 * cdef object __Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter(object (*f)(list, object, object) ):
 *     def wrap(list greenlets, object exception, object waiter):
*/
struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter {
  PyObject_HEAD
  PyObject *(*__pyx_v_f)(PyObject *, PyObject *, PyObject *);
};

struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception {
  PyObject_HEAD
  PyObject *(*__pyx_v_f)(PyObject *, PyObject *);
};



/* "gevent/_gevent_c_ident.pxd":18
 *     cdef object value
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class IdentRegistry:
 *     cdef object _registry
*/

struct __pyx_vtabstruct_6gevent_15_gevent_c_ident_IdentRegistry {
  PyObject *(*get_ident)(struct __pyx_obj_6gevent_15_gevent_c_ident_IdentRegistry *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*_return_ident)(struct __pyx_obj_6gevent_15_gevent_c_ident_IdentRegistry *, struct __pyx_obj_6gevent_15_gevent_c_ident_ValuedWeakRef *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6gevent_15_gevent_c_ident_IdentRegistry *__pyx_vtabptr_6gevent_15_gevent_c_ident_IdentRegistry;


/* "gevent/_gevent_c_greenlet_primitives.pxd":40
 *     pass
 * 
 * cdef class SwitchOutGreenletWithLoop(TrackedRawGreenlet):             # <<<<<<<<<<<<<<
 *     cdef public loop
 * 
*/

struct __pyx_vtabstruct_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop {
  PyObject *(*__pyx_switch)(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *, int __pyx_skip_dispatch);
  PyObject *(*switch_out)(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *__pyx_vtabptr_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop;


/* "gevent/_gevent_c_waiter.pxd":33
 *         _greenlet_imported = True
 * 
 * cdef class Waiter:             # <<<<<<<<<<<<<<
 *     cdef readonly SwitchOutGreenletWithLoop hub
 *     cdef readonly greenlet greenlet
*/

struct __pyx_vtabstruct_6gevent_16_gevent_c_waiter_Waiter {
  PyObject *(*get)(struct __pyx_obj_6gevent_16_gevent_c_waiter_Waiter *, int __pyx_skip_dispatch);
  PyObject *(*clear)(struct __pyx_obj_6gevent_16_gevent_c_waiter_Waiter *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6gevent_16_gevent_c_waiter_Waiter *__pyx_vtabptr_6gevent_16_gevent_c_waiter_Waiter;


/* "gevent/_gevent_c_waiter.pxd":45
 *     #cpdef switch(self, value)
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * @cython.internal
 * cdef class MultipleWaiter(Waiter):
*/

struct __pyx_vtabstruct_6gevent_16_gevent_c_waiter_MultipleWaiter {
  struct __pyx_vtabstruct_6gevent_16_gevent_c_waiter_Waiter __pyx_base;
};
static struct __pyx_vtabstruct_6gevent_16_gevent_c_waiter_MultipleWaiter *__pyx_vtabptr_6gevent_16_gevent_c_waiter_MultipleWaiter;


/* "src/gevent/greenlet.py":177
 * _greenlet__init__ = greenlet.__init__
 * 
 * class Greenlet(greenlet):             # <<<<<<<<<<<<<<
 *     """
 *     A light-weight cooperatively-scheduled execution unit.
*/

struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet {
  int (*has_links)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, int __pyx_skip_dispatch);
  PyObject *(*join)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, int __pyx_skip_dispatch, struct __pyx_opt_args_6gevent_17_gevent_cgreenlet_8Greenlet_join *__pyx_optional_args);
  PyObject *(*kill)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, int __pyx_skip_dispatch, struct __pyx_opt_args_6gevent_17_gevent_cgreenlet_8Greenlet_kill *__pyx_optional_args);
  int (*ready)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, int __pyx_skip_dispatch);
  int (*successful)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, int __pyx_skip_dispatch);
  PyObject *(*rawlink)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*_formatinfo)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, int __pyx_skip_dispatch);
  int (*_maybe_kill_before_start)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*_get_minimal_ident)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *);
  int (*_Greenlet__started_but_aborted)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *);
  int (*_Greenlet__start_cancelled_by_kill)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *);
  int (*_Greenlet__start_pending)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *);
  int (*_Greenlet__never_started_or_killed)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *);
  int (*_Greenlet__start_completed)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *);
  PyObject *(*_Greenlet__handle_death_before_start)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, PyObject *);
  void (*_Greenlet__free)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *);
  PyObject *(*_Greenlet__cancel_start)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *);
  PyObject *(*_Greenlet__report_result)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, PyObject *);
  PyObject *(*_Greenlet__report_error)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, PyObject *);
  PyObject *(*_notify_links)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_vtabptr_6gevent_17_gevent_cgreenlet_Greenlet;
static CYTHON_INLINE void __pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__Greenlet__free(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *);
static CYTHON_INLINE PyObject *__pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__Greenlet__report_result(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, PyObject *);
static CYTHON_INLINE PyObject *__pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__Greenlet__report_error(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, PyObject *);


/* "src/gevent/greenlet.py":1035
 * 
 * 
 * class _dummy_event(object):             # <<<<<<<<<<<<<<
 *     __slots__ = ('pending', 'active')
 * 
*/

struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet__dummy_event {
  PyObject *(*stop)(struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *, int __pyx_skip_dispatch);
  PyObject *(*start)(struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*close)(struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet__dummy_event *__pyx_vtabptr_6gevent_17_gevent_cgreenlet__dummy_event;
static PyObject *__pyx_f_6gevent_17_gevent_cgreenlet_12_dummy_event_stop(struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *, int __pyx_skip_dispatch);
static PyObject *__pyx_f_6gevent_17_gevent_cgreenlet_12_dummy_event_start(struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *, PyObject *, int __pyx_skip_dispatch);
static PyObject *__pyx_f_6gevent_17_gevent_cgreenlet_12_dummy_event_close(struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *, int __pyx_skip_dispatch);
/* #### Code section: utility_code_proto ### */

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#include "src/gevent/_generated_include/Refnanny_proto_00d2ab1aa529311d487a88a16574063b4d3b8ffa11a25109d76165964b208920.h"
/* PyErrExceptionMatches.proto (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* PyThreadStateGet.proto (used by PyErrFetchRestore) */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#if PY_VERSION_HEX >= 0x030C00A6
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->current_exception != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->current_exception ? (PyObject*) Py_TYPE(__pyx_tstate->current_exception) : (PyObject*) NULL)
#else
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->curexc_type != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->curexc_type)
#endif
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  (PyErr_Occurred() != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto (used by PyObjectGetAttrStrNoError) */
#include "src/gevent/_generated_include/PyErrFetchRestore_proto_b219ba96ee79f73e7240a9715dc835e7e817ccd9f4f99ab4145b09780817bd8a.h"
/* PyObjectGetAttrStr.proto (used by PyObjectGetAttrStrNoError) */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* PyObjectGetAttrStrNoError.proto (used by GetBuiltinName) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name);

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* TupleAndListFromArray.proto (used by fastcall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n);
#endif
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject* __Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n);
#endif

/* IncludeStringH.proto (used by BytesEquals) */
#include <string.h>

/* BytesEquals.proto (used by UnicodeEquals) */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto (used by fastcall) */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* fastcall.proto */
#include "src/gevent/_generated_include/fastcall_proto_66690a1464eb22fa574c56237a11be9953f14c69fdee2df9c4141aa9c5e2a76d.h"
/* py_dict_items.proto (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Items(PyObject* d);

/* CallCFunction.proto (used by CallUnboundCMethod0) */
#define __Pyx_CallCFunction(cfunc, self, args)\
    ((PyCFunction)(void(*)(void))(cfunc)->func)(self, args)
#define __Pyx_CallCFunctionWithKeywords(cfunc, self, args, kwargs)\
    ((PyCFunctionWithKeywords)(void(*)(void))(cfunc)->func)(self, args, kwargs)
#define __Pyx_CallCFunctionFast(cfunc, self, args, nargs)\
    ((__Pyx_PyCFunctionFast)(void(*)(void))(PyCFunction)(cfunc)->func)(self, args, nargs)
#define __Pyx_CallCFunctionFastWithKeywords(cfunc, self, args, nargs, kwnames)\
    ((__Pyx_PyCFunctionFastWithKeywords)(void(*)(void))(PyCFunction)(cfunc)->func)(self, args, nargs, kwnames)

/* PyObjectCall.proto (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyObjectCallMethO.proto (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectFastCall.proto (used by PyObjectCallOneArg) */
#define __Pyx_PyObject_FastCall(func, args, nargs)  __Pyx_PyObject_FastCallDict(func, args, (size_t)(nargs), NULL)
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject * const*args, size_t nargs, PyObject *kwargs);

/* PyObjectCallOneArg.proto (used by CallUnboundCMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* UnpackUnboundCMethod.proto (used by CallUnboundCMethod0) */
typedef struct {
    PyObject *type;
    PyObject **method_name;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && CYTHON_ATOMICS
    __pyx_atomic_int_type initialized;
#endif
    PyCFunction func;
    PyObject *method;
    int flag;
} __Pyx_CachedCFunction;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
static CYTHON_INLINE int __Pyx_CachedCFunction_GetAndSetInitializing(__Pyx_CachedCFunction *cfunc) {
#if !CYTHON_ATOMICS
    return 1;
#else
    __pyx_nonatomic_int_type expected = 0;
    if (__pyx_atomic_int_cmp_exchange(&cfunc->initialized, &expected, 1)) {
        return 0;
    }
    return expected;
#endif
}
static CYTHON_INLINE void __Pyx_CachedCFunction_SetFinishedInitializing(__Pyx_CachedCFunction *cfunc) {
#if CYTHON_ATOMICS
    __pyx_atomic_store(&cfunc->initialized, 2);
#endif
}
#else
#define __Pyx_CachedCFunction_GetAndSetInitializing(cfunc) 2
#define __Pyx_CachedCFunction_SetFinishedInitializing(cfunc)
#endif

/* CallUnboundCMethod0.proto */
CYTHON_UNUSED
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#else
#define __Pyx_CallUnboundCMethod0(cfunc, self)  __Pyx__CallUnboundCMethod0(cfunc, self)
#endif

/* py_dict_values.proto (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Values(PyObject* d);

/* OwnedDictNext.proto (used by ParseKeywordsImpl) */
#if CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, PyObject **ppos, PyObject **pkey, PyObject **pvalue);
#else
CYTHON_INLINE
static int __Pyx_PyDict_NextRef(PyObject *p, Py_ssize_t *ppos, PyObject **pkey, PyObject **pvalue);
#endif

/* RaiseDoubleKeywords.proto (used by ParseKeywordsImpl) */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywordsImpl.export */
static int __Pyx_ParseKeywordsTuple(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);
static int __Pyx_ParseKeywordDictToDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name
);
static int __Pyx_ParseKeywordDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);

/* CallUnboundCMethod2.proto */
CYTHON_UNUSED
static PyObject* __Pyx__CallUnboundCMethod2(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg1, PyObject* arg2);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject *__Pyx_CallUnboundCMethod2(__Pyx_CachedCFunction *cfunc, PyObject *self, PyObject *arg1, PyObject *arg2);
#else
#define __Pyx_CallUnboundCMethod2(cfunc, self, arg1, arg2)  __Pyx__CallUnboundCMethod2(cfunc, self, arg1, arg2)
#endif

/* ParseKeywords.proto */
static CYTHON_INLINE int __Pyx_ParseKeywords(
    PyObject *kwds, PyObject *const *kwvalues, PyObject ** const argnames[],
    PyObject *kwds2, PyObject *values[],
    Py_ssize_t num_pos_args, Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* ArgTypeTestFunc.export */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact);

/* ArgTypeTest.proto */
#define __Pyx_ArgTypeTest(obj, type, none_allowed, name, exact)\
    ((likely(__Pyx_IS_TYPE(obj, type) | (none_allowed && (obj == Py_None)))) ? 1 :\
        __Pyx__ArgTypeTest(obj, type, name, exact))

/* dict_setdefault.proto (used by FetchCommonType) */
static CYTHON_INLINE PyObject *__Pyx_PyDict_SetDefault(PyObject *d, PyObject *key, PyObject *default_value);

/* LimitedApiGetTypeDict.proto (used by SetItemOnTypeDict) */
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_GetTypeDict(PyTypeObject *tp);
#endif

/* SetItemOnTypeDict.proto (used by FixUpExtensionType) */
static int __Pyx__SetItemOnTypeDict(PyTypeObject *tp, PyObject *k, PyObject *v);
#define __Pyx_SetItemOnTypeDict(tp, k, v) __Pyx__SetItemOnTypeDict((PyTypeObject*)tp, k, v)

/* FixUpExtensionType.proto (used by FetchCommonType) */
static CYTHON_INLINE int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type);

/* AddModuleRef.proto (used by FetchSharedCythonModule) */
#if ((CYTHON_COMPILING_IN_CPYTHON_FREETHREADING ) ||\
     __PYX_LIMITED_VERSION_HEX < 0x030d0000)
  static PyObject *__Pyx_PyImport_AddModuleRef(const char *name);
#else
  #define __Pyx_PyImport_AddModuleRef(name) PyImport_AddModuleRef(name)
#endif

/* FetchSharedCythonModule.proto (used by FetchCommonType) */
static PyObject *__Pyx_FetchSharedCythonABIModule(void);

/* FetchCommonType.proto (used by CommonTypesMetaclass) */
static PyTypeObject* __Pyx_FetchCommonTypeFromSpec(PyTypeObject *metaclass, PyObject *module, PyType_Spec *spec, PyObject *bases);

/* CommonTypesMetaclass.proto (used by CythonFunctionShared) */
static int __pyx_CommonTypesMetaclass_init(PyObject *module);
#define __Pyx_CommonTypesMetaclass_USED

/* CallTypeTraverse.proto (used by CythonFunctionShared) */
#if !CYTHON_USE_TYPE_SPECS || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x03090000)
#define __Pyx_call_type_traverse(o, always_call, visit, arg) 0
#else
static int __Pyx_call_type_traverse(PyObject *o, int always_call, visitproc visit, void *arg);
#endif

/* PyMethodNew.proto (used by CythonFunctionShared) */
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ);

/* PyVectorcallFastCallDict.proto (used by CythonFunctionShared) */
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw);
#endif

/* CythonFunctionShared.proto (used by CythonFunction) */
#include "src/gevent/_generated_include/CythonFunctionShared_proto_cfd16e7b1cdcce8e6454094d94c7459b788326000c3b790f09af3662926ca152.h"
/* CythonFunction.proto */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);

/* ExtTypeTest.proto */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type);

/* CallableCheck.proto */
#if CYTHON_USE_TYPE_SLOTS && !CYTHON_COMPILING_IN_PYPY
#define __Pyx_PyCallable_Check(obj)   (Py_TYPE(obj)->tp_call != NULL)
#else
#define __Pyx_PyCallable_Check(obj)   PyCallable_Check(obj)
#endif

/* PyTypeError_Check.proto */
#define __Pyx_PyExc_TypeError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_TypeError)

/* PyObjectFormatAndDecref.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatSimpleAndDecref(PyObject* s, PyObject* f);
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatAndDecref(PyObject* s, PyObject* f);

/* RaiseException.export */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* PyObjectFastCallMethod.proto */
#if CYTHON_VECTORCALL && PY_VERSION_HEX >= 0x03090000
#define __Pyx_PyObject_FastCallMethod(name, args, nargsf) PyObject_VectorcallMethod(name, args, nargsf, NULL)
#else
static PyObject *__Pyx_PyObject_FastCallMethod(PyObject *name, PyObject *const *args, size_t nargsf);
#endif

/* GetAttr3.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *, PyObject *, PyObject *);

/* PyObject_Unicode.proto */
#define __Pyx_PyObject_Unicode(obj)\
    (likely(PyUnicode_CheckExact(obj)) ? __Pyx_NewRef(obj) : PyObject_Str(obj))

/* AssertionsEnabled.proto */
#if CYTHON_COMPILING_IN_LIMITED_API  ||  PY_VERSION_HEX >= 0x030C0000
  static int __pyx_assertions_enabled_flag;
  #define __pyx_assertions_enabled() (__pyx_assertions_enabled_flag)
  #if __clang__ || __GNUC__
  __attribute__((no_sanitize("thread")))
  #endif
  static int __Pyx_init_assertions_enabled(void) {
    PyObject *builtins, *debug, *debug_str;
    int flag;
    builtins = PyEval_GetBuiltins();
    if (!builtins) goto bad;
    debug_str = PyUnicode_FromStringAndSize("__debug__", 9);
    if (!debug_str) goto bad;
    debug = PyObject_GetItem(builtins, debug_str);
    Py_DECREF(debug_str);
    if (!debug) goto bad;
    flag = PyObject_IsTrue(debug);
    Py_DECREF(debug);
    if (flag == -1) goto bad;
    __pyx_assertions_enabled_flag = flag;
    return 0;
  bad:
    __pyx_assertions_enabled_flag = 1;
    return -1;
  }
#else
  #define __Pyx_init_assertions_enabled()  (0)
  #define __pyx_assertions_enabled()  (!Py_OptimizeFlag)
#endif

/* PyAssertionError_Check.proto */
#define __Pyx_PyExc_AssertionError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_AssertionError)

/* GetAttr.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *, PyObject *);

/* RejectKeywords.export */
static void __Pyx_RejectKeywords(const char* function_name, PyObject *kwds);

/* GetTopmostException.proto (used by SaveResetException) */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem * __Pyx_PyErr_GetTopmostException(PyThreadState *tstate);
#endif

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* PyValueError_Check.proto */
#define __Pyx_PyExc_ValueError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_ValueError)

/* PyObjectDelAttr.proto (used by PyObjectSetAttrStr) */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030d0000
#define __Pyx_PyObject_DelAttr(o, n) PyObject_SetAttr(o, n, NULL)
#else
#define __Pyx_PyObject_DelAttr(o, n) PyObject_DelAttr(o, n)
#endif

/* PyObjectSetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o, n, NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value);
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   __Pyx_PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

/* RaiseUnexpectedTypeError.proto */
static int __Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj);

/* PyAttributeError_Check.proto */
#define __Pyx_PyExc_AttributeError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_AttributeError)

/* GetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_GetException(type, value, tb)  __Pyx__GetException(__pyx_tstate, type, value, tb)
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* GetItemInt.proto */
#include "src/gevent/_generated_include/GetItemInt_proto_3b42f7f7de85b71eab2f8b6ae51ddc7168a53d31d56dd1f1e34c94c36c959f55.h"
/* PyDictVersioning.proto */
#include "src/gevent/_generated_include/PyDictVersioning_proto_fc9ab32633f390bb88d05edfc7599e60bc4df8ea122afe432e3adec504912045.h"
/* PySequenceContains.proto */
static CYTHON_INLINE int __Pyx_PySequence_ContainsTF(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* JoinPyUnicode.export */
static PyObject* __Pyx_PyUnicode_Join(PyObject** values, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char);

/* PyUnicode_Unicode.proto */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Unicode(PyObject *obj);

/* PyNumber_Hex.proto */
#define __Pyx_PyNumber_Hex(obj) PyNumber_ToBase((obj), 16)

/* UnicodeConcatInPlace.proto */
#include "src/gevent/_generated_include/UnicodeConcatInPlace_proto_bad23f3f25a1a5b795c7c8780db690b4ca025f6fa980d8798c511f0283aef257.h"
/* ListCompAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_ListComp_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len)) {
        Py_INCREF(x);
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
        L->ob_item[len] = x;
        #else
        PyList_SET_ITEM(list, len, x);
        #endif
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_ListComp_Append(L,x) PyList_Append(L,x)
#endif

/* PyUnicode_Substring.proto */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Substring(
            PyObject* text, Py_ssize_t start, Py_ssize_t stop);

/* ListExtend.proto */
static CYTHON_INLINE int __Pyx_PyList_Extend(PyObject* L, PyObject* v) {
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00a2
    return PyList_Extend(L, v);
#elif CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000
    PyObject* none = _PyList_Extend((PyListObject*)L, v);
    if (unlikely(!none))
        return -1;
    Py_DECREF(none);
    return 0;
#else
    return PyList_SetSlice(L, PY_SSIZE_T_MAX, PY_SSIZE_T_MAX, v);
#endif
}

/* IterFinish.proto (used by dict_iter) */
static CYTHON_INLINE int __Pyx_IterFinish(void);

/* PyObjectCallNoArg.proto (used by PyObjectCallMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);

/* PyObjectGetMethod.proto (used by PyObjectCallMethod0) */
#if !(CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000)))
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method);
#endif

/* PyObjectCallMethod0.proto (used by dict_iter) */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name);

/* RaiseNeedMoreValuesToUnpack.proto (used by UnpackTuple2) */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

/* RaiseTooManyValuesToUnpack.proto (used by UnpackItemEndCheck) */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

/* UnpackItemEndCheck.proto (used by UnpackTuple2) */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected);

/* RaiseNoneIterError.proto (used by UnpackTupleError) */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void);

/* UnpackTupleError.proto (used by UnpackTuple2) */
static void __Pyx_UnpackTupleError(PyObject *, Py_ssize_t index);

/* UnpackTuple2.proto (used by dict_iter) */
static CYTHON_INLINE int __Pyx_unpack_tuple2(
    PyObject* tuple, PyObject** value1, PyObject** value2, int is_tuple, int has_known_size, int decref_tuple);
static CYTHON_INLINE int __Pyx_unpack_tuple2_exact(
    PyObject* tuple, PyObject** value1, PyObject** value2, int decref_tuple);
static int __Pyx_unpack_tuple2_generic(
    PyObject* tuple, PyObject** value1, PyObject** value2, int has_known_size, int decref_tuple);

/* dict_iter.proto */
static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* dict, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_is_dict);
static CYTHON_INLINE int __Pyx_dict_iter_next(PyObject* dict_or_iter, Py_ssize_t orig_length, Py_ssize_t* ppos,
                                              PyObject** pkey, PyObject** pvalue, PyObject** pitem, int is_dict);

/* SwapException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSwap(type, value, tb)  __Pyx__ExceptionSwap(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* pyfrozenset_new.proto (used by py_set_discard_unhashable) */
static CYTHON_INLINE PyObject* __Pyx_PyFrozenSet_New(PyObject* it);

/* py_set_discard.proto */
static CYTHON_INLINE int __Pyx_PySet_Discard(PyObject *set, PyObject *key);

/* KeywordStringCheck.proto */
static CYTHON_INLINE int __Pyx_CheckKeywordStrings(const char* function_name, PyObject *kw);

/* PyDictContains.proto */
static CYTHON_INLINE int __Pyx_PyDict_ContainsTF(PyObject* item, PyObject* dict, int eq) {
    int result = PyDict_Contains(dict, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* GetModuleGlobalName.proto */
#include "src/gevent/_generated_include/GetModuleGlobalName_proto_35020a92d25e00989051b6cce92e00e13fc50c1cb05740bd074404c24babc545.h"
/* RaiseUnboundLocalError.proto */
static void __Pyx_RaiseUnboundLocalError(const char *varname);

/* py_dict_clear.proto */
#define __Pyx_PyDict_Clear(d) (PyDict_Clear(d), 0)

/* ListAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
        L->ob_item[len] = x;
        #else
        PyList_SET_ITEM(list, len, x);
        #endif
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

/* SliceObject.proto */
#define __Pyx_PyObject_DelSlice(obj, cstart, cstop, py_start, py_stop, py_slice, has_cstart, has_cstop, wraparound)\
    __Pyx_PyObject_SetSlice(obj, (PyObject*)NULL, cstart, cstop, py_start, py_stop, py_slice, has_cstart, has_cstop, wraparound)
static CYTHON_INLINE int __Pyx_PyObject_SetSlice(
        PyObject* obj, PyObject* value, Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** py_start, PyObject** py_stop, PyObject** py_slice,
        int has_cstart, int has_cstop, int wraparound);

/* PyObjectVectorCallKwBuilder.proto (used by PyObjectVectorCallMethodKwBuilder) */
CYTHON_UNUSED static int __Pyx_VectorcallBuilder_AddArg_Check(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n);
#if CYTHON_VECTORCALL
#if PY_VERSION_HEX >= 0x03090000
#define __Pyx_Object_Vectorcall_CallFromBuilder PyObject_Vectorcall
#else
#define __Pyx_Object_Vectorcall_CallFromBuilder _PyObject_Vectorcall
#endif
#define __Pyx_MakeVectorcallBuilderKwds(n) PyTuple_New(n)
static int __Pyx_VectorcallBuilder_AddArg(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n);
static int __Pyx_VectorcallBuilder_AddArgStr(const char *key, PyObject *value, PyObject *builder, PyObject **args, int n);
#else
#define __Pyx_Object_Vectorcall_CallFromBuilder __Pyx_PyObject_FastCallDict
#define __Pyx_MakeVectorcallBuilderKwds(n) __Pyx_PyDict_NewPresized(n)
#define __Pyx_VectorcallBuilder_AddArg(key, value, builder, args, n) PyDict_SetItem(builder, key, value)
#define __Pyx_VectorcallBuilder_AddArgStr(key, value, builder, args, n) PyDict_SetItemString(builder, key, value)
#endif

/* PyObjectVectorCallMethodKwBuilder.proto */
#if CYTHON_VECTORCALL && PY_VERSION_HEX >= 0x03090000
#define __Pyx_Object_VectorcallMethod_CallFromBuilder PyObject_VectorcallMethod
#else
static PyObject *__Pyx_Object_VectorcallMethod_CallFromBuilder(PyObject *name, PyObject *const *args, size_t nargsf, PyObject *kwnames);
#endif

/* PyObjectCall2Args.proto (used by PyObjectCallMethod1) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2);

/* PyObjectCallMethod1.proto (used by pop_index) */
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg);

/* pop_index.proto */
#include "src/gevent/_generated_include/pop_index_proto_13e12234b1856f782d167dd24a3c0ac7e2081b646923cd746bb691c45f504a2f.h"
/* HasAttr.proto */
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
#define __Pyx_HasAttr(o, n)  PyObject_HasAttrWithError(o, n)
#else
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *, PyObject *);
#endif

/* set_iter.proto */
static CYTHON_INLINE PyObject* __Pyx_set_iterator(PyObject* iterable, int is_set,
                                                  Py_ssize_t* p_orig_length, int* p_source_is_set);
static CYTHON_INLINE int __Pyx_set_iter_next(
        PyObject* iter_obj, Py_ssize_t orig_length,
        Py_ssize_t* ppos, PyObject **value,
        int source_is_set);

/* AllocateExtensionType.proto */
static PyObject *__Pyx_AllocateExtensionType(PyTypeObject *t, int is_final);

/* CallNextTpDealloc.proto */
static void __Pyx_call_next_tp_dealloc(PyObject* obj, destructor current_tp_dealloc);

/* CallNextTpTraverse.proto */
static int __Pyx_call_next_tp_traverse(PyObject* obj, visitproc v, void *a, traverseproc current_tp_traverse);

/* CallNextTpClear.proto */
static void __Pyx_call_next_tp_clear(PyObject* obj, inquiry current_tp_clear);

/* CheckTypeForFreelists.proto */
#if CYTHON_USE_FREELISTS
#if CYTHON_USE_TYPE_SPECS
#define __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, expected_tp, expected_size) ((int) ((t) == (expected_tp)))
#define __PYX_CHECK_TYPE_FOR_FREELIST_FLAGS  Py_TPFLAGS_IS_ABSTRACT
#else
#define __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, expected_tp, expected_size) ((int) ((t)->tp_basicsize == (expected_size)))
#define __PYX_CHECK_TYPE_FOR_FREELIST_FLAGS  (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)
#endif
#define __PYX_CHECK_TYPE_FOR_FREELISTS(t, expected_tp, expected_size)\
    (__PYX_CHECK_FINAL_TYPE_FOR_FREELISTS((t), (expected_tp), (expected_size)) &\
     (int) (!__Pyx_PyType_HasFeature((t), __PYX_CHECK_TYPE_FOR_FREELIST_FLAGS)))
#endif

/* VoidPtrExport.proto */
static int __Pyx_ExportVoidPtr(PyObject *api_dict, const char *name, void *p, const char *sig);

/* GetApiDict.proto */
static PyObject *__Pyx_ApiExport_GetApiDict(void);

/* FunctionExport.proto */
static int __Pyx_ExportFunction(PyObject *api_dict, const char *name, void (*f)(void), const char *sig);

/* TypeImport.proto */
#ifndef __PYX_HAVE_RT_ImportType_proto_3_2_4
#define __PYX_HAVE_RT_ImportType_proto_3_2_4
#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#include <stdalign.h>
#endif
#if (defined (__STDC_VERSION__) && __STDC_VERSION__ >= 201112L) || __cplusplus >= 201103L
#define __PYX_GET_STRUCT_ALIGNMENT_3_2_4(s) alignof(s)
#else
#define __PYX_GET_STRUCT_ALIGNMENT_3_2_4(s) sizeof(void*)
#endif
enum __Pyx_ImportType_CheckSize_3_2_4 {
   __Pyx_ImportType_CheckSize_Error_3_2_4 = 0,
   __Pyx_ImportType_CheckSize_Warn_3_2_4 = 1,
   __Pyx_ImportType_CheckSize_Ignore_3_2_4 = 2
};
static PyTypeObject *__Pyx_ImportType_3_2_4(PyObject* module, const char *module_name, const char *class_name, size_t size, size_t alignment, enum __Pyx_ImportType_CheckSize_3_2_4 check_size);
#endif

/* ValidateBasesTuple.proto (used by PyType_Ready) */
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_USE_TYPE_SPECS
static int __Pyx_validate_bases_tuple(const char *type_name, Py_ssize_t dictoffset, PyObject *bases);
#endif

/* PyType_Ready.proto */
CYTHON_UNUSED static int __Pyx_PyType_Ready(PyTypeObject *t);

/* FormatTypeName.proto (used by ValidateExternBase) */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%U"
#define __Pyx_DECREF_TypeName(obj) Py_XDECREF(obj)
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
#define __Pyx_PyType_GetFullyQualifiedName PyType_GetFullyQualifiedName
#else
static __Pyx_TypeName __Pyx_PyType_GetFullyQualifiedName(PyTypeObject* tp);
#endif
#else  // !LIMITED_API
typedef const char *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%.200s"
#define __Pyx_PyType_GetFullyQualifiedName(tp) ((tp)->tp_name)
#define __Pyx_DECREF_TypeName(obj)
#endif

/* ValidateExternBase.proto */
static int __Pyx_validate_extern_base(PyTypeObject *base);

/* SetVTable.proto */
static int __Pyx_SetVtable(PyTypeObject* typeptr , void* vtable);

/* GetVTable.proto (used by MergeVTables) */
static void* __Pyx_GetVtable(PyTypeObject *type);

/* MergeVTables.proto */
static int __Pyx_MergeVtables(PyTypeObject *type);

/* VoidPtrImport.proto */
static int __Pyx_ImportVoidPtr_3_2_4(PyObject *module, const char *name, void **p, const char *sig);

/* FunctionImport.proto */
static int __Pyx_ImportFunction_3_2_4(PyObject *module, const char *funcname, void (**f)(void), const char *sig);

/* ImportImpl.export */
static PyObject *__Pyx__Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, PyObject *moddict, int level);

/* Import.proto */
static CYTHON_INLINE PyObject *__Pyx_Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, int level);

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* ListPack.proto */
static PyObject *__Pyx_PyList_Pack(Py_ssize_t n, ...);

/* GetNameInClass.proto */
#define __Pyx_GetNameInClass(var, nmspace, name)  (var) = __Pyx__GetNameInClass(nmspace, name)
static PyObject *__Pyx__GetNameInClass(PyObject *nmspace, PyObject *name);

/* ClassMethod.proto */
#if !CYTHON_COMPILING_IN_LIMITED_API
#include "descrobject.h"
#endif
CYTHON_UNUSED static PyObject* __Pyx_Method_ClassMethod(PyObject *method);

/* Globals.proto */
static PyObject* __Pyx_Globals(void);

/* CLineInTraceback.proto (used by AddTraceback) */
#if CYTHON_CLINE_IN_TRACEBACK && CYTHON_CLINE_IN_TRACEBACK_RUNTIME
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#else
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#endif

/* CodeObjectCache.proto (used by AddTraceback) */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject __Pyx_CachedCodeObjectType;
#else
typedef PyCodeObject __Pyx_CachedCodeObjectType;
#endif
typedef struct {
    __Pyx_CachedCodeObjectType* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_atomic_int_type accessor_count;
  #endif
};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static __Pyx_CachedCodeObjectType *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, __Pyx_CachedCodeObjectType* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* GCCDiagnostics.proto */
#if !defined(__INTEL_COMPILER) && defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6))
#define __Pyx_HAS_GCC_DIAGNOSTIC
#endif

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_int(int value);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyLong_As_int(PyObject *);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_long(long value);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyLong_As_long(PyObject *);

/* FastTypeChecks.proto */
#include "src/gevent/_generated_include/FastTypeChecks_proto_b6a1eb5ffa2a3fc9ebedcc671e034de99427399b8e4cbe35bbcd118ac87e0e6e.h"
/* GetRuntimeVersion.proto */
#if __PYX_LIMITED_VERSION_HEX < 0x030b0000
static unsigned long __Pyx_cached_runtime_version = 0;
static void __Pyx_init_runtime_version(void);
#else
#define __Pyx_init_runtime_version()
#endif
static unsigned long __Pyx_get_runtime_version(void);

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer);

/* DecompressString.proto */
static PyObject *__Pyx_DecompressString(const char *s, Py_ssize_t length, int algo);

/* MultiPhaseInitModuleState.proto */
#if CYTHON_PEP489_MULTI_PHASE_INIT && CYTHON_USE_MODULE_STATE
static PyObject *__Pyx_State_FindModule(void*);
static int __Pyx_State_AddModule(PyObject* module, void*);
static int __Pyx_State_RemoveModule(void*);
#elif CYTHON_USE_MODULE_STATE
#define __Pyx_State_FindModule PyState_FindModule
#define __Pyx_State_AddModule PyState_AddModule
#define __Pyx_State_RemoveModule PyState_RemoveModule
#endif

/* #### Code section: module_declarations ### */
/* CythonABIVersion.proto */
#include "src/gevent/_generated_include/CythonABIVersion_proto_6de230514e3c249dc5d32a29298796e6371a56c148e74d1832d78a4b882841b1.h"
static PyObject *__pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__get_minimal_ident(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self); /* proto*/
static int __pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__Greenlet__never_started_or_killed(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self); /* proto*/
static int __pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__Greenlet__start_pending(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self); /* proto*/
static int __pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__Greenlet__start_cancelled_by_kill(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self); /* proto*/
static int __pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__Greenlet__start_completed(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self); /* proto*/
static int __pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__Greenlet__started_but_aborted(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__Greenlet__cancel_start(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__Greenlet__handle_death_before_start(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, PyObject *__pyx_v_args); /* proto*/
static int __pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet_ready(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet_successful(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__formatinfo(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__maybe_kill_before_start(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, PyObject *__pyx_v_exception, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet_kill(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, int __pyx_skip_dispatch, struct __pyx_opt_args_6gevent_17_gevent_cgreenlet_8Greenlet_kill *__pyx_optional_args); /* proto*/
static PyObject *__pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet_join(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, int __pyx_skip_dispatch, struct __pyx_opt_args_6gevent_17_gevent_cgreenlet_8Greenlet_join *__pyx_optional_args); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__Greenlet__report_result(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, PyObject *__pyx_v_result); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__Greenlet__report_error(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, PyObject *__pyx_v_exc_info); /* proto*/
static CYTHON_INLINE void __pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__Greenlet__free(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self); /* proto*/
static int __pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet_has_links(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet_rawlink(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, PyObject *__pyx_v_callback, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__notify_links(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6gevent_17_gevent_cgreenlet_12_dummy_event_stop(CYTHON_UNUSED struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *__pyx_v_self, CYTHON_UNUSED int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6gevent_17_gevent_cgreenlet_12_dummy_event_start(CYTHON_UNUSED struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_cb, CYTHON_UNUSED int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6gevent_17_gevent_cgreenlet_12_dummy_event_close(CYTHON_UNUSED struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *__pyx_v_self, CYTHON_UNUSED int __pyx_skip_dispatch); /* proto*/

/* Module declarations from "cython" */

/* Module declarations from "libc.string" */

/* Module declarations from "libc.stdio" */

/* Module declarations from "__builtin__" */

/* Module declarations from "cpython.type" */

/* Module declarations from "cpython" */

/* Module declarations from "cpython.object" */

/* Module declarations from "cpython.ref" */

/* Module declarations from "weakref" */

/* Module declarations from "gevent._gevent_c_ident" */
static PyObject **__pyx_vp_6gevent_15_gevent_c_ident_heappop = 0;
#define __pyx_v_6gevent_15_gevent_c_ident_heappop (*__pyx_vp_6gevent_15_gevent_c_ident_heappop)
static PyObject **__pyx_vp_6gevent_15_gevent_c_ident_heappush = 0;
#define __pyx_v_6gevent_15_gevent_c_ident_heappush (*__pyx_vp_6gevent_15_gevent_c_ident_heappush)
static PyObject **__pyx_vp_6gevent_15_gevent_c_ident_WeakKeyDictionary = 0;
#define __pyx_v_6gevent_15_gevent_c_ident_WeakKeyDictionary (*__pyx_vp_6gevent_15_gevent_c_ident_WeakKeyDictionary)

/* Module declarations from "greenlet" */

/* Module declarations from "gevent._gevent_c_greenlet_primitives" */
static PyObject **__pyx_vp_6gevent_29_gevent_c_greenlet_primitives_get_objects = 0;
#define __pyx_v_6gevent_29_gevent_c_greenlet_primitives_get_objects (*__pyx_vp_6gevent_29_gevent_c_greenlet_primitives_get_objects)
static PyObject **__pyx_vp_6gevent_29_gevent_c_greenlet_primitives_wref = 0;
#define __pyx_v_6gevent_29_gevent_c_greenlet_primitives_wref (*__pyx_vp_6gevent_29_gevent_c_greenlet_primitives_wref)
static PyObject **__pyx_vp_6gevent_29_gevent_c_greenlet_primitives_BlockingSwitchOutError = 0;
#define __pyx_v_6gevent_29_gevent_c_greenlet_primitives_BlockingSwitchOutError (*__pyx_vp_6gevent_29_gevent_c_greenlet_primitives_BlockingSwitchOutError)
static int *__pyx_vp_6gevent_29_gevent_c_greenlet_primitives__greenlet_imported = 0;
#define __pyx_v_6gevent_29_gevent_c_greenlet_primitives__greenlet_imported (*__pyx_vp_6gevent_29_gevent_c_greenlet_primitives__greenlet_imported)
static PyTypeObject **__pyx_vp_6gevent_29_gevent_c_greenlet_primitives__memoryview = 0;
#define __pyx_v_6gevent_29_gevent_c_greenlet_primitives__memoryview (*__pyx_vp_6gevent_29_gevent_c_greenlet_primitives__memoryview)
static PyTypeObject **__pyx_vp_6gevent_29_gevent_c_greenlet_primitives__buffer = 0;
#define __pyx_v_6gevent_29_gevent_c_greenlet_primitives__buffer (*__pyx_vp_6gevent_29_gevent_c_greenlet_primitives__buffer)

/* Module declarations from "gevent._gevent_c_hub_local" */
static PyObject **__pyx_vp_6gevent_19_gevent_c_hub_local__threadlocal = 0;
#define __pyx_v_6gevent_19_gevent_c_hub_local__threadlocal (*__pyx_vp_6gevent_19_gevent_c_hub_local__threadlocal)
static struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *(*__pyx_f_6gevent_19_gevent_c_hub_local_get_hub_noargs)(int __pyx_skip_dispatch); /*proto*/

/* Module declarations from "gevent._gevent_c_waiter" */
static PyObject **__pyx_vp_6gevent_16_gevent_c_waiter_sys = 0;
#define __pyx_v_6gevent_16_gevent_c_waiter_sys (*__pyx_vp_6gevent_16_gevent_c_waiter_sys)
static PyObject **__pyx_vp_6gevent_16_gevent_c_waiter_ConcurrentObjectUseError = 0;
#define __pyx_v_6gevent_16_gevent_c_waiter_ConcurrentObjectUseError (*__pyx_vp_6gevent_16_gevent_c_waiter_ConcurrentObjectUseError)
static int *__pyx_vp_6gevent_16_gevent_c_waiter__greenlet_imported = 0;
#define __pyx_v_6gevent_16_gevent_c_waiter__greenlet_imported (*__pyx_vp_6gevent_16_gevent_c_waiter__greenlet_imported)
static PyObject **__pyx_vp_6gevent_16_gevent_c_waiter__NONE = 0;
#define __pyx_v_6gevent_16_gevent_c_waiter__NONE (*__pyx_vp_6gevent_16_gevent_c_waiter__NONE)

/* Module declarations from "gevent._gevent_cgreenlet" */
static int __pyx_v_6gevent_17_gevent_cgreenlet__PYPY;
static PyObject *__pyx_v_6gevent_17_gevent_cgreenlet_sys_getframe = 0;
static PyObject *__pyx_v_6gevent_17_gevent_cgreenlet_sys_exc_info = 0;
static PyObject *__pyx_v_6gevent_17_gevent_cgreenlet_Timeout = 0;
static PyObject *__pyx_v_6gevent_17_gevent_cgreenlet_GreenletExit = 0;
static PyObject *__pyx_v_6gevent_17_gevent_cgreenlet_InvalidSwitchError = 0;
static int __pyx_v_6gevent_17_gevent_cgreenlet__greenlet_imported;
static PyObject *__pyx_v_6gevent_17_gevent_cgreenlet__greenlet__init__ = 0;
static PyObject *__pyx_v_6gevent_17_gevent_cgreenlet__threadlocal = 0;
static PyObject *__pyx_v_6gevent_17_gevent_cgreenlet_get_hub_class = 0;
static PyObject *__pyx_v_6gevent_17_gevent_cgreenlet_wref = 0;
static PyObject *__pyx_v_6gevent_17_gevent_cgreenlet_dump_traceback = 0;
static PyObject *__pyx_v_6gevent_17_gevent_cgreenlet_load_traceback = 0;
static PyObject *__pyx_v_6gevent_17_gevent_cgreenlet_wait = 0;
static PyObject *__pyx_v_6gevent_17_gevent_cgreenlet_iwait = 0;
static PyObject *__pyx_v_6gevent_17_gevent_cgreenlet_reraise = 0;
static PyObject *__pyx_v_6gevent_17_gevent_cgreenlet_GEVENT_CONFIG = 0;
static struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *__pyx_v_6gevent_17_gevent_cgreenlet__cancelled_start_event = 0;
static struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *__pyx_v_6gevent_17_gevent_cgreenlet__start_completed_event = 0;
static PyObject *__pyx_v_6gevent_17_gevent_cgreenlet__spawn_callbacks = 0;
static CYTHON_INLINE PyGreenlet *__pyx_f_6gevent_17_gevent_cgreenlet_getcurrent(void); /*proto*/
static CYTHON_INLINE PyObject *__pyx_f_6gevent_17_gevent_cgreenlet_get_generic_parent(PyGreenlet *); /*proto*/
static CYTHON_INLINE struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *__pyx_f_6gevent_17_gevent_cgreenlet_get_my_hub(PyGreenlet *); /*proto*/
static CYTHON_INLINE void __pyx_f_6gevent_17_gevent_cgreenlet_greenlet_init(void); /*proto*/
static void __pyx_f_6gevent_17_gevent_cgreenlet__init(void); /*proto*/
static struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *__pyx_f_6gevent_17_gevent_cgreenlet__extract_stack(int); /*proto*/
static PyObject *__pyx_f_6gevent_17_gevent_cgreenlet__kill(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, PyObject *, PyObject *, int __pyx_skip_dispatch); /*proto*/
static PyObject *__pyx_f_6gevent_17_gevent_cgreenlet__killall3(PyObject *, PyObject *, PyObject *); /*proto*/
static PyObject *__pyx_f_6gevent_17_gevent_cgreenlet__killall(PyObject *, PyObject *); /*proto*/
static PyObject *__pyx_f_6gevent_17_gevent_cgreenlet_joinall(PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_6gevent_17_gevent_cgreenlet_joinall *__pyx_optional_args); /*proto*/
static void __pyx_f_6gevent_17_gevent_cgreenlet__call_spawn_callbacks(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *); /*proto*/
static PyObject *__Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter(PyObject *(*)(PyObject *, PyObject *, PyObject *)); /*proto*/
static PyObject *__Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception(PyObject *(*)(PyObject *, PyObject *)); /*proto*/
/* #### Code section: typeinfo ### */
/* #### Code section: before_global_var ### */
#define __Pyx_MODULE_NAME "gevent._gevent_cgreenlet"
extern int __pyx_module_is_main_gevent___gevent_cgreenlet;
int __pyx_module_is_main_gevent___gevent_cgreenlet = 0;

/* Implementation of "gevent._gevent_cgreenlet" */
/* #### Code section: global_var ### */
static PyObject *__pyx_builtin___import__;
static PyObject *__pyx_builtin_staticmethod;
static PyObject *__pyx_builtin_id;
/* #### Code section: string_decls ### */
/* #### Code section: decls ### */
static PyObject *__pyx_lambda_funcdef_6gevent_17_gevent_cgreenlet_lambda(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_lambda_funcdef_6gevent_17_gevent_cgreenlet_lambda1(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_s); /* proto */
static PyObject *__pyx_lambda_funcdef_6gevent_17_gevent_cgreenlet_lambda2(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_s); /* proto */
static PyObject *__pyx_lambda_funcdef_6gevent_17_gevent_cgreenlet_lambda3(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_frame); /* proto */
static PyObject *__pyx_lambda_funcdef_6gevent_17_gevent_cgreenlet_lambda4(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_frame); /* proto */
static PyObject *__pyx_lambda_funcdef_6gevent_17_gevent_cgreenlet_lambda5(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_frame); /* proto */
static PyObject *__pyx_pf_11cfunc_dot_to_py_107__Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter_wrap(PyObject *__pyx_self, PyObject *__pyx_v_greenlets, PyObject *__pyx_v_exception, PyObject *__pyx_v_waiter); /* proto */
static PyObject *__pyx_pf_11cfunc_dot_to_py_99__Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_wrap(PyObject *__pyx_self, PyObject *__pyx_v_greenlets, PyObject *__pyx_v_exception); /* proto */
static int __pyx_pf_6gevent_17_gevent_cgreenlet_11SpawnedLink___init__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink *__pyx_v_self, PyObject *__pyx_v_callback); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_11SpawnedLink_2__call__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink *__pyx_v_self, PyObject *__pyx_v_source); /* proto */
static Py_hash_t __pyx_pf_6gevent_17_gevent_cgreenlet_11SpawnedLink_4__hash__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_11SpawnedLink_6__eq__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_11SpawnedLink_8__str__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_11SpawnedLink_10__repr__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_11SpawnedLink_12__getattr__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink *__pyx_v_self, PyObject *__pyx_v_item); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_11SpawnedLink_8callback___get__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink *__pyx_v_self); /* proto */
static int __pyx_pf_6gevent_17_gevent_cgreenlet_11SpawnedLink_8callback_2__set__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6gevent_17_gevent_cgreenlet_11SpawnedLink_8callback_4__del__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_18SuccessSpawnedLink___call__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink *__pyx_v_self, PyObject *__pyx_v_source); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_18FailureSpawnedLink___call__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_FailureSpawnedLink *__pyx_v_self, PyObject *__pyx_v_source); /* proto */
static int __pyx_pf_6gevent_17_gevent_cgreenlet_6_Frame___init__(struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_6_Frame_9f_globals___get__(CYTHON_UNUSED struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_6_Frame_6f_code___get__(struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_6_Frame_8f_lineno___get__(struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_6_Frame_6f_back___get__(struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *__pyx_v_self); /* proto */
static int __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet___init__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, PyObject *__pyx_v_run, PyObject *__pyx_v_args, PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_13minimal_ident___get__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_2name(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_4_raise_exception(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_4loop___get__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self); /* proto */
static int __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_6__bool__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_4dead___get__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_7started___get__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_8ready(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_10successful(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_12__repr__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_14_formatinfo(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_9exception___get__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_8exc_info___get__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_16throw(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_18start(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_20start_later(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, PyObject *__pyx_v_seconds); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_22add_spawn_callback(PyObject *__pyx_v_callback); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_24remove_spawn_callback(PyObject *__pyx_v_callback); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_26spawn(PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_args, PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_28spawn_later(PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_seconds, PyObject *__pyx_v_args, PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_30_maybe_kill_before_start(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, PyObject *__pyx_v_exception); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_32kill(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, PyObject *__pyx_v_exception, PyObject *__pyx_v_block, PyObject *__pyx_v_timeout); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_34get(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, PyObject *__pyx_v_block, PyObject *__pyx_v_timeout); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_36join(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, PyObject *__pyx_v_timeout); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_38__enter__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_40__exit__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, PyObject *__pyx_v_t, PyObject *__pyx_v_v, PyObject *__pyx_v_tb); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_42run(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_44_run(CYTHON_UNUSED struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_46has_links(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_48rawlink(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, PyObject *__pyx_v_callback); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_50link(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, PyObject *__pyx_v_callback, PyObject *__pyx_v_SpawnedLink); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_52unlink(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, PyObject *__pyx_v_callback); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_54unlink_all(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_56link_value(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, PyObject *__pyx_v_callback, PyObject *__pyx_v_SpawnedLink); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_58link_exception(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, PyObject *__pyx_v_callback, PyObject *__pyx_v_SpawnedLink); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_60_notify_links(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_5value___get__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_4args___get__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_6kwargs___get__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_17spawning_greenlet___get__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_14spawning_stack___get__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_17spawn_tree_locals___get__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self); /* proto */
static int __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_17spawn_tree_locals_2__set__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_17spawn_tree_locals_4__del__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self); /* proto */
static int __pyx_pf_6gevent_17_gevent_cgreenlet_12_dummy_event___init__(struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_12_dummy_event_2stop(struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_12_dummy_event_4start(struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *__pyx_v_self, PyObject *__pyx_v_cb); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_12_dummy_event_6close(struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_12_dummy_event_7pending___get__(struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_12_dummy_event_6active___get__(struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet__kill(CYTHON_UNUSED PyObject *__pyx_self, struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_glet, PyObject *__pyx_v_exception, PyObject *__pyx_v_waiter); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_2joinall(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_greenlets, PyObject *__pyx_v_timeout, PyObject *__pyx_v_raise_error, PyObject *__pyx_v_count); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_12__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_4killall(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_greenlets, PyObject *__pyx_v_exception, PyObject *__pyx_v_block, PyObject *__pyx_v_timeout); /* proto */
static PyObject *__pyx_tp_new_6gevent_17_gevent_cgreenlet_SpawnedLink(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6gevent_17_gevent_cgreenlet__Frame(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6gevent_17_gevent_cgreenlet_Greenlet(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6gevent_17_gevent_cgreenlet__dummy_event(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6gevent_17_gevent_cgreenlet___pyx_defaults(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
/* #### Code section: late_includes ### */
/* #### Code section: module_state ### */
/* SmallCodeConfig */
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif

typedef struct {
  PyObject *__pyx_d;
  PyObject *__pyx_b;
  PyObject *__pyx_cython_runtime;
  PyObject *__pyx_empty_tuple;
  PyObject *__pyx_empty_bytes;
  PyObject *__pyx_empty_unicode;
  PyTypeObject *__pyx_ptype_7cpython_4type_type;
  PyTypeObject *__pyx_ptype_6gevent_15_gevent_c_ident_ref;
  PyTypeObject *__pyx_ptype_6gevent_15_gevent_c_ident_ValuedWeakRef;
  PyTypeObject *__pyx_ptype_6gevent_15_gevent_c_ident_IdentRegistry;
  PyTypeObject *__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_greenlet;
  PyTypeObject *__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet;
  PyTypeObject *__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop;
  PyTypeObject *__pyx_ptype_6gevent_16_gevent_c_waiter_greenlet;
  PyTypeObject *__pyx_ptype_6gevent_16_gevent_c_waiter_Waiter;
  PyTypeObject *__pyx_ptype_6gevent_16_gevent_c_waiter_MultipleWaiter;
  PyObject *__pyx_type_6gevent_17_gevent_cgreenlet_SpawnedLink;
  PyObject *__pyx_type_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink;
  PyObject *__pyx_type_6gevent_17_gevent_cgreenlet_FailureSpawnedLink;
  PyObject *__pyx_type_6gevent_17_gevent_cgreenlet__Frame;
  PyObject *__pyx_type_6gevent_17_gevent_cgreenlet_Greenlet;
  PyObject *__pyx_type_6gevent_17_gevent_cgreenlet__dummy_event;
  PyObject *__pyx_type_6gevent_17_gevent_cgreenlet___pyx_defaults;
  PyObject *__pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter;
  PyObject *__pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception;
  PyTypeObject *__pyx_ptype_6gevent_17_gevent_cgreenlet_greenlet;
  PyTypeObject *__pyx_ptype_6gevent_17_gevent_cgreenlet_SpawnedLink;
  PyTypeObject *__pyx_ptype_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink;
  PyTypeObject *__pyx_ptype_6gevent_17_gevent_cgreenlet_FailureSpawnedLink;
  PyTypeObject *__pyx_ptype_6gevent_17_gevent_cgreenlet__Frame;
  PyTypeObject *__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet;
  PyTypeObject *__pyx_ptype_6gevent_17_gevent_cgreenlet__dummy_event;
  PyTypeObject *__pyx_ptype_6gevent_17_gevent_cgreenlet___pyx_defaults;
  PyTypeObject *__pyx_ptype___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter;
  PyTypeObject *__pyx_ptype___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_items;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_pop;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_values;
  PyObject *__pyx_k__12;
  PyObject *__pyx_k__13;
  PyObject *__pyx_k__14;
  PyObject *__pyx_k__15;
  PyObject *__pyx_tuple[6];
  PyObject *__pyx_codeobj_tab[42];
  PyObject *__pyx_string_tab[268];
  PyObject *__pyx_number_tab[2];
/* #### Code section: module_state_contents ### */
/* CommonTypesMetaclass.module_state_decls */
PyTypeObject *__pyx_CommonTypesMetaclassType;

/* CachedMethodType.module_state_decls */
#if CYTHON_COMPILING_IN_LIMITED_API
PyObject *__Pyx_CachedMethodType;
#endif

/* CythonFunctionShared.module_state_decls */
PyTypeObject *__pyx_CyFunctionType;


#if CYTHON_USE_FREELISTS
struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter *__pyx_freelist___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter[8];
int __pyx_freecount___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter;
#endif

#if CYTHON_USE_FREELISTS
struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception *__pyx_freelist___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception[8];
int __pyx_freecount___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception;
#endif
/* CodeObjectCache.module_state_decls */
struct __Pyx_CodeObjectCache __pyx_code_cache;

/* #### Code section: module_state_end ### */
} __pyx_mstatetype;

#if CYTHON_USE_MODULE_STATE
#ifdef __cplusplus
namespace {
extern struct PyModuleDef __pyx_moduledef;
} /* anonymous namespace */
#else
static struct PyModuleDef __pyx_moduledef;
#endif

#define __pyx_mstate_global (__Pyx_PyModule_GetState(__Pyx_State_FindModule(&__pyx_moduledef)))

#define __pyx_m (__Pyx_State_FindModule(&__pyx_moduledef))
#else
static __pyx_mstatetype __pyx_mstate_global_static =
#ifdef __cplusplus
    {};
#else
    {0};
#endif
static __pyx_mstatetype * const __pyx_mstate_global = &__pyx_mstate_global_static;
#endif
/* #### Code section: constant_name_defines ### */
#define __pyx_kp_u_ __pyx_string_tab[0]
#define __pyx_kp_u_Cannot_start_the_dummy_event __pyx_string_tab[1]
#define __pyx_kp_u_Expected_callable __pyx_string_tab[2]
#define __pyx_kp_u_Greenlet __pyx_string_tab[3]
#define __pyx_kp_u_Invalid_switch_into_Greenlet_get __pyx_string_tab[4]
#define __pyx_kp_u_Invalid_switch_into_Greenlet_joi __pyx_string_tab[5]
#define __pyx_kp_u_None __pyx_string_tab[6]
#define __pyx_kp_u_Note_that_Cython_is_deliberately __pyx_string_tab[7]
#define __pyx_kp_u_The_run_argument_or_self__run_mu __pyx_string_tab[8]
#define __pyx_kp_u__10 __pyx_string_tab[9]
#define __pyx_kp_u__11 __pyx_string_tab[10]
#define __pyx_kp_u__16 __pyx_string_tab[11]
#define __pyx_kp_u__17 __pyx_string_tab[12]
#define __pyx_kp_u__2 __pyx_string_tab[13]
#define __pyx_kp_u__3 __pyx_string_tab[14]
#define __pyx_kp_u__4 __pyx_string_tab[15]
#define __pyx_kp_u__5 __pyx_string_tab[16]
#define __pyx_kp_u__6 __pyx_string_tab[17]
#define __pyx_kp_u__7 __pyx_string_tab[18]
#define __pyx_kp_u__8 __pyx_string_tab[19]
#define __pyx_kp_u__9 __pyx_string_tab[20]
#define __pyx_kp_u_add_note __pyx_string_tab[21]
#define __pyx_kp_u_at __pyx_string_tab[22]
#define __pyx_kp_u_cfunc_to_py __pyx_string_tab[23]
#define __pyx_kp_u_disable __pyx_string_tab[24]
#define __pyx_kp_u_enable __pyx_string_tab[25]
#define __pyx_kp_u_gc __pyx_string_tab[26]
#define __pyx_kp_u_gevent__greenlet __pyx_string_tab[27]
#define __pyx_kp_u_isenabled __pyx_string_tab[28]
#define __pyx_kp_u_src_gevent_greenlet_py __pyx_string_tab[29]
#define __pyx_n_u_FailureSpawnedLink __pyx_string_tab[30]
#define __pyx_n_u_Frame __pyx_string_tab[31]
#define __pyx_n_u_Gevent_PyFrame_GetBack __pyx_string_tab[32]
#define __pyx_n_u_Gevent_PyFrame_GetCode __pyx_string_tab[33]
#define __pyx_n_u_Gevent_PyFrame_GetLineNumber __pyx_string_tab[34]
#define __pyx_n_u_GreenletExit __pyx_string_tab[35]
#define __pyx_n_u_Greenlet_2 __pyx_string_tab[36]
#define __pyx_n_u_Greenlet___enter __pyx_string_tab[37]
#define __pyx_n_u_Greenlet___exit __pyx_string_tab[38]
#define __pyx_n_u_Greenlet__formatinfo __pyx_string_tab[39]
#define __pyx_n_u_Greenlet__maybe_kill_before_star __pyx_string_tab[40]
#define __pyx_n_u_Greenlet__notify_links __pyx_string_tab[41]
#define __pyx_n_u_Greenlet__raise_exception __pyx_string_tab[42]
#define __pyx_n_u_Greenlet__run __pyx_string_tab[43]
#define __pyx_n_u_Greenlet_add_spawn_callback __pyx_string_tab[44]
#define __pyx_n_u_Greenlet_get __pyx_string_tab[45]
#define __pyx_n_u_Greenlet_has_links __pyx_string_tab[46]
#define __pyx_n_u_Greenlet_join __pyx_string_tab[47]
#define __pyx_n_u_Greenlet_kill __pyx_string_tab[48]
#define __pyx_n_u_Greenlet_link __pyx_string_tab[49]
#define __pyx_n_u_Greenlet_link_exception __pyx_string_tab[50]
#define __pyx_n_u_Greenlet_link_value __pyx_string_tab[51]
#define __pyx_n_u_Greenlet_name __pyx_string_tab[52]
#define __pyx_n_u_Greenlet_rawlink __pyx_string_tab[53]
#define __pyx_n_u_Greenlet_ready __pyx_string_tab[54]
#define __pyx_n_u_Greenlet_remove_spawn_callback __pyx_string_tab[55]
#define __pyx_n_u_Greenlet_run __pyx_string_tab[56]
#define __pyx_n_u_Greenlet_spawn __pyx_string_tab[57]
#define __pyx_n_u_Greenlet_spawn_later __pyx_string_tab[58]
#define __pyx_n_u_Greenlet_start __pyx_string_tab[59]
#define __pyx_n_u_Greenlet_start_later __pyx_string_tab[60]
#define __pyx_n_u_Greenlet_successful __pyx_string_tab[61]
#define __pyx_n_u_Greenlet_throw __pyx_string_tab[62]
#define __pyx_n_u_Greenlet_unlink __pyx_string_tab[63]
#define __pyx_n_u_Greenlet_unlink_all __pyx_string_tab[64]
#define __pyx_n_u_InvalidSwitchError __pyx_string_tab[65]
#define __pyx_n_u_PYPY __pyx_string_tab[66]
#define __pyx_n_u_Pyx_CFunc_53f338__6gevent_17_g __pyx_string_tab[67]
#define __pyx_n_u_Pyx_CFunc_adc8fb__6gevent_17_g __pyx_string_tab[68]
#define __pyx_n_u_Pyx_PyDict_NextRef __pyx_string_tab[69]
#define __pyx_n_u_SpawnedLink __pyx_string_tab[70]
#define __pyx_n_u_SuccessSpawnedLink __pyx_string_tab[71]
#define __pyx_n_u_Timeout __pyx_string_tab[72]
#define __pyx_n_u_Waiter __pyx_string_tab[73]
#define __pyx_n_u_active __pyx_string_tab[74]
#define __pyx_n_u_add_spawn_callback __pyx_string_tab[75]
#define __pyx_n_u_alive __pyx_string_tab[76]
#define __pyx_n_u_all __pyx_string_tab[77]
#define __pyx_n_u_args __pyx_string_tab[78]
#define __pyx_n_u_asyncio_coroutines __pyx_string_tab[79]
#define __pyx_n_u_block __pyx_string_tab[80]
#define __pyx_n_u_call __pyx_string_tab[81]
#define __pyx_n_u_callback __pyx_string_tab[82]
#define __pyx_n_u_cancel __pyx_string_tab[83]
#define __pyx_n_u_cb __pyx_string_tab[84]
#define __pyx_n_u_cfunc_to_py __pyx_string_tab[85]
#define __pyx_n_u_class __pyx_string_tab[86]
#define __pyx_n_u_cline_in_traceback __pyx_string_tab[87]
#define __pyx_n_u_close __pyx_string_tab[88]
#define __pyx_n_u_cls __pyx_string_tab[89]
#define __pyx_n_u_config __pyx_string_tab[90]
#define __pyx_n_u_continuation __pyx_string_tab[91]
#define __pyx_n_u_continulet __pyx_string_tab[92]
#define __pyx_n_u_continulet_2 __pyx_string_tab[93]
#define __pyx_n_u_count __pyx_string_tab[94]
#define __pyx_n_u_d __pyx_string_tab[95]
#define __pyx_n_u_dead __pyx_string_tab[96]
#define __pyx_n_u_dict __pyx_string_tab[97]
#define __pyx_n_u_dummy_event __pyx_string_tab[98]
#define __pyx_n_u_dummy_event_close __pyx_string_tab[99]
#define __pyx_n_u_dummy_event_start __pyx_string_tab[100]
#define __pyx_n_u_dummy_event_stop __pyx_string_tab[101]
#define __pyx_n_u_dump_traceback __pyx_string_tab[102]
#define __pyx_n_u_enter __pyx_string_tab[103]
#define __pyx_n_u_exc_info __pyx_string_tab[104]
#define __pyx_n_u_exception __pyx_string_tab[105]
#define __pyx_n_u_exit __pyx_string_tab[106]
#define __pyx_n_u_f_back __pyx_string_tab[107]
#define __pyx_n_u_f_code __pyx_string_tab[108]
#define __pyx_n_u_f_lineno __pyx_string_tab[109]
#define __pyx_n_u_formatinfo __pyx_string_tab[110]
#define __pyx_n_u_frame __pyx_string_tab[111]
#define __pyx_n_u_func __pyx_string_tab[112]
#define __pyx_n_u_g __pyx_string_tab[113]
#define __pyx_n_u_get __pyx_string_tab[114]
#define __pyx_n_u_get_2 __pyx_string_tab[115]
#define __pyx_n_u_get_generic_parent __pyx_string_tab[116]
#define __pyx_n_u_get_hub_noargs __pyx_string_tab[117]
#define __pyx_n_u_get_my_hub __pyx_string_tab[118]
#define __pyx_n_u_getcurrent __pyx_string_tab[119]
#define __pyx_n_u_getframe __pyx_string_tab[120]
#define __pyx_n_u_gevent __pyx_string_tab[121]
#define __pyx_n_u_gevent__compat __pyx_string_tab[122]
#define __pyx_n_u_gevent__config __pyx_string_tab[123]
#define __pyx_n_u_gevent__gevent_cgreenlet __pyx_string_tab[124]
#define __pyx_n_u_gevent__hub_local __pyx_string_tab[125]
#define __pyx_n_u_gevent__hub_primitives __pyx_string_tab[126]
#define __pyx_n_u_gevent__tblib __pyx_string_tab[127]
#define __pyx_n_u_gevent__util __pyx_string_tab[128]
#define __pyx_n_u_gevent_exceptions __pyx_string_tab[129]
#define __pyx_n_u_gevent_timeout __pyx_string_tab[130]
#define __pyx_n_u_glet __pyx_string_tab[131]
#define __pyx_n_u_greenlet __pyx_string_tab[132]
#define __pyx_n_u_greenlet_init __pyx_string_tab[133]
#define __pyx_n_u_greenlets __pyx_string_tab[134]
#define __pyx_n_u_handle_error __pyx_string_tab[135]
#define __pyx_n_u_has_links __pyx_string_tab[136]
#define __pyx_n_u_hub __pyx_string_tab[137]
#define __pyx_n_u_id __pyx_string_tab[138]
#define __pyx_n_u_ident_registry __pyx_string_tab[139]
#define __pyx_n_u_import __pyx_string_tab[140]
#define __pyx_n_u_import_c_accel __pyx_string_tab[141]
#define __pyx_n_u_init __pyx_string_tab[142]
#define __pyx_n_u_is_coroutine __pyx_string_tab[143]
#define __pyx_n_u_items __pyx_string_tab[144]
#define __pyx_n_u_iwait_on_objects __pyx_string_tab[145]
#define __pyx_n_u_join __pyx_string_tab[146]
#define __pyx_n_u_joinall __pyx_string_tab[147]
#define __pyx_n_u_kill __pyx_string_tab[148]
#define __pyx_n_u_kill_2 __pyx_string_tab[149]
#define __pyx_n_u_killall __pyx_string_tab[150]
#define __pyx_n_u_kwargs __pyx_string_tab[151]
#define __pyx_n_u_lambda __pyx_string_tab[152]
#define __pyx_n_u_link __pyx_string_tab[153]
#define __pyx_n_u_link_exception __pyx_string_tab[154]
#define __pyx_n_u_link_value __pyx_string_tab[155]
#define __pyx_n_u_load_traceback __pyx_string_tab[156]
#define __pyx_n_u_loop __pyx_string_tab[157]
#define __pyx_n_u_main __pyx_string_tab[158]
#define __pyx_n_u_maybe_kill_before_start __pyx_string_tab[159]
#define __pyx_n_u_minimal_ident __pyx_string_tab[160]
#define __pyx_n_u_module __pyx_string_tab[161]
#define __pyx_n_u_name __pyx_string_tab[162]
#define __pyx_n_u_name_2 __pyx_string_tab[163]
#define __pyx_n_u_need_killed __pyx_string_tab[164]
#define __pyx_n_u_notify_links __pyx_string_tab[165]
#define __pyx_n_u_parent __pyx_string_tab[166]
#define __pyx_n_u_pending __pyx_string_tab[167]
#define __pyx_n_u_pop __pyx_string_tab[168]
#define __pyx_n_u_pyx_capi __pyx_string_tab[169]
#define __pyx_n_u_pyx_vtable __pyx_string_tab[170]
#define __pyx_n_u_qualname __pyx_string_tab[171]
#define __pyx_n_u_raise_error __pyx_string_tab[172]
#define __pyx_n_u_raise_exception __pyx_string_tab[173]
#define __pyx_n_u_rawlink __pyx_string_tab[174]
#define __pyx_n_u_readproperty __pyx_string_tab[175]
#define __pyx_n_u_ready __pyx_string_tab[176]
#define __pyx_n_u_ref __pyx_string_tab[177]
#define __pyx_n_u_remove __pyx_string_tab[178]
#define __pyx_n_u_remove_spawn_callback __pyx_string_tab[179]
#define __pyx_n_u_reraise __pyx_string_tab[180]
#define __pyx_n_u_result __pyx_string_tab[181]
#define __pyx_n_u_run __pyx_string_tab[182]
#define __pyx_n_u_run_2 __pyx_string_tab[183]
#define __pyx_n_u_run_callback __pyx_string_tab[184]
#define __pyx_n_u_s __pyx_string_tab[185]
#define __pyx_n_u_seconds __pyx_string_tab[186]
#define __pyx_n_u_self __pyx_string_tab[187]
#define __pyx_n_u_self_2 __pyx_string_tab[188]
#define __pyx_n_u_set_name __pyx_string_tab[189]
#define __pyx_n_u_setdefault __pyx_string_tab[190]
#define __pyx_n_u_slots __pyx_string_tab[191]
#define __pyx_n_u_source __pyx_string_tab[192]
#define __pyx_n_u_spawn __pyx_string_tab[193]
#define __pyx_n_u_spawn_later __pyx_string_tab[194]
#define __pyx_n_u_spawn_tree_locals __pyx_string_tab[195]
#define __pyx_n_u_spawning_stack_limit __pyx_string_tab[196]
#define __pyx_n_u_start __pyx_string_tab[197]
#define __pyx_n_u_start_later __pyx_string_tab[198]
#define __pyx_n_u_start_new_or_dummy __pyx_string_tab[199]
#define __pyx_n_u_staticmethod __pyx_string_tab[200]
#define __pyx_n_u_stop __pyx_string_tab[201]
#define __pyx_n_u_successful __pyx_string_tab[202]
#define __pyx_n_u_switch __pyx_string_tab[203]
#define __pyx_n_u_sys __pyx_string_tab[204]
#define __pyx_n_u_t __pyx_string_tab[205]
#define __pyx_n_u_tb __pyx_string_tab[206]
#define __pyx_n_u_test __pyx_string_tab[207]
#define __pyx_n_u_throw __pyx_string_tab[208]
#define __pyx_n_u_timeout __pyx_string_tab[209]
#define __pyx_n_u_timer __pyx_string_tab[210]
#define __pyx_n_u_track_greenlet_tree __pyx_string_tab[211]
#define __pyx_n_u_unlink __pyx_string_tab[212]
#define __pyx_n_u_unlink_all __pyx_string_tab[213]
#define __pyx_n_u_v __pyx_string_tab[214]
#define __pyx_n_u_values __pyx_string_tab[215]
#define __pyx_n_u_wait_on_objects __pyx_string_tab[216]
#define __pyx_n_u_waiter __pyx_string_tab[217]
#define __pyx_n_u_waiter_2 __pyx_string_tab[218]
#define __pyx_n_u_weakref __pyx_string_tab[219]
#define __pyx_n_u_wrap __pyx_string_tab[220]
#define __pyx_kp_b_PyObject_PyObject_PyObject_PyObj __pyx_string_tab[221]
#define __pyx_kp_b_PyObject_PyTypeObject_int_Blocki __pyx_string_tab[222]
#define __pyx_kp_b_PyObject_WeakKeyDictionary_heapp __pyx_string_tab[223]
#define __pyx_kp_b_PyObject__threadlocal __pyx_string_tab[224]
#define __pyx_kp_b_PyObject_int_ConcurrentObjectUse __pyx_string_tab[225]
#define __pyx_kp_b_PyObject_int_struct___pyx_obj_6g __pyx_string_tab[226]
#define __pyx_kp_b_iso88591_1A __pyx_string_tab[227]
#define __pyx_kp_b_iso88591_1A_2 __pyx_string_tab[228]
#define __pyx_kp_b_iso88591_1F_T_waq_t6_7_1_t1_4q_q_q_M_Q_G __pyx_string_tab[229]
#define __pyx_kp_b_iso88591_1_4vQ_2Q_HAQ_1A_1E_7_A_ZZ_q_s_q __pyx_string_tab[230]
#define __pyx_kp_b_iso88591_1_a_t1_t1Kxy_a_1_uA_q_7_5_V7_wa __pyx_string_tab[231]
#define __pyx_kp_b_iso88591_1_qd_4t_AQ_t6_V6_A_AQ_uM_wgQ_d __pyx_string_tab[232]
#define __pyx_kp_b_iso88591_31_E_L __pyx_string_tab[233]
#define __pyx_kp_b_iso88591_5 __pyx_string_tab[234]
#define __pyx_kp_b_iso88591_A __pyx_string_tab[235]
#define __pyx_kp_b_iso88591_A_2 __pyx_string_tab[236]
#define __pyx_kp_b_iso88591_A_2S_E_E_Rs_Q __pyx_string_tab[237]
#define __pyx_kp_b_iso88591_A_4_S_AQ_5_Qd __pyx_string_tab[238]
#define __pyx_kp_b_iso88591_A_4_S_AQ_5_aq_V1D __pyx_string_tab[239]
#define __pyx_kp_b_iso88591_A_4s_4t5_F_1A_Cr_Qa_q __pyx_string_tab[240]
#define __pyx_kp_b_iso88591_A_4xq_1_7q_G7_1_4vS_D_D_A_AQ_S_4 __pyx_string_tab[241]
#define __pyx_kp_b_iso88591_A_A __pyx_string_tab[242]
#define __pyx_kp_b_iso88591_A_Cq_AQ __pyx_string_tab[243]
#define __pyx_kp_b_iso88591_A_Cr_q_q __pyx_string_tab[244]
#define __pyx_kp_b_iso88591_A_D_q __pyx_string_tab[245]
#define __pyx_kp_b_iso88591_A_G1_HAQ_t1_1 __pyx_string_tab[246]
#define __pyx_kp_b_iso88591_A_O1_G1_t1_1_z_WD_1Ks_q_AQ_q __pyx_string_tab[247]
#define __pyx_kp_b_iso88591_A_O1_t4q_awa_AQ __pyx_string_tab[248]
#define __pyx_kp_b_iso88591_A_d_4wd_1_AQ_5_RvX __pyx_string_tab[249]
#define __pyx_kp_b_iso88591_A_nAQ __pyx_string_tab[250]
#define __pyx_kp_b_iso88591_A_q __pyx_string_tab[251]
#define __pyx_kp_b_iso88591_A_q_A __pyx_string_tab[252]
#define __pyx_kp_b_iso88591_A_q_Kq __pyx_string_tab[253]
#define __pyx_kp_b_iso88591_A_q_U_D_Q_O1L_AQ_q __pyx_string_tab[254]
#define __pyx_kp_b_iso88591_A_r_Q __pyx_string_tab[255]
#define __pyx_kp_b_iso88591_A_s_4q __pyx_string_tab[256]
#define __pyx_kp_b_iso88591_A_t1_5_q_1_t1_A_83a_q_WA_t1A_wav __pyx_string_tab[257]
#define __pyx_kp_b_iso88591_A_t6_D_7 __pyx_string_tab[258]
#define __pyx_kp_b_iso88591_A_t_gU_d_AS_1 __pyx_string_tab[259]
#define __pyx_kp_b_iso88591_A_waq __pyx_string_tab[260]
#define __pyx_kp_b_iso88591_HA __pyx_string_tab[261]
#define __pyx_kp_b_iso88591_HA_2 __pyx_string_tab[262]
#define __pyx_kp_b_iso88591_Qk_Cq_3a_b_aq_5_Qg_wgQ_gQa __pyx_string_tab[263]
#define __pyx_kp_b_iso88591_a __pyx_string_tab[264]
#define __pyx_kp_b_iso88591_a_4vQ_t_a_t1_4q_2Q_HAQ_1A_1E_7 __pyx_string_tab[265]
#define __pyx_kp_b_iso88591_q_E_L __pyx_string_tab[266]
#define __pyx_kp_b_struct___pyx_obj_6gevent_29_geve __pyx_string_tab[267]
#define __pyx_int_0 __pyx_number_tab[0]
#define __pyx_int_10 __pyx_number_tab[1]
/* #### Code section: module_state_clear ### */
#if CYTHON_USE_MODULE_STATE
static CYTHON_SMALL_CODE int __pyx_m_clear(PyObject *m) {
  __pyx_mstatetype *clear_module_state = __Pyx_PyModule_GetState(m);
  if (!clear_module_state) return 0;
  Py_CLEAR(clear_module_state->__pyx_d);
  Py_CLEAR(clear_module_state->__pyx_b);
  Py_CLEAR(clear_module_state->__pyx_cython_runtime);
  Py_CLEAR(clear_module_state->__pyx_empty_tuple);
  Py_CLEAR(clear_module_state->__pyx_empty_bytes);
  Py_CLEAR(clear_module_state->__pyx_empty_unicode);
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __Pyx_State_RemoveModule(NULL);
  #endif
  Py_CLEAR(clear_module_state->__pyx_ptype_7cpython_4type_type);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_15_gevent_c_ident_ref);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_15_gevent_c_ident_ValuedWeakRef);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_15_gevent_c_ident_IdentRegistry);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_greenlet);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_16_gevent_c_waiter_greenlet);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_16_gevent_c_waiter_Waiter);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_16_gevent_c_waiter_MultipleWaiter);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet_greenlet);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet_SpawnedLink);
  Py_CLEAR(clear_module_state->__pyx_type_6gevent_17_gevent_cgreenlet_SpawnedLink);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink);
  Py_CLEAR(clear_module_state->__pyx_type_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet_FailureSpawnedLink);
  Py_CLEAR(clear_module_state->__pyx_type_6gevent_17_gevent_cgreenlet_FailureSpawnedLink);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet__Frame);
  Py_CLEAR(clear_module_state->__pyx_type_6gevent_17_gevent_cgreenlet__Frame);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet);
  Py_CLEAR(clear_module_state->__pyx_type_6gevent_17_gevent_cgreenlet_Greenlet);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet__dummy_event);
  Py_CLEAR(clear_module_state->__pyx_type_6gevent_17_gevent_cgreenlet__dummy_event);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet___pyx_defaults);
  Py_CLEAR(clear_module_state->__pyx_type_6gevent_17_gevent_cgreenlet___pyx_defaults);
  Py_CLEAR(clear_module_state->__pyx_ptype___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter);
  Py_CLEAR(clear_module_state->__pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter);
  Py_CLEAR(clear_module_state->__pyx_ptype___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception);
  Py_CLEAR(clear_module_state->__pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception);
  Py_CLEAR(clear_module_state->__pyx_k__12);
  Py_CLEAR(clear_module_state->__pyx_k__13);
  Py_CLEAR(clear_module_state->__pyx_k__14);
  Py_CLEAR(clear_module_state->__pyx_k__15);
  for (int i=0; i<6; ++i) { Py_CLEAR(clear_module_state->__pyx_tuple[i]); }
  for (int i=0; i<42; ++i) { Py_CLEAR(clear_module_state->__pyx_codeobj_tab[i]); }
  for (int i=0; i<268; ++i) { Py_CLEAR(clear_module_state->__pyx_string_tab[i]); }
  for (int i=0; i<2; ++i) { Py_CLEAR(clear_module_state->__pyx_number_tab[i]); }
/* #### Code section: module_state_clear_contents ### */
/* CommonTypesMetaclass.module_state_clear */
Py_CLEAR(clear_module_state->__pyx_CommonTypesMetaclassType);

/* CythonFunctionShared.module_state_clear */
Py_CLEAR(clear_module_state->__pyx_CyFunctionType);

/* #### Code section: module_state_clear_end ### */
return 0;
}
#endif
/* #### Code section: module_state_traverse ### */
#if CYTHON_USE_MODULE_STATE
static CYTHON_SMALL_CODE int __pyx_m_traverse(PyObject *m, visitproc visit, void *arg) {
  __pyx_mstatetype *traverse_module_state = __Pyx_PyModule_GetState(m);
  if (!traverse_module_state) return 0;
  Py_VISIT(traverse_module_state->__pyx_d);
  Py_VISIT(traverse_module_state->__pyx_b);
  Py_VISIT(traverse_module_state->__pyx_cython_runtime);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_tuple);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_bytes);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_unicode);
  Py_VISIT(traverse_module_state->__pyx_ptype_7cpython_4type_type);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_15_gevent_c_ident_ref);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_15_gevent_c_ident_ValuedWeakRef);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_15_gevent_c_ident_IdentRegistry);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_greenlet);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_16_gevent_c_waiter_greenlet);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_16_gevent_c_waiter_Waiter);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_16_gevent_c_waiter_MultipleWaiter);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet_greenlet);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet_SpawnedLink);
  Py_VISIT(traverse_module_state->__pyx_type_6gevent_17_gevent_cgreenlet_SpawnedLink);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink);
  Py_VISIT(traverse_module_state->__pyx_type_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet_FailureSpawnedLink);
  Py_VISIT(traverse_module_state->__pyx_type_6gevent_17_gevent_cgreenlet_FailureSpawnedLink);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet__Frame);
  Py_VISIT(traverse_module_state->__pyx_type_6gevent_17_gevent_cgreenlet__Frame);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet);
  Py_VISIT(traverse_module_state->__pyx_type_6gevent_17_gevent_cgreenlet_Greenlet);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet__dummy_event);
  Py_VISIT(traverse_module_state->__pyx_type_6gevent_17_gevent_cgreenlet__dummy_event);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_17_gevent_cgreenlet___pyx_defaults);
  Py_VISIT(traverse_module_state->__pyx_type_6gevent_17_gevent_cgreenlet___pyx_defaults);
  Py_VISIT(traverse_module_state->__pyx_ptype___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter);
  Py_VISIT(traverse_module_state->__pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter);
  Py_VISIT(traverse_module_state->__pyx_ptype___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception);
  Py_VISIT(traverse_module_state->__pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception);
  Py_VISIT(traverse_module_state->__pyx_k__12);
  Py_VISIT(traverse_module_state->__pyx_k__13);
  Py_VISIT(traverse_module_state->__pyx_k__14);
  Py_VISIT(traverse_module_state->__pyx_k__15);
  for (int i=0; i<6; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_tuple[i]); }
  for (int i=0; i<42; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_codeobj_tab[i]); }
  for (int i=0; i<268; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_string_tab[i]); }
  for (int i=0; i<2; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_number_tab[i]); }
/* #### Code section: module_state_traverse_contents ### */
/* CommonTypesMetaclass.module_state_traverse */
Py_VISIT(traverse_module_state->__pyx_CommonTypesMetaclassType);

/* CythonFunctionShared.module_state_traverse */
Py_VISIT(traverse_module_state->__pyx_CyFunctionType);

/* #### Code section: module_state_traverse_end ### */
return 0;
}
#endif
/* #### Code section: module_code ### */

/* "src/gevent/greenlet.py":45
 * # error.
 * locals()['getcurrent'] = __import__('greenlet').getcurrent
 * locals()['greenlet_init'] = lambda: None             # <<<<<<<<<<<<<<
 * locals()['Waiter'] = _waiter.Waiter
 * # With Cython, this raises a TypeError if the parent is *not*
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_6lambda(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_6gevent_17_gevent_cgreenlet_6lambda = {"lambda", (PyCFunction)__pyx_pw_6gevent_17_gevent_cgreenlet_6lambda, METH_NOARGS, 0};
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_6lambda(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_lambda_funcdef_6gevent_17_gevent_cgreenlet_lambda(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_6gevent_17_gevent_cgreenlet_lambda(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":53
 * # This must ONLY be called when we know that `s` is not None and is in fact a greenlet
 * # object (e.g., when called on `self`)
 * locals()['get_my_hub'] = lambda s: s.parent             # <<<<<<<<<<<<<<
 * # This must also ONLY be called when we know that S is not None and is in fact a greenlet
 * # object (including the result of getcurrent())
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_7lambda1(PyObject *__pyx_self, PyObject *__pyx_v_s); /*proto*/
static PyMethodDef __pyx_mdef_6gevent_17_gevent_cgreenlet_7lambda1 = {"lambda1", (PyCFunction)__pyx_pw_6gevent_17_gevent_cgreenlet_7lambda1, METH_O, 0};
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_7lambda1(PyObject *__pyx_self, PyObject *__pyx_v_s) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda1 (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_lambda_funcdef_6gevent_17_gevent_cgreenlet_lambda1(__pyx_self, ((PyObject *)__pyx_v_s));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_6gevent_17_gevent_cgreenlet_lambda1(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_s) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda1", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_s, __pyx_mstate_global->__pyx_n_u_parent); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 53, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.lambda1", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":56
 * # This must also ONLY be called when we know that S is not None and is in fact a greenlet
 * # object (including the result of getcurrent())
 * locals()['get_generic_parent'] = lambda s: s.parent             # <<<<<<<<<<<<<<
 * 
 * # Frame access
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8lambda2(PyObject *__pyx_self, PyObject *__pyx_v_s); /*proto*/
static PyMethodDef __pyx_mdef_6gevent_17_gevent_cgreenlet_8lambda2 = {"lambda2", (PyCFunction)__pyx_pw_6gevent_17_gevent_cgreenlet_8lambda2, METH_O, 0};
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8lambda2(PyObject *__pyx_self, PyObject *__pyx_v_s) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda2 (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_lambda_funcdef_6gevent_17_gevent_cgreenlet_lambda2(__pyx_self, ((PyObject *)__pyx_v_s));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_6gevent_17_gevent_cgreenlet_lambda2(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_s) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda2", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_s, __pyx_mstate_global->__pyx_n_u_parent); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 56, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.lambda2", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":59
 * 
 * # Frame access
 * locals()['Gevent_PyFrame_GetCode'] = lambda frame: frame.f_code             # <<<<<<<<<<<<<<
 * locals()['Gevent_PyFrame_GetLineNumber'] = lambda frame: frame.f_lineno
 * locals()['Gevent_PyFrame_GetBack'] = lambda frame: frame.f_back
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_9lambda3(PyObject *__pyx_self, PyObject *__pyx_v_frame); /*proto*/
static PyMethodDef __pyx_mdef_6gevent_17_gevent_cgreenlet_9lambda3 = {"lambda3", (PyCFunction)__pyx_pw_6gevent_17_gevent_cgreenlet_9lambda3, METH_O, 0};
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_9lambda3(PyObject *__pyx_self, PyObject *__pyx_v_frame) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda3 (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_lambda_funcdef_6gevent_17_gevent_cgreenlet_lambda3(__pyx_self, ((PyObject *)__pyx_v_frame));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_6gevent_17_gevent_cgreenlet_lambda3(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_frame) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda3", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_frame, __pyx_mstate_global->__pyx_n_u_f_code); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 59, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.lambda3", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":60
 * # Frame access
 * locals()['Gevent_PyFrame_GetCode'] = lambda frame: frame.f_code
 * locals()['Gevent_PyFrame_GetLineNumber'] = lambda frame: frame.f_lineno             # <<<<<<<<<<<<<<
 * locals()['Gevent_PyFrame_GetBack'] = lambda frame: frame.f_back
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_10lambda4(PyObject *__pyx_self, PyObject *__pyx_v_frame); /*proto*/
static PyMethodDef __pyx_mdef_6gevent_17_gevent_cgreenlet_10lambda4 = {"lambda4", (PyCFunction)__pyx_pw_6gevent_17_gevent_cgreenlet_10lambda4, METH_O, 0};
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_10lambda4(PyObject *__pyx_self, PyObject *__pyx_v_frame) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda4 (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_lambda_funcdef_6gevent_17_gevent_cgreenlet_lambda4(__pyx_self, ((PyObject *)__pyx_v_frame));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_6gevent_17_gevent_cgreenlet_lambda4(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_frame) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda4", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_frame, __pyx_mstate_global->__pyx_n_u_f_lineno); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 60, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.lambda4", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":61
 * locals()['Gevent_PyFrame_GetCode'] = lambda frame: frame.f_code
 * locals()['Gevent_PyFrame_GetLineNumber'] = lambda frame: frame.f_lineno
 * locals()['Gevent_PyFrame_GetBack'] = lambda frame: frame.f_back             # <<<<<<<<<<<<<<
 * 
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_11lambda5(PyObject *__pyx_self, PyObject *__pyx_v_frame); /*proto*/
static PyMethodDef __pyx_mdef_6gevent_17_gevent_cgreenlet_11lambda5 = {"lambda5", (PyCFunction)__pyx_pw_6gevent_17_gevent_cgreenlet_11lambda5, METH_O, 0};
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_11lambda5(PyObject *__pyx_self, PyObject *__pyx_v_frame) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda5 (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_lambda_funcdef_6gevent_17_gevent_cgreenlet_lambda5(__pyx_self, ((PyObject *)__pyx_v_frame));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_6gevent_17_gevent_cgreenlet_lambda5(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_frame) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda5", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_frame, __pyx_mstate_global->__pyx_n_u_f_back); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 61, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.lambda5", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cfunc.to_py":67
 * @cname("__Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter")
 * cdef object __Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter(object (*f)(list, object, object) ):
 *     def wrap(list greenlets, object exception, object waiter):             # <<<<<<<<<<<<<<
 *         """wrap(greenlets: list, exception, waiter)"""
 *         return f(greenlets, exception, waiter)
*/

/* Python wrapper */
static PyObject *__pyx_pw_11cfunc_dot_to_py_107__Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter_1wrap(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_11cfunc_dot_to_py_107__Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter_wrap, "wrap(greenlets: list, exception, waiter)");
static PyMethodDef __pyx_mdef_11cfunc_dot_to_py_107__Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter_1wrap = {"wrap", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_11cfunc_dot_to_py_107__Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter_1wrap, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_11cfunc_dot_to_py_107__Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter_wrap};
static PyObject *__pyx_pw_11cfunc_dot_to_py_107__Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter_1wrap(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_greenlets = 0;
  PyObject *__pyx_v_exception = 0;
  PyObject *__pyx_v_waiter = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("wrap (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_greenlets,&__pyx_mstate_global->__pyx_n_u_exception,&__pyx_mstate_global->__pyx_n_u_waiter,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(1, 67, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(1, 67, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(1, 67, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(1, 67, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "wrap", 0) < (0)) __PYX_ERR(1, 67, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("wrap", 1, 3, 3, i); __PYX_ERR(1, 67, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(1, 67, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(1, 67, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(1, 67, __pyx_L3_error)
    }
    __pyx_v_greenlets = ((PyObject*)values[0]);
    __pyx_v_exception = values[1];
    __pyx_v_waiter = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("wrap", 1, 3, 3, __pyx_nargs); __PYX_ERR(1, 67, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("cfunc.to_py.__Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter.wrap", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_greenlets), (&PyList_Type), 1, "greenlets", 1))) __PYX_ERR(1, 67, __pyx_L1_error)
  __pyx_r = __pyx_pf_11cfunc_dot_to_py_107__Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter_wrap(__pyx_self, __pyx_v_greenlets, __pyx_v_exception, __pyx_v_waiter);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11cfunc_dot_to_py_107__Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter_wrap(PyObject *__pyx_self, PyObject *__pyx_v_greenlets, PyObject *__pyx_v_exception, PyObject *__pyx_v_waiter) {
  struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter *__pyx_cur_scope;
  struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("wrap", 0);
  __pyx_outer_scope = (struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cfunc.to_py":69
 *     def wrap(list greenlets, object exception, object waiter):
 *         """wrap(greenlets: list, exception, waiter)"""
 *         return f(greenlets, exception, waiter)             # <<<<<<<<<<<<<<
 *     return wrap
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_cur_scope->__pyx_v_f(__pyx_v_greenlets, __pyx_v_exception, __pyx_v_waiter); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 69, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cfunc.to_py":67
 * @cname("__Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter")
 * cdef object __Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter(object (*f)(list, object, object) ):
 *     def wrap(list greenlets, object exception, object waiter):             # <<<<<<<<<<<<<<
 *         """wrap(greenlets: list, exception, waiter)"""
 *         return f(greenlets, exception, waiter)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cfunc.to_py.__Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter.wrap", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cfunc.to_py":65
 * 
 * 
 * @cname("__Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter")             # <<<<<<<<<<<<<<
 * cdef object __Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter(object (*f)(list, object, object) ):
 *     def wrap(list greenlets, object exception, object waiter):
*/

static PyObject *__Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter(PyObject *(*__pyx_v_f)(PyObject *, PyObject *, PyObject *)) {
  struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter *__pyx_cur_scope;
  PyObject *__pyx_v_wrap = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter", 0);
  __pyx_cur_scope = (struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter *)__pyx_tp_new___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter(__pyx_mstate_global->__pyx_ptype___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter, __pyx_mstate_global->__pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(1, 65, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_f = __pyx_v_f;

  /* "cfunc.to_py":67
 * @cname("__Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter")
 * cdef object __Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter(object (*f)(list, object, object) ):
 *     def wrap(list greenlets, object exception, object waiter):             # <<<<<<<<<<<<<<
 *         """wrap(greenlets: list, exception, waiter)"""
 *         return f(greenlets, exception, waiter)
*/
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_11cfunc_dot_to_py_107__Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter_1wrap, 0, __pyx_mstate_global->__pyx_n_u_Pyx_CFunc_53f338__6gevent_17_g, ((PyObject*)__pyx_cur_scope), __pyx_mstate_global->__pyx_n_u_cfunc_to_py, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[0])); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 67, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_wrap = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cfunc.to_py":70
 *         """wrap(greenlets: list, exception, waiter)"""
 *         return f(greenlets, exception, waiter)
 *     return wrap             # <<<<<<<<<<<<<<
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_wrap);
  __pyx_r = __pyx_v_wrap;
  goto __pyx_L0;

  /* "cfunc.to_py":65
 * 
 * 
 * @cname("__Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter")             # <<<<<<<<<<<<<<
 * cdef object __Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter(object (*f)(list, object, object) ):
 *     def wrap(list greenlets, object exception, object waiter):
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cfunc.to_py.__Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_wrap);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cfunc.to_py":67
 * @cname("__Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception")
 * cdef object __Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception(object (*f)(list, object) ):
 *     def wrap(list greenlets, object exception):             # <<<<<<<<<<<<<<
 *         """wrap(greenlets: list, exception)"""
 *         return f(greenlets, exception)
*/

/* Python wrapper */
static PyObject *__pyx_pw_11cfunc_dot_to_py_99__Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_1wrap(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_11cfunc_dot_to_py_99__Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_wrap, "wrap(greenlets: list, exception)");
static PyMethodDef __pyx_mdef_11cfunc_dot_to_py_99__Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_1wrap = {"wrap", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_11cfunc_dot_to_py_99__Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_1wrap, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_11cfunc_dot_to_py_99__Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_wrap};
static PyObject *__pyx_pw_11cfunc_dot_to_py_99__Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_1wrap(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_greenlets = 0;
  PyObject *__pyx_v_exception = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("wrap (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_greenlets,&__pyx_mstate_global->__pyx_n_u_exception,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(1, 67, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(1, 67, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(1, 67, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "wrap", 0) < (0)) __PYX_ERR(1, 67, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("wrap", 1, 2, 2, i); __PYX_ERR(1, 67, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(1, 67, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(1, 67, __pyx_L3_error)
    }
    __pyx_v_greenlets = ((PyObject*)values[0]);
    __pyx_v_exception = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("wrap", 1, 2, 2, __pyx_nargs); __PYX_ERR(1, 67, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("cfunc.to_py.__Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception.wrap", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_greenlets), (&PyList_Type), 1, "greenlets", 1))) __PYX_ERR(1, 67, __pyx_L1_error)
  __pyx_r = __pyx_pf_11cfunc_dot_to_py_99__Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_wrap(__pyx_self, __pyx_v_greenlets, __pyx_v_exception);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11cfunc_dot_to_py_99__Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_wrap(PyObject *__pyx_self, PyObject *__pyx_v_greenlets, PyObject *__pyx_v_exception) {
  struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception *__pyx_cur_scope;
  struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("wrap", 0);
  __pyx_outer_scope = (struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cfunc.to_py":69
 *     def wrap(list greenlets, object exception):
 *         """wrap(greenlets: list, exception)"""
 *         return f(greenlets, exception)             # <<<<<<<<<<<<<<
 *     return wrap
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_cur_scope->__pyx_v_f(__pyx_v_greenlets, __pyx_v_exception); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 69, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cfunc.to_py":67
 * @cname("__Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception")
 * cdef object __Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception(object (*f)(list, object) ):
 *     def wrap(list greenlets, object exception):             # <<<<<<<<<<<<<<
 *         """wrap(greenlets: list, exception)"""
 *         return f(greenlets, exception)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cfunc.to_py.__Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception.wrap", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cfunc.to_py":65
 * 
 * 
 * @cname("__Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception")             # <<<<<<<<<<<<<<
 * cdef object __Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception(object (*f)(list, object) ):
 *     def wrap(list greenlets, object exception):
*/

static PyObject *__Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception(PyObject *(*__pyx_v_f)(PyObject *, PyObject *)) {
  struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception *__pyx_cur_scope;
  PyObject *__pyx_v_wrap = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception", 0);
  __pyx_cur_scope = (struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception *)__pyx_tp_new___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception(__pyx_mstate_global->__pyx_ptype___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception, __pyx_mstate_global->__pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(1, 65, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_f = __pyx_v_f;

  /* "cfunc.to_py":67
 * @cname("__Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception")
 * cdef object __Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception(object (*f)(list, object) ):
 *     def wrap(list greenlets, object exception):             # <<<<<<<<<<<<<<
 *         """wrap(greenlets: list, exception)"""
 *         return f(greenlets, exception)
*/
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_11cfunc_dot_to_py_99__Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_1wrap, 0, __pyx_mstate_global->__pyx_n_u_Pyx_CFunc_adc8fb__6gevent_17_g, ((PyObject*)__pyx_cur_scope), __pyx_mstate_global->__pyx_n_u_cfunc_to_py, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[1])); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 67, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_wrap = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cfunc.to_py":70
 *         """wrap(greenlets: list, exception)"""
 *         return f(greenlets, exception)
 *     return wrap             # <<<<<<<<<<<<<<
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_wrap);
  __pyx_r = __pyx_v_wrap;
  goto __pyx_L0;

  /* "cfunc.to_py":65
 * 
 * 
 * @cname("__Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception")             # <<<<<<<<<<<<<<
 * cdef object __Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception(object (*f)(list, object) ):
 *     def wrap(list greenlets, object exception):
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cfunc.to_py.__Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_wrap);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/_gevent_c_greenlet_primitives.pxd":22
 *     void PyGreenlet_Import()
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef inline greenlet getcurrent():
 *     return PyGreenlet_GetCurrent()
*/

static CYTHON_INLINE PyGreenlet *__pyx_f_6gevent_29_gevent_c_greenlet_primitives_getcurrent(void) {
  PyGreenlet *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getcurrent", 0);

  /* "gevent/_gevent_c_greenlet_primitives.pxd":24
 * @cython.final
 * cdef inline greenlet getcurrent():
 *     return PyGreenlet_GetCurrent()             # <<<<<<<<<<<<<<
 * 
 * cdef bint _greenlet_imported
*/
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __pyx_t_1 = ((PyObject *)PyGreenlet_GetCurrent()); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = ((PyGreenlet *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "gevent/_gevent_c_greenlet_primitives.pxd":22
 *     void PyGreenlet_Import()
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef inline greenlet getcurrent():
 *     return PyGreenlet_GetCurrent()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_c_greenlet_primitives.getcurrent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/_gevent_c_greenlet_primitives.pxd":28
 * cdef bint _greenlet_imported
 * 
 * cdef inline void greenlet_init():             # <<<<<<<<<<<<<<
 *     global _greenlet_imported
 *     if not _greenlet_imported:
*/

static CYTHON_INLINE void __pyx_f_6gevent_29_gevent_c_greenlet_primitives_greenlet_init(void) {
  int __pyx_t_1;

  /* "gevent/_gevent_c_greenlet_primitives.pxd":30
 * cdef inline void greenlet_init():
 *     global _greenlet_imported
 *     if not _greenlet_imported:             # <<<<<<<<<<<<<<
 *         PyGreenlet_Import()
 *         _greenlet_imported = True
*/
  __pyx_t_1 = (!__pyx_v_6gevent_29_gevent_c_greenlet_primitives__greenlet_imported);
  if (__pyx_t_1) {

    /* "gevent/_gevent_c_greenlet_primitives.pxd":31
 *     global _greenlet_imported
 *     if not _greenlet_imported:
 *         PyGreenlet_Import()             # <<<<<<<<<<<<<<
 *         _greenlet_imported = True
 * 
*/
    PyGreenlet_Import();

    /* "gevent/_gevent_c_greenlet_primitives.pxd":32
 *     if not _greenlet_imported:
 *         PyGreenlet_Import()
 *         _greenlet_imported = True             # <<<<<<<<<<<<<<
 * 
 * cdef inline object _greenlet_switch(greenlet self):
*/
    __pyx_v_6gevent_29_gevent_c_greenlet_primitives__greenlet_imported = 1;

    /* "gevent/_gevent_c_greenlet_primitives.pxd":30
 * cdef inline void greenlet_init():
 *     global _greenlet_imported
 *     if not _greenlet_imported:             # <<<<<<<<<<<<<<
 *         PyGreenlet_Import()
 *         _greenlet_imported = True
*/
  }

  /* "gevent/_gevent_c_greenlet_primitives.pxd":28
 * cdef bint _greenlet_imported
 * 
 * cdef inline void greenlet_init():             # <<<<<<<<<<<<<<
 *     global _greenlet_imported
 *     if not _greenlet_imported:
*/

  /* function exit code */
}

/* "gevent/_gevent_c_greenlet_primitives.pxd":34
 *         _greenlet_imported = True
 * 
 * cdef inline object _greenlet_switch(greenlet self):             # <<<<<<<<<<<<<<
 *     return PyGreenlet_Switch(self, NULL, NULL)
 * 
*/

static CYTHON_INLINE PyObject *__pyx_f_6gevent_29_gevent_c_greenlet_primitives__greenlet_switch(PyGreenlet *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_greenlet_switch", 0);

  /* "gevent/_gevent_c_greenlet_primitives.pxd":35
 * 
 * cdef inline object _greenlet_switch(greenlet self):
 *     return PyGreenlet_Switch(self, NULL, NULL)             # <<<<<<<<<<<<<<
 * 
 * cdef class TrackedRawGreenlet(greenlet):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyGreenlet_Switch(__pyx_v_self, NULL, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 35, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "gevent/_gevent_c_greenlet_primitives.pxd":34
 *         _greenlet_imported = True
 * 
 * cdef inline object _greenlet_switch(greenlet self):             # <<<<<<<<<<<<<<
 *     return PyGreenlet_Switch(self, NULL, NULL)
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_c_greenlet_primitives._greenlet_switch", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/_gevent_c_waiter.pxd":24
 *     void PyGreenlet_Import()
 * 
 * cdef inline greenlet getcurrent():             # <<<<<<<<<<<<<<
 *     return PyGreenlet_GetCurrent()
 * 
*/

static CYTHON_INLINE PyGreenlet *__pyx_f_6gevent_16_gevent_c_waiter_getcurrent(void) {
  PyGreenlet *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getcurrent", 0);

  /* "gevent/_gevent_c_waiter.pxd":25
 * 
 * cdef inline greenlet getcurrent():
 *     return PyGreenlet_GetCurrent()             # <<<<<<<<<<<<<<
 * 
 * cdef inline void greenlet_init():
*/
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __pyx_t_1 = ((PyObject *)PyGreenlet_GetCurrent()); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = ((PyGreenlet *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "gevent/_gevent_c_waiter.pxd":24
 *     void PyGreenlet_Import()
 * 
 * cdef inline greenlet getcurrent():             # <<<<<<<<<<<<<<
 *     return PyGreenlet_GetCurrent()
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_c_waiter.getcurrent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/_gevent_c_waiter.pxd":27
 *     return PyGreenlet_GetCurrent()
 * 
 * cdef inline void greenlet_init():             # <<<<<<<<<<<<<<
 *     global _greenlet_imported
 *     if not _greenlet_imported:
*/

static CYTHON_INLINE void __pyx_f_6gevent_16_gevent_c_waiter_greenlet_init(void) {
  int __pyx_t_1;

  /* "gevent/_gevent_c_waiter.pxd":29
 * cdef inline void greenlet_init():
 *     global _greenlet_imported
 *     if not _greenlet_imported:             # <<<<<<<<<<<<<<
 *         PyGreenlet_Import()
 *         _greenlet_imported = True
*/
  __pyx_t_1 = (!__pyx_v_6gevent_16_gevent_c_waiter__greenlet_imported);
  if (__pyx_t_1) {

    /* "gevent/_gevent_c_waiter.pxd":30
 *     global _greenlet_imported
 *     if not _greenlet_imported:
 *         PyGreenlet_Import()             # <<<<<<<<<<<<<<
 *         _greenlet_imported = True
 * 
*/
    PyGreenlet_Import();

    /* "gevent/_gevent_c_waiter.pxd":31
 *     if not _greenlet_imported:
 *         PyGreenlet_Import()
 *         _greenlet_imported = True             # <<<<<<<<<<<<<<
 * 
 * cdef class Waiter:
*/
    __pyx_v_6gevent_16_gevent_c_waiter__greenlet_imported = 1;

    /* "gevent/_gevent_c_waiter.pxd":29
 * cdef inline void greenlet_init():
 *     global _greenlet_imported
 *     if not _greenlet_imported:             # <<<<<<<<<<<<<<
 *         PyGreenlet_Import()
 *         _greenlet_imported = True
*/
  }

  /* "gevent/_gevent_c_waiter.pxd":27
 *     return PyGreenlet_GetCurrent()
 * 
 * cdef inline void greenlet_init():             # <<<<<<<<<<<<<<
 *     global _greenlet_imported
 *     if not _greenlet_imported:
*/

  /* function exit code */
}

/* "gevent/_gevent_cgreenlet.pxd":36
 *     void PyGreenlet_Import()
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef inline greenlet getcurrent():
 *     return PyGreenlet_GetCurrent()
*/

static CYTHON_INLINE PyGreenlet *__pyx_f_6gevent_17_gevent_cgreenlet_getcurrent(void) {
  PyGreenlet *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getcurrent", 0);

  /* "gevent/_gevent_cgreenlet.pxd":38
 * @cython.final
 * cdef inline greenlet getcurrent():
 *     return PyGreenlet_GetCurrent()             # <<<<<<<<<<<<<<
 * 
 * cdef inline object get_generic_parent(greenlet s):
*/
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __pyx_t_1 = ((PyObject *)PyGreenlet_GetCurrent()); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 38, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = ((PyGreenlet *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "gevent/_gevent_cgreenlet.pxd":36
 *     void PyGreenlet_Import()
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef inline greenlet getcurrent():
 *     return PyGreenlet_GetCurrent()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.getcurrent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/_gevent_cgreenlet.pxd":40
 *     return PyGreenlet_GetCurrent()
 * 
 * cdef inline object get_generic_parent(greenlet s):             # <<<<<<<<<<<<<<
 *     # We don't use any typed functions on the return of this,
 *     # so save the type check by making it just an object.
*/

static CYTHON_INLINE PyObject *__pyx_f_6gevent_17_gevent_cgreenlet_get_generic_parent(PyGreenlet *__pyx_v_s) {
  PyObject *__pyx_v_result = 0;
  void *__pyx_v_parent;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("get_generic_parent", 0);

  /* "gevent/_gevent_cgreenlet.pxd":44
 *     # so save the type check by making it just an object.
 *     cdef object result
 *     cdef void* parent = PyGreenlet_GetParent(s)             # <<<<<<<<<<<<<<
 *     if parent != NULL:
 *         # The cast will perform an incref; but the GetParent
*/
  __pyx_v_parent = PyGreenlet_GetParent(__pyx_v_s);

  /* "gevent/_gevent_cgreenlet.pxd":45
 *     cdef object result
 *     cdef void* parent = PyGreenlet_GetParent(s)
 *     if parent != NULL:             # <<<<<<<<<<<<<<
 *         # The cast will perform an incref; but the GetParent
 *         # function already did an incref if we got it (and not NULL).
*/
  __pyx_t_1 = (__pyx_v_parent != NULL);
  if (__pyx_t_1) {

    /* "gevent/_gevent_cgreenlet.pxd":49
 *         # function already did an incref if we got it (and not NULL).
 *         # Therefore, we must DECREF immediately.
 *         result = <object>parent             # <<<<<<<<<<<<<<
 *         Py_DECREF(result)
 *         return result
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_parent);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v_result = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "gevent/_gevent_cgreenlet.pxd":50
 *         # Therefore, we must DECREF immediately.
 *         result = <object>parent
 *         Py_DECREF(result)             # <<<<<<<<<<<<<<
 *         return result
 * 
*/
    Py_DECREF(__pyx_v_result);

    /* "gevent/_gevent_cgreenlet.pxd":51
 *         result = <object>parent
 *         Py_DECREF(result)
 *         return result             # <<<<<<<<<<<<<<
 * 
 * cdef inline SwitchOutGreenletWithLoop get_my_hub(greenlet s):
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_result);
    __pyx_r = __pyx_v_result;
    goto __pyx_L0;

    /* "gevent/_gevent_cgreenlet.pxd":45
 *     cdef object result
 *     cdef void* parent = PyGreenlet_GetParent(s)
 *     if parent != NULL:             # <<<<<<<<<<<<<<
 *         # The cast will perform an incref; but the GetParent
 *         # function already did an incref if we got it (and not NULL).
*/
  }

  /* "gevent/_gevent_cgreenlet.pxd":40
 *     return PyGreenlet_GetCurrent()
 * 
 * cdef inline object get_generic_parent(greenlet s):             # <<<<<<<<<<<<<<
 *     # We don't use any typed functions on the return of this,
 *     # so save the type check by making it just an object.
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/_gevent_cgreenlet.pxd":53
 *         return result
 * 
 * cdef inline SwitchOutGreenletWithLoop get_my_hub(greenlet s):             # <<<<<<<<<<<<<<
 *     # This one we do want type checked on the return value.
 *     # Must not be called with s = None
*/

static CYTHON_INLINE struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *__pyx_f_6gevent_17_gevent_cgreenlet_get_my_hub(PyGreenlet *__pyx_v_s) {
  PyObject *__pyx_v_result = 0;
  void *__pyx_v_parent;
  struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_my_hub", 0);

  /* "gevent/_gevent_cgreenlet.pxd":57
 *     # Must not be called with s = None
 *     cdef object result
 *     cdef void* parent = PyGreenlet_GetParent(s)             # <<<<<<<<<<<<<<
 *     if parent != NULL:
 *         result = <object>parent
*/
  __pyx_v_parent = PyGreenlet_GetParent(__pyx_v_s);

  /* "gevent/_gevent_cgreenlet.pxd":58
 *     cdef object result
 *     cdef void* parent = PyGreenlet_GetParent(s)
 *     if parent != NULL:             # <<<<<<<<<<<<<<
 *         result = <object>parent
 *         # See above
*/
  __pyx_t_1 = (__pyx_v_parent != NULL);
  if (__pyx_t_1) {

    /* "gevent/_gevent_cgreenlet.pxd":59
 *     cdef void* parent = PyGreenlet_GetParent(s)
 *     if parent != NULL:
 *         result = <object>parent             # <<<<<<<<<<<<<<
 *         # See above
 *         Py_DECREF(result)
*/
    __pyx_t_2 = ((PyObject *)__pyx_v_parent);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v_result = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "gevent/_gevent_cgreenlet.pxd":61
 *         result = <object>parent
 *         # See above
 *         Py_DECREF(result)             # <<<<<<<<<<<<<<
 *         return result
 * 
*/
    Py_DECREF(__pyx_v_result);

    /* "gevent/_gevent_cgreenlet.pxd":62
 *         # See above
 *         Py_DECREF(result)
 *         return result             # <<<<<<<<<<<<<<
 * 
 * cdef bint _greenlet_imported
*/
    __Pyx_XDECREF((PyObject *)__pyx_r);
    if (!(likely(((__pyx_v_result) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_result, __pyx_mstate_global->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop))))) __PYX_ERR(4, 62, __pyx_L1_error)
    __Pyx_INCREF(__pyx_v_result);
    __pyx_r = ((struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *)__pyx_v_result);
    goto __pyx_L0;

    /* "gevent/_gevent_cgreenlet.pxd":58
 *     cdef object result
 *     cdef void* parent = PyGreenlet_GetParent(s)
 *     if parent != NULL:             # <<<<<<<<<<<<<<
 *         result = <object>parent
 *         # See above
*/
  }

  /* "gevent/_gevent_cgreenlet.pxd":53
 *         return result
 * 
 * cdef inline SwitchOutGreenletWithLoop get_my_hub(greenlet s):             # <<<<<<<<<<<<<<
 *     # This one we do want type checked on the return value.
 *     # Must not be called with s = None
*/

  /* function exit code */
  __pyx_r = ((struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *)Py_None); __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.get_my_hub", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/_gevent_cgreenlet.pxd":66
 * cdef bint _greenlet_imported
 * 
 * cdef inline void greenlet_init():             # <<<<<<<<<<<<<<
 *     global _greenlet_imported
 *     if not _greenlet_imported:
*/

static CYTHON_INLINE void __pyx_f_6gevent_17_gevent_cgreenlet_greenlet_init(void) {
  int __pyx_t_1;

  /* "gevent/_gevent_cgreenlet.pxd":68
 * cdef inline void greenlet_init():
 *     global _greenlet_imported
 *     if not _greenlet_imported:             # <<<<<<<<<<<<<<
 *         PyGreenlet_Import()
 *         _greenlet_imported = True
*/
  __pyx_t_1 = (!__pyx_v_6gevent_17_gevent_cgreenlet__greenlet_imported);
  if (__pyx_t_1) {

    /* "gevent/_gevent_cgreenlet.pxd":69
 *     global _greenlet_imported
 *     if not _greenlet_imported:
 *         PyGreenlet_Import()             # <<<<<<<<<<<<<<
 *         _greenlet_imported = True
 * 
*/
    PyGreenlet_Import();

    /* "gevent/_gevent_cgreenlet.pxd":70
 *     if not _greenlet_imported:
 *         PyGreenlet_Import()
 *         _greenlet_imported = True             # <<<<<<<<<<<<<<
 * 
 * ctypedef object CodeType
*/
    __pyx_v_6gevent_17_gevent_cgreenlet__greenlet_imported = 1;

    /* "gevent/_gevent_cgreenlet.pxd":68
 * cdef inline void greenlet_init():
 *     global _greenlet_imported
 *     if not _greenlet_imported:             # <<<<<<<<<<<<<<
 *         PyGreenlet_Import()
 *         _greenlet_imported = True
*/
  }

  /* "gevent/_gevent_cgreenlet.pxd":66
 * cdef bint _greenlet_imported
 * 
 * cdef inline void greenlet_init():             # <<<<<<<<<<<<<<
 *     global _greenlet_imported
 *     if not _greenlet_imported:
*/

  /* function exit code */
}

/* "src/gevent/greenlet.py":77
 *     __slots__ = ['callback']
 * 
 *     def __init__(self, callback):             # <<<<<<<<<<<<<<
 *         if not callable(callback):
 *             raise TypeError("Expected callable: %r" % (callback, ))
*/

/* Python wrapper */
static int __pyx_pw_6gevent_17_gevent_cgreenlet_11SpawnedLink_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6gevent_17_gevent_cgreenlet_11SpawnedLink_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_callback = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_callback,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 77, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 77, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__init__", 0) < (0)) __PYX_ERR(0, 77, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__init__", 1, 1, 1, i); __PYX_ERR(0, 77, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 77, __pyx_L3_error)
    }
    __pyx_v_callback = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 77, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.SpawnedLink.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_11SpawnedLink___init__(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink *)__pyx_v_self), __pyx_v_callback);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6gevent_17_gevent_cgreenlet_11SpawnedLink___init__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink *__pyx_v_self, PyObject *__pyx_v_callback) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  size_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "src/gevent/greenlet.py":78
 * 
 *     def __init__(self, callback):
 *         if not callable(callback):             # <<<<<<<<<<<<<<
 *             raise TypeError("Expected callable: %r" % (callback, ))
 *         self.callback = callback
*/
  __pyx_t_1 = __Pyx_PyCallable_Check(__pyx_v_callback); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 78, __pyx_L1_error)
  __pyx_t_2 = (!__pyx_t_1);
  if (unlikely(__pyx_t_2)) {

    /* "src/gevent/greenlet.py":79
 *     def __init__(self, callback):
 *         if not callable(callback):
 *             raise TypeError("Expected callable: %r" % (callback, ))             # <<<<<<<<<<<<<<
 *         self.callback = callback
 * 
*/
    __pyx_t_4 = NULL;
    __pyx_t_5 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_callback), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 79, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_Expected_callable, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 79, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_7 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_6};
      __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_TypeError)), __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 79, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 79, __pyx_L1_error)

    /* "src/gevent/greenlet.py":78
 * 
 *     def __init__(self, callback):
 *         if not callable(callback):             # <<<<<<<<<<<<<<
 *             raise TypeError("Expected callable: %r" % (callback, ))
 *         self.callback = callback
*/
  }

  /* "src/gevent/greenlet.py":80
 *         if not callable(callback):
 *             raise TypeError("Expected callable: %r" % (callback, ))
 *         self.callback = callback             # <<<<<<<<<<<<<<
 * 
 *     def __call__(self, source):
*/
  __Pyx_INCREF(__pyx_v_callback);
  __Pyx_GIVEREF(__pyx_v_callback);
  __Pyx_GOTREF(__pyx_v_self->callback);
  __Pyx_DECREF(__pyx_v_self->callback);
  __pyx_v_self->callback = __pyx_v_callback;

  /* "src/gevent/greenlet.py":77
 *     __slots__ = ['callback']
 * 
 *     def __init__(self, callback):             # <<<<<<<<<<<<<<
 *         if not callable(callback):
 *             raise TypeError("Expected callable: %r" % (callback, ))
*/

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.SpawnedLink.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":82
 *         self.callback = callback
 * 
 *     def __call__(self, source):             # <<<<<<<<<<<<<<
 *         g = greenlet(self.callback, get_hub())
 *         g.switch(source)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_11SpawnedLink_3__call__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_11SpawnedLink_3__call__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_source = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__call__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_source,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 82, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 82, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__call__", 0) < (0)) __PYX_ERR(0, 82, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__call__", 1, 1, 1, i); __PYX_ERR(0, 82, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 82, __pyx_L3_error)
    }
    __pyx_v_source = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__call__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 82, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.SpawnedLink.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_11SpawnedLink_2__call__(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink *)__pyx_v_self), __pyx_v_source);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_11SpawnedLink_2__call__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink *__pyx_v_self, PyObject *__pyx_v_source) {
  PyGreenlet *__pyx_v_g = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__call__", 0);

  /* "src/gevent/greenlet.py":83
 * 
 *     def __call__(self, source):
 *         g = greenlet(self.callback, get_hub())             # <<<<<<<<<<<<<<
 *         g.switch(source)
 * 
*/
  __pyx_t_2 = NULL;
  __pyx_t_3 = ((PyObject *)__pyx_f_6gevent_19_gevent_c_hub_local_get_hub_noargs(0)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 83, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = 1;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_self->callback, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_greenlet, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 83, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_1);
  }
  __pyx_v_g = ((PyGreenlet *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "src/gevent/greenlet.py":84
 *     def __call__(self, source):
 *         g = greenlet(self.callback, get_hub())
 *         g.switch(source)             # <<<<<<<<<<<<<<
 * 
 *     def __hash__(self):
*/
  __pyx_t_3 = ((PyObject *)__pyx_v_g);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_source};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_switch, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 84, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "src/gevent/greenlet.py":82
 *         self.callback = callback
 * 
 *     def __call__(self, source):             # <<<<<<<<<<<<<<
 *         g = greenlet(self.callback, get_hub())
 *         g.switch(source)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.SpawnedLink.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_g);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":86
 *         g.switch(source)
 * 
 *     def __hash__(self):             # <<<<<<<<<<<<<<
 *         return hash(self.callback)
 * 
*/

/* Python wrapper */
static Py_hash_t __pyx_pw_6gevent_17_gevent_cgreenlet_11SpawnedLink_5__hash__(PyObject *__pyx_v_self); /*proto*/
static Py_hash_t __pyx_pw_6gevent_17_gevent_cgreenlet_11SpawnedLink_5__hash__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  Py_hash_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__hash__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_11SpawnedLink_4__hash__(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_hash_t __pyx_pf_6gevent_17_gevent_cgreenlet_11SpawnedLink_4__hash__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink *__pyx_v_self) {
  Py_hash_t __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_hash_t __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__hash__", 0);

  /* "src/gevent/greenlet.py":87
 * 
 *     def __hash__(self):
 *         return hash(self.callback)             # <<<<<<<<<<<<<<
 * 
 *     def __eq__(self, other):
*/
  __pyx_t_1 = __pyx_v_self->callback;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Hash(__pyx_t_1); if (unlikely(__pyx_t_2 == ((Py_hash_t)-1))) __PYX_ERR(0, 87, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  goto __pyx_L0;

  /* "src/gevent/greenlet.py":86
 *         g.switch(source)
 * 
 *     def __hash__(self):             # <<<<<<<<<<<<<<
 *         return hash(self.callback)
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.SpawnedLink.__hash__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  if (unlikely(__pyx_r == -1) && !PyErr_Occurred()) __pyx_r = -2;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":89
 *         return hash(self.callback)
 * 
 *     def __eq__(self, other):             # <<<<<<<<<<<<<<
 *         return self.callback == getattr(other, 'callback', other)
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_11SpawnedLink_7__eq__(PyObject *__pyx_v_self, PyObject *__pyx_v_other); /*proto*/
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_11SpawnedLink_7__eq__(PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__eq__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_11SpawnedLink_6__eq__(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink *)__pyx_v_self), ((PyObject *)__pyx_v_other));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_11SpawnedLink_6__eq__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__eq__", 0);

  /* "src/gevent/greenlet.py":90
 * 
 *     def __eq__(self, other):
 *         return self.callback == getattr(other, 'callback', other)             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_GetAttr3(__pyx_v_other, __pyx_mstate_global->__pyx_n_u_callback, __pyx_v_other); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 90, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_RichCompare(__pyx_v_self->callback, __pyx_t_1, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 90, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "src/gevent/greenlet.py":89
 *         return hash(self.callback)
 * 
 *     def __eq__(self, other):             # <<<<<<<<<<<<<<
 *         return self.callback == getattr(other, 'callback', other)
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.SpawnedLink.__eq__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":92
 *         return self.callback == getattr(other, 'callback', other)
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return str(self.callback)
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_11SpawnedLink_9__str__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_11SpawnedLink_9__str__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_11SpawnedLink_8__str__(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_11SpawnedLink_8__str__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 0);

  /* "src/gevent/greenlet.py":93
 * 
 *     def __str__(self):
 *         return str(self.callback)             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_Unicode(__pyx_v_self->callback); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 93, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "src/gevent/greenlet.py":92
 *         return self.callback == getattr(other, 'callback', other)
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return str(self.callback)
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.SpawnedLink.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":95
 *         return str(self.callback)
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return repr(self.callback)
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_11SpawnedLink_11__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_11SpawnedLink_11__repr__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_11SpawnedLink_10__repr__(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_11SpawnedLink_10__repr__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "src/gevent/greenlet.py":96
 * 
 *     def __repr__(self):
 *         return repr(self.callback)             # <<<<<<<<<<<<<<
 * 
 *     def __getattr__(self, item):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_v_self->callback;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Repr(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 96, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "src/gevent/greenlet.py":95
 *         return str(self.callback)
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return repr(self.callback)
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.SpawnedLink.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":98
 *         return repr(self.callback)
 * 
 *     def __getattr__(self, item):             # <<<<<<<<<<<<<<
 *         assert item != 'callback'
 *         return getattr(self.callback, item)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_11SpawnedLink_13__getattr__(PyObject *__pyx_v_self, PyObject *__pyx_v_item); /*proto*/
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_11SpawnedLink_13__getattr__(PyObject *__pyx_v_self, PyObject *__pyx_v_item) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getattr__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_11SpawnedLink_12__getattr__(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink *)__pyx_v_self), ((PyObject *)__pyx_v_item));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_11SpawnedLink_12__getattr__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink *__pyx_v_self, PyObject *__pyx_v_item) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getattr__", 0);

  /* "src/gevent/greenlet.py":99
 * 
 *     def __getattr__(self, item):
 *         assert item != 'callback'             # <<<<<<<<<<<<<<
 *         return getattr(self.callback, item)
 * 
*/
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(__pyx_assertions_enabled())) {
    __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_item, __pyx_mstate_global->__pyx_n_u_callback, Py_NE)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 99, __pyx_L1_error)
    if (unlikely(!__pyx_t_1)) {
      __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_AssertionError))), 0, 0, 0);
      __PYX_ERR(0, 99, __pyx_L1_error)
    }
  }
  #else
  if ((1)); else __PYX_ERR(0, 99, __pyx_L1_error)
  #endif

  /* "src/gevent/greenlet.py":100
 *     def __getattr__(self, item):
 *         assert item != 'callback'
 *         return getattr(self.callback, item)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __pyx_v_self->callback;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_GetAttr(__pyx_t_2, __pyx_v_item); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 100, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "src/gevent/greenlet.py":98
 *         return repr(self.callback)
 * 
 *     def __getattr__(self, item):             # <<<<<<<<<<<<<<
 *         assert item != 'callback'
 *         return getattr(self.callback, item)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.SpawnedLink.__getattr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/_gevent_cgreenlet.pxd":101
 * 
 * cdef class SpawnedLink:
 *     cdef public object callback             # <<<<<<<<<<<<<<
 * 
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_11SpawnedLink_8callback_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_11SpawnedLink_8callback_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_11SpawnedLink_8callback___get__(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_11SpawnedLink_8callback___get__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->callback);
  __pyx_r = __pyx_v_self->callback;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6gevent_17_gevent_cgreenlet_11SpawnedLink_8callback_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6gevent_17_gevent_cgreenlet_11SpawnedLink_8callback_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_11SpawnedLink_8callback_2__set__(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6gevent_17_gevent_cgreenlet_11SpawnedLink_8callback_2__set__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->callback);
  __Pyx_DECREF(__pyx_v_self->callback);
  __pyx_v_self->callback = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6gevent_17_gevent_cgreenlet_11SpawnedLink_8callback_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6gevent_17_gevent_cgreenlet_11SpawnedLink_8callback_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_11SpawnedLink_8callback_4__del__(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6gevent_17_gevent_cgreenlet_11SpawnedLink_8callback_4__del__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->callback);
  __Pyx_DECREF(__pyx_v_self->callback);
  __pyx_v_self->callback = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":110
 *     __slots__ = []
 * 
 *     def __call__(self, source):             # <<<<<<<<<<<<<<
 *         if source.successful():
 *             return SpawnedLink.__call__(self, source)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_18SuccessSpawnedLink_1__call__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_18SuccessSpawnedLink_1__call__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_source = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__call__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_source,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 110, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 110, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__call__", 0) < (0)) __PYX_ERR(0, 110, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__call__", 1, 1, 1, i); __PYX_ERR(0, 110, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 110, __pyx_L3_error)
    }
    __pyx_v_source = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__call__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 110, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.SuccessSpawnedLink.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_18SuccessSpawnedLink___call__(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink *)__pyx_v_self), __pyx_v_source);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_18SuccessSpawnedLink___call__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink *__pyx_v_self, PyObject *__pyx_v_source) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__call__", 0);

  /* "src/gevent/greenlet.py":111
 * 
 *     def __call__(self, source):
 *         if source.successful():             # <<<<<<<<<<<<<<
 *             return SpawnedLink.__call__(self, source)
 * 
*/
  __pyx_t_2 = __pyx_v_source;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_successful, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 111, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_4) {

    /* "src/gevent/greenlet.py":112
 *     def __call__(self, source):
 *         if source.successful():
 *             return SpawnedLink.__call__(self, source)             # <<<<<<<<<<<<<<
 * 
 * 
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_SpawnedLink);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_2, ((PyObject *)__pyx_v_self), __pyx_v_source};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_call, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 112, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "src/gevent/greenlet.py":111
 * 
 *     def __call__(self, source):
 *         if source.successful():             # <<<<<<<<<<<<<<
 *             return SpawnedLink.__call__(self, source)
 * 
*/
  }

  /* "src/gevent/greenlet.py":110
 *     __slots__ = []
 * 
 *     def __call__(self, source):             # <<<<<<<<<<<<<<
 *         if source.successful():
 *             return SpawnedLink.__call__(self, source)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.SuccessSpawnedLink.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":122
 *     __slots__ = []
 * 
 *     def __call__(self, source):             # <<<<<<<<<<<<<<
 *         if not source.successful():
 *             return SpawnedLink.__call__(self, source)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_18FailureSpawnedLink_1__call__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_18FailureSpawnedLink_1__call__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_source = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__call__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_source,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 122, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 122, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__call__", 0) < (0)) __PYX_ERR(0, 122, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__call__", 1, 1, 1, i); __PYX_ERR(0, 122, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 122, __pyx_L3_error)
    }
    __pyx_v_source = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__call__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 122, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.FailureSpawnedLink.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_18FailureSpawnedLink___call__(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_FailureSpawnedLink *)__pyx_v_self), __pyx_v_source);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_18FailureSpawnedLink___call__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_FailureSpawnedLink *__pyx_v_self, PyObject *__pyx_v_source) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__call__", 0);

  /* "src/gevent/greenlet.py":123
 * 
 *     def __call__(self, source):
 *         if not source.successful():             # <<<<<<<<<<<<<<
 *             return SpawnedLink.__call__(self, source)
 * 
*/
  __pyx_t_2 = __pyx_v_source;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_successful, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 123, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 123, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = (!__pyx_t_4);
  if (__pyx_t_5) {

    /* "src/gevent/greenlet.py":124
 *     def __call__(self, source):
 *         if not source.successful():
 *             return SpawnedLink.__call__(self, source)             # <<<<<<<<<<<<<<
 * 
 * class _Frame(object):
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_SpawnedLink);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_2, ((PyObject *)__pyx_v_self), __pyx_v_source};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_call, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 124, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "src/gevent/greenlet.py":123
 * 
 *     def __call__(self, source):
 *         if not source.successful():             # <<<<<<<<<<<<<<
 *             return SpawnedLink.__call__(self, source)
 * 
*/
  }

  /* "src/gevent/greenlet.py":122
 *     __slots__ = []
 * 
 *     def __call__(self, source):             # <<<<<<<<<<<<<<
 *         if not source.successful():
 *             return SpawnedLink.__call__(self, source)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.FailureSpawnedLink.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":130
 *     __slots__ = ('f_code', 'f_lineno', 'f_back')
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self.f_code = None
 *         self.f_back = None
*/

/* Python wrapper */
static int __pyx_pw_6gevent_17_gevent_cgreenlet_6_Frame_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6gevent_17_gevent_cgreenlet_6_Frame_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("__init__", 1, 0, 0, __pyx_nargs); return -1; }
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return -1;
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("__init__", __pyx_kwds); return -1;}
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_6_Frame___init__(((struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6gevent_17_gevent_cgreenlet_6_Frame___init__(struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "src/gevent/greenlet.py":131
 * 
 *     def __init__(self):
 *         self.f_code = None             # <<<<<<<<<<<<<<
 *         self.f_back = None
 *         self.f_lineno = 0
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->f_code);
  __Pyx_DECREF(__pyx_v_self->f_code);
  __pyx_v_self->f_code = ((__pyx_t_6gevent_17_gevent_cgreenlet_CodeType)Py_None);

  /* "src/gevent/greenlet.py":132
 *     def __init__(self):
 *         self.f_code = None
 *         self.f_back = None             # <<<<<<<<<<<<<<
 *         self.f_lineno = 0
 * 
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->f_back);
  __Pyx_DECREF((PyObject *)__pyx_v_self->f_back);
  __pyx_v_self->f_back = ((struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *)Py_None);

  /* "src/gevent/greenlet.py":133
 *         self.f_code = None
 *         self.f_back = None
 *         self.f_lineno = 0             # <<<<<<<<<<<<<<
 * 
 *     @property
*/
  __pyx_v_self->f_lineno = 0;

  /* "src/gevent/greenlet.py":130
 *     __slots__ = ('f_code', 'f_lineno', 'f_back')
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self.f_code = None
 *         self.f_back = None
*/

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":135
 *         self.f_lineno = 0
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def f_globals(self):
 *         return None
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_6_Frame_9f_globals_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_6_Frame_9f_globals_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_6_Frame_9f_globals___get__(((struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_6_Frame_9f_globals___get__(CYTHON_UNUSED struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "src/gevent/greenlet.py":137
 *     @property
 *     def f_globals(self):
 *         return None             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;

  /* "src/gevent/greenlet.py":135
 *         self.f_lineno = 0
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def f_globals(self):
 *         return None
*/

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/_gevent_cgreenlet.pxd":116
 * @cython.freelist(1000)
 * cdef class _Frame:
 *     cdef readonly CodeType f_code             # <<<<<<<<<<<<<<
 *     cdef readonly int f_lineno
 *     cdef readonly _Frame f_back
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_6_Frame_6f_code_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_6_Frame_6f_code_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_6_Frame_6f_code___get__(((struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_6_Frame_6f_code___get__(struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->f_code);
  __pyx_r = ((PyObject *)__pyx_v_self->f_code);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/_gevent_cgreenlet.pxd":117
 * cdef class _Frame:
 *     cdef readonly CodeType f_code
 *     cdef readonly int f_lineno             # <<<<<<<<<<<<<<
 *     cdef readonly _Frame f_back
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_6_Frame_8f_lineno_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_6_Frame_8f_lineno_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_6_Frame_8f_lineno___get__(((struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_6_Frame_8f_lineno___get__(struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyLong_From_int(__pyx_v_self->f_lineno); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet._Frame.f_lineno.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/_gevent_cgreenlet.pxd":118
 *     cdef readonly CodeType f_code
 *     cdef readonly int f_lineno
 *     cdef readonly _Frame f_back             # <<<<<<<<<<<<<<
 * 
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_6_Frame_6f_back_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_6_Frame_6f_back_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_6_Frame_6f_back___get__(((struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_6_Frame_6f_back___get__(struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->f_back);
  __pyx_r = ((PyObject *)__pyx_v_self->f_back);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":140
 * 
 * 
 * def _extract_stack(limit):             # <<<<<<<<<<<<<<
 *     try:
 *         frame = sys_getframe()
*/

static struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *__pyx_f_6gevent_17_gevent_cgreenlet__extract_stack(int __pyx_v_limit) {
  struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *__pyx_v_newest_Frame = 0;
  struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *__pyx_v_newer_Frame = 0;
  struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *__pyx_v_older_Frame = 0;
  PyObject *__pyx_v_frame = NULL;
  struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  size_t __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_extract_stack", 0);

  /* "src/gevent/greenlet.py":141
 * 
 * def _extract_stack(limit):
 *     try:             # <<<<<<<<<<<<<<
 *         frame = sys_getframe()
 *     except ValueError:
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "src/gevent/greenlet.py":142
 * def _extract_stack(limit):
 *     try:
 *         frame = sys_getframe()             # <<<<<<<<<<<<<<
 *     except ValueError:
 *         # In certain embedded cases that directly use the Python C api
*/
      __pyx_t_5 = NULL;
      __Pyx_INCREF(__pyx_v_6gevent_17_gevent_cgreenlet_sys_getframe);
      __pyx_t_6 = __pyx_v_6gevent_17_gevent_cgreenlet_sys_getframe; 
      __pyx_t_7 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
        assert(__pyx_t_5);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
        __pyx_t_7 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
        __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_7, (1-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 142, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
      }
      __pyx_v_frame = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "src/gevent/greenlet.py":141
 * 
 * def _extract_stack(limit):
 *     try:             # <<<<<<<<<<<<<<
 *         frame = sys_getframe()
 *     except ValueError:
*/
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "src/gevent/greenlet.py":143
 *     try:
 *         frame = sys_getframe()
 *     except ValueError:             # <<<<<<<<<<<<<<
 *         # In certain embedded cases that directly use the Python C api
 *         # to call Greenlet.spawn (e.g., uwsgi) this can raise
*/
    __pyx_t_8 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_ValueError))));
    if (__pyx_t_8) {
      __Pyx_ErrRestore(0,0,0);

      /* "src/gevent/greenlet.py":151
 *         # not the Python level.
 *         # See https://github.com/gevent/gevent/issues/1212
 *         frame = None             # <<<<<<<<<<<<<<
 * 
 *     newest_Frame = None
*/
      __Pyx_INCREF(Py_None);
      __Pyx_XDECREF_SET(__pyx_v_frame, Py_None);
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;

    /* "src/gevent/greenlet.py":141
 * 
 * def _extract_stack(limit):
 *     try:             # <<<<<<<<<<<<<<
 *         frame = sys_getframe()
 *     except ValueError:
*/
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    __pyx_L8_try_end:;
  }

  /* "src/gevent/greenlet.py":153
 *         frame = None
 * 
 *     newest_Frame = None             # <<<<<<<<<<<<<<
 *     newer_Frame = None
 * 
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_newest_Frame = ((struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *)Py_None);

  /* "src/gevent/greenlet.py":154
 * 
 *     newest_Frame = None
 *     newer_Frame = None             # <<<<<<<<<<<<<<
 * 
 *     while limit and frame is not None:
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_newer_Frame = ((struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *)Py_None);

  /* "src/gevent/greenlet.py":156
 *     newer_Frame = None
 * 
 *     while limit and frame is not None:             # <<<<<<<<<<<<<<
 *         limit -= 1
 *         older_Frame = _Frame()
*/
  while (1) {
    __pyx_t_10 = (__pyx_v_limit != 0);
    if (__pyx_t_10) {
    } else {
      __pyx_t_9 = __pyx_t_10;
      goto __pyx_L13_bool_binop_done;
    }
    __pyx_t_10 = (__pyx_v_frame != Py_None);
    __pyx_t_9 = __pyx_t_10;
    __pyx_L13_bool_binop_done:;
    if (!__pyx_t_9) break;

    /* "src/gevent/greenlet.py":157
 * 
 *     while limit and frame is not None:
 *         limit -= 1             # <<<<<<<<<<<<<<
 *         older_Frame = _Frame()
 *         # Arguments are always passed to the constructor as Python objects,
*/
    __pyx_v_limit = (__pyx_v_limit - 1);

    /* "src/gevent/greenlet.py":158
 *     while limit and frame is not None:
 *         limit -= 1
 *         older_Frame = _Frame()             # <<<<<<<<<<<<<<
 *         # Arguments are always passed to the constructor as Python objects,
 *         # meaning we wind up boxing the f_lineno just to unbox it if we pass it.
*/
    __pyx_t_6 = NULL;
    __pyx_t_7 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
      __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet__Frame, __pyx_callargs+__pyx_t_7, (1-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 158, __pyx_L1_error)
      __Pyx_GOTREF((PyObject *)__pyx_t_4);
    }
    __Pyx_XDECREF_SET(__pyx_v_older_Frame, ((struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *)__pyx_t_4));
    __pyx_t_4 = 0;

    /* "src/gevent/greenlet.py":162
 *         # meaning we wind up boxing the f_lineno just to unbox it if we pass it.
 *         # It's faster to simply assign once the object is created.
 *         older_Frame.f_code = Gevent_PyFrame_GetCode(frame)  # pylint:disable=undefined-variable             # <<<<<<<<<<<<<<
 *         older_Frame.f_lineno = Gevent_PyFrame_GetLineNumber(frame) # pylint:disable=undefined-variable
 *         if newer_Frame is not None:
*/
    __pyx_t_4 = ((PyObject *)Gevent_PyFrame_GetCode(((__pyx_t_6gevent_17_gevent_cgreenlet_FrameType)__pyx_v_frame))); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 162, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __Pyx_GOTREF(__pyx_v_older_Frame->f_code);
    __Pyx_DECREF(__pyx_v_older_Frame->f_code);
    __pyx_v_older_Frame->f_code = ((__pyx_t_6gevent_17_gevent_cgreenlet_CodeType)__pyx_t_4);
    __pyx_t_4 = 0;

    /* "src/gevent/greenlet.py":163
 *         # It's faster to simply assign once the object is created.
 *         older_Frame.f_code = Gevent_PyFrame_GetCode(frame)  # pylint:disable=undefined-variable
 *         older_Frame.f_lineno = Gevent_PyFrame_GetLineNumber(frame) # pylint:disable=undefined-variable             # <<<<<<<<<<<<<<
 *         if newer_Frame is not None:
 *             newer_Frame.f_back = older_Frame
*/
    __pyx_v_older_Frame->f_lineno = Gevent_PyFrame_GetLineNumber(((__pyx_t_6gevent_17_gevent_cgreenlet_FrameType)__pyx_v_frame));

    /* "src/gevent/greenlet.py":164
 *         older_Frame.f_code = Gevent_PyFrame_GetCode(frame)  # pylint:disable=undefined-variable
 *         older_Frame.f_lineno = Gevent_PyFrame_GetLineNumber(frame) # pylint:disable=undefined-variable
 *         if newer_Frame is not None:             # <<<<<<<<<<<<<<
 *             newer_Frame.f_back = older_Frame
 *         newer_Frame = older_Frame
*/
    __pyx_t_9 = (((PyObject *)__pyx_v_newer_Frame) != Py_None);
    if (__pyx_t_9) {

      /* "src/gevent/greenlet.py":165
 *         older_Frame.f_lineno = Gevent_PyFrame_GetLineNumber(frame) # pylint:disable=undefined-variable
 *         if newer_Frame is not None:
 *             newer_Frame.f_back = older_Frame             # <<<<<<<<<<<<<<
 *         newer_Frame = older_Frame
 *         if newest_Frame is None:
*/
      __Pyx_INCREF((PyObject *)__pyx_v_older_Frame);
      __Pyx_GIVEREF((PyObject *)__pyx_v_older_Frame);
      __Pyx_GOTREF((PyObject *)__pyx_v_newer_Frame->f_back);
      __Pyx_DECREF((PyObject *)__pyx_v_newer_Frame->f_back);
      __pyx_v_newer_Frame->f_back = __pyx_v_older_Frame;

      /* "src/gevent/greenlet.py":164
 *         older_Frame.f_code = Gevent_PyFrame_GetCode(frame)  # pylint:disable=undefined-variable
 *         older_Frame.f_lineno = Gevent_PyFrame_GetLineNumber(frame) # pylint:disable=undefined-variable
 *         if newer_Frame is not None:             # <<<<<<<<<<<<<<
 *             newer_Frame.f_back = older_Frame
 *         newer_Frame = older_Frame
*/
    }

    /* "src/gevent/greenlet.py":166
 *         if newer_Frame is not None:
 *             newer_Frame.f_back = older_Frame
 *         newer_Frame = older_Frame             # <<<<<<<<<<<<<<
 *         if newest_Frame is None:
 *             newest_Frame = newer_Frame
*/
    __Pyx_INCREF((PyObject *)__pyx_v_older_Frame);
    __Pyx_DECREF_SET(__pyx_v_newer_Frame, __pyx_v_older_Frame);

    /* "src/gevent/greenlet.py":167
 *             newer_Frame.f_back = older_Frame
 *         newer_Frame = older_Frame
 *         if newest_Frame is None:             # <<<<<<<<<<<<<<
 *             newest_Frame = newer_Frame
 * 
*/
    __pyx_t_9 = (((PyObject *)__pyx_v_newest_Frame) == Py_None);
    if (__pyx_t_9) {

      /* "src/gevent/greenlet.py":168
 *         newer_Frame = older_Frame
 *         if newest_Frame is None:
 *             newest_Frame = newer_Frame             # <<<<<<<<<<<<<<
 * 
 *         frame = Gevent_PyFrame_GetBack(frame) # pylint:disable=undefined-variable
*/
      __Pyx_INCREF((PyObject *)__pyx_v_newer_Frame);
      __Pyx_DECREF_SET(__pyx_v_newest_Frame, __pyx_v_newer_Frame);

      /* "src/gevent/greenlet.py":167
 *             newer_Frame.f_back = older_Frame
 *         newer_Frame = older_Frame
 *         if newest_Frame is None:             # <<<<<<<<<<<<<<
 *             newest_Frame = newer_Frame
 * 
*/
    }

    /* "src/gevent/greenlet.py":170
 *             newest_Frame = newer_Frame
 * 
 *         frame = Gevent_PyFrame_GetBack(frame) # pylint:disable=undefined-variable             # <<<<<<<<<<<<<<
 * 
 *     return newest_Frame
*/
    __pyx_t_4 = Gevent_PyFrame_GetBack(((__pyx_t_6gevent_17_gevent_cgreenlet_FrameType)__pyx_v_frame)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 170, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF_SET(__pyx_v_frame, __pyx_t_4);
    __pyx_t_4 = 0;
  }

  /* "src/gevent/greenlet.py":172
 *         frame = Gevent_PyFrame_GetBack(frame) # pylint:disable=undefined-variable
 * 
 *     return newest_Frame             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_newest_Frame);
  __pyx_r = __pyx_v_newest_Frame;
  goto __pyx_L0;

  /* "src/gevent/greenlet.py":140
 * 
 * 
 * def _extract_stack(limit):             # <<<<<<<<<<<<<<
 *     try:
 *         frame = sys_getframe()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet._extract_stack", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_newest_Frame);
  __Pyx_XDECREF((PyObject *)__pyx_v_newer_Frame);
  __Pyx_XDECREF((PyObject *)__pyx_v_older_Frame);
  __Pyx_XDECREF(__pyx_v_frame);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":186
 * 
 *     # pylint:disable=keyword-arg-before-vararg,super-init-not-called
 *     def __init__(self, run=None, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         """
 *         :param args: The arguments passed to the ``run`` function.
*/

/* Python wrapper */
static int __pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet___init__, "\n        :param args: The arguments passed to the ``run`` function.\n        :param kwargs: The keyword arguments passed to the ``run`` function.\n        :keyword callable run: The callable object to run. If not given, this object's\n            `_run` method will be invoked (typically defined by subclasses).\n\n        .. versionchanged:: 1.1b1\n            The ``run`` argument to the constructor is now verified to be a callable\n            object. Previously, passing a non-callable object would fail after the greenlet\n            was spawned.\n\n        .. versionchanged:: 1.3b1\n           The ``GEVENT_TRACK_GREENLET_TREE`` configuration value may be set to\n           a false value to disable ``spawn_tree_locals``, ``spawning_greenlet``,\n           and ``spawning_stack``. The first two will be None in that case, and the\n           latter will be empty.\n\n        .. versionchanged:: 1.5\n           Greenlet objects are now more careful to verify that their ``parent`` is really\n           a gevent hub, raising a ``TypeError`` earlier instead of an ``AttributeError`` later.\n\n        .. versionchanged:: 20.12.1\n           Greenlet objects now function as context managers. Exiting the ``with`` suite\n           ensures that the greenlet has completed by :meth:`joining <join>`\n           the greenlet (blocking, with\n           no timeout). If the body of the suite raises an exception, the greenlet is\n           :meth:`killed <kill>` with the default arguments and not joined in that case.\n        ");
#if CYTHON_UPDATE_DESCRIPTOR_DOC
struct wrapperbase __pyx_wrapperbase_6gevent_17_gevent_cgreenlet_8Greenlet___init__;
#endif
static int __pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_run = 0;
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_v_kwargs = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_v_kwargs = PyDict_New(); if (unlikely(!__pyx_v_kwargs)) return -1;
  __Pyx_GOTREF(__pyx_v_kwargs);
  __pyx_v_args = __Pyx_ArgsSlice_VARARGS(__pyx_args, 1, __pyx_nargs);
  if (unlikely(!__pyx_v_args)) {
    __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
    __Pyx_RefNannyFinishContext();
    return -1;
  }
  __Pyx_GOTREF(__pyx_v_args);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_run,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 186, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        default:
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 186, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      const Py_ssize_t used_pos_args = (kwd_pos_args < 1) ? kwd_pos_args : 1;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_kwargs, values, used_pos_args, __pyx_kwds_len, "__init__", 1) < (0)) __PYX_ERR(0, 186, __pyx_L3_error)
      if (!values[0]) values[0] = __Pyx_NewRef(((PyObject *)Py_None));
    } else {
      switch (__pyx_nargs) {
        default:
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 186, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
      }
      if (!values[0]) values[0] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_run = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_DECREF(__pyx_v_args); __pyx_v_args = 0;
  __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet___init__(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self), __pyx_v_run, __pyx_v_args, __pyx_v_kwargs);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_DECREF(__pyx_v_kwargs);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet___init__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, PyObject *__pyx_v_run, PyObject *__pyx_v_args, PyObject *__pyx_v_kwargs) {
  PyGreenlet *__pyx_v_spawner = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "src/gevent/greenlet.py":253
 *         # PyPy2 7.1    : Mean +- std dev: 12.3 us +- 0.8 us
 * 
 *         _greenlet__init__(self, None, get_hub())             # <<<<<<<<<<<<<<
 * 
 *         if run is not None:
*/
  __pyx_t_2 = NULL;
  __Pyx_INCREF(__pyx_v_6gevent_17_gevent_cgreenlet__greenlet__init__);
  __pyx_t_3 = __pyx_v_6gevent_17_gevent_cgreenlet__greenlet__init__; 
  __pyx_t_4 = ((PyObject *)__pyx_f_6gevent_19_gevent_c_hub_local_get_hub_noargs(0)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_5 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_2, ((PyObject *)__pyx_v_self), Py_None, __pyx_t_4};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_5, (4-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 253, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "src/gevent/greenlet.py":255
 *         _greenlet__init__(self, None, get_hub())
 * 
 *         if run is not None:             # <<<<<<<<<<<<<<
 *             self._run = run
 * 
*/
  __pyx_t_6 = (__pyx_v_run != Py_None);
  if (__pyx_t_6) {

    /* "src/gevent/greenlet.py":256
 * 
 *         if run is not None:
 *             self._run = run             # <<<<<<<<<<<<<<
 * 
 *         # If they didn't pass a callable at all, then they must
*/
    if (__Pyx_PyObject_SetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_run_2, __pyx_v_run) < (0)) __PYX_ERR(0, 256, __pyx_L1_error)

    /* "src/gevent/greenlet.py":255
 *         _greenlet__init__(self, None, get_hub())
 * 
 *         if run is not None:             # <<<<<<<<<<<<<<
 *             self._run = run
 * 
*/
  }

  /* "src/gevent/greenlet.py":261
 *         # already have one. Note that subclassing to override the run() method
 *         # itself has never been documented or supported.
 *         if not callable(self._run):             # <<<<<<<<<<<<<<
 *             raise TypeError("The run argument or self._run must be callable")
 * 
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_run_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 261, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = __Pyx_PyCallable_Check(__pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 261, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_7 = (!__pyx_t_6);
  if (unlikely(__pyx_t_7)) {

    /* "src/gevent/greenlet.py":262
 *         # itself has never been documented or supported.
 *         if not callable(self._run):
 *             raise TypeError("The run argument or self._run must be callable")             # <<<<<<<<<<<<<<
 * 
 *         self.args = args
*/
    __pyx_t_3 = NULL;
    __pyx_t_5 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u_The_run_argument_or_self__run_mu};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_TypeError)), __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 262, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 262, __pyx_L1_error)

    /* "src/gevent/greenlet.py":261
 *         # already have one. Note that subclassing to override the run() method
 *         # itself has never been documented or supported.
 *         if not callable(self._run):             # <<<<<<<<<<<<<<
 *             raise TypeError("The run argument or self._run must be callable")
 * 
*/
  }

  /* "src/gevent/greenlet.py":264
 *             raise TypeError("The run argument or self._run must be callable")
 * 
 *         self.args = args             # <<<<<<<<<<<<<<
 *         self.kwargs = kwargs
 *         self.value = None
*/
  __Pyx_INCREF(__pyx_v_args);
  __Pyx_GIVEREF(__pyx_v_args);
  __Pyx_GOTREF(__pyx_v_self->args);
  __Pyx_DECREF(__pyx_v_self->args);
  __pyx_v_self->args = __pyx_v_args;

  /* "src/gevent/greenlet.py":265
 * 
 *         self.args = args
 *         self.kwargs = kwargs             # <<<<<<<<<<<<<<
 *         self.value = None
 * 
*/
  __Pyx_INCREF(__pyx_v_kwargs);
  __Pyx_GIVEREF(__pyx_v_kwargs);
  __Pyx_GOTREF(__pyx_v_self->kwargs);
  __Pyx_DECREF(__pyx_v_self->kwargs);
  __pyx_v_self->kwargs = __pyx_v_kwargs;

  /* "src/gevent/greenlet.py":266
 *         self.args = args
 *         self.kwargs = kwargs
 *         self.value = None             # <<<<<<<<<<<<<<
 * 
 *         #: An event, such as a timer or a callback that fires. It is established in
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->value);
  __Pyx_DECREF(__pyx_v_self->value);
  __pyx_v_self->value = Py_None;

  /* "src/gevent/greenlet.py":276
 *         #: In the usual case, this transitions as follows: None -> event -> _start_completed_event.
 *         #: A value of None means we've never been started.
 *         self._start_event = None             # <<<<<<<<<<<<<<
 * 
 *         self._notifier = None
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_start_event);
  __Pyx_DECREF(__pyx_v_self->_start_event);
  __pyx_v_self->_start_event = Py_None;

  /* "src/gevent/greenlet.py":278
 *         self._start_event = None
 * 
 *         self._notifier = None             # <<<<<<<<<<<<<<
 *         self._formatted_info = None
 *         self._links = []
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_notifier);
  __Pyx_DECREF(__pyx_v_self->_notifier);
  __pyx_v_self->_notifier = Py_None;

  /* "src/gevent/greenlet.py":279
 * 
 *         self._notifier = None
 *         self._formatted_info = None             # <<<<<<<<<<<<<<
 *         self._links = []
 *         self._ident = None
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_formatted_info);
  __Pyx_DECREF(__pyx_v_self->_formatted_info);
  __pyx_v_self->_formatted_info = ((PyObject*)Py_None);

  /* "src/gevent/greenlet.py":280
 *         self._notifier = None
 *         self._formatted_info = None
 *         self._links = []             # <<<<<<<<<<<<<<
 *         self._ident = None
 * 
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 280, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_links);
  __Pyx_DECREF(__pyx_v_self->_links);
  __pyx_v_self->_links = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "src/gevent/greenlet.py":281
 *         self._formatted_info = None
 *         self._links = []
 *         self._ident = None             # <<<<<<<<<<<<<<
 * 
 *         # Initial state: None.
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_ident);
  __Pyx_DECREF(__pyx_v_self->_ident);
  __pyx_v_self->_ident = Py_None;

  /* "src/gevent/greenlet.py":286
 *         # Completed successfully: (None, None, None)
 *         # Failed with exception: (t, v, dump_traceback(tb)))
 *         self._exc_info = None             # <<<<<<<<<<<<<<
 * 
 *         if GEVENT_CONFIG.track_greenlet_tree:
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_exc_info);
  __Pyx_DECREF(__pyx_v_self->_exc_info);
  __pyx_v_self->_exc_info = ((PyObject*)Py_None);

  /* "src/gevent/greenlet.py":288
 *         self._exc_info = None
 * 
 *         if GEVENT_CONFIG.track_greenlet_tree:             # <<<<<<<<<<<<<<
 *             spawner = getcurrent() # pylint:disable=undefined-variable
 *             self.spawning_greenlet = wref(spawner)
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_6gevent_17_gevent_cgreenlet_GEVENT_CONFIG, __pyx_mstate_global->__pyx_n_u_track_greenlet_tree); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 288, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_7) {

    /* "src/gevent/greenlet.py":289
 * 
 *         if GEVENT_CONFIG.track_greenlet_tree:
 *             spawner = getcurrent() # pylint:disable=undefined-variable             # <<<<<<<<<<<<<<
 *             self.spawning_greenlet = wref(spawner)
 *             try:
*/
    __pyx_t_1 = ((PyObject *)__pyx_f_6gevent_17_gevent_cgreenlet_getcurrent()); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 289, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_spawner = ((PyGreenlet *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "src/gevent/greenlet.py":290
 *         if GEVENT_CONFIG.track_greenlet_tree:
 *             spawner = getcurrent() # pylint:disable=undefined-variable
 *             self.spawning_greenlet = wref(spawner)             # <<<<<<<<<<<<<<
 *             try:
 *                 self.spawn_tree_locals = spawner.spawn_tree_locals
*/
    __pyx_t_3 = NULL;
    __Pyx_INCREF(__pyx_v_6gevent_17_gevent_cgreenlet_wref);
    __pyx_t_4 = __pyx_v_6gevent_17_gevent_cgreenlet_wref; 
    __pyx_t_5 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      assert(__pyx_t_3);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
      __pyx_t_5 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, ((PyObject *)__pyx_v_spawner)};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 290, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_v_self->spawning_greenlet);
    __Pyx_DECREF(__pyx_v_self->spawning_greenlet);
    __pyx_v_self->spawning_greenlet = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "src/gevent/greenlet.py":291
 *             spawner = getcurrent() # pylint:disable=undefined-variable
 *             self.spawning_greenlet = wref(spawner)
 *             try:             # <<<<<<<<<<<<<<
 *                 self.spawn_tree_locals = spawner.spawn_tree_locals
 *             except AttributeError:
*/
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_10);
      /*try:*/ {

        /* "src/gevent/greenlet.py":292
 *             self.spawning_greenlet = wref(spawner)
 *             try:
 *                 self.spawn_tree_locals = spawner.spawn_tree_locals             # <<<<<<<<<<<<<<
 *             except AttributeError:
 *                 self.spawn_tree_locals = {}
*/
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_spawner), __pyx_mstate_global->__pyx_n_u_spawn_tree_locals); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 292, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_1);
        if (!(likely(PyDict_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("dict", __pyx_t_1))) __PYX_ERR(0, 292, __pyx_L6_error)
        __Pyx_GIVEREF(__pyx_t_1);
        __Pyx_GOTREF(__pyx_v_self->spawn_tree_locals);
        __Pyx_DECREF(__pyx_v_self->spawn_tree_locals);
        __pyx_v_self->spawn_tree_locals = ((PyObject*)__pyx_t_1);
        __pyx_t_1 = 0;

        /* "src/gevent/greenlet.py":291
 *             spawner = getcurrent() # pylint:disable=undefined-variable
 *             self.spawning_greenlet = wref(spawner)
 *             try:             # <<<<<<<<<<<<<<
 *                 self.spawn_tree_locals = spawner.spawn_tree_locals
 *             except AttributeError:
*/
      }
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      goto __pyx_L11_try_end;
      __pyx_L6_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "src/gevent/greenlet.py":293
 *             try:
 *                 self.spawn_tree_locals = spawner.spawn_tree_locals
 *             except AttributeError:             # <<<<<<<<<<<<<<
 *                 self.spawn_tree_locals = {}
 *                 if get_generic_parent(spawner) is not None: # pylint:disable=undefined-variable
*/
      __pyx_t_11 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_AttributeError))));
      if (__pyx_t_11) {
        __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_4, &__pyx_t_3) < 0) __PYX_ERR(0, 293, __pyx_L8_except_error)
        __Pyx_XGOTREF(__pyx_t_1);
        __Pyx_XGOTREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_t_3);

        /* "src/gevent/greenlet.py":294
 *                 self.spawn_tree_locals = spawner.spawn_tree_locals
 *             except AttributeError:
 *                 self.spawn_tree_locals = {}             # <<<<<<<<<<<<<<
 *                 if get_generic_parent(spawner) is not None: # pylint:disable=undefined-variable
 *                     # The main greenlet has no parent.
*/
        __pyx_t_2 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 294, __pyx_L8_except_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_GIVEREF(__pyx_t_2);
        __Pyx_GOTREF(__pyx_v_self->spawn_tree_locals);
        __Pyx_DECREF(__pyx_v_self->spawn_tree_locals);
        __pyx_v_self->spawn_tree_locals = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;

        /* "src/gevent/greenlet.py":295
 *             except AttributeError:
 *                 self.spawn_tree_locals = {}
 *                 if get_generic_parent(spawner) is not None: # pylint:disable=undefined-variable             # <<<<<<<<<<<<<<
 *                     # The main greenlet has no parent.
 *                     # Its children get separate locals.
*/
        __pyx_t_2 = __pyx_f_6gevent_17_gevent_cgreenlet_get_generic_parent(__pyx_v_spawner); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 295, __pyx_L8_except_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_7 = (__pyx_t_2 != Py_None);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (__pyx_t_7) {

          /* "src/gevent/greenlet.py":298
 *                     # The main greenlet has no parent.
 *                     # Its children get separate locals.
 *                     spawner.spawn_tree_locals = self.spawn_tree_locals             # <<<<<<<<<<<<<<
 * 
 *             self.spawning_stack = _extract_stack(self.spawning_stack_limit)
*/
          __pyx_t_2 = __pyx_v_self->spawn_tree_locals;
          __Pyx_INCREF(__pyx_t_2);
          if (__Pyx_PyObject_SetAttrStr(((PyObject *)__pyx_v_spawner), __pyx_mstate_global->__pyx_n_u_spawn_tree_locals, __pyx_t_2) < (0)) __PYX_ERR(0, 298, __pyx_L8_except_error)
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

          /* "src/gevent/greenlet.py":295
 *             except AttributeError:
 *                 self.spawn_tree_locals = {}
 *                 if get_generic_parent(spawner) is not None: # pylint:disable=undefined-variable             # <<<<<<<<<<<<<<
 *                     # The main greenlet has no parent.
 *                     # Its children get separate locals.
*/
        }
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        goto __pyx_L7_exception_handled;
      }
      goto __pyx_L8_except_error;

      /* "src/gevent/greenlet.py":291
 *             spawner = getcurrent() # pylint:disable=undefined-variable
 *             self.spawning_greenlet = wref(spawner)
 *             try:             # <<<<<<<<<<<<<<
 *                 self.spawn_tree_locals = spawner.spawn_tree_locals
 *             except AttributeError:
*/
      __pyx_L8_except_error:;
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      goto __pyx_L1_error;
      __pyx_L7_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      __pyx_L11_try_end:;
    }

    /* "src/gevent/greenlet.py":300
 *                     spawner.spawn_tree_locals = self.spawn_tree_locals
 * 
 *             self.spawning_stack = _extract_stack(self.spawning_stack_limit)             # <<<<<<<<<<<<<<
 *             # Don't copy the spawning greenlet's
 *             # '_spawning_stack_frames' into ours. That's somewhat
*/
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_spawning_stack_limit); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 300, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_11 = __Pyx_PyLong_As_int(__pyx_t_3); if (unlikely((__pyx_t_11 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 300, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = ((PyObject *)__pyx_f_6gevent_17_gevent_cgreenlet__extract_stack(__pyx_t_11)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 300, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->spawning_stack);
    __Pyx_DECREF((PyObject *)__pyx_v_self->spawning_stack);
    __pyx_v_self->spawning_stack = ((struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "src/gevent/greenlet.py":288
 *         self._exc_info = None
 * 
 *         if GEVENT_CONFIG.track_greenlet_tree:             # <<<<<<<<<<<<<<
 *             spawner = getcurrent() # pylint:disable=undefined-variable
 *             self.spawning_greenlet = wref(spawner)
*/
    goto __pyx_L5;
  }

  /* "src/gevent/greenlet.py":311
 *             # None is the default for all of these in Cython, but we
 *             # need to declare them for pure-Python mode.
 *             self.spawning_greenlet = None             # <<<<<<<<<<<<<<
 *             self.spawn_tree_locals = None
 *             self.spawning_stack = None
*/
  /*else*/ {
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_self->spawning_greenlet);
    __Pyx_DECREF(__pyx_v_self->spawning_greenlet);
    __pyx_v_self->spawning_greenlet = Py_None;

    /* "src/gevent/greenlet.py":312
 *             # need to declare them for pure-Python mode.
 *             self.spawning_greenlet = None
 *             self.spawn_tree_locals = None             # <<<<<<<<<<<<<<
 *             self.spawning_stack = None
 * 
*/
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_self->spawn_tree_locals);
    __Pyx_DECREF(__pyx_v_self->spawn_tree_locals);
    __pyx_v_self->spawn_tree_locals = ((PyObject*)Py_None);

    /* "src/gevent/greenlet.py":313
 *             self.spawning_greenlet = None
 *             self.spawn_tree_locals = None
 *             self.spawning_stack = None             # <<<<<<<<<<<<<<
 * 
 *     def _get_minimal_ident(self):
*/
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->spawning_stack);
    __Pyx_DECREF((PyObject *)__pyx_v_self->spawning_stack);
    __pyx_v_self->spawning_stack = ((struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *)Py_None);
  }
  __pyx_L5:;

  /* "src/gevent/greenlet.py":186
 * 
 *     # pylint:disable=keyword-arg-before-vararg,super-init-not-called
 *     def __init__(self, run=None, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         """
 *         :param args: The arguments passed to the ``run`` function.
*/

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_spawner);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":315
 *             self.spawning_stack = None
 * 
 *     def _get_minimal_ident(self):             # <<<<<<<<<<<<<<
 *         # Helper function for cython, to allow typing `reg` and making a
 *         # C call to get_ident.
*/

static PyObject *__pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__get_minimal_ident(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self) {
  struct __pyx_obj_6gevent_15_gevent_c_ident_IdentRegistry *__pyx_v_reg = 0;
  struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *__pyx_v_hub = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_get_minimal_ident", 0);

  /* "src/gevent/greenlet.py":324
 *         # If our parent is no longer the hub for whatever reason, this will raise a
 *         # AttributeError or TypeError.
 *         hub = get_my_hub(self) # pylint:disable=undefined-variable             # <<<<<<<<<<<<<<
 * 
 *         reg = hub.ident_registry
*/
  __pyx_t_1 = ((PyObject *)__pyx_f_6gevent_17_gevent_cgreenlet_get_my_hub(((PyGreenlet *)__pyx_v_self))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 324, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_hub = ((struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "src/gevent/greenlet.py":326
 *         hub = get_my_hub(self) # pylint:disable=undefined-variable
 * 
 *         reg = hub.ident_registry             # <<<<<<<<<<<<<<
 *         return reg.get_ident(self)
 * 
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_hub), __pyx_mstate_global->__pyx_n_u_ident_registry); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 326, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_mstate_global->__pyx_ptype_6gevent_15_gevent_c_ident_IdentRegistry))))) __PYX_ERR(0, 326, __pyx_L1_error)
  __pyx_v_reg = ((struct __pyx_obj_6gevent_15_gevent_c_ident_IdentRegistry *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "src/gevent/greenlet.py":327
 * 
 *         reg = hub.ident_registry
 *         return reg.get_ident(self)             # <<<<<<<<<<<<<<
 * 
 *     @property
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((struct __pyx_vtabstruct_6gevent_15_gevent_c_ident_IdentRegistry *)__pyx_v_reg->__pyx_vtab)->get_ident(__pyx_v_reg, ((PyObject *)__pyx_v_self), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 327, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "src/gevent/greenlet.py":315
 *             self.spawning_stack = None
 * 
 *     def _get_minimal_ident(self):             # <<<<<<<<<<<<<<
 *         # Helper function for cython, to allow typing `reg` and making a
 *         # C call to get_ident.
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet._get_minimal_ident", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_reg);
  __Pyx_XDECREF((PyObject *)__pyx_v_hub);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":329
 *         return reg.get_ident(self)
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def minimal_ident(self):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_13minimal_ident_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_13minimal_ident_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_13minimal_ident___get__(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_13minimal_ident___get__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "src/gevent/greenlet.py":352
 *         # Not @Lazy, implemented manually because _ident is in the structure
 *         # of the greenlet for fast access
 *         if self._ident is None:             # <<<<<<<<<<<<<<
 *             self._ident = self._get_minimal_ident()
 *         return self._ident
*/
  __pyx_t_1 = (__pyx_v_self->_ident == Py_None);
  if (__pyx_t_1) {

    /* "src/gevent/greenlet.py":353
 *         # of the greenlet for fast access
 *         if self._ident is None:
 *             self._ident = self._get_minimal_ident()             # <<<<<<<<<<<<<<
 *         return self._ident
 * 
*/
    __pyx_t_2 = ((struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self->__pyx_vtab)->_get_minimal_ident(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 353, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __Pyx_GOTREF(__pyx_v_self->_ident);
    __Pyx_DECREF(__pyx_v_self->_ident);
    __pyx_v_self->_ident = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "src/gevent/greenlet.py":352
 *         # Not @Lazy, implemented manually because _ident is in the structure
 *         # of the greenlet for fast access
 *         if self._ident is None:             # <<<<<<<<<<<<<<
 *             self._ident = self._get_minimal_ident()
 *         return self._ident
*/
  }

  /* "src/gevent/greenlet.py":354
 *         if self._ident is None:
 *             self._ident = self._get_minimal_ident()
 *         return self._ident             # <<<<<<<<<<<<<<
 * 
 *     @readproperty
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_ident);
  __pyx_r = __pyx_v_self->_ident;
  goto __pyx_L0;

  /* "src/gevent/greenlet.py":329
 *         return reg.get_ident(self)
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def minimal_ident(self):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.minimal_ident.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":356
 *         return self._ident
 * 
 *     @readproperty             # <<<<<<<<<<<<<<
 *     def name(self):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_3name(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_2name, "Greenlet.name(self)\n\nThe greenlet name. By default, a unique name is constructed using\nthe :attr:`minimal_ident`. You can assign a string to this\nvalue to change it. It is shown in the `repr` of this object if it\nhas been assigned to or if the `minimal_ident` has already been generated.\n\n.. versionadded:: 1.3a2\n.. versionchanged:: 1.4\n   Stop showing generated names in the `repr` when the ``minimal_ident``\n   hasn't been requested. This reduces overhead and may be less confusing,\n   since ``minimal_ident`` can get reused.");
static PyMethodDef __pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_3name = {"name", (PyCFunction)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_3name, METH_NOARGS, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_2name};
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_3name(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("name (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_2name(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_2name(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("name", 0);

  /* "src/gevent/greenlet.py":370
 *            since ``minimal_ident`` can get reused.
 *         """
 *         return 'Greenlet-%d' % (self.minimal_ident,)             # <<<<<<<<<<<<<<
 * 
 *     def _raise_exception(self):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_minimal_ident); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 370, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_FormatAndDecref(__Pyx_PyNumber_Long(__pyx_t_1), __pyx_mstate_global->__pyx_n_u_d); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 370, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_Greenlet, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 370, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "src/gevent/greenlet.py":356
 *         return self._ident
 * 
 *     @readproperty             # <<<<<<<<<<<<<<
 *     def name(self):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":372
 *         return 'Greenlet-%d' % (self.minimal_ident,)
 * 
 *     def _raise_exception(self):             # <<<<<<<<<<<<<<
 *         reraise(*self.exc_info)
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_5_raise_exception(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_4_raise_exception, "Greenlet._raise_exception(self)");
static PyMethodDef __pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_5_raise_exception = {"_raise_exception", (PyCFunction)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_5_raise_exception, METH_NOARGS, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_4_raise_exception};
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_5_raise_exception(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_raise_exception (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_4_raise_exception(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_4_raise_exception(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_raise_exception", 0);

  /* "src/gevent/greenlet.py":373
 * 
 *     def _raise_exception(self):
 *         reraise(*self.exc_info)             # <<<<<<<<<<<<<<
 * 
 *     @property
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_exc_info); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 373, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PySequence_Tuple(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 373, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_v_6gevent_17_gevent_cgreenlet_reraise, __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 373, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "src/gevent/greenlet.py":372
 *         return 'Greenlet-%d' % (self.minimal_ident,)
 * 
 *     def _raise_exception(self):             # <<<<<<<<<<<<<<
 *         reraise(*self.exc_info)
 * 
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet._raise_exception", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":375
 *         reraise(*self.exc_info)
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def loop(self):
 *         # needed by killall
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_4loop_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_4loop_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_4loop___get__(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_4loop___get__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self) {
  struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *__pyx_v_hub = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "src/gevent/greenlet.py":378
 *     def loop(self):
 *         # needed by killall
 *         hub = get_my_hub(self) # pylint:disable=undefined-variable             # <<<<<<<<<<<<<<
 *         return hub.loop
 * 
*/
  __pyx_t_1 = ((PyObject *)__pyx_f_6gevent_17_gevent_cgreenlet_get_my_hub(((PyGreenlet *)__pyx_v_self))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_hub = ((struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "src/gevent/greenlet.py":379
 *         # needed by killall
 *         hub = get_my_hub(self) # pylint:disable=undefined-variable
 *         return hub.loop             # <<<<<<<<<<<<<<
 * 
 *     def __bool__(self):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_hub->loop);
  __pyx_r = __pyx_v_hub->loop;
  goto __pyx_L0;

  /* "src/gevent/greenlet.py":375
 *         reraise(*self.exc_info)
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def loop(self):
 *         # needed by killall
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.loop.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_hub);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":381
 *         return hub.loop
 * 
 *     def __bool__(self):             # <<<<<<<<<<<<<<
 *         return self._start_event is not None and self._exc_info is None
 * 
*/

/* Python wrapper */
static int __pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_7__bool__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_7__bool__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__bool__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_6__bool__(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_6__bool__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self) {
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;

  /* "src/gevent/greenlet.py":382
 * 
 *     def __bool__(self):
 *         return self._start_event is not None and self._exc_info is None             # <<<<<<<<<<<<<<
 * 
 *     ### Lifecycle
*/
  __pyx_t_2 = (__pyx_v_self->_start_event != Py_None);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_2 = (__pyx_v_self->_exc_info == ((PyObject*)Py_None));
  __pyx_t_1 = __pyx_t_2;
  __pyx_L3_bool_binop_done:;
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "src/gevent/greenlet.py":381
 *         return hub.loop
 * 
 *     def __bool__(self):             # <<<<<<<<<<<<<<
 *         return self._start_event is not None and self._exc_info is None
 * 
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "src/gevent/greenlet.py":401
 *             return self._greenlet__started and not _continulet.is_pending(self)
 *     else:
 *         @property             # <<<<<<<<<<<<<<
 *         def dead(self):
 *             """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_4dead_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_4dead_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_4dead___get__(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_4dead___get__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "src/gevent/greenlet.py":422
 *             # window __started_but_aborted() incorrectly concludes the
 *             # greenlet was aborted.
 *             if getcurrent() is self: # pylint:disable=undefined-variable             # <<<<<<<<<<<<<<
 *                 return False
 *             return (
*/
  __pyx_t_1 = ((PyObject *)__pyx_f_6gevent_17_gevent_cgreenlet_getcurrent()); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 422, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__pyx_t_1 == ((PyObject *)__pyx_v_self));
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "src/gevent/greenlet.py":423
 *             # greenlet was aborted.
 *             if getcurrent() is self: # pylint:disable=undefined-variable
 *                 return False             # <<<<<<<<<<<<<<
 *             return (
 *                 self.__start_cancelled_by_kill()
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;

    /* "src/gevent/greenlet.py":422
 *             # window __started_but_aborted() incorrectly concludes the
 *             # greenlet was aborted.
 *             if getcurrent() is self: # pylint:disable=undefined-variable             # <<<<<<<<<<<<<<
 *                 return False
 *             return (
*/
  }

  /* "src/gevent/greenlet.py":424
 *             if getcurrent() is self: # pylint:disable=undefined-variable
 *                 return False
 *             return (             # <<<<<<<<<<<<<<
 *                 self.__start_cancelled_by_kill()
 *                 or self.__started_but_aborted()
*/
  __Pyx_XDECREF(__pyx_r);

  /* "src/gevent/greenlet.py":425
 *                 return False
 *             return (
 *                 self.__start_cancelled_by_kill()             # <<<<<<<<<<<<<<
 *                 or self.__started_but_aborted()
 *                 or greenlet.dead.__get__(self)
*/
  __pyx_t_2 = ((struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self->__pyx_vtab)->_Greenlet__start_cancelled_by_kill(__pyx_v_self); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 425, __pyx_L1_error)
  if (!__pyx_t_2) {
  } else {
    __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 425, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L4_bool_binop_done;
  }

  /* "src/gevent/greenlet.py":426
 *             return (
 *                 self.__start_cancelled_by_kill()
 *                 or self.__started_but_aborted()             # <<<<<<<<<<<<<<
 *                 or greenlet.dead.__get__(self)
 *             )
*/
  __pyx_t_2 = ((struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self->__pyx_vtab)->_Greenlet__started_but_aborted(__pyx_v_self); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 426, __pyx_L1_error)
  if (!__pyx_t_2) {
  } else {
    __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 426, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L4_bool_binop_done;
  }

  /* "src/gevent/greenlet.py":427
 *                 self.__start_cancelled_by_kill()
 *                 or self.__started_but_aborted()
 *                 or greenlet.dead.__get__(self)             # <<<<<<<<<<<<<<
 *             )
 * 
*/
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_greenlet), __pyx_mstate_global->__pyx_n_u_dead); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 427, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = __pyx_t_5;
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, ((PyObject *)__pyx_v_self)};
    __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_get, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 427, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_1 = __pyx_t_3;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_L4_bool_binop_done:;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "src/gevent/greenlet.py":401
 *             return self._greenlet__started and not _continulet.is_pending(self)
 *     else:
 *         @property             # <<<<<<<<<<<<<<
 *         def dead(self):
 *             """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.dead.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":430
 *             )
 * 
 *     def __never_started_or_killed(self):             # <<<<<<<<<<<<<<
 *         return self._start_event is None
 * 
*/

static int __pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__Greenlet__never_started_or_killed(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self) {
  int __pyx_r;
  int __pyx_t_1;

  /* "src/gevent/greenlet.py":431
 * 
 *     def __never_started_or_killed(self):
 *         return self._start_event is None             # <<<<<<<<<<<<<<
 * 
 *     def __start_pending(self):
*/
  __pyx_t_1 = (__pyx_v_self->_start_event == Py_None);
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "src/gevent/greenlet.py":430
 *             )
 * 
 *     def __never_started_or_killed(self):             # <<<<<<<<<<<<<<
 *         return self._start_event is None
 * 
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "src/gevent/greenlet.py":433
 *         return self._start_event is None
 * 
 *     def __start_pending(self):             # <<<<<<<<<<<<<<
 *         return (
 *             self._start_event is not None
*/

static int __pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__Greenlet__start_pending(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_Greenlet__start_pending", 0);

  /* "src/gevent/greenlet.py":435
 *     def __start_pending(self):
 *         return (
 *             self._start_event is not None             # <<<<<<<<<<<<<<
 *             and (self._start_event.pending or getattr(self._start_event, 'active', False))
 *         )
*/
  __pyx_t_2 = (__pyx_v_self->_start_event != Py_None);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L3_bool_binop_done;
  }

  /* "src/gevent/greenlet.py":436
 *         return (
 *             self._start_event is not None
 *             and (self._start_event.pending or getattr(self._start_event, 'active', False))             # <<<<<<<<<<<<<<
 *         )
 * 
*/
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_start_event, __pyx_mstate_global->__pyx_n_u_pending); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 436, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_3 = __pyx_v_self->_start_event;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_GetAttr3(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_active, Py_False); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 436, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_1 = __pyx_t_2;
  __pyx_L3_bool_binop_done:;
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "src/gevent/greenlet.py":433
 *         return self._start_event is None
 * 
 *     def __start_pending(self):             # <<<<<<<<<<<<<<
 *         return (
 *             self._start_event is not None
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet._Greenlet__start_pending", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":439
 *         )
 * 
 *     def __start_cancelled_by_kill(self):             # <<<<<<<<<<<<<<
 *         return self._start_event is _cancelled_start_event
 * 
*/

static int __pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__Greenlet__start_cancelled_by_kill(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self) {
  int __pyx_r;
  int __pyx_t_1;

  /* "src/gevent/greenlet.py":440
 * 
 *     def __start_cancelled_by_kill(self):
 *         return self._start_event is _cancelled_start_event             # <<<<<<<<<<<<<<
 * 
 *     def __start_completed(self):
*/
  __pyx_t_1 = (__pyx_v_self->_start_event == ((PyObject *)__pyx_v_6gevent_17_gevent_cgreenlet__cancelled_start_event));
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "src/gevent/greenlet.py":439
 *         )
 * 
 *     def __start_cancelled_by_kill(self):             # <<<<<<<<<<<<<<
 *         return self._start_event is _cancelled_start_event
 * 
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "src/gevent/greenlet.py":442
 *         return self._start_event is _cancelled_start_event
 * 
 *     def __start_completed(self):             # <<<<<<<<<<<<<<
 *         return self._start_event is _start_completed_event
 * 
*/

static int __pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__Greenlet__start_completed(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self) {
  int __pyx_r;
  int __pyx_t_1;

  /* "src/gevent/greenlet.py":443
 * 
 *     def __start_completed(self):
 *         return self._start_event is _start_completed_event             # <<<<<<<<<<<<<<
 * 
 *     def __started_but_aborted(self):
*/
  __pyx_t_1 = (__pyx_v_self->_start_event == ((PyObject *)__pyx_v_6gevent_17_gevent_cgreenlet__start_completed_event));
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "src/gevent/greenlet.py":442
 *         return self._start_event is _cancelled_start_event
 * 
 *     def __start_completed(self):             # <<<<<<<<<<<<<<
 *         return self._start_event is _start_completed_event
 * 
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "src/gevent/greenlet.py":445
 *         return self._start_event is _start_completed_event
 * 
 *     def __started_but_aborted(self):             # <<<<<<<<<<<<<<
 *         return (
 *             not self.__never_started_or_killed() # we have been started or killed
*/

static int __pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__Greenlet__started_but_aborted(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self) {
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;

  /* "src/gevent/greenlet.py":447
 *     def __started_but_aborted(self):
 *         return (
 *             not self.__never_started_or_killed() # we have been started or killed             # <<<<<<<<<<<<<<
 *             and not self.__start_cancelled_by_kill() # we weren't killed, so we must have been started
 *             and not self.__start_completed() # the start never completed
*/
  __pyx_t_2 = ((struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self->__pyx_vtab)->_Greenlet__never_started_or_killed(__pyx_v_self); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 447, __pyx_L1_error)
  __pyx_t_3 = (!__pyx_t_2);
  if (__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L3_bool_binop_done;
  }

  /* "src/gevent/greenlet.py":448
 *         return (
 *             not self.__never_started_or_killed() # we have been started or killed
 *             and not self.__start_cancelled_by_kill() # we weren't killed, so we must have been started             # <<<<<<<<<<<<<<
 *             and not self.__start_completed() # the start never completed
 *             and not self.__start_pending() # and we're not pending, so we must have been aborted
*/
  __pyx_t_3 = ((struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self->__pyx_vtab)->_Greenlet__start_cancelled_by_kill(__pyx_v_self); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 448, __pyx_L1_error)
  __pyx_t_2 = (!__pyx_t_3);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L3_bool_binop_done;
  }

  /* "src/gevent/greenlet.py":449
 *             not self.__never_started_or_killed() # we have been started or killed
 *             and not self.__start_cancelled_by_kill() # we weren't killed, so we must have been started
 *             and not self.__start_completed() # the start never completed             # <<<<<<<<<<<<<<
 *             and not self.__start_pending() # and we're not pending, so we must have been aborted
 *         )
*/
  __pyx_t_2 = ((struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self->__pyx_vtab)->_Greenlet__start_completed(__pyx_v_self); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 449, __pyx_L1_error)
  __pyx_t_3 = (!__pyx_t_2);
  if (__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L3_bool_binop_done;
  }

  /* "src/gevent/greenlet.py":450
 *             and not self.__start_cancelled_by_kill() # we weren't killed, so we must have been started
 *             and not self.__start_completed() # the start never completed
 *             and not self.__start_pending() # and we're not pending, so we must have been aborted             # <<<<<<<<<<<<<<
 *         )
 * 
*/
  __pyx_t_3 = ((struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self->__pyx_vtab)->_Greenlet__start_pending(__pyx_v_self); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 450, __pyx_L1_error)
  __pyx_t_2 = (!__pyx_t_3);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L3_bool_binop_done:;
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "src/gevent/greenlet.py":445
 *         return self._start_event is _start_completed_event
 * 
 *     def __started_but_aborted(self):             # <<<<<<<<<<<<<<
 *         return (
 *             not self.__never_started_or_killed() # we have been started or killed
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet._Greenlet__started_but_aborted", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  return __pyx_r;
}

/* "src/gevent/greenlet.py":453
 *         )
 * 
 *     def __cancel_start(self):             # <<<<<<<<<<<<<<
 *         if self._start_event is None:
 *             # prevent self from ever being started in the future
*/

static PyObject *__pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__Greenlet__cancel_start(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_Greenlet__cancel_start", 0);

  /* "src/gevent/greenlet.py":454
 * 
 *     def __cancel_start(self):
 *         if self._start_event is None:             # <<<<<<<<<<<<<<
 *             # prevent self from ever being started in the future
 *             self._start_event = _cancelled_start_event
*/
  __pyx_t_1 = (__pyx_v_self->_start_event == Py_None);
  if (__pyx_t_1) {

    /* "src/gevent/greenlet.py":456
 *         if self._start_event is None:
 *             # prevent self from ever being started in the future
 *             self._start_event = _cancelled_start_event             # <<<<<<<<<<<<<<
 *         # cancel any pending start event
 *         # NOTE: If this was a real pending start event, this will leave a
*/
    __Pyx_INCREF((PyObject *)__pyx_v_6gevent_17_gevent_cgreenlet__cancelled_start_event);
    __Pyx_GIVEREF((PyObject *)__pyx_v_6gevent_17_gevent_cgreenlet__cancelled_start_event);
    __Pyx_GOTREF(__pyx_v_self->_start_event);
    __Pyx_DECREF(__pyx_v_self->_start_event);
    __pyx_v_self->_start_event = ((PyObject *)__pyx_v_6gevent_17_gevent_cgreenlet__cancelled_start_event);

    /* "src/gevent/greenlet.py":454
 * 
 *     def __cancel_start(self):
 *         if self._start_event is None:             # <<<<<<<<<<<<<<
 *             # prevent self from ever being started in the future
 *             self._start_event = _cancelled_start_event
*/
  }

  /* "src/gevent/greenlet.py":463
 *         # variable copy of that list (in _run_callbacks). This isn't a problem,
 *         # except for the leak-tests.
 *         self._start_event.stop()             # <<<<<<<<<<<<<<
 *         self._start_event.close()
 * 
*/
  __pyx_t_3 = __pyx_v_self->_start_event;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_stop, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 463, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/greenlet.py":464
 *         # except for the leak-tests.
 *         self._start_event.stop()
 *         self._start_event.close()             # <<<<<<<<<<<<<<
 * 
 *     def __handle_death_before_start(self, args):
*/
  __pyx_t_3 = __pyx_v_self->_start_event;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_close, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 464, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/greenlet.py":453
 *         )
 * 
 *     def __cancel_start(self):             # <<<<<<<<<<<<<<
 *         if self._start_event is None:
 *             # prevent self from ever being started in the future
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet._Greenlet__cancel_start", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":466
 *         self._start_event.close()
 * 
 *     def __handle_death_before_start(self, args):             # <<<<<<<<<<<<<<
 *         # args is (t, v, tb) or simply t or v.
 *         # The last two cases are transformed into (t, v, None);
*/

static PyObject *__pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__Greenlet__handle_death_before_start(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_v_arg = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  size_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_Greenlet__handle_death_before_start", 0);
  __Pyx_INCREF(__pyx_v_args);

  /* "src/gevent/greenlet.py":475
 *         # user error---instead of silently printing something to stderr, we still
 *         # kill the greenlet).
 *         if self._exc_info is None and self.dead:             # <<<<<<<<<<<<<<
 *             # the greenlet was never switched to before and it will
 *             # never be; _report_error was not called, the result was
*/
  __pyx_t_2 = (__pyx_v_self->_exc_info == ((PyObject*)Py_None));
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_dead); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 475, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "src/gevent/greenlet.py":485
 *             # exception raised by throw() is caught somewhere inside
 *             # the greenlet).
 *             if len(args) == 1:             # <<<<<<<<<<<<<<
 *                 arg = args[0]
 *                 if isinstance(arg, type) and issubclass(arg, BaseException):
*/
    if (unlikely(__pyx_v_args == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
      __PYX_ERR(0, 485, __pyx_L1_error)
    }
    __pyx_t_4 = __Pyx_PyTuple_GET_SIZE(__pyx_v_args); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(0, 485, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_4 == 1);
    if (__pyx_t_1) {

      /* "src/gevent/greenlet.py":486
 *             # the greenlet).
 *             if len(args) == 1:
 *                 arg = args[0]             # <<<<<<<<<<<<<<
 *                 if isinstance(arg, type) and issubclass(arg, BaseException):
 *                     args = (arg, arg(), None)
*/
      if (unlikely(__pyx_v_args == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 486, __pyx_L1_error)
      }
      __pyx_t_3 = __Pyx_GetItemInt_Tuple(__pyx_v_args, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 486, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_v_arg = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "src/gevent/greenlet.py":487
 *             if len(args) == 1:
 *                 arg = args[0]
 *                 if isinstance(arg, type) and issubclass(arg, BaseException):             # <<<<<<<<<<<<<<
 *                     args = (arg, arg(), None)
 *                 else:
*/
      __pyx_t_2 = PyType_Check(__pyx_v_arg); 
      if (__pyx_t_2) {
      } else {
        __pyx_t_1 = __pyx_t_2;
        goto __pyx_L8_bool_binop_done;
      }
      __pyx_t_2 = PyObject_IsSubclass(__pyx_v_arg, ((PyObject *)(((PyTypeObject*)PyExc_BaseException)))); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 487, __pyx_L1_error)
      __pyx_t_1 = __pyx_t_2;
      __pyx_L8_bool_binop_done:;
      if (__pyx_t_1) {

        /* "src/gevent/greenlet.py":488
 *                 arg = args[0]
 *                 if isinstance(arg, type) and issubclass(arg, BaseException):
 *                     args = (arg, arg(), None)             # <<<<<<<<<<<<<<
 *                 else:
 *                     args = (type(arg), arg, None)
*/
        __pyx_t_5 = NULL;
        __Pyx_INCREF(__pyx_v_arg);
        __pyx_t_6 = __pyx_v_arg; 
        __pyx_t_7 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_6))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
          assert(__pyx_t_5);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
          __pyx_t_7 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
          __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_7, (1-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 488, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
        }
        __pyx_t_6 = PyTuple_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 488, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_INCREF(__pyx_v_arg);
        __Pyx_GIVEREF(__pyx_v_arg);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_v_arg) != (0)) __PYX_ERR(0, 488, __pyx_L1_error);
        __Pyx_GIVEREF(__pyx_t_3);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_3) != (0)) __PYX_ERR(0, 488, __pyx_L1_error);
        __Pyx_INCREF(Py_None);
        __Pyx_GIVEREF(Py_None);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 2, Py_None) != (0)) __PYX_ERR(0, 488, __pyx_L1_error);
        __pyx_t_3 = 0;
        __Pyx_DECREF_SET(__pyx_v_args, ((PyObject*)__pyx_t_6));
        __pyx_t_6 = 0;

        /* "src/gevent/greenlet.py":487
 *             if len(args) == 1:
 *                 arg = args[0]
 *                 if isinstance(arg, type) and issubclass(arg, BaseException):             # <<<<<<<<<<<<<<
 *                     args = (arg, arg(), None)
 *                 else:
*/
        goto __pyx_L7;
      }

      /* "src/gevent/greenlet.py":490
 *                     args = (arg, arg(), None)
 *                 else:
 *                     args = (type(arg), arg, None)             # <<<<<<<<<<<<<<
 *             elif not args:
 *                 args = (GreenletExit, GreenletExit(), None)
*/
      /*else*/ {
        __pyx_t_6 = PyTuple_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 490, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_INCREF(((PyObject *)Py_TYPE(__pyx_v_arg)));
        __Pyx_GIVEREF(((PyObject *)Py_TYPE(__pyx_v_arg)));
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, ((PyObject *)Py_TYPE(__pyx_v_arg))) != (0)) __PYX_ERR(0, 490, __pyx_L1_error);
        __Pyx_INCREF(__pyx_v_arg);
        __Pyx_GIVEREF(__pyx_v_arg);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_v_arg) != (0)) __PYX_ERR(0, 490, __pyx_L1_error);
        __Pyx_INCREF(Py_None);
        __Pyx_GIVEREF(Py_None);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 2, Py_None) != (0)) __PYX_ERR(0, 490, __pyx_L1_error);
        __Pyx_DECREF_SET(__pyx_v_args, ((PyObject*)__pyx_t_6));
        __pyx_t_6 = 0;
      }
      __pyx_L7:;

      /* "src/gevent/greenlet.py":485
 *             # exception raised by throw() is caught somewhere inside
 *             # the greenlet).
 *             if len(args) == 1:             # <<<<<<<<<<<<<<
 *                 arg = args[0]
 *                 if isinstance(arg, type) and issubclass(arg, BaseException):
*/
      goto __pyx_L6;
    }

    /* "src/gevent/greenlet.py":491
 *                 else:
 *                     args = (type(arg), arg, None)
 *             elif not args:             # <<<<<<<<<<<<<<
 *                 args = (GreenletExit, GreenletExit(), None)
 *             if not issubclass(args[0], BaseException):
*/
    if (__pyx_v_args == Py_None) __pyx_t_1 = 0;
    else
    {
      Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_v_args);
      if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 491, __pyx_L1_error)
      __pyx_t_1 = (__pyx_temp != 0);
    }

    __pyx_t_2 = (!__pyx_t_1);
    if (__pyx_t_2) {

      /* "src/gevent/greenlet.py":492
 *                     args = (type(arg), arg, None)
 *             elif not args:
 *                 args = (GreenletExit, GreenletExit(), None)             # <<<<<<<<<<<<<<
 *             if not issubclass(args[0], BaseException):
 *                 # Random non-type, non-exception arguments.
*/
      __pyx_t_3 = NULL;
      __Pyx_INCREF(__pyx_v_6gevent_17_gevent_cgreenlet_GreenletExit);
      __pyx_t_5 = __pyx_v_6gevent_17_gevent_cgreenlet_GreenletExit; 
      __pyx_t_7 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
        assert(__pyx_t_3);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
        __pyx_t_7 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
        __pyx_t_6 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_7, (1-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 492, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
      }
      __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 492, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_v_6gevent_17_gevent_cgreenlet_GreenletExit);
      __Pyx_GIVEREF(__pyx_v_6gevent_17_gevent_cgreenlet_GreenletExit);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_6gevent_17_gevent_cgreenlet_GreenletExit) != (0)) __PYX_ERR(0, 492, __pyx_L1_error);
      __Pyx_GIVEREF(__pyx_t_6);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_6) != (0)) __PYX_ERR(0, 492, __pyx_L1_error);
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 2, Py_None) != (0)) __PYX_ERR(0, 492, __pyx_L1_error);
      __pyx_t_6 = 0;
      __Pyx_DECREF_SET(__pyx_v_args, ((PyObject*)__pyx_t_5));
      __pyx_t_5 = 0;

      /* "src/gevent/greenlet.py":491
 *                 else:
 *                     args = (type(arg), arg, None)
 *             elif not args:             # <<<<<<<<<<<<<<
 *                 args = (GreenletExit, GreenletExit(), None)
 *             if not issubclass(args[0], BaseException):
*/
    }
    __pyx_L6:;

    /* "src/gevent/greenlet.py":493
 *             elif not args:
 *                 args = (GreenletExit, GreenletExit(), None)
 *             if not issubclass(args[0], BaseException):             # <<<<<<<<<<<<<<
 *                 # Random non-type, non-exception arguments.
 *                 args = (BaseException, BaseException(args), None)
*/
    if (unlikely(__pyx_v_args == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 493, __pyx_L1_error)
    }
    __pyx_t_5 = __Pyx_GetItemInt_Tuple(__pyx_v_args, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 493, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_2 = PyObject_IsSubclass(__pyx_t_5, ((PyObject *)(((PyTypeObject*)PyExc_BaseException)))); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 493, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_1 = (!__pyx_t_2);
    if (__pyx_t_1) {

      /* "src/gevent/greenlet.py":495
 *             if not issubclass(args[0], BaseException):
 *                 # Random non-type, non-exception arguments.
 *                 args = (BaseException, BaseException(args), None)             # <<<<<<<<<<<<<<
 *             assert issubclass(args[0], BaseException)
 *             self.__report_error(args)
*/
      __pyx_t_6 = NULL;
      __pyx_t_7 = 1;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_v_args};
        __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_BaseException)), __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 495, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
      }
      __pyx_t_6 = PyTuple_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 495, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_INCREF((PyObject *)(((PyTypeObject*)PyExc_BaseException)));
      __Pyx_GIVEREF((PyObject *)(((PyTypeObject*)PyExc_BaseException)));
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, ((PyObject *)(((PyTypeObject*)PyExc_BaseException)))) != (0)) __PYX_ERR(0, 495, __pyx_L1_error);
      __Pyx_GIVEREF(__pyx_t_5);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_5) != (0)) __PYX_ERR(0, 495, __pyx_L1_error);
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 2, Py_None) != (0)) __PYX_ERR(0, 495, __pyx_L1_error);
      __pyx_t_5 = 0;
      __Pyx_DECREF_SET(__pyx_v_args, ((PyObject*)__pyx_t_6));
      __pyx_t_6 = 0;

      /* "src/gevent/greenlet.py":493
 *             elif not args:
 *                 args = (GreenletExit, GreenletExit(), None)
 *             if not issubclass(args[0], BaseException):             # <<<<<<<<<<<<<<
 *                 # Random non-type, non-exception arguments.
 *                 args = (BaseException, BaseException(args), None)
*/
    }

    /* "src/gevent/greenlet.py":496
 *                 # Random non-type, non-exception arguments.
 *                 args = (BaseException, BaseException(args), None)
 *             assert issubclass(args[0], BaseException)             # <<<<<<<<<<<<<<
 *             self.__report_error(args)
 * 
*/
    #ifndef CYTHON_WITHOUT_ASSERTIONS
    if (unlikely(__pyx_assertions_enabled())) {
      if (unlikely(__pyx_v_args == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 496, __pyx_L1_error)
      }
      __pyx_t_6 = __Pyx_GetItemInt_Tuple(__pyx_v_args, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 496, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_1 = PyObject_IsSubclass(__pyx_t_6, ((PyObject *)(((PyTypeObject*)PyExc_BaseException)))); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 496, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) {
        __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_AssertionError))), 0, 0, 0);
        __PYX_ERR(0, 496, __pyx_L1_error)
      }
    }
    #else
    if ((1)); else __PYX_ERR(0, 496, __pyx_L1_error)
    #endif

    /* "src/gevent/greenlet.py":497
 *                 args = (BaseException, BaseException(args), None)
 *             assert issubclass(args[0], BaseException)
 *             self.__report_error(args)             # <<<<<<<<<<<<<<
 * 
 *     @property
*/
    __pyx_t_6 = __pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__Greenlet__report_error(__pyx_v_self, __pyx_v_args); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 497, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "src/gevent/greenlet.py":475
 *         # user error---instead of silently printing something to stderr, we still
 *         # kill the greenlet).
 *         if self._exc_info is None and self.dead:             # <<<<<<<<<<<<<<
 *             # the greenlet was never switched to before and it will
 *             # never be; _report_error was not called, the result was
*/
  }

  /* "src/gevent/greenlet.py":466
 *         self._start_event.close()
 * 
 *     def __handle_death_before_start(self, args):             # <<<<<<<<<<<<<<
 *         # args is (t, v, tb) or simply t or v.
 *         # The last two cases are transformed into (t, v, None);
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet._Greenlet__handle_death_before_start", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_arg);
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":499
 *             self.__report_error(args)
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def started(self):
 *         # DEPRECATED
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_7started_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_7started_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_7started___get__(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_7started___get__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "src/gevent/greenlet.py":502
 *     def started(self):
 *         # DEPRECATED
 *         return bool(self)             # <<<<<<<<<<<<<<
 * 
 *     def ready(self):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 502, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyBool_FromLong((!(!__pyx_t_1))); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 502, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "src/gevent/greenlet.py":499
 *             self.__report_error(args)
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def started(self):
 *         # DEPRECATED
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.started.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":504
 *         return bool(self)
 * 
 *     def ready(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return a true value if and only if the greenlet has finished
*/

static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_9ready(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet_ready(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ready", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (
  #if !CYTHON_USE_TYPE_SLOTS
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet &&
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
  #else
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
  #endif
  ) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_ready); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 504, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_9ready)) {
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 504, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 504, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_6;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "src/gevent/greenlet.py":513
 *             necessarily the literal constants ``True`` or ``False``.
 *         """
 *         return self.dead or self._exc_info is not None             # <<<<<<<<<<<<<<
 * 
 *     def successful(self):
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_dead); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 513, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!__pyx_t_7) {
  } else {
    __pyx_t_6 = __pyx_t_7;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_7 = (__pyx_v_self->_exc_info != ((PyObject*)Py_None));
  __pyx_t_6 = __pyx_t_7;
  __pyx_L3_bool_binop_done:;
  __pyx_r = __pyx_t_6;
  goto __pyx_L0;

  /* "src/gevent/greenlet.py":504
 *         return bool(self)
 * 
 *     def ready(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return a true value if and only if the greenlet has finished
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.ready", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_9ready(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_8ready, "Greenlet.ready(self) -> bool\n\nReturn a true value if and only if the greenlet has finished\nexecution.\n\n.. versionchanged:: 1.1\n    This function is only guaranteed to return true or false *values*, not\n    necessarily the literal constants ``True`` or ``False``.");
static PyMethodDef __pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_9ready = {"ready", (PyCFunction)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_9ready, METH_NOARGS, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_8ready};
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_9ready(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ready (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_8ready(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_8ready(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ready", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet_ready(__pyx_v_self, 1); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 504, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.ready", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":515
 *         return self.dead or self._exc_info is not None
 * 
 *     def successful(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return a true value if and only if the greenlet has finished execution
*/

static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_11successful(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet_successful(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("successful", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (
  #if !CYTHON_USE_TYPE_SLOTS
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet &&
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
  #else
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
  #endif
  ) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_successful); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 515, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_11successful)) {
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 515, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 515, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_6;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "src/gevent/greenlet.py":527
 *               not necessarily the literal constants ``True`` or ``False``.
 *         """
 *         return self._exc_info is not None and self._exc_info[1] is None             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
*/
  __pyx_t_7 = (__pyx_v_self->_exc_info != ((PyObject*)Py_None));
  if (__pyx_t_7) {
  } else {
    __pyx_t_6 = __pyx_t_7;
    goto __pyx_L3_bool_binop_done;
  }
  if (unlikely(__pyx_v_self->_exc_info == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 527, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v_self->_exc_info, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = (__pyx_t_1 == Py_None);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = __pyx_t_7;
  __pyx_L3_bool_binop_done:;
  __pyx_r = __pyx_t_6;
  goto __pyx_L0;

  /* "src/gevent/greenlet.py":515
 *         return self.dead or self._exc_info is not None
 * 
 *     def successful(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return a true value if and only if the greenlet has finished execution
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.successful", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_11successful(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_10successful, "Greenlet.successful(self) -> bool\n\nReturn a true value if and only if the greenlet has finished execution\nsuccessfully, that is, without raising an error.\n\n.. tip:: A greenlet that has been killed with the default\n    :class:`GreenletExit` exception is considered successful.\n    That is, ``GreenletExit`` is not considered an error.\n\n.. note:: This function is only guaranteed to return true or false *values*,\n      not necessarily the literal constants ``True`` or ``False``.");
static PyMethodDef __pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_11successful = {"successful", (PyCFunction)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_11successful, METH_NOARGS, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_10successful};
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_11successful(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("successful (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_10successful(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_10successful(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("successful", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet_successful(__pyx_v_self, 1); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 515, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.successful", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":529
 *         return self._exc_info is not None and self._exc_info[1] is None
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         classname = self.__class__.__name__
 *         # If no name has been assigned, don't generate one, including a minimal_ident,
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_13__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_13__repr__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_12__repr__(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_12__repr__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self) {
  PyObject *__pyx_v_classname = NULL;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_formatted = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5[3];
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7[5];
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "src/gevent/greenlet.py":530
 * 
 *     def __repr__(self):
 *         classname = self.__class__.__name__             # <<<<<<<<<<<<<<
 *         # If no name has been assigned, don't generate one, including a minimal_ident,
 *         # if not necessary. This reduces the use of weak references and associated
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_class); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_classname = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "src/gevent/greenlet.py":534
 *         # if not necessary. This reduces the use of weak references and associated
 *         # overhead.
 *         if 'name' not in self.__dict__ and self._ident is None:             # <<<<<<<<<<<<<<
 *             name = ' '
 *         else:
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_dict); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 534, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = (__Pyx_PySequence_ContainsTF(__pyx_mstate_global->__pyx_n_u_name_2, __pyx_t_2, Py_NE)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 534, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = (__pyx_v_self->_ident == Py_None);
  __pyx_t_3 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_3) {

    /* "src/gevent/greenlet.py":535
 *         # overhead.
 *         if 'name' not in self.__dict__ and self._ident is None:
 *             name = ' '             # <<<<<<<<<<<<<<
 *         else:
 *             name = ' "%s" ' % (self.name,)
*/
    __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_u_);
    __pyx_v_name = __pyx_mstate_global->__pyx_kp_u_;

    /* "src/gevent/greenlet.py":534
 *         # if not necessary. This reduces the use of weak references and associated
 *         # overhead.
 *         if 'name' not in self.__dict__ and self._ident is None:             # <<<<<<<<<<<<<<
 *             name = ' '
 *         else:
*/
    goto __pyx_L3;
  }

  /* "src/gevent/greenlet.py":537
 *             name = ' '
 *         else:
 *             name = ' "%s" ' % (self.name,)             # <<<<<<<<<<<<<<
 *         result = '<%s%sat %s' % (classname, name, hex(id(self)))
 *         formatted = self._formatinfo()
*/
  /*else*/ {
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 537, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_2), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 537, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_5[0] = __pyx_mstate_global->__pyx_kp_u__2;
    __pyx_t_5[1] = __pyx_t_1;
    __pyx_t_5[2] = __pyx_mstate_global->__pyx_kp_u__3;
    __pyx_t_2 = __Pyx_PyUnicode_Join(__pyx_t_5, 3, 2 * 2 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1));
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 537, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_name = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;
  }
  __pyx_L3:;

  /* "src/gevent/greenlet.py":538
 *         else:
 *             name = ' "%s" ' % (self.name,)
 *         result = '<%s%sat %s' % (classname, name, hex(id(self)))             # <<<<<<<<<<<<<<
 *         formatted = self._formatinfo()
 *         if formatted:
*/
  __pyx_t_2 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_v_classname), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 538, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_id, ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 538, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = __Pyx_PyNumber_Hex(__pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 538, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyUnicode_Unicode(__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 538, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_7[0] = __pyx_mstate_global->__pyx_kp_u__4;
  __pyx_t_7[1] = __pyx_t_2;
  __pyx_t_7[2] = __pyx_v_name;
  __pyx_t_7[3] = __pyx_mstate_global->__pyx_kp_u_at;
  __pyx_t_7[4] = __pyx_t_1;
  __pyx_t_6 = __Pyx_PyUnicode_Join(__pyx_t_7, 5, 1 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2) + __Pyx_PyUnicode_GET_LENGTH(__pyx_v_name) + 3 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_v_name) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1));
  if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 538, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_result = ((PyObject*)__pyx_t_6);
  __pyx_t_6 = 0;

  /* "src/gevent/greenlet.py":539
 *             name = ' "%s" ' % (self.name,)
 *         result = '<%s%sat %s' % (classname, name, hex(id(self)))
 *         formatted = self._formatinfo()             # <<<<<<<<<<<<<<
 *         if formatted:
 *             result += ': ' + formatted
*/
  __pyx_t_6 = ((struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self->__pyx_vtab)->_formatinfo(__pyx_v_self, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 539, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_v_formatted = ((PyObject*)__pyx_t_6);
  __pyx_t_6 = 0;

  /* "src/gevent/greenlet.py":540
 *         result = '<%s%sat %s' % (classname, name, hex(id(self)))
 *         formatted = self._formatinfo()
 *         if formatted:             # <<<<<<<<<<<<<<
 *             result += ': ' + formatted
 *         return result + '>'
*/
  if (__pyx_v_formatted == Py_None) __pyx_t_3 = 0;
  else
  {
    Py_ssize_t __pyx_temp = __Pyx_PyUnicode_IS_TRUE(__pyx_v_formatted);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 540, __pyx_L1_error)
    __pyx_t_3 = (__pyx_temp != 0);
  }

  if (__pyx_t_3) {

    /* "src/gevent/greenlet.py":541
 *         formatted = self._formatinfo()
 *         if formatted:
 *             result += ': ' + formatted             # <<<<<<<<<<<<<<
 *         return result + '>'
 * 
*/
    __pyx_t_6 = __Pyx_PyUnicode_ConcatSafe(__pyx_mstate_global->__pyx_kp_u__5, __pyx_v_formatted); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 541, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_1 = __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_OwnStrongReferenceInPlace(__pyx_v_result, __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 541, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF_SET(__pyx_v_result, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "src/gevent/greenlet.py":540
 *         result = '<%s%sat %s' % (classname, name, hex(id(self)))
 *         formatted = self._formatinfo()
 *         if formatted:             # <<<<<<<<<<<<<<
 *             result += ': ' + formatted
 *         return result + '>'
*/
  }

  /* "src/gevent/greenlet.py":542
 *         if formatted:
 *             result += ': ' + formatted
 *         return result + '>'             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyUnicode_Concat(__pyx_v_result, __pyx_mstate_global->__pyx_kp_u__6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 542, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "src/gevent/greenlet.py":529
 *         return self._exc_info is not None and self._exc_info[1] is None
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         classname = self.__class__.__name__
 *         # If no name has been assigned, don't generate one, including a minimal_ident,
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_classname);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_formatted);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":545
 * 
 * 
 *     def _formatinfo(self):             # <<<<<<<<<<<<<<
 *         info = self._formatted_info
 *         if info is not None:
*/

static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_15_formatinfo(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__formatinfo(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_info = NULL;
  PyObject *__pyx_v_func = NULL;
  PyObject *__pyx_v_im_self = NULL;
  PyObject *__pyx_v_funcname = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_args = NULL;
  PyObject *__pyx_7genexpr__pyx_v_x = NULL;
  PyObject *__pyx_8genexpr1__pyx_v_key = NULL;
  PyObject *__pyx_8genexpr1__pyx_v_value = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12[3];
  int __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_formatinfo", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (
  #if !CYTHON_USE_TYPE_SLOTS
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet &&
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
  #else
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
  #endif
  ) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_formatinfo); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 545, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_15_formatinfo)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 545, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None) || __Pyx_RaiseUnexpectedTypeError("str", __pyx_t_2))) __PYX_ERR(0, 545, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "src/gevent/greenlet.py":546
 * 
 *     def _formatinfo(self):
 *         info = self._formatted_info             # <<<<<<<<<<<<<<
 *         if info is not None:
 *             return info
*/
  __pyx_t_1 = __pyx_v_self->_formatted_info;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_info = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "src/gevent/greenlet.py":547
 *     def _formatinfo(self):
 *         info = self._formatted_info
 *         if info is not None:             # <<<<<<<<<<<<<<
 *             return info
 * 
*/
  __pyx_t_6 = (__pyx_v_info != ((PyObject*)Py_None));
  if (__pyx_t_6) {

    /* "src/gevent/greenlet.py":548
 *         info = self._formatted_info
 *         if info is not None:
 *             return info             # <<<<<<<<<<<<<<
 * 
 *         # Are we running an arbitrary function provided to the constructor,
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_info);
    __pyx_r = __pyx_v_info;
    goto __pyx_L0;

    /* "src/gevent/greenlet.py":547
 *     def _formatinfo(self):
 *         info = self._formatted_info
 *         if info is not None:             # <<<<<<<<<<<<<<
 *             return info
 * 
*/
  }

  /* "src/gevent/greenlet.py":552
 *         # Are we running an arbitrary function provided to the constructor,
 *         # or did a subclass override _run?
 *         func = self._run             # <<<<<<<<<<<<<<
 *         im_self = getattr(func, '__self__', None)
 *         if im_self is self:
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_run_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 552, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_func = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "src/gevent/greenlet.py":553
 *         # or did a subclass override _run?
 *         func = self._run
 *         im_self = getattr(func, '__self__', None)             # <<<<<<<<<<<<<<
 *         if im_self is self:
 *             funcname = '_run'
*/
  __pyx_t_1 = __Pyx_GetAttr3(__pyx_v_func, __pyx_mstate_global->__pyx_n_u_self, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 553, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_im_self = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "src/gevent/greenlet.py":554
 *         func = self._run
 *         im_self = getattr(func, '__self__', None)
 *         if im_self is self:             # <<<<<<<<<<<<<<
 *             funcname = '_run'
 *         elif im_self is not None:
*/
  __pyx_t_6 = (__pyx_v_im_self == ((PyObject *)__pyx_v_self));
  if (__pyx_t_6) {

    /* "src/gevent/greenlet.py":555
 *         im_self = getattr(func, '__self__', None)
 *         if im_self is self:
 *             funcname = '_run'             # <<<<<<<<<<<<<<
 *         elif im_self is not None:
 *             funcname = repr(func)
*/
    __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_run_2);
    __pyx_v_funcname = __pyx_mstate_global->__pyx_n_u_run_2;

    /* "src/gevent/greenlet.py":554
 *         func = self._run
 *         im_self = getattr(func, '__self__', None)
 *         if im_self is self:             # <<<<<<<<<<<<<<
 *             funcname = '_run'
 *         elif im_self is not None:
*/
    goto __pyx_L4;
  }

  /* "src/gevent/greenlet.py":556
 *         if im_self is self:
 *             funcname = '_run'
 *         elif im_self is not None:             # <<<<<<<<<<<<<<
 *             funcname = repr(func)
 *         else:
*/
  __pyx_t_6 = (__pyx_v_im_self != Py_None);
  if (__pyx_t_6) {

    /* "src/gevent/greenlet.py":557
 *             funcname = '_run'
 *         elif im_self is not None:
 *             funcname = repr(func)             # <<<<<<<<<<<<<<
 *         else:
 *             funcname = getattr(func, '__name__', '') or repr(func)
*/
    __pyx_t_1 = PyObject_Repr(__pyx_v_func); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 557, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_funcname = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "src/gevent/greenlet.py":556
 *         if im_self is self:
 *             funcname = '_run'
 *         elif im_self is not None:             # <<<<<<<<<<<<<<
 *             funcname = repr(func)
 *         else:
*/
    goto __pyx_L4;
  }

  /* "src/gevent/greenlet.py":559
 *             funcname = repr(func)
 *         else:
 *             funcname = getattr(func, '__name__', '') or repr(func)             # <<<<<<<<<<<<<<
 * 
 *         result = funcname
*/
  /*else*/ {
    __pyx_t_2 = __Pyx_GetAttr3(__pyx_v_func, __pyx_mstate_global->__pyx_n_u_name, __pyx_mstate_global->__pyx_kp_u__7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 559, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 559, __pyx_L1_error)
    if (!__pyx_t_6) {
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else {
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_1 = __pyx_t_2;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      goto __pyx_L5_bool_binop_done;
    }
    __pyx_t_2 = PyObject_Repr(__pyx_v_func); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 559, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_1 = __pyx_t_2;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_L5_bool_binop_done:;
    __pyx_v_funcname = __pyx_t_1;
    __pyx_t_1 = 0;
  }
  __pyx_L4:;

  /* "src/gevent/greenlet.py":561
 *             funcname = getattr(func, '__name__', '') or repr(func)
 * 
 *         result = funcname             # <<<<<<<<<<<<<<
 *         args = []
 *         if self.args:
*/
  __Pyx_INCREF(__pyx_v_funcname);
  __pyx_v_result = __pyx_v_funcname;

  /* "src/gevent/greenlet.py":562
 * 
 *         result = funcname
 *         args = []             # <<<<<<<<<<<<<<
 *         if self.args:
 *             args = [repr(x)[:50] for x in self.args]
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_args = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "src/gevent/greenlet.py":563
 *         result = funcname
 *         args = []
 *         if self.args:             # <<<<<<<<<<<<<<
 *             args = [repr(x)[:50] for x in self.args]
 *         if self.kwargs:
*/
  if (__pyx_v_self->args == Py_None) __pyx_t_6 = 0;
  else
  {
    Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_v_self->args);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 563, __pyx_L1_error)
    __pyx_t_6 = (__pyx_temp != 0);
  }

  if (__pyx_t_6) {

    /* "src/gevent/greenlet.py":564
 *         args = []
 *         if self.args:
 *             args = [repr(x)[:50] for x in self.args]             # <<<<<<<<<<<<<<
 *         if self.kwargs:
 *             args.extend(['%s=%s' % (key, repr(value)[:50]) for (key, value) in self.kwargs.items()])
*/
    { /* enter inner scope */
      __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 564, __pyx_L10_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (unlikely(__pyx_v_self->args == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
        __PYX_ERR(0, 564, __pyx_L10_error)
      }
      __pyx_t_2 = __pyx_v_self->args; __Pyx_INCREF(__pyx_t_2);
      __pyx_t_7 = 0;
      for (;;) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 564, __pyx_L10_error)
          #endif
          if (__pyx_t_7 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_7));
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_7);
        #endif
        ++__pyx_t_7;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 564, __pyx_L10_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_XDECREF_SET(__pyx_7genexpr__pyx_v_x, __pyx_t_4);
        __pyx_t_4 = 0;
        __pyx_t_4 = PyObject_Repr(__pyx_7genexpr__pyx_v_x); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 564, __pyx_L10_error)
        __Pyx_GOTREF(__pyx_t_4);
        if (unlikely(__pyx_t_4 == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 564, __pyx_L10_error)
        }
        __pyx_t_3 = __Pyx_PyUnicode_Substring(__pyx_t_4, 0, 50); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 564, __pyx_L10_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_3))) __PYX_ERR(0, 564, __pyx_L10_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_7genexpr__pyx_v_x); __pyx_7genexpr__pyx_v_x = 0;
      goto __pyx_L14_exit_scope;
      __pyx_L10_error:;
      __Pyx_XDECREF(__pyx_7genexpr__pyx_v_x); __pyx_7genexpr__pyx_v_x = 0;
      goto __pyx_L1_error;
      __pyx_L14_exit_scope:;
    } /* exit inner scope */
    __Pyx_DECREF_SET(__pyx_v_args, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "src/gevent/greenlet.py":563
 *         result = funcname
 *         args = []
 *         if self.args:             # <<<<<<<<<<<<<<
 *             args = [repr(x)[:50] for x in self.args]
 *         if self.kwargs:
*/
  }

  /* "src/gevent/greenlet.py":565
 *         if self.args:
 *             args = [repr(x)[:50] for x in self.args]
 *         if self.kwargs:             # <<<<<<<<<<<<<<
 *             args.extend(['%s=%s' % (key, repr(value)[:50]) for (key, value) in self.kwargs.items()])
 *         if args:
*/
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_self->kwargs); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 565, __pyx_L1_error)
  if (__pyx_t_6) {

    /* "src/gevent/greenlet.py":566
 *             args = [repr(x)[:50] for x in self.args]
 *         if self.kwargs:
 *             args.extend(['%s=%s' % (key, repr(value)[:50]) for (key, value) in self.kwargs.items()])             # <<<<<<<<<<<<<<
 *         if args:
 *             result += '(' + ', '.join(args) + ')'
*/
    { /* enter inner scope */
      __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 566, __pyx_L18_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_7 = 0;
      if (unlikely(__pyx_v_self->kwargs == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "items");
        __PYX_ERR(0, 566, __pyx_L18_error)
      }
      __pyx_t_3 = __Pyx_dict_iterator(__pyx_v_self->kwargs, 1, __pyx_mstate_global->__pyx_n_u_items, (&__pyx_t_8), (&__pyx_t_9)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 566, __pyx_L18_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_XDECREF(__pyx_t_2);
      __pyx_t_2 = __pyx_t_3;
      __pyx_t_3 = 0;
      while (1) {
        __pyx_t_10 = __Pyx_dict_iter_next(__pyx_t_2, __pyx_t_8, &__pyx_t_7, &__pyx_t_3, &__pyx_t_4, NULL, __pyx_t_9);
        if (unlikely(__pyx_t_10 == 0)) break;
        if (unlikely(__pyx_t_10 == -1)) __PYX_ERR(0, 566, __pyx_L18_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_XDECREF_SET(__pyx_8genexpr1__pyx_v_key, __pyx_t_3);
        __pyx_t_3 = 0;
        __Pyx_XDECREF_SET(__pyx_8genexpr1__pyx_v_value, __pyx_t_4);
        __pyx_t_4 = 0;
        __pyx_t_4 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_8genexpr1__pyx_v_key), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 566, __pyx_L18_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_3 = PyObject_Repr(__pyx_8genexpr1__pyx_v_value); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 566, __pyx_L18_error)
        __Pyx_GOTREF(__pyx_t_3);
        if (unlikely(__pyx_t_3 == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 566, __pyx_L18_error)
        }
        __pyx_t_11 = __Pyx_PyUnicode_Substring(__pyx_t_3, 0, 50); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 566, __pyx_L18_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_12[0] = __pyx_t_4;
        __pyx_t_12[1] = __pyx_mstate_global->__pyx_kp_u__8;
        __pyx_t_12[2] = __pyx_t_11;
        __pyx_t_3 = __Pyx_PyUnicode_Join(__pyx_t_12, 3, __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4) + 1 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_11), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_11));
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 566, __pyx_L18_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_3))) __PYX_ERR(0, 566, __pyx_L18_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_key); __pyx_8genexpr1__pyx_v_key = 0;
      __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_value); __pyx_8genexpr1__pyx_v_value = 0;
      goto __pyx_L21_exit_scope;
      __pyx_L18_error:;
      __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_key); __pyx_8genexpr1__pyx_v_key = 0;
      __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_value); __pyx_8genexpr1__pyx_v_value = 0;
      goto __pyx_L1_error;
      __pyx_L21_exit_scope:;
    } /* exit inner scope */
    __pyx_t_13 = __Pyx_PyList_Extend(__pyx_v_args, __pyx_t_1); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 566, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "src/gevent/greenlet.py":565
 *         if self.args:
 *             args = [repr(x)[:50] for x in self.args]
 *         if self.kwargs:             # <<<<<<<<<<<<<<
 *             args.extend(['%s=%s' % (key, repr(value)[:50]) for (key, value) in self.kwargs.items()])
 *         if args:
*/
  }

  /* "src/gevent/greenlet.py":567
 *         if self.kwargs:
 *             args.extend(['%s=%s' % (key, repr(value)[:50]) for (key, value) in self.kwargs.items()])
 *         if args:             # <<<<<<<<<<<<<<
 *             result += '(' + ', '.join(args) + ')'
 *         # it is important to save the result here, because once the greenlet exits '_run' attribute will be removed
*/
  {
    Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_args);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 567, __pyx_L1_error)
    __pyx_t_6 = (__pyx_temp != 0);
  }

  if (__pyx_t_6) {

    /* "src/gevent/greenlet.py":568
 *             args.extend(['%s=%s' % (key, repr(value)[:50]) for (key, value) in self.kwargs.items()])
 *         if args:
 *             result += '(' + ', '.join(args) + ')'             # <<<<<<<<<<<<<<
 *         # it is important to save the result here, because once the greenlet exits '_run' attribute will be removed
 *         self._formatted_info = result
*/
    __pyx_t_1 = PyUnicode_Join(__pyx_mstate_global->__pyx_kp_u__10, __pyx_v_args); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 568, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u__9, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 568, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_OwnStrongReferenceInPlace(__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__11); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 568, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyNumber_InPlaceAdd(__pyx_v_result, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 568, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_result, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "src/gevent/greenlet.py":567
 *         if self.kwargs:
 *             args.extend(['%s=%s' % (key, repr(value)[:50]) for (key, value) in self.kwargs.items()])
 *         if args:             # <<<<<<<<<<<<<<
 *             result += '(' + ', '.join(args) + ')'
 *         # it is important to save the result here, because once the greenlet exits '_run' attribute will be removed
*/
  }

  /* "src/gevent/greenlet.py":570
 *             result += '(' + ', '.join(args) + ')'
 *         # it is important to save the result here, because once the greenlet exits '_run' attribute will be removed
 *         self._formatted_info = result             # <<<<<<<<<<<<<<
 *         return result
 * 
*/
  __pyx_t_2 = __pyx_v_result;
  __Pyx_INCREF(__pyx_t_2);
  if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None) || __Pyx_RaiseUnexpectedTypeError("str", __pyx_t_2))) __PYX_ERR(0, 570, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_self->_formatted_info);
  __Pyx_DECREF(__pyx_v_self->_formatted_info);
  __pyx_v_self->_formatted_info = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "src/gevent/greenlet.py":571
 *         # it is important to save the result here, because once the greenlet exits '_run' attribute will be removed
 *         self._formatted_info = result
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     @property
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __pyx_v_result;
  __Pyx_INCREF(__pyx_t_2);
  if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None) || __Pyx_RaiseUnexpectedTypeError("str", __pyx_t_2))) __PYX_ERR(0, 571, __pyx_L1_error)
  __pyx_r = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "src/gevent/greenlet.py":545
 * 
 * 
 *     def _formatinfo(self):             # <<<<<<<<<<<<<<
 *         info = self._formatted_info
 *         if info is not None:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet._formatinfo", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_info);
  __Pyx_XDECREF(__pyx_v_func);
  __Pyx_XDECREF(__pyx_v_im_self);
  __Pyx_XDECREF(__pyx_v_funcname);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_7genexpr__pyx_v_x);
  __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_key);
  __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_value);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_15_formatinfo(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_14_formatinfo, "Greenlet._formatinfo(self) -> str");
static PyMethodDef __pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_15_formatinfo = {"_formatinfo", (PyCFunction)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_15_formatinfo, METH_NOARGS, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_14_formatinfo};
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_15_formatinfo(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_formatinfo (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_14_formatinfo(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_14_formatinfo(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_formatinfo", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__formatinfo(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet._formatinfo", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":573
 *         return result
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def exception(self):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_9exception_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_9exception_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_9exception___get__(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_9exception___get__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "src/gevent/greenlet.py":579
 *         greenlet has finished with an error. Otherwise ``None``.
 *         """
 *         return self._exc_info[1] if self._exc_info is not None else None             # <<<<<<<<<<<<<<
 * 
 *     @property
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = (__pyx_v_self->_exc_info != ((PyObject*)Py_None));
  if (__pyx_t_2) {
    if (unlikely(__pyx_v_self->_exc_info == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 579, __pyx_L1_error)
    }
    __pyx_t_3 = __Pyx_GetItemInt_Tuple(__pyx_v_self->_exc_info, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 579, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
  } else {
    __Pyx_INCREF(Py_None);
    __pyx_t_1 = Py_None;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "src/gevent/greenlet.py":573
 *         return result
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def exception(self):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.exception.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":581
 *         return self._exc_info[1] if self._exc_info is not None else None
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def exc_info(self):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_8exc_info_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_8exc_info_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_8exc_info___get__(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_8exc_info___get__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self) {
  PyObject *__pyx_v_ei = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  size_t __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "src/gevent/greenlet.py":591
 *         .. versionadded:: 1.1
 *         """
 *         ei = self._exc_info             # <<<<<<<<<<<<<<
 *         if ei is not None and ei[0] is not None:
 *             return (
*/
  __pyx_t_1 = __pyx_v_self->_exc_info;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_ei = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "src/gevent/greenlet.py":592
 *         """
 *         ei = self._exc_info
 *         if ei is not None and ei[0] is not None:             # <<<<<<<<<<<<<<
 *             return (
 *                 ei[0],
*/
  __pyx_t_3 = (__pyx_v_ei != ((PyObject*)Py_None));
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  if (unlikely(__pyx_v_ei == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 592, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v_ei, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 592, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = (__pyx_t_1 != Py_None);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "src/gevent/greenlet.py":593
 *         ei = self._exc_info
 *         if ei is not None and ei[0] is not None:
 *             return (             # <<<<<<<<<<<<<<
 *                 ei[0],
 *                 ei[1],
*/
    __Pyx_XDECREF(__pyx_r);

    /* "src/gevent/greenlet.py":594
 *         if ei is not None and ei[0] is not None:
 *             return (
 *                 ei[0],             # <<<<<<<<<<<<<<
 *                 ei[1],
 *                 # The pickled traceback may be None if we couldn't pickle it.
*/
    if (unlikely(__pyx_v_ei == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 594, __pyx_L1_error)
    }
    __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v_ei, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 594, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);

    /* "src/gevent/greenlet.py":595
 *             return (
 *                 ei[0],
 *                 ei[1],             # <<<<<<<<<<<<<<
 *                 # The pickled traceback may be None if we couldn't pickle it.
 *                 load_traceback(ei[2]) if ei[2] else None
*/
    if (unlikely(__pyx_v_ei == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 595, __pyx_L1_error)
    }
    __pyx_t_4 = __Pyx_GetItemInt_Tuple(__pyx_v_ei, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 595, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);

    /* "src/gevent/greenlet.py":597
 *                 ei[1],
 *                 # The pickled traceback may be None if we couldn't pickle it.
 *                 load_traceback(ei[2]) if ei[2] else None             # <<<<<<<<<<<<<<
 *             )
 * 
*/
    if (unlikely(__pyx_v_ei == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 597, __pyx_L1_error)
    }
    __pyx_t_6 = __Pyx_GetItemInt_Tuple(__pyx_v_ei, 2, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 597, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 597, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (__pyx_t_2) {
      __pyx_t_7 = NULL;
      __Pyx_INCREF(__pyx_v_6gevent_17_gevent_cgreenlet_load_traceback);
      __pyx_t_8 = __pyx_v_6gevent_17_gevent_cgreenlet_load_traceback; 
      if (unlikely(__pyx_v_ei == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 597, __pyx_L1_error)
      }
      __pyx_t_9 = __Pyx_GetItemInt_Tuple(__pyx_v_ei, 2, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 597, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_8);
        assert(__pyx_t_7);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_8, __pyx__function);
        __pyx_t_10 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_9};
        __pyx_t_6 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_8, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 597, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
      }
      __pyx_t_5 = __pyx_t_6;
      __pyx_t_6 = 0;
    } else {
      __Pyx_INCREF(Py_None);
      __pyx_t_5 = Py_None;
    }

    /* "src/gevent/greenlet.py":594
 *         if ei is not None and ei[0] is not None:
 *             return (
 *                 ei[0],             # <<<<<<<<<<<<<<
 *                 ei[1],
 *                 # The pickled traceback may be None if we couldn't pickle it.
*/
    __pyx_t_6 = PyTuple_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 594, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_1) != (0)) __PYX_ERR(0, 594, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_4) != (0)) __PYX_ERR(0, 594, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_5);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_t_5) != (0)) __PYX_ERR(0, 594, __pyx_L1_error);
    __pyx_t_1 = 0;
    __pyx_t_4 = 0;
    __pyx_t_5 = 0;
    __pyx_r = __pyx_t_6;
    __pyx_t_6 = 0;
    goto __pyx_L0;

    /* "src/gevent/greenlet.py":592
 *         """
 *         ei = self._exc_info
 *         if ei is not None and ei[0] is not None:             # <<<<<<<<<<<<<<
 *             return (
 *                 ei[0],
*/
  }

  /* "src/gevent/greenlet.py":581
 *         return self._exc_info[1] if self._exc_info is not None else None
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def exc_info(self):
 *         """
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.exc_info.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ei);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":600
 *             )
 * 
 *     def throw(self, *args):             # <<<<<<<<<<<<<<
 *         """Immediately switch into the greenlet and raise an exception in it.
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_17throw(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_16throw, "Greenlet.throw(self, *args)\n\nImmediately switch into the greenlet and raise an exception in it.\n\nShould only be called from the HUB, otherwise the current greenlet is left unscheduled forever.\nTo raise an exception in a safe manner from any greenlet, use :meth:`kill`.\n\nIf a greenlet was started but never switched to yet, then also\na) cancel the event that will start it\nb) fire the notifications as if an exception was raised in a greenlet");
static PyMethodDef __pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_17throw = {"throw", (PyCFunction)(void(*)(void))(PyCFunctionWithKeywords)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_17throw, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_16throw};
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_17throw(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("throw (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return NULL;
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("throw", __pyx_kwds); return NULL;}
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_16throw(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_16throw(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  char const *__pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("throw", 0);

  /* "src/gevent/greenlet.py":610
 *         b) fire the notifications as if an exception was raised in a greenlet
 *         """
 *         self.__cancel_start()             # <<<<<<<<<<<<<<
 * 
 *         try:
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self->__pyx_vtab)->_Greenlet__cancel_start(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 610, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "src/gevent/greenlet.py":612
 *         self.__cancel_start()
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             if not self.dead:
 *                 # Prevent switching into a greenlet *at all* if we had never
*/
  /*try:*/ {

    /* "src/gevent/greenlet.py":613
 * 
 *         try:
 *             if not self.dead:             # <<<<<<<<<<<<<<
 *                 # Prevent switching into a greenlet *at all* if we had never
 *                 # started it. Usually this is the same thing that happens by throwing,
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_dead); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 613, __pyx_L4_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 613, __pyx_L4_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_3 = (!__pyx_t_2);
    if (__pyx_t_3) {

      /* "src/gevent/greenlet.py":618
 *                 # but if this is done from the hub with nothing else running, prevents a
 *                 # LoopExit.
 *                 greenlet.throw(self, *args)             # <<<<<<<<<<<<<<
 *         finally:
 *             self.__handle_death_before_start(args)
*/
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_greenlet), __pyx_mstate_global->__pyx_n_u_throw); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 618, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 618, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF((PyObject *)__pyx_v_self);
      __Pyx_GIVEREF((PyObject *)__pyx_v_self);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_v_self)) != (0)) __PYX_ERR(0, 618, __pyx_L4_error);
      __pyx_t_5 = PyNumber_Add(__pyx_t_4, __pyx_v_args); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 618, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 618, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "src/gevent/greenlet.py":613
 * 
 *         try:
 *             if not self.dead:             # <<<<<<<<<<<<<<
 *                 # Prevent switching into a greenlet *at all* if we had never
 *                 # started it. Usually this is the same thing that happens by throwing,
*/
    }
  }

  /* "src/gevent/greenlet.py":620
 *                 greenlet.throw(self, *args)
 *         finally:
 *             self.__handle_death_before_start(args)             # <<<<<<<<<<<<<<
 * 
 *     def start(self):
*/
  /*finally:*/ {
    /*normal exit:*/{
      __pyx_t_4 = ((struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self->__pyx_vtab)->_Greenlet__handle_death_before_start(__pyx_v_self, __pyx_v_args); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 620, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      goto __pyx_L5;
    }
    __pyx_L4_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
       __Pyx_ExceptionSwap(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14);
      if ( unlikely(__Pyx_GetException(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11) < 0)) __Pyx_ErrFetch(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_14);
      __pyx_t_6 = __pyx_lineno; __pyx_t_7 = __pyx_clineno; __pyx_t_8 = __pyx_filename;
      {
        __pyx_t_4 = ((struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self->__pyx_vtab)->_Greenlet__handle_death_before_start(__pyx_v_self, __pyx_v_args); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 620, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __Pyx_XGIVEREF(__pyx_t_12);
      __Pyx_XGIVEREF(__pyx_t_13);
      __Pyx_XGIVEREF(__pyx_t_14);
      __Pyx_ExceptionReset(__pyx_t_12, __pyx_t_13, __pyx_t_14);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_ErrRestore(__pyx_t_9, __pyx_t_10, __pyx_t_11);
      __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0;
      __pyx_lineno = __pyx_t_6; __pyx_clineno = __pyx_t_7; __pyx_filename = __pyx_t_8;
      goto __pyx_L1_error;
      __pyx_L8_error:;
      __Pyx_XGIVEREF(__pyx_t_12);
      __Pyx_XGIVEREF(__pyx_t_13);
      __Pyx_XGIVEREF(__pyx_t_14);
      __Pyx_ExceptionReset(__pyx_t_12, __pyx_t_13, __pyx_t_14);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0;
      goto __pyx_L1_error;
    }
    __pyx_L5:;
  }

  /* "src/gevent/greenlet.py":600
 *             )
 * 
 *     def throw(self, *args):             # <<<<<<<<<<<<<<
 *         """Immediately switch into the greenlet and raise an exception in it.
 * 
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.throw", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":622
 *             self.__handle_death_before_start(args)
 * 
 *     def start(self):             # <<<<<<<<<<<<<<
 *         """Schedule the greenlet to run in this loop iteration"""
 *         if self._start_event is None:
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_19start(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_18start, "Greenlet.start(self)\n\nSchedule the greenlet to run in this loop iteration");
static PyMethodDef __pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_19start = {"start", (PyCFunction)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_19start, METH_NOARGS, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_18start};
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_19start(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("start (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_18start(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_18start(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self) {
  struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *__pyx_v_hub = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("start", 0);

  /* "src/gevent/greenlet.py":624
 *     def start(self):
 *         """Schedule the greenlet to run in this loop iteration"""
 *         if self._start_event is None:             # <<<<<<<<<<<<<<
 *             _call_spawn_callbacks(self)
 *             hub = get_my_hub(self) # pylint:disable=undefined-variable
*/
  __pyx_t_1 = (__pyx_v_self->_start_event == Py_None);
  if (__pyx_t_1) {

    /* "src/gevent/greenlet.py":625
 *         """Schedule the greenlet to run in this loop iteration"""
 *         if self._start_event is None:
 *             _call_spawn_callbacks(self)             # <<<<<<<<<<<<<<
 *             hub = get_my_hub(self) # pylint:disable=undefined-variable
 *             self._start_event = hub.loop.run_callback(self.switch)
*/
    __pyx_f_6gevent_17_gevent_cgreenlet__call_spawn_callbacks(__pyx_v_self); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 625, __pyx_L1_error)

    /* "src/gevent/greenlet.py":626
 *         if self._start_event is None:
 *             _call_spawn_callbacks(self)
 *             hub = get_my_hub(self) # pylint:disable=undefined-variable             # <<<<<<<<<<<<<<
 *             self._start_event = hub.loop.run_callback(self.switch)
 * 
*/
    __pyx_t_2 = ((PyObject *)__pyx_f_6gevent_17_gevent_cgreenlet_get_my_hub(((PyGreenlet *)__pyx_v_self))); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 626, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_hub = ((struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "src/gevent/greenlet.py":627
 *             _call_spawn_callbacks(self)
 *             hub = get_my_hub(self) # pylint:disable=undefined-variable
 *             self._start_event = hub.loop.run_callback(self.switch)             # <<<<<<<<<<<<<<
 * 
 *     def start_later(self, seconds):
*/
    __pyx_t_3 = __pyx_v_hub->loop;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_switch); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 627, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_4};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_run_callback, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 627, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_GIVEREF(__pyx_t_2);
    __Pyx_GOTREF(__pyx_v_self->_start_event);
    __Pyx_DECREF(__pyx_v_self->_start_event);
    __pyx_v_self->_start_event = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "src/gevent/greenlet.py":624
 *     def start(self):
 *         """Schedule the greenlet to run in this loop iteration"""
 *         if self._start_event is None:             # <<<<<<<<<<<<<<
 *             _call_spawn_callbacks(self)
 *             hub = get_my_hub(self) # pylint:disable=undefined-variable
*/
  }

  /* "src/gevent/greenlet.py":622
 *             self.__handle_death_before_start(args)
 * 
 *     def start(self):             # <<<<<<<<<<<<<<
 *         """Schedule the greenlet to run in this loop iteration"""
 *         if self._start_event is None:
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.start", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_hub);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":629
 *             self._start_event = hub.loop.run_callback(self.switch)
 * 
 *     def start_later(self, seconds):             # <<<<<<<<<<<<<<
 *         """
 *         start_later(seconds) -> None
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_21start_later(PyObject *__pyx_v_self, PyObject *__pyx_v_seconds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_20start_later, "Greenlet.start_later(self, seconds)\n\nstart_later(seconds) -> None\n\nSchedule the greenlet to run in the future loop iteration\n*seconds* later");
static PyMethodDef __pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_21start_later = {"start_later", (PyCFunction)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_21start_later, METH_O, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_20start_later};
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_21start_later(PyObject *__pyx_v_self, PyObject *__pyx_v_seconds) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("start_later (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_20start_later(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self), ((PyObject *)__pyx_v_seconds));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_20start_later(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, PyObject *__pyx_v_seconds) {
  struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *__pyx_v_hub = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("start_later", 0);

  /* "src/gevent/greenlet.py":636
 *         *seconds* later
 *         """
 *         if self._start_event is None:             # <<<<<<<<<<<<<<
 *             _call_spawn_callbacks(self)
 *             hub = get_my_hub(self) # pylint:disable=undefined-variable
*/
  __pyx_t_1 = (__pyx_v_self->_start_event == Py_None);
  if (__pyx_t_1) {

    /* "src/gevent/greenlet.py":637
 *         """
 *         if self._start_event is None:
 *             _call_spawn_callbacks(self)             # <<<<<<<<<<<<<<
 *             hub = get_my_hub(self) # pylint:disable=undefined-variable
 *             self._start_event = hub.loop.timer(seconds)
*/
    __pyx_f_6gevent_17_gevent_cgreenlet__call_spawn_callbacks(__pyx_v_self); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 637, __pyx_L1_error)

    /* "src/gevent/greenlet.py":638
 *         if self._start_event is None:
 *             _call_spawn_callbacks(self)
 *             hub = get_my_hub(self) # pylint:disable=undefined-variable             # <<<<<<<<<<<<<<
 *             self._start_event = hub.loop.timer(seconds)
 *             self._start_event.start(self.switch)
*/
    __pyx_t_2 = ((PyObject *)__pyx_f_6gevent_17_gevent_cgreenlet_get_my_hub(((PyGreenlet *)__pyx_v_self))); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 638, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_hub = ((struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "src/gevent/greenlet.py":639
 *             _call_spawn_callbacks(self)
 *             hub = get_my_hub(self) # pylint:disable=undefined-variable
 *             self._start_event = hub.loop.timer(seconds)             # <<<<<<<<<<<<<<
 *             self._start_event.start(self.switch)
 * 
*/
    __pyx_t_3 = __pyx_v_hub->loop;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_seconds};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_timer, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 639, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_GIVEREF(__pyx_t_2);
    __Pyx_GOTREF(__pyx_v_self->_start_event);
    __Pyx_DECREF(__pyx_v_self->_start_event);
    __pyx_v_self->_start_event = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "src/gevent/greenlet.py":640
 *             hub = get_my_hub(self) # pylint:disable=undefined-variable
 *             self._start_event = hub.loop.timer(seconds)
 *             self._start_event.start(self.switch)             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/
    __pyx_t_3 = __pyx_v_self->_start_event;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_switch); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 640, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_5};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_start, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 640, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "src/gevent/greenlet.py":636
 *         *seconds* later
 *         """
 *         if self._start_event is None:             # <<<<<<<<<<<<<<
 *             _call_spawn_callbacks(self)
 *             hub = get_my_hub(self) # pylint:disable=undefined-variable
*/
  }

  /* "src/gevent/greenlet.py":629
 *             self._start_event = hub.loop.run_callback(self.switch)
 * 
 *     def start_later(self, seconds):             # <<<<<<<<<<<<<<
 *         """
 *         start_later(seconds) -> None
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.start_later", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_hub);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":642
 *             self._start_event.start(self.switch)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def add_spawn_callback(callback):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_23add_spawn_callback(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_22add_spawn_callback, "Greenlet.add_spawn_callback(callback)\n\nadd_spawn_callback(callback) -> None\n\nSet up a *callback* to be invoked when :class:`Greenlet` objects\nare started.\n\nThe invocation order of spawn callbacks is unspecified.  Adding the\nsame callback more than one time will not cause it to be called more\nthan once.\n\n.. versionadded:: 1.4.0");
static PyMethodDef __pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_23add_spawn_callback = {"add_spawn_callback", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_23add_spawn_callback, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_22add_spawn_callback};
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_23add_spawn_callback(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_callback = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("add_spawn_callback (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_callback,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 642, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 642, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "add_spawn_callback", 0) < (0)) __PYX_ERR(0, 642, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("add_spawn_callback", 1, 1, 1, i); __PYX_ERR(0, 642, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 642, __pyx_L3_error)
    }
    __pyx_v_callback = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("add_spawn_callback", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 642, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.add_spawn_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_22add_spawn_callback(__pyx_v_callback);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_22add_spawn_callback(PyObject *__pyx_v_callback) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("add_spawn_callback", 0);

  /* "src/gevent/greenlet.py":657
 *         """
 *         global _spawn_callbacks
 *         if _spawn_callbacks is None:  # pylint:disable=used-before-assignment             # <<<<<<<<<<<<<<
 *             _spawn_callbacks = set()
 *         _spawn_callbacks.add(callback)
*/
  __pyx_t_1 = (__pyx_v_6gevent_17_gevent_cgreenlet__spawn_callbacks == ((PyObject*)Py_None));
  if (__pyx_t_1) {

    /* "src/gevent/greenlet.py":658
 *         global _spawn_callbacks
 *         if _spawn_callbacks is None:  # pylint:disable=used-before-assignment
 *             _spawn_callbacks = set()             # <<<<<<<<<<<<<<
 *         _spawn_callbacks.add(callback)
 * 
*/
    __pyx_t_2 = PySet_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 658, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_v_6gevent_17_gevent_cgreenlet__spawn_callbacks);
    __Pyx_DECREF_SET(__pyx_v_6gevent_17_gevent_cgreenlet__spawn_callbacks, ((PyObject*)__pyx_t_2));
    __Pyx_GIVEREF(__pyx_t_2);
    __pyx_t_2 = 0;

    /* "src/gevent/greenlet.py":657
 *         """
 *         global _spawn_callbacks
 *         if _spawn_callbacks is None:  # pylint:disable=used-before-assignment             # <<<<<<<<<<<<<<
 *             _spawn_callbacks = set()
 *         _spawn_callbacks.add(callback)
*/
  }

  /* "src/gevent/greenlet.py":659
 *         if _spawn_callbacks is None:  # pylint:disable=used-before-assignment
 *             _spawn_callbacks = set()
 *         _spawn_callbacks.add(callback)             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/
  if (unlikely(__pyx_v_6gevent_17_gevent_cgreenlet__spawn_callbacks == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "add");
    __PYX_ERR(0, 659, __pyx_L1_error)
  }
  __pyx_t_3 = PySet_Add(__pyx_v_6gevent_17_gevent_cgreenlet__spawn_callbacks, __pyx_v_callback); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(0, 659, __pyx_L1_error)

  /* "src/gevent/greenlet.py":642
 *             self._start_event.start(self.switch)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def add_spawn_callback(callback):
 *         """
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.add_spawn_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":661
 *         _spawn_callbacks.add(callback)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def remove_spawn_callback(callback):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_25remove_spawn_callback(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_24remove_spawn_callback, "Greenlet.remove_spawn_callback(callback)\n\nremove_spawn_callback(callback) -> None\n\nRemove *callback* function added with :meth:`Greenlet.add_spawn_callback`.\nThis function will not fail if *callback* has been already removed or\nif *callback* was never added.\n\n.. versionadded:: 1.4.0");
static PyMethodDef __pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_25remove_spawn_callback = {"remove_spawn_callback", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_25remove_spawn_callback, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_24remove_spawn_callback};
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_25remove_spawn_callback(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_callback = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("remove_spawn_callback (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_callback,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 661, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 661, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "remove_spawn_callback", 0) < (0)) __PYX_ERR(0, 661, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("remove_spawn_callback", 1, 1, 1, i); __PYX_ERR(0, 661, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 661, __pyx_L3_error)
    }
    __pyx_v_callback = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("remove_spawn_callback", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 661, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.remove_spawn_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_24remove_spawn_callback(__pyx_v_callback);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_24remove_spawn_callback(PyObject *__pyx_v_callback) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("remove_spawn_callback", 0);

  /* "src/gevent/greenlet.py":673
 *         """
 *         global _spawn_callbacks
 *         if _spawn_callbacks is not None:             # <<<<<<<<<<<<<<
 *             _spawn_callbacks.discard(callback)
 *             if not _spawn_callbacks:
*/
  __pyx_t_1 = (__pyx_v_6gevent_17_gevent_cgreenlet__spawn_callbacks != ((PyObject*)Py_None));
  if (__pyx_t_1) {

    /* "src/gevent/greenlet.py":674
 *         global _spawn_callbacks
 *         if _spawn_callbacks is not None:
 *             _spawn_callbacks.discard(callback)             # <<<<<<<<<<<<<<
 *             if not _spawn_callbacks:
 *                 _spawn_callbacks = None
*/
    if (unlikely(__pyx_v_6gevent_17_gevent_cgreenlet__spawn_callbacks == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "discard");
      __PYX_ERR(0, 674, __pyx_L1_error)
    }
    __pyx_t_2 = __Pyx_PySet_Discard(__pyx_v_6gevent_17_gevent_cgreenlet__spawn_callbacks, __pyx_v_callback); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 674, __pyx_L1_error)

    /* "src/gevent/greenlet.py":675
 *         if _spawn_callbacks is not None:
 *             _spawn_callbacks.discard(callback)
 *             if not _spawn_callbacks:             # <<<<<<<<<<<<<<
 *                 _spawn_callbacks = None
 * 
*/
    if (__pyx_v_6gevent_17_gevent_cgreenlet__spawn_callbacks == Py_None) __pyx_t_1 = 0;
    else
    {
      Py_ssize_t __pyx_temp = __Pyx_PySet_GET_SIZE(__pyx_v_6gevent_17_gevent_cgreenlet__spawn_callbacks);
      if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 675, __pyx_L1_error)
      __pyx_t_1 = (__pyx_temp != 0);
    }

    __pyx_t_3 = (!__pyx_t_1);
    if (__pyx_t_3) {

      /* "src/gevent/greenlet.py":676
 *             _spawn_callbacks.discard(callback)
 *             if not _spawn_callbacks:
 *                 _spawn_callbacks = None             # <<<<<<<<<<<<<<
 * 
 *     @classmethod
*/
      __Pyx_INCREF(Py_None);
      __Pyx_XGOTREF(__pyx_v_6gevent_17_gevent_cgreenlet__spawn_callbacks);
      __Pyx_DECREF_SET(__pyx_v_6gevent_17_gevent_cgreenlet__spawn_callbacks, ((PyObject*)Py_None));
      __Pyx_GIVEREF(Py_None);

      /* "src/gevent/greenlet.py":675
 *         if _spawn_callbacks is not None:
 *             _spawn_callbacks.discard(callback)
 *             if not _spawn_callbacks:             # <<<<<<<<<<<<<<
 *                 _spawn_callbacks = None
 * 
*/
    }

    /* "src/gevent/greenlet.py":673
 *         """
 *         global _spawn_callbacks
 *         if _spawn_callbacks is not None:             # <<<<<<<<<<<<<<
 *             _spawn_callbacks.discard(callback)
 *             if not _spawn_callbacks:
*/
  }

  /* "src/gevent/greenlet.py":661
 *         _spawn_callbacks.add(callback)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def remove_spawn_callback(callback):
 *         """
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.remove_spawn_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":678
 *                 _spawn_callbacks = None
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def spawn(cls, *args, **kwargs):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_27spawn(PyObject *__pyx_v_cls, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_26spawn, "Greenlet.spawn(cls, *args, **kwargs)\n\nspawn(function, *args, **kwargs) -> Greenlet\n\nCreate a new :class:`Greenlet` object and schedule it to run ``function(*args, **kwargs)``.\nThis can be used as ``gevent.spawn`` or ``Greenlet.spawn``.\n\nThe arguments are passed to :meth:`Greenlet.__init__`.\n\n.. versionchanged:: 1.1b1\n    If a *function* is given that is not callable, immediately raise a :exc:`TypeError`\n    instead of spawning a greenlet that will raise an uncaught TypeError.");
static PyMethodDef __pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_27spawn = {"spawn", (PyCFunction)(void(*)(void))(PyCFunctionWithKeywords)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_27spawn, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_26spawn};
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_27spawn(PyObject *__pyx_v_cls, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_v_kwargs = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("spawn (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return NULL;
  if (__pyx_kwds_len > 0) {
    if (unlikely(__Pyx_CheckKeywordStrings("spawn", __pyx_kwds) == -1)) return NULL;
    __pyx_v_kwargs = __Pyx_KwargsAsDict_VARARGS(__pyx_kwds, __pyx_kwvalues);
    if (unlikely(!__pyx_v_kwargs)) return NULL;
    __Pyx_GOTREF(__pyx_v_kwargs);
  } else {
    __pyx_v_kwargs = PyDict_New();
    if (unlikely(!__pyx_v_kwargs)) return NULL;
    __Pyx_GOTREF(__pyx_v_kwargs);
  }
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_26spawn(((PyTypeObject*)__pyx_v_cls), __pyx_v_args, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_DECREF(__pyx_v_kwargs);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_26spawn(PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_args, PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_v_g = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("spawn", 0);

  /* "src/gevent/greenlet.py":692
 *             instead of spawning a greenlet that will raise an uncaught TypeError.
 *         """
 *         g = cls(*args, **kwargs)             # <<<<<<<<<<<<<<
 *         g.start()
 *         return g
*/
  __pyx_t_1 = PyDict_Copy(__pyx_v_kwargs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 692, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_v_cls), __pyx_v_args, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 692, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_g = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "src/gevent/greenlet.py":693
 *         """
 *         g = cls(*args, **kwargs)
 *         g.start()             # <<<<<<<<<<<<<<
 *         return g
 * 
*/
  __pyx_t_1 = __pyx_v_g;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_start, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 693, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/greenlet.py":694
 *         g = cls(*args, **kwargs)
 *         g.start()
 *         return g             # <<<<<<<<<<<<<<
 * 
 *     @classmethod
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_g);
  __pyx_r = __pyx_v_g;
  goto __pyx_L0;

  /* "src/gevent/greenlet.py":678
 *                 _spawn_callbacks = None
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def spawn(cls, *args, **kwargs):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.spawn", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_g);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":696
 *         return g
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def spawn_later(cls, seconds, *args, **kwargs):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_29spawn_later(PyObject *__pyx_v_cls, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_28spawn_later, "Greenlet.spawn_later(cls, seconds, *args, **kwargs)\n\nspawn_later(seconds, function, *args, **kwargs) -> Greenlet\n\nCreate and return a new `Greenlet` object scheduled to run ``function(*args, **kwargs)``\nin a future loop iteration *seconds* later. This can be used as ``Greenlet.spawn_later``\nor ``gevent.spawn_later``.\n\nThe arguments are passed to :meth:`Greenlet.__init__`.\n\n.. versionchanged:: 1.1b1\n   If an argument that's meant to be a function (the first argument in *args*, or the ``run`` keyword )\n   is given to this classmethod (and not a classmethod of a subclass),\n   it is verified to be callable. Previously, the spawned greenlet would have failed\n   when it started running.");
static PyMethodDef __pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_29spawn_later = {"spawn_later", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_29spawn_later, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_28spawn_later};
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_29spawn_later(PyObject *__pyx_v_cls, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_seconds = 0;
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_v_kwargs = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("spawn_later (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_kwargs = PyDict_New(); if (unlikely(!__pyx_v_kwargs)) return NULL;
  __Pyx_GOTREF(__pyx_v_kwargs);
  __pyx_v_args = __Pyx_ArgsSlice_FASTCALL(__pyx_args, 1, __pyx_nargs);
  if (unlikely(!__pyx_v_args)) {
    __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __Pyx_GOTREF(__pyx_v_args);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_seconds,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 696, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        default:
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 696, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      const Py_ssize_t used_pos_args = (kwd_pos_args < 1) ? kwd_pos_args : 1;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_kwargs, values, used_pos_args, __pyx_kwds_len, "spawn_later", 1) < (0)) __PYX_ERR(0, 696, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("spawn_later", 0, 1, 1, i); __PYX_ERR(0, 696, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs < 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 696, __pyx_L3_error)
    }
    __pyx_v_seconds = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("spawn_later", 0, 1, 1, __pyx_nargs); __PYX_ERR(0, 696, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_DECREF(__pyx_v_args); __pyx_v_args = 0;
  __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.spawn_later", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_28spawn_later(((PyTypeObject*)__pyx_v_cls), __pyx_v_seconds, __pyx_v_args, __pyx_v_kwargs);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_DECREF(__pyx_v_kwargs);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_28spawn_later(PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_seconds, PyObject *__pyx_v_args, PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_v_g = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("spawn_later", 0);

  /* "src/gevent/greenlet.py":713
 *            when it started running.
 *         """
 *         if cls is Greenlet and not args and 'run' not in kwargs:             # <<<<<<<<<<<<<<
 *             raise TypeError("")
 *         g = cls(*args, **kwargs)
*/
  __pyx_t_2 = (__pyx_v_cls == __pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  {
    Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_v_args);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 713, __pyx_L1_error)
    __pyx_t_2 = (__pyx_temp != 0);
  }

  __pyx_t_3 = (!__pyx_t_2);
  if (__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = (__Pyx_PyDict_ContainsTF(__pyx_mstate_global->__pyx_n_u_run, __pyx_v_kwargs, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 713, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_1)) {

    /* "src/gevent/greenlet.py":714
 *         """
 *         if cls is Greenlet and not args and 'run' not in kwargs:
 *             raise TypeError("")             # <<<<<<<<<<<<<<
 *         g = cls(*args, **kwargs)
 *         g.start_later(seconds)
*/
    __pyx_t_5 = NULL;
    __pyx_t_6 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_mstate_global->__pyx_kp_u__7};
      __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_TypeError)), __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 714, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(0, 714, __pyx_L1_error)

    /* "src/gevent/greenlet.py":713
 *            when it started running.
 *         """
 *         if cls is Greenlet and not args and 'run' not in kwargs:             # <<<<<<<<<<<<<<
 *             raise TypeError("")
 *         g = cls(*args, **kwargs)
*/
  }

  /* "src/gevent/greenlet.py":715
 *         if cls is Greenlet and not args and 'run' not in kwargs:
 *             raise TypeError("")
 *         g = cls(*args, **kwargs)             # <<<<<<<<<<<<<<
 *         g.start_later(seconds)
 *         return g
*/
  __pyx_t_4 = PyDict_Copy(__pyx_v_kwargs); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_Call(((PyObject *)__pyx_v_cls), __pyx_v_args, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_g = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "src/gevent/greenlet.py":716
 *             raise TypeError("")
 *         g = cls(*args, **kwargs)
 *         g.start_later(seconds)             # <<<<<<<<<<<<<<
 *         return g
 * 
*/
  __pyx_t_4 = __pyx_v_g;
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_seconds};
    __pyx_t_5 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_start_later, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 716, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "src/gevent/greenlet.py":717
 *         g = cls(*args, **kwargs)
 *         g.start_later(seconds)
 *         return g             # <<<<<<<<<<<<<<
 * 
 *     def _maybe_kill_before_start(self, exception):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_g);
  __pyx_r = __pyx_v_g;
  goto __pyx_L0;

  /* "src/gevent/greenlet.py":696
 *         return g
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def spawn_later(cls, seconds, *args, **kwargs):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.spawn_later", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_g);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":719
 *         return g
 * 
 *     def _maybe_kill_before_start(self, exception):             # <<<<<<<<<<<<<<
 *         # Helper for Greenlet.kill(), and also for killall()
 *         self.__cancel_start()
*/

static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_31_maybe_kill_before_start(PyObject *__pyx_v_self, PyObject *__pyx_v_exception); /*proto*/
static int __pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__maybe_kill_before_start(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, PyObject *__pyx_v_exception, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_dead = NULL;
  PyObject *__pyx_v_args = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_maybe_kill_before_start", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (
  #if !CYTHON_USE_TYPE_SLOTS
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet &&
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
  #else
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
  #endif
  ) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_maybe_kill_before_start); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 719, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_31_maybe_kill_before_start)) {
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_exception};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 719, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 719, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_6;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "src/gevent/greenlet.py":721
 *     def _maybe_kill_before_start(self, exception):
 *         # Helper for Greenlet.kill(), and also for killall()
 *         self.__cancel_start()             # <<<<<<<<<<<<<<
 *         self.__free()
 *         dead = self.dead
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self->__pyx_vtab)->_Greenlet__cancel_start(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 721, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "src/gevent/greenlet.py":722
 *         # Helper for Greenlet.kill(), and also for killall()
 *         self.__cancel_start()
 *         self.__free()             # <<<<<<<<<<<<<<
 *         dead = self.dead
 *         if dead:
*/
  __pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__Greenlet__free(__pyx_v_self); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 722, __pyx_L1_error)

  /* "src/gevent/greenlet.py":723
 *         self.__cancel_start()
 *         self.__free()
 *         dead = self.dead             # <<<<<<<<<<<<<<
 *         if dead:
 *             if isinstance(exception, tuple) and len(exception) == 3:
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_dead); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_dead = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "src/gevent/greenlet.py":724
 *         self.__free()
 *         dead = self.dead
 *         if dead:             # <<<<<<<<<<<<<<
 *             if isinstance(exception, tuple) and len(exception) == 3:
 *                 args = exception
*/
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_dead); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 724, __pyx_L1_error)
  if (__pyx_t_6) {

    /* "src/gevent/greenlet.py":725
 *         dead = self.dead
 *         if dead:
 *             if isinstance(exception, tuple) and len(exception) == 3:             # <<<<<<<<<<<<<<
 *                 args = exception
 *             else:
*/
    __pyx_t_7 = PyTuple_Check(__pyx_v_exception); 
    if (__pyx_t_7) {
    } else {
      __pyx_t_6 = __pyx_t_7;
      goto __pyx_L5_bool_binop_done;
    }
    __pyx_t_8 = PyObject_Length(__pyx_v_exception); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 725, __pyx_L1_error)
    __pyx_t_7 = (__pyx_t_8 == 3);
    __pyx_t_6 = __pyx_t_7;
    __pyx_L5_bool_binop_done:;
    if (__pyx_t_6) {

      /* "src/gevent/greenlet.py":726
 *         if dead:
 *             if isinstance(exception, tuple) and len(exception) == 3:
 *                 args = exception             # <<<<<<<<<<<<<<
 *             else:
 *                 args = (exception,)
*/
      __Pyx_INCREF(__pyx_v_exception);
      __pyx_v_args = __pyx_v_exception;

      /* "src/gevent/greenlet.py":725
 *         dead = self.dead
 *         if dead:
 *             if isinstance(exception, tuple) and len(exception) == 3:             # <<<<<<<<<<<<<<
 *                 args = exception
 *             else:
*/
      goto __pyx_L4;
    }

    /* "src/gevent/greenlet.py":728
 *                 args = exception
 *             else:
 *                 args = (exception,)             # <<<<<<<<<<<<<<
 *             self.__handle_death_before_start(args)
 *         return dead
*/
    /*else*/ {
      __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 728, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_v_exception);
      __Pyx_GIVEREF(__pyx_v_exception);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_exception) != (0)) __PYX_ERR(0, 728, __pyx_L1_error);
      __pyx_v_args = __pyx_t_1;
      __pyx_t_1 = 0;
    }
    __pyx_L4:;

    /* "src/gevent/greenlet.py":729
 *             else:
 *                 args = (exception,)
 *             self.__handle_death_before_start(args)             # <<<<<<<<<<<<<<
 *         return dead
 * 
*/
    __pyx_t_1 = __pyx_v_args;
    __Pyx_INCREF(__pyx_t_1);
    if (!(likely(PyTuple_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_t_1))) __PYX_ERR(0, 729, __pyx_L1_error)
    __pyx_t_2 = ((struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self->__pyx_vtab)->_Greenlet__handle_death_before_start(__pyx_v_self, ((PyObject*)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 729, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "src/gevent/greenlet.py":724
 *         self.__free()
 *         dead = self.dead
 *         if dead:             # <<<<<<<<<<<<<<
 *             if isinstance(exception, tuple) and len(exception) == 3:
 *                 args = exception
*/
  }

  /* "src/gevent/greenlet.py":730
 *                 args = (exception,)
 *             self.__handle_death_before_start(args)
 *         return dead             # <<<<<<<<<<<<<<
 * 
 *     def kill(self, exception=GreenletExit, block=True, timeout=None):
*/
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_dead); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 730, __pyx_L1_error)
  __pyx_r = __pyx_t_6;
  goto __pyx_L0;

  /* "src/gevent/greenlet.py":719
 *         return g
 * 
 *     def _maybe_kill_before_start(self, exception):             # <<<<<<<<<<<<<<
 *         # Helper for Greenlet.kill(), and also for killall()
 *         self.__cancel_start()
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet._maybe_kill_before_start", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_dead);
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_31_maybe_kill_before_start(PyObject *__pyx_v_self, PyObject *__pyx_v_exception); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_30_maybe_kill_before_start, "Greenlet._maybe_kill_before_start(self, exception) -> bool");
static PyMethodDef __pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_31_maybe_kill_before_start = {"_maybe_kill_before_start", (PyCFunction)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_31_maybe_kill_before_start, METH_O, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_30_maybe_kill_before_start};
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_31_maybe_kill_before_start(PyObject *__pyx_v_self, PyObject *__pyx_v_exception) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_maybe_kill_before_start (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_30_maybe_kill_before_start(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self), ((PyObject *)__pyx_v_exception));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_30_maybe_kill_before_start(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, PyObject *__pyx_v_exception) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_maybe_kill_before_start", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__maybe_kill_before_start(__pyx_v_self, __pyx_v_exception, 1); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 719, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 719, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet._maybe_kill_before_start", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":732
 *         return dead
 * 
 *     def kill(self, exception=GreenletExit, block=True, timeout=None):             # <<<<<<<<<<<<<<
 *         """
 *         Raise the ``exception`` in the greenlet.
*/

static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_33kill(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet_kill(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, int __pyx_skip_dispatch, struct __pyx_opt_args_6gevent_17_gevent_cgreenlet_8Greenlet_kill *__pyx_optional_args) {
  PyObject *__pyx_v_exception = __pyx_mstate_global->__pyx_k__12;
  PyObject *__pyx_v_block = ((PyObject *)Py_True);
  PyObject *__pyx_v_timeout = ((PyObject *)Py_None);
  PyObject *__pyx_v_waiter = NULL;
  struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *__pyx_v_hub = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  struct __pyx_opt_args_6gevent_17_gevent_cgreenlet_8Greenlet_join __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("kill", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_exception = __pyx_optional_args->exception;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_block = __pyx_optional_args->block;
        if (__pyx_optional_args->__pyx_n > 2) {
          __pyx_v_timeout = __pyx_optional_args->timeout;
        }
      }
    }
  }
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (
  #if !CYTHON_USE_TYPE_SLOTS
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet &&
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
  #else
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
  #endif
  ) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_kill); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 732, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_33kill)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[4] = {__pyx_t_3, __pyx_v_exception, __pyx_v_block, __pyx_v_timeout};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (4-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 732, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "src/gevent/greenlet.py":782
 *             requiring a trip around the event loop.
 *         """
 *         if not self._maybe_kill_before_start(exception):             # <<<<<<<<<<<<<<
 *             if self.ready():
 *                 return
*/
  __pyx_t_6 = ((struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self->__pyx_vtab)->_maybe_kill_before_start(__pyx_v_self, __pyx_v_exception, 0); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 782, __pyx_L1_error)
  __pyx_t_7 = (!__pyx_t_6);
  if (__pyx_t_7) {

    /* "src/gevent/greenlet.py":783
 *         """
 *         if not self._maybe_kill_before_start(exception):
 *             if self.ready():             # <<<<<<<<<<<<<<
 *                 return
 * 
*/
    __pyx_t_7 = ((struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self->__pyx_vtab)->ready(__pyx_v_self, 0); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 783, __pyx_L1_error)
    if (__pyx_t_7) {

      /* "src/gevent/greenlet.py":784
 *         if not self._maybe_kill_before_start(exception):
 *             if self.ready():
 *                 return             # <<<<<<<<<<<<<<
 * 
 *             waiter = Waiter() if block else None # pylint:disable=undefined-variable
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      goto __pyx_L0;

      /* "src/gevent/greenlet.py":783
 *         """
 *         if not self._maybe_kill_before_start(exception):
 *             if self.ready():             # <<<<<<<<<<<<<<
 *                 return
 * 
*/
    }

    /* "src/gevent/greenlet.py":786
 *                 return
 * 
 *             waiter = Waiter() if block else None # pylint:disable=undefined-variable             # <<<<<<<<<<<<<<
 *             hub = get_my_hub(self) # pylint:disable=undefined-variable
 *             hub.loop.run_callback(_kill, self, exception, waiter)
*/
    __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_v_block); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 786, __pyx_L1_error)
    if (__pyx_t_7) {
      __pyx_t_4 = NULL;
      __pyx_t_5 = 1;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
        __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6gevent_16_gevent_c_waiter_Waiter, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 786, __pyx_L1_error)
        __Pyx_GOTREF((PyObject *)__pyx_t_2);
      }
      __pyx_t_1 = ((PyObject *)__pyx_t_2);
      __pyx_t_2 = 0;
    } else {
      __Pyx_INCREF(Py_None);
      __pyx_t_1 = Py_None;
    }
    __pyx_v_waiter = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "src/gevent/greenlet.py":787
 * 
 *             waiter = Waiter() if block else None # pylint:disable=undefined-variable
 *             hub = get_my_hub(self) # pylint:disable=undefined-variable             # <<<<<<<<<<<<<<
 *             hub.loop.run_callback(_kill, self, exception, waiter)
 *             if waiter is not None:
*/
    __pyx_t_1 = ((PyObject *)__pyx_f_6gevent_17_gevent_cgreenlet_get_my_hub(((PyGreenlet *)__pyx_v_self))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 787, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_hub = ((struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "src/gevent/greenlet.py":788
 *             waiter = Waiter() if block else None # pylint:disable=undefined-variable
 *             hub = get_my_hub(self) # pylint:disable=undefined-variable
 *             hub.loop.run_callback(_kill, self, exception, waiter)             # <<<<<<<<<<<<<<
 *             if waiter is not None:
 *                 waiter.get()
*/
    __pyx_t_2 = __pyx_v_hub->loop;
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_kill_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 788, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[5] = {__pyx_t_2, __pyx_t_4, ((PyObject *)__pyx_v_self), __pyx_v_exception, __pyx_v_waiter};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_run_callback, __pyx_callargs+__pyx_t_5, (5-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 788, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "src/gevent/greenlet.py":789
 *             hub = get_my_hub(self) # pylint:disable=undefined-variable
 *             hub.loop.run_callback(_kill, self, exception, waiter)
 *             if waiter is not None:             # <<<<<<<<<<<<<<
 *                 waiter.get()
 *                 self.join(timeout)
*/
    __pyx_t_7 = (__pyx_v_waiter != Py_None);
    if (__pyx_t_7) {

      /* "src/gevent/greenlet.py":790
 *             hub.loop.run_callback(_kill, self, exception, waiter)
 *             if waiter is not None:
 *                 waiter.get()             # <<<<<<<<<<<<<<
 *                 self.join(timeout)
 * 
*/
      __pyx_t_4 = __pyx_v_waiter;
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_get_2, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 790, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "src/gevent/greenlet.py":791
 *             if waiter is not None:
 *                 waiter.get()
 *                 self.join(timeout)             # <<<<<<<<<<<<<<
 * 
 *     def get(self, block=True, timeout=None):
*/
      __pyx_t_8.__pyx_n = 1;
      __pyx_t_8.timeout = __pyx_v_timeout;
      __pyx_t_1 = ((struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self->__pyx_vtab)->join(__pyx_v_self, 0, &__pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 791, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "src/gevent/greenlet.py":789
 *             hub = get_my_hub(self) # pylint:disable=undefined-variable
 *             hub.loop.run_callback(_kill, self, exception, waiter)
 *             if waiter is not None:             # <<<<<<<<<<<<<<
 *                 waiter.get()
 *                 self.join(timeout)
*/
    }

    /* "src/gevent/greenlet.py":782
 *             requiring a trip around the event loop.
 *         """
 *         if not self._maybe_kill_before_start(exception):             # <<<<<<<<<<<<<<
 *             if self.ready():
 *                 return
*/
  }

  /* "src/gevent/greenlet.py":732
 *         return dead
 * 
 *     def kill(self, exception=GreenletExit, block=True, timeout=None):             # <<<<<<<<<<<<<<
 *         """
 *         Raise the ``exception`` in the greenlet.
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.kill", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_waiter);
  __Pyx_XDECREF((PyObject *)__pyx_v_hub);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_33kill(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_32kill, "Greenlet.kill(self, exception=GreenletExit, block=True, timeout=None)\n\nRaise the ``exception`` in the greenlet.\n\nIf ``block`` is ``True`` (the default), wait until the greenlet\ndies or the optional timeout expires; this may require switching\ngreenlets.\nIf block is ``False``, the current greenlet is not unscheduled.\n\nThis function always returns ``None`` and never raises an error. It\nmay be called multpile times on the same greenlet object, and may be\ncalled on an unstarted or dead greenlet.\n\n.. note::\n\n    Depending on what this greenlet is executing and the state\n    of the event loop, the exception may or may not be raised\n    immediately when this greenlet resumes execution. It may\n    be raised on a subsequent green call, or, if this greenlet\n    exits before making such a call, it may not be raised at\n    all. As of 1.1, an example where the exception is raised\n    later is if this greenlet had called :func:`sleep(0)\n    <gevent.sleep>`; an example where the exception is raised\n    immediately is if this greenlet had called\n    :func:`sleep(0.1) <gevent.sleep>`.\n\n.. caution::\n\n    Use care when killing greenlets. If the code executing is not\n    exception safe (e.g., makes proper use of ``finally``) then an\n    unexpected exception could result in corrupted state. Using\n    a :meth:`link` or :meth:`rawlink` (cheaper) may be a safer way to\n    clean up resources.\n\nSee also :func:`gevent.kill` and :func:`gevent.killall`.\n\n:keyword type exception: The type of exception to raise in the greenlet. The default\n    is :class:`GreenletExit`, which indicates a :meth:`successful` completion\n    of the greenlet.\n\n.. versionchanged:: 0.13.0\n    *block* is now ``True`` by default.\n.. versionchanged:: 1.1a2\n    If this greenlet had never been switched to, killing it will\n    prevent it from *ever* being switched to. Links (:meth:`rawlink`)\n    will still be executed, though.\n.. versionchanged:: 20.12.1\n    If this greenlet is :me""th:`ready`, immediately return instead of\n    requiring a trip around the event loop.");
static PyMethodDef __pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_33kill = {"kill", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_33kill, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_32kill};
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_33kill(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_exception = 0;
  PyObject *__pyx_v_block = 0;
  PyObject *__pyx_v_timeout = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("kill (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_exception,&__pyx_mstate_global->__pyx_n_u_block,&__pyx_mstate_global->__pyx_n_u_timeout,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 732, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 732, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 732, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 732, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "kill", 0) < (0)) __PYX_ERR(0, 732, __pyx_L3_error)
      if (!values[0]) values[0] = __Pyx_NewRef(__pyx_mstate_global->__pyx_k__12);
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_True));
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
    } else {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 732, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 732, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 732, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[0]) values[0] = __Pyx_NewRef(__pyx_mstate_global->__pyx_k__12);
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_True));
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_exception = values[0];
    __pyx_v_block = values[1];
    __pyx_v_timeout = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("kill", 0, 0, 3, __pyx_nargs); __PYX_ERR(0, 732, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.kill", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_32kill(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self), __pyx_v_exception, __pyx_v_block, __pyx_v_timeout);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_32kill(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, PyObject *__pyx_v_exception, PyObject *__pyx_v_block, PyObject *__pyx_v_timeout) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_6gevent_17_gevent_cgreenlet_8Greenlet_kill __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("kill", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 3;
  __pyx_t_2.exception = __pyx_v_exception;
  __pyx_t_2.block = __pyx_v_block;
  __pyx_t_2.timeout = __pyx_v_timeout;
  __pyx_t_1 = __pyx_vtabptr_6gevent_17_gevent_cgreenlet_Greenlet->kill(__pyx_v_self, 1, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 732, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.kill", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":793
 *                 self.join(timeout)
 * 
 *     def get(self, block=True, timeout=None):             # <<<<<<<<<<<<<<
 *         """
 *         get(block=True, timeout=None) -> object
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_35get(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_34get, "Greenlet.get(self, block=True, timeout=None)\n\nget(block=True, timeout=None) -> object\n\nReturn the result the greenlet has returned or re-raise the\nexception it has raised.\n\nIf block is ``False``, raise :class:`gevent.Timeout` if the\ngreenlet is still alive. If block is ``True``, unschedule the\ncurrent greenlet until the result is available or the timeout\nexpires. In the latter case, :class:`gevent.Timeout` is\nraised.");
static PyMethodDef __pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_35get = {"get", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_35get, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_34get};
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_35get(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_block = 0;
  PyObject *__pyx_v_timeout = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_block,&__pyx_mstate_global->__pyx_n_u_timeout,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 793, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 793, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 793, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "get", 0) < (0)) __PYX_ERR(0, 793, __pyx_L3_error)
      if (!values[0]) values[0] = __Pyx_NewRef(((PyObject *)Py_True));
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
    } else {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 793, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 793, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[0]) values[0] = __Pyx_NewRef(((PyObject *)Py_True));
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_block = values[0];
    __pyx_v_timeout = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get", 0, 0, 2, __pyx_nargs); __PYX_ERR(0, 793, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.get", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_34get(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self), __pyx_v_block, __pyx_v_timeout);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_34get(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, PyObject *__pyx_v_block, PyObject *__pyx_v_timeout) {
  PyObject *__pyx_v_switch = NULL;
  PyObject *__pyx_v_t = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  int __pyx_t_13;
  char const *__pyx_t_14;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get", 0);

  /* "src/gevent/greenlet.py":806
 *         raised.
 *         """
 *         if self.ready():             # <<<<<<<<<<<<<<
 *             if self.successful():
 *                 return self.value
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self->__pyx_vtab)->ready(__pyx_v_self, 0); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 806, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "src/gevent/greenlet.py":807
 *         """
 *         if self.ready():
 *             if self.successful():             # <<<<<<<<<<<<<<
 *                 return self.value
 *             self._raise_exception()
*/
    __pyx_t_1 = ((struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self->__pyx_vtab)->successful(__pyx_v_self, 0); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 807, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "src/gevent/greenlet.py":808
 *         if self.ready():
 *             if self.successful():
 *                 return self.value             # <<<<<<<<<<<<<<
 *             self._raise_exception()
 *         if not block:
*/
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_self->value);
      __pyx_r = __pyx_v_self->value;
      goto __pyx_L0;

      /* "src/gevent/greenlet.py":807
 *         """
 *         if self.ready():
 *             if self.successful():             # <<<<<<<<<<<<<<
 *                 return self.value
 *             self._raise_exception()
*/
    }

    /* "src/gevent/greenlet.py":809
 *             if self.successful():
 *                 return self.value
 *             self._raise_exception()             # <<<<<<<<<<<<<<
 *         if not block:
 *             raise Timeout()
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_self);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_raise_exception, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 809, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "src/gevent/greenlet.py":806
 *         raised.
 *         """
 *         if self.ready():             # <<<<<<<<<<<<<<
 *             if self.successful():
 *                 return self.value
*/
  }

  /* "src/gevent/greenlet.py":810
 *                 return self.value
 *             self._raise_exception()
 *         if not block:             # <<<<<<<<<<<<<<
 *             raise Timeout()
 * 
*/
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_block); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 810, __pyx_L1_error)
  __pyx_t_5 = (!__pyx_t_1);
  if (unlikely(__pyx_t_5)) {

    /* "src/gevent/greenlet.py":811
 *             self._raise_exception()
 *         if not block:
 *             raise Timeout()             # <<<<<<<<<<<<<<
 * 
 *         switch = getcurrent().switch # pylint:disable=undefined-variable
*/
    __pyx_t_3 = NULL;
    __Pyx_INCREF(__pyx_v_6gevent_17_gevent_cgreenlet_Timeout);
    __pyx_t_6 = __pyx_v_6gevent_17_gevent_cgreenlet_Timeout; 
    __pyx_t_4 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_6);
      assert(__pyx_t_3);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
      __pyx_t_4 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 811, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 811, __pyx_L1_error)

    /* "src/gevent/greenlet.py":810
 *                 return self.value
 *             self._raise_exception()
 *         if not block:             # <<<<<<<<<<<<<<
 *             raise Timeout()
 * 
*/
  }

  /* "src/gevent/greenlet.py":813
 *             raise Timeout()
 * 
 *         switch = getcurrent().switch # pylint:disable=undefined-variable             # <<<<<<<<<<<<<<
 *         self.rawlink(switch)
 *         try:
*/
  __pyx_t_2 = ((PyObject *)__pyx_f_6gevent_17_gevent_cgreenlet_getcurrent()); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 813, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_switch); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 813, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_switch = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "src/gevent/greenlet.py":814
 * 
 *         switch = getcurrent().switch # pylint:disable=undefined-variable
 *         self.rawlink(switch)             # <<<<<<<<<<<<<<
 *         try:
 *             t = Timeout._start_new_or_dummy(timeout)
*/
  __pyx_t_6 = ((struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self->__pyx_vtab)->rawlink(__pyx_v_self, __pyx_v_switch, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 814, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "src/gevent/greenlet.py":815
 *         switch = getcurrent().switch # pylint:disable=undefined-variable
 *         self.rawlink(switch)
 *         try:             # <<<<<<<<<<<<<<
 *             t = Timeout._start_new_or_dummy(timeout)
 *             try:
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
    __Pyx_XGOTREF(__pyx_t_7);
    __Pyx_XGOTREF(__pyx_t_8);
    __Pyx_XGOTREF(__pyx_t_9);
    /*try:*/ {

      /* "src/gevent/greenlet.py":816
 *         self.rawlink(switch)
 *         try:
 *             t = Timeout._start_new_or_dummy(timeout)             # <<<<<<<<<<<<<<
 *             try:
 *                 result = get_my_hub(self).switch() # pylint:disable=undefined-variable
*/
      __pyx_t_2 = __pyx_v_6gevent_17_gevent_cgreenlet_Timeout;
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_timeout};
        __pyx_t_6 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_start_new_or_dummy, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 816, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_6);
      }
      __pyx_v_t = __pyx_t_6;
      __pyx_t_6 = 0;

      /* "src/gevent/greenlet.py":817
 *         try:
 *             t = Timeout._start_new_or_dummy(timeout)
 *             try:             # <<<<<<<<<<<<<<
 *                 result = get_my_hub(self).switch() # pylint:disable=undefined-variable
 *                 if result is not self:
*/
      /*try:*/ {

        /* "src/gevent/greenlet.py":818
 *             t = Timeout._start_new_or_dummy(timeout)
 *             try:
 *                 result = get_my_hub(self).switch() # pylint:disable=undefined-variable             # <<<<<<<<<<<<<<
 *                 if result is not self:
 *                     raise InvalidSwitchError('Invalid switch into Greenlet.get(): %r' % (result, ))
*/
        __pyx_t_6 = ((PyObject *)__pyx_f_6gevent_17_gevent_cgreenlet_get_my_hub(((PyGreenlet *)__pyx_v_self))); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 818, __pyx_L13_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_2 = ((struct __pyx_vtabstruct_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *)((struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *)__pyx_t_6)->__pyx_vtab)->__pyx_switch(((struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *)__pyx_t_6), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 818, __pyx_L13_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_v_result = __pyx_t_2;
        __pyx_t_2 = 0;

        /* "src/gevent/greenlet.py":819
 *             try:
 *                 result = get_my_hub(self).switch() # pylint:disable=undefined-variable
 *                 if result is not self:             # <<<<<<<<<<<<<<
 *                     raise InvalidSwitchError('Invalid switch into Greenlet.get(): %r' % (result, ))
 *             finally:
*/
        __pyx_t_5 = (__pyx_v_result != ((PyObject *)__pyx_v_self));
        if (unlikely(__pyx_t_5)) {

          /* "src/gevent/greenlet.py":820
 *                 result = get_my_hub(self).switch() # pylint:disable=undefined-variable
 *                 if result is not self:
 *                     raise InvalidSwitchError('Invalid switch into Greenlet.get(): %r' % (result, ))             # <<<<<<<<<<<<<<
 *             finally:
 *                 t.cancel()
*/
          __pyx_t_6 = NULL;
          __Pyx_INCREF(__pyx_v_6gevent_17_gevent_cgreenlet_InvalidSwitchError);
          __pyx_t_3 = __pyx_v_6gevent_17_gevent_cgreenlet_InvalidSwitchError; 
          __pyx_t_10 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_result), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 820, __pyx_L13_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_11 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_Invalid_switch_into_Greenlet_get, __pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 820, __pyx_L13_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __pyx_t_4 = 1;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_3))) {
            __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
            assert(__pyx_t_6);
            PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(__pyx__function);
            __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
            __pyx_t_4 = 0;
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_11};
            __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 820, __pyx_L13_error)
            __Pyx_GOTREF(__pyx_t_2);
          }
          __Pyx_Raise(__pyx_t_2, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __PYX_ERR(0, 820, __pyx_L13_error)

          /* "src/gevent/greenlet.py":819
 *             try:
 *                 result = get_my_hub(self).switch() # pylint:disable=undefined-variable
 *                 if result is not self:             # <<<<<<<<<<<<<<
 *                     raise InvalidSwitchError('Invalid switch into Greenlet.get(): %r' % (result, ))
 *             finally:
*/
        }
      }

      /* "src/gevent/greenlet.py":822
 *                     raise InvalidSwitchError('Invalid switch into Greenlet.get(): %r' % (result, ))
 *             finally:
 *                 t.cancel()             # <<<<<<<<<<<<<<
 *         except:
 *             # unlinking in 'except' instead of finally is an optimization:
*/
      /*finally:*/ {
        /*normal exit:*/{
          __pyx_t_3 = __pyx_v_t;
          __Pyx_INCREF(__pyx_t_3);
          __pyx_t_4 = 0;
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
            __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_cancel, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
            if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 822, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_2);
          }
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          goto __pyx_L14;
        }
        __pyx_L13_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0;
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
           __Pyx_ExceptionSwap(&__pyx_t_18, &__pyx_t_19, &__pyx_t_20);
          if ( unlikely(__Pyx_GetException(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17) < 0)) __Pyx_ErrFetch(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_15);
          __Pyx_XGOTREF(__pyx_t_16);
          __Pyx_XGOTREF(__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_20);
          __pyx_t_12 = __pyx_lineno; __pyx_t_13 = __pyx_clineno; __pyx_t_14 = __pyx_filename;
          {
            __pyx_t_3 = __pyx_v_t;
            __Pyx_INCREF(__pyx_t_3);
            __pyx_t_4 = 0;
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
              __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_cancel, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
              __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
              if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 822, __pyx_L17_error)
              __Pyx_GOTREF(__pyx_t_2);
            }
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          }
          __Pyx_XGIVEREF(__pyx_t_18);
          __Pyx_XGIVEREF(__pyx_t_19);
          __Pyx_XGIVEREF(__pyx_t_20);
          __Pyx_ExceptionReset(__pyx_t_18, __pyx_t_19, __pyx_t_20);
          __Pyx_XGIVEREF(__pyx_t_15);
          __Pyx_XGIVEREF(__pyx_t_16);
          __Pyx_XGIVEREF(__pyx_t_17);
          __Pyx_ErrRestore(__pyx_t_15, __pyx_t_16, __pyx_t_17);
          __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0;
          __pyx_lineno = __pyx_t_12; __pyx_clineno = __pyx_t_13; __pyx_filename = __pyx_t_14;
          goto __pyx_L6_error;
          __pyx_L17_error:;
          __Pyx_XGIVEREF(__pyx_t_18);
          __Pyx_XGIVEREF(__pyx_t_19);
          __Pyx_XGIVEREF(__pyx_t_20);
          __Pyx_ExceptionReset(__pyx_t_18, __pyx_t_19, __pyx_t_20);
          __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
          __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
          __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
          __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0;
          goto __pyx_L6_error;
        }
        __pyx_L14:;
      }

      /* "src/gevent/greenlet.py":815
 *         switch = getcurrent().switch # pylint:disable=undefined-variable
 *         self.rawlink(switch)
 *         try:             # <<<<<<<<<<<<<<
 *             t = Timeout._start_new_or_dummy(timeout)
 *             try:
*/
    }
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    goto __pyx_L11_try_end;
    __pyx_L6_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "src/gevent/greenlet.py":823
 *             finally:
 *                 t.cancel()
 *         except:             # <<<<<<<<<<<<<<
 *             # unlinking in 'except' instead of finally is an optimization:
 *             # if switch occurred normally then link was already removed in _notify_links
*/
    /*except:*/ {
      __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.get", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_3, &__pyx_t_11) < 0) __PYX_ERR(0, 823, __pyx_L8_except_error)
      __Pyx_XGOTREF(__pyx_t_2);
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_11);

      /* "src/gevent/greenlet.py":829
 *             # Note, however, that if "Invalid switch" assert was removed and invalid switch
 *             # did happen, the link would remain, causing another invalid switch later in this greenlet.
 *             self.unlink(switch)             # <<<<<<<<<<<<<<
 *             raise
 * 
*/
      __pyx_t_10 = ((PyObject *)__pyx_v_self);
      __Pyx_INCREF(__pyx_t_10);
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_v_switch};
        __pyx_t_6 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_unlink, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 829, __pyx_L8_except_error)
        __Pyx_GOTREF(__pyx_t_6);
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "src/gevent/greenlet.py":830
 *             # did happen, the link would remain, causing another invalid switch later in this greenlet.
 *             self.unlink(switch)
 *             raise             # <<<<<<<<<<<<<<
 * 
 *         if self.ready():
*/
      __Pyx_GIVEREF(__pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_ErrRestoreWithState(__pyx_t_2, __pyx_t_3, __pyx_t_11);
      __pyx_t_2 = 0;  __pyx_t_3 = 0;  __pyx_t_11 = 0; 
      __PYX_ERR(0, 830, __pyx_L8_except_error)
    }

    /* "src/gevent/greenlet.py":815
 *         switch = getcurrent().switch # pylint:disable=undefined-variable
 *         self.rawlink(switch)
 *         try:             # <<<<<<<<<<<<<<
 *             t = Timeout._start_new_or_dummy(timeout)
 *             try:
*/
    __pyx_L8_except_error:;
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
    goto __pyx_L1_error;
    __pyx_L11_try_end:;
  }

  /* "src/gevent/greenlet.py":832
 *             raise
 * 
 *         if self.ready():             # <<<<<<<<<<<<<<
 *             if self.successful():
 *                 return self.value
*/
  __pyx_t_5 = ((struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self->__pyx_vtab)->ready(__pyx_v_self, 0); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 832, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "src/gevent/greenlet.py":833
 * 
 *         if self.ready():
 *             if self.successful():             # <<<<<<<<<<<<<<
 *                 return self.value
 *             self._raise_exception()
*/
    __pyx_t_5 = ((struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self->__pyx_vtab)->successful(__pyx_v_self, 0); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 833, __pyx_L1_error)
    if (__pyx_t_5) {

      /* "src/gevent/greenlet.py":834
 *         if self.ready():
 *             if self.successful():
 *                 return self.value             # <<<<<<<<<<<<<<
 *             self._raise_exception()
 * 
*/
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_self->value);
      __pyx_r = __pyx_v_self->value;
      goto __pyx_L0;

      /* "src/gevent/greenlet.py":833
 * 
 *         if self.ready():
 *             if self.successful():             # <<<<<<<<<<<<<<
 *                 return self.value
 *             self._raise_exception()
*/
    }

    /* "src/gevent/greenlet.py":835
 *             if self.successful():
 *                 return self.value
 *             self._raise_exception()             # <<<<<<<<<<<<<<
 * 
 *     def join(self, timeout=None):
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_self);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_11 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_raise_exception, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 835, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
    }
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

    /* "src/gevent/greenlet.py":832
 *             raise
 * 
 *         if self.ready():             # <<<<<<<<<<<<<<
 *             if self.successful():
 *                 return self.value
*/
  }

  /* "src/gevent/greenlet.py":793
 *                 self.join(timeout)
 * 
 *     def get(self, block=True, timeout=None):             # <<<<<<<<<<<<<<
 *         """
 *         get(block=True, timeout=None) -> object
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.get", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_switch);
  __Pyx_XDECREF(__pyx_v_t);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":837
 *             self._raise_exception()
 * 
 *     def join(self, timeout=None):             # <<<<<<<<<<<<<<
 *         """
 *         join(timeout=None) -> None
*/

static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_37join(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet_join(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, int __pyx_skip_dispatch, struct __pyx_opt_args_6gevent_17_gevent_cgreenlet_8Greenlet_join *__pyx_optional_args) {
  PyObject *__pyx_v_timeout = ((PyObject *)Py_None);
  PyObject *__pyx_v_switch = NULL;
  PyObject *__pyx_v_t = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_ex = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  int __pyx_t_12;
  char const *__pyx_t_13;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  char const *__pyx_t_20;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("join", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_timeout = __pyx_optional_args->timeout;
    }
  }
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (
  #if !CYTHON_USE_TYPE_SLOTS
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet &&
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
  #else
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
  #endif
  ) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_join); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 837, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_37join)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_timeout};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 837, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "src/gevent/greenlet.py":844
 *         ``None`` regardless.
 *         """
 *         if self.ready():             # <<<<<<<<<<<<<<
 *             return
 * 
*/
  __pyx_t_6 = ((struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self->__pyx_vtab)->ready(__pyx_v_self, 0); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 844, __pyx_L1_error)
  if (__pyx_t_6) {

    /* "src/gevent/greenlet.py":845
 *         """
 *         if self.ready():
 *             return             # <<<<<<<<<<<<<<
 * 
 *         switch = getcurrent().switch # pylint:disable=undefined-variable
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "src/gevent/greenlet.py":844
 *         ``None`` regardless.
 *         """
 *         if self.ready():             # <<<<<<<<<<<<<<
 *             return
 * 
*/
  }

  /* "src/gevent/greenlet.py":847
 *             return
 * 
 *         switch = getcurrent().switch # pylint:disable=undefined-variable             # <<<<<<<<<<<<<<
 *         self.rawlink(switch)
 *         try:
*/
  __pyx_t_1 = ((PyObject *)__pyx_f_6gevent_17_gevent_cgreenlet_getcurrent()); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 847, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_switch); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 847, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_switch = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "src/gevent/greenlet.py":848
 * 
 *         switch = getcurrent().switch # pylint:disable=undefined-variable
 *         self.rawlink(switch)             # <<<<<<<<<<<<<<
 *         try:
 *             t = Timeout._start_new_or_dummy(timeout)
*/
  __pyx_t_2 = ((struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self->__pyx_vtab)->rawlink(__pyx_v_self, __pyx_v_switch, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 848, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/greenlet.py":849
 *         switch = getcurrent().switch # pylint:disable=undefined-variable
 *         self.rawlink(switch)
 *         try:             # <<<<<<<<<<<<<<
 *             t = Timeout._start_new_or_dummy(timeout)
 *             try:
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
    __Pyx_XGOTREF(__pyx_t_7);
    __Pyx_XGOTREF(__pyx_t_8);
    __Pyx_XGOTREF(__pyx_t_9);
    /*try:*/ {

      /* "src/gevent/greenlet.py":850
 *         self.rawlink(switch)
 *         try:
 *             t = Timeout._start_new_or_dummy(timeout)             # <<<<<<<<<<<<<<
 *             try:
 *                 result = get_my_hub(self).switch() # pylint:disable=undefined-variable
*/
      __pyx_t_1 = __pyx_v_6gevent_17_gevent_cgreenlet_Timeout;
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_timeout};
        __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_start_new_or_dummy, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 850, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __pyx_v_t = __pyx_t_2;
      __pyx_t_2 = 0;

      /* "src/gevent/greenlet.py":851
 *         try:
 *             t = Timeout._start_new_or_dummy(timeout)
 *             try:             # <<<<<<<<<<<<<<
 *                 result = get_my_hub(self).switch() # pylint:disable=undefined-variable
 *                 if result is not self:
*/
      /*try:*/ {

        /* "src/gevent/greenlet.py":852
 *             t = Timeout._start_new_or_dummy(timeout)
 *             try:
 *                 result = get_my_hub(self).switch() # pylint:disable=undefined-variable             # <<<<<<<<<<<<<<
 *                 if result is not self:
 *                     raise InvalidSwitchError('Invalid switch into Greenlet.join(): %r' % (result, ))
*/
        __pyx_t_2 = ((PyObject *)__pyx_f_6gevent_17_gevent_cgreenlet_get_my_hub(((PyGreenlet *)__pyx_v_self))); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 852, __pyx_L11_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_1 = ((struct __pyx_vtabstruct_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *)((struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *)__pyx_t_2)->__pyx_vtab)->__pyx_switch(((struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *)__pyx_t_2), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 852, __pyx_L11_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_v_result = __pyx_t_1;
        __pyx_t_1 = 0;

        /* "src/gevent/greenlet.py":853
 *             try:
 *                 result = get_my_hub(self).switch() # pylint:disable=undefined-variable
 *                 if result is not self:             # <<<<<<<<<<<<<<
 *                     raise InvalidSwitchError('Invalid switch into Greenlet.join(): %r' % (result, ))
 *             finally:
*/
        __pyx_t_6 = (__pyx_v_result != ((PyObject *)__pyx_v_self));
        if (unlikely(__pyx_t_6)) {

          /* "src/gevent/greenlet.py":854
 *                 result = get_my_hub(self).switch() # pylint:disable=undefined-variable
 *                 if result is not self:
 *                     raise InvalidSwitchError('Invalid switch into Greenlet.join(): %r' % (result, ))             # <<<<<<<<<<<<<<
 *             finally:
 *                 t.cancel()
*/
          __pyx_t_2 = NULL;
          __Pyx_INCREF(__pyx_v_6gevent_17_gevent_cgreenlet_InvalidSwitchError);
          __pyx_t_4 = __pyx_v_6gevent_17_gevent_cgreenlet_InvalidSwitchError; 
          __pyx_t_3 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_result), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 854, __pyx_L11_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_10 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_Invalid_switch_into_Greenlet_joi, __pyx_t_3); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 854, __pyx_L11_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_5 = 1;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_4))) {
            __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
            assert(__pyx_t_2);
            PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_2);
            __Pyx_INCREF(__pyx__function);
            __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
            __pyx_t_5 = 0;
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_10};
            __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 854, __pyx_L11_error)
            __Pyx_GOTREF(__pyx_t_1);
          }
          __Pyx_Raise(__pyx_t_1, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __PYX_ERR(0, 854, __pyx_L11_error)

          /* "src/gevent/greenlet.py":853
 *             try:
 *                 result = get_my_hub(self).switch() # pylint:disable=undefined-variable
 *                 if result is not self:             # <<<<<<<<<<<<<<
 *                     raise InvalidSwitchError('Invalid switch into Greenlet.join(): %r' % (result, ))
 *             finally:
*/
        }
      }

      /* "src/gevent/greenlet.py":856
 *                     raise InvalidSwitchError('Invalid switch into Greenlet.join(): %r' % (result, ))
 *             finally:
 *                 t.cancel()             # <<<<<<<<<<<<<<
 *         except Timeout as ex:
 *             self.unlink(switch)
*/
      /*finally:*/ {
        /*normal exit:*/{
          __pyx_t_4 = __pyx_v_t;
          __Pyx_INCREF(__pyx_t_4);
          __pyx_t_5 = 0;
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
            __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_cancel, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 856, __pyx_L4_error)
            __Pyx_GOTREF(__pyx_t_1);
          }
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          goto __pyx_L12;
        }
        __pyx_L11_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0;
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
           __Pyx_ExceptionSwap(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19);
          if ( unlikely(__Pyx_GetException(&__pyx_t_14, &__pyx_t_15, &__pyx_t_16) < 0)) __Pyx_ErrFetch(&__pyx_t_14, &__pyx_t_15, &__pyx_t_16);
          __Pyx_XGOTREF(__pyx_t_14);
          __Pyx_XGOTREF(__pyx_t_15);
          __Pyx_XGOTREF(__pyx_t_16);
          __Pyx_XGOTREF(__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_19);
          __pyx_t_11 = __pyx_lineno; __pyx_t_12 = __pyx_clineno; __pyx_t_13 = __pyx_filename;
          {
            __pyx_t_4 = __pyx_v_t;
            __Pyx_INCREF(__pyx_t_4);
            __pyx_t_5 = 0;
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
              __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_cancel, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
              __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
              if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 856, __pyx_L15_error)
              __Pyx_GOTREF(__pyx_t_1);
            }
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          }
          __Pyx_XGIVEREF(__pyx_t_17);
          __Pyx_XGIVEREF(__pyx_t_18);
          __Pyx_XGIVEREF(__pyx_t_19);
          __Pyx_ExceptionReset(__pyx_t_17, __pyx_t_18, __pyx_t_19);
          __Pyx_XGIVEREF(__pyx_t_14);
          __Pyx_XGIVEREF(__pyx_t_15);
          __Pyx_XGIVEREF(__pyx_t_16);
          __Pyx_ErrRestore(__pyx_t_14, __pyx_t_15, __pyx_t_16);
          __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0;
          __pyx_lineno = __pyx_t_11; __pyx_clineno = __pyx_t_12; __pyx_filename = __pyx_t_13;
          goto __pyx_L4_error;
          __pyx_L15_error:;
          __Pyx_XGIVEREF(__pyx_t_17);
          __Pyx_XGIVEREF(__pyx_t_18);
          __Pyx_XGIVEREF(__pyx_t_19);
          __Pyx_ExceptionReset(__pyx_t_17, __pyx_t_18, __pyx_t_19);
          __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
          __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
          __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
          __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0;
          goto __pyx_L4_error;
        }
        __pyx_L12:;
      }

      /* "src/gevent/greenlet.py":849
 *         switch = getcurrent().switch # pylint:disable=undefined-variable
 *         self.rawlink(switch)
 *         try:             # <<<<<<<<<<<<<<
 *             t = Timeout._start_new_or_dummy(timeout)
 *             try:
*/
    }
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    goto __pyx_L9_try_end;
    __pyx_L4_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "src/gevent/greenlet.py":857
 *             finally:
 *                 t.cancel()
 *         except Timeout as ex:             # <<<<<<<<<<<<<<
 *             self.unlink(switch)
 *             if ex is not t:
*/
    __pyx_t_12 = __Pyx_PyErr_ExceptionMatches(__pyx_v_6gevent_17_gevent_cgreenlet_Timeout);
    if (__pyx_t_12) {
      __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.join", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_4, &__pyx_t_10) < 0) __PYX_ERR(0, 857, __pyx_L6_except_error)
      __Pyx_XGOTREF(__pyx_t_1);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_4);
      __pyx_v_ex = __pyx_t_4;
      /*try:*/ {

        /* "src/gevent/greenlet.py":858
 *                 t.cancel()
 *         except Timeout as ex:
 *             self.unlink(switch)             # <<<<<<<<<<<<<<
 *             if ex is not t:
 *                 raise
*/
        __pyx_t_3 = ((PyObject *)__pyx_v_self);
        __Pyx_INCREF(__pyx_t_3);
        __pyx_t_5 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_switch};
          __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_unlink, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 858, __pyx_L21_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "src/gevent/greenlet.py":859
 *         except Timeout as ex:
 *             self.unlink(switch)
 *             if ex is not t:             # <<<<<<<<<<<<<<
 *                 raise
 *         except:
*/
        if (unlikely(!__pyx_v_t)) { __Pyx_RaiseUnboundLocalError("t"); __PYX_ERR(0, 859, __pyx_L21_error) }
        __pyx_t_6 = (__pyx_v_ex != ((PyObject*)__pyx_v_t));
        if (unlikely(__pyx_t_6)) {

          /* "src/gevent/greenlet.py":860
 *             self.unlink(switch)
 *             if ex is not t:
 *                 raise             # <<<<<<<<<<<<<<
 *         except:
 *             self.unlink(switch)
*/
          __Pyx_GIVEREF(__pyx_t_1);
          __Pyx_GIVEREF(__pyx_t_4);
          __Pyx_XGIVEREF(__pyx_t_10);
          __Pyx_ErrRestoreWithState(__pyx_t_1, __pyx_t_4, __pyx_t_10);
          __pyx_t_1 = 0;  __pyx_t_4 = 0;  __pyx_t_10 = 0; 
          __PYX_ERR(0, 860, __pyx_L21_error)

          /* "src/gevent/greenlet.py":859
 *         except Timeout as ex:
 *             self.unlink(switch)
 *             if ex is not t:             # <<<<<<<<<<<<<<
 *                 raise
 *         except:
*/
        }
      }

      /* "src/gevent/greenlet.py":857
 *             finally:
 *                 t.cancel()
 *         except Timeout as ex:             # <<<<<<<<<<<<<<
 *             self.unlink(switch)
 *             if ex is not t:
*/
      /*finally:*/ {
        /*normal exit:*/{
          __Pyx_DECREF(__pyx_v_ex); __pyx_v_ex = 0;
          goto __pyx_L22;
        }
        __pyx_L21_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_19 = 0; __pyx_t_18 = 0; __pyx_t_17 = 0; __pyx_t_16 = 0; __pyx_t_15 = 0; __pyx_t_14 = 0;
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
           __Pyx_ExceptionSwap(&__pyx_t_16, &__pyx_t_15, &__pyx_t_14);
          if ( unlikely(__Pyx_GetException(&__pyx_t_19, &__pyx_t_18, &__pyx_t_17) < 0)) __Pyx_ErrFetch(&__pyx_t_19, &__pyx_t_18, &__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_16);
          __Pyx_XGOTREF(__pyx_t_15);
          __Pyx_XGOTREF(__pyx_t_14);
          __pyx_t_12 = __pyx_lineno; __pyx_t_11 = __pyx_clineno; __pyx_t_20 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_ex); __pyx_v_ex = 0;
          }
          __Pyx_XGIVEREF(__pyx_t_16);
          __Pyx_XGIVEREF(__pyx_t_15);
          __Pyx_XGIVEREF(__pyx_t_14);
          __Pyx_ExceptionReset(__pyx_t_16, __pyx_t_15, __pyx_t_14);
          __Pyx_XGIVEREF(__pyx_t_19);
          __Pyx_XGIVEREF(__pyx_t_18);
          __Pyx_XGIVEREF(__pyx_t_17);
          __Pyx_ErrRestore(__pyx_t_19, __pyx_t_18, __pyx_t_17);
          __pyx_t_19 = 0; __pyx_t_18 = 0; __pyx_t_17 = 0; __pyx_t_16 = 0; __pyx_t_15 = 0; __pyx_t_14 = 0;
          __pyx_lineno = __pyx_t_12; __pyx_clineno = __pyx_t_11; __pyx_filename = __pyx_t_20;
          goto __pyx_L6_except_error;
        }
        __pyx_L22:;
      }
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      goto __pyx_L5_exception_handled;
    }

    /* "src/gevent/greenlet.py":861
 *             if ex is not t:
 *                 raise
 *         except:             # <<<<<<<<<<<<<<
 *             self.unlink(switch)
 *             raise
*/
    /*except:*/ {
      __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.join", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_10, &__pyx_t_4, &__pyx_t_1) < 0) __PYX_ERR(0, 861, __pyx_L6_except_error)
      __Pyx_XGOTREF(__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_1);

      /* "src/gevent/greenlet.py":862
 *                 raise
 *         except:
 *             self.unlink(switch)             # <<<<<<<<<<<<<<
 *             raise
 * 
*/
      __pyx_t_3 = ((PyObject *)__pyx_v_self);
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_switch};
        __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_unlink, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 862, __pyx_L6_except_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "src/gevent/greenlet.py":863
 *         except:
 *             self.unlink(switch)
 *             raise             # <<<<<<<<<<<<<<
 * 
 *     def __enter__(self):
*/
      __Pyx_GIVEREF(__pyx_t_10);
      __Pyx_GIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_1);
      __Pyx_ErrRestoreWithState(__pyx_t_10, __pyx_t_4, __pyx_t_1);
      __pyx_t_10 = 0;  __pyx_t_4 = 0;  __pyx_t_1 = 0; 
      __PYX_ERR(0, 863, __pyx_L6_except_error)
    }

    /* "src/gevent/greenlet.py":849
 *         switch = getcurrent().switch # pylint:disable=undefined-variable
 *         self.rawlink(switch)
 *         try:             # <<<<<<<<<<<<<<
 *             t = Timeout._start_new_or_dummy(timeout)
 *             try:
*/
    __pyx_L6_except_error:;
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
    goto __pyx_L1_error;
    __pyx_L5_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
    __pyx_L9_try_end:;
  }

  /* "src/gevent/greenlet.py":837
 *             self._raise_exception()
 * 
 *     def join(self, timeout=None):             # <<<<<<<<<<<<<<
 *         """
 *         join(timeout=None) -> None
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.join", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_switch);
  __Pyx_XDECREF(__pyx_v_t);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_ex);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_37join(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_36join, "Greenlet.join(self, timeout=None)\n\njoin(timeout=None) -> None\n\nWait until the greenlet finishes or *timeout* expires. Return\n``None`` regardless.");
static PyMethodDef __pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_37join = {"join", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_37join, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_36join};
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_37join(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_timeout = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("join (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_timeout,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 837, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 837, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "join", 0) < (0)) __PYX_ERR(0, 837, __pyx_L3_error)
      if (!values[0]) values[0] = __Pyx_NewRef(((PyObject *)Py_None));
    } else {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 837, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[0]) values[0] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_timeout = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("join", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 837, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.join", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_36join(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self), __pyx_v_timeout);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_36join(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, PyObject *__pyx_v_timeout) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_6gevent_17_gevent_cgreenlet_8Greenlet_join __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("join", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.timeout = __pyx_v_timeout;
  __pyx_t_1 = __pyx_vtabptr_6gevent_17_gevent_cgreenlet_Greenlet->join(__pyx_v_self, 1, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 837, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.join", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":865
 *             raise
 * 
 *     def __enter__(self):             # <<<<<<<<<<<<<<
 *         return self
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_39__enter__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_38__enter__, "Greenlet.__enter__(self)");
static PyMethodDef __pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_39__enter__ = {"__enter__", (PyCFunction)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_39__enter__, METH_NOARGS, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_38__enter__};
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_39__enter__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__enter__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_38__enter__(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_38__enter__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__enter__", 0);

  /* "src/gevent/greenlet.py":866
 * 
 *     def __enter__(self):
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def __exit__(self, t, v, tb):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __pyx_r = ((PyObject *)__pyx_v_self);
  goto __pyx_L0;

  /* "src/gevent/greenlet.py":865
 *             raise
 * 
 *     def __enter__(self):             # <<<<<<<<<<<<<<
 *         return self
 * 
*/

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":868
 *         return self
 * 
 *     def __exit__(self, t, v, tb):             # <<<<<<<<<<<<<<
 *         if t is None:
 *             try:
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_41__exit__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_40__exit__, "Greenlet.__exit__(self, t, v, tb)");
static PyMethodDef __pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_41__exit__ = {"__exit__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_41__exit__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_40__exit__};
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_41__exit__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_t = 0;
  PyObject *__pyx_v_v = 0;
  PyObject *__pyx_v_tb = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__exit__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_t,&__pyx_mstate_global->__pyx_n_u_v,&__pyx_mstate_global->__pyx_n_u_tb,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 868, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 868, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 868, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 868, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__exit__", 0) < (0)) __PYX_ERR(0, 868, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__exit__", 1, 3, 3, i); __PYX_ERR(0, 868, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 868, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 868, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 868, __pyx_L3_error)
    }
    __pyx_v_t = values[0];
    __pyx_v_v = values[1];
    __pyx_v_tb = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__exit__", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 868, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.__exit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_40__exit__(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self), __pyx_v_t, __pyx_v_v, __pyx_v_tb);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_40__exit__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, PyObject *__pyx_v_t, PyObject *__pyx_v_v, PyObject *__pyx_v_tb) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  char const *__pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  struct __pyx_opt_args_6gevent_17_gevent_cgreenlet_8Greenlet_kill __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__exit__", 0);

  /* "src/gevent/greenlet.py":869
 * 
 *     def __exit__(self, t, v, tb):
 *         if t is None:             # <<<<<<<<<<<<<<
 *             try:
 *                 self.join()
*/
  __pyx_t_1 = (__pyx_v_t == Py_None);
  if (__pyx_t_1) {

    /* "src/gevent/greenlet.py":870
 *     def __exit__(self, t, v, tb):
 *         if t is None:
 *             try:             # <<<<<<<<<<<<<<
 *                 self.join()
 *             finally:
*/
    /*try:*/ {

      /* "src/gevent/greenlet.py":871
 *         if t is None:
 *             try:
 *                 self.join()             # <<<<<<<<<<<<<<
 *             finally:
 *                 self.kill()
*/
      __pyx_t_2 = ((struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self->__pyx_vtab)->join(__pyx_v_self, 0, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 871, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }

    /* "src/gevent/greenlet.py":873
 *                 self.join()
 *             finally:
 *                 self.kill()             # <<<<<<<<<<<<<<
 *         else:
 *             self.kill((t, v, tb))
*/
    /*finally:*/ {
      /*normal exit:*/{
        __pyx_t_2 = ((struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self->__pyx_vtab)->kill(__pyx_v_self, 0, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 873, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        goto __pyx_L6;
      }
      __pyx_L5_error:;
      /*exception exit:*/{
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __pyx_t_6 = 0; __pyx_t_7 = 0; __pyx_t_8 = 0; __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0;
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
         __Pyx_ExceptionSwap(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11);
        if ( unlikely(__Pyx_GetException(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8) < 0)) __Pyx_ErrFetch(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_7);
        __Pyx_XGOTREF(__pyx_t_8);
        __Pyx_XGOTREF(__pyx_t_9);
        __Pyx_XGOTREF(__pyx_t_10);
        __Pyx_XGOTREF(__pyx_t_11);
        __pyx_t_3 = __pyx_lineno; __pyx_t_4 = __pyx_clineno; __pyx_t_5 = __pyx_filename;
        {
          __pyx_t_2 = ((struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self->__pyx_vtab)->kill(__pyx_v_self, 0, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 873, __pyx_L8_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        }
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_ErrRestore(__pyx_t_6, __pyx_t_7, __pyx_t_8);
        __pyx_t_6 = 0; __pyx_t_7 = 0; __pyx_t_8 = 0; __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0;
        __pyx_lineno = __pyx_t_3; __pyx_clineno = __pyx_t_4; __pyx_filename = __pyx_t_5;
        goto __pyx_L1_error;
        __pyx_L8_error:;
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0;
        goto __pyx_L1_error;
      }
      __pyx_L6:;
    }

    /* "src/gevent/greenlet.py":869
 * 
 *     def __exit__(self, t, v, tb):
 *         if t is None:             # <<<<<<<<<<<<<<
 *             try:
 *                 self.join()
*/
    goto __pyx_L3;
  }

  /* "src/gevent/greenlet.py":875
 *                 self.kill()
 *         else:
 *             self.kill((t, v, tb))             # <<<<<<<<<<<<<<
 * 
 *     def __report_result(self, result):
*/
  /*else*/ {
    __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 875, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_t);
    __Pyx_GIVEREF(__pyx_v_t);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_t) != (0)) __PYX_ERR(0, 875, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_v);
    __Pyx_GIVEREF(__pyx_v_v);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_v) != (0)) __PYX_ERR(0, 875, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_tb);
    __Pyx_GIVEREF(__pyx_v_tb);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_v_tb) != (0)) __PYX_ERR(0, 875, __pyx_L1_error);
    __pyx_t_13.__pyx_n = 1;
    __pyx_t_13.exception = __pyx_t_2;
    __pyx_t_12 = ((struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self->__pyx_vtab)->kill(__pyx_v_self, 0, &__pyx_t_13); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 875, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  }
  __pyx_L3:;

  /* "src/gevent/greenlet.py":868
 *         return self
 * 
 *     def __exit__(self, t, v, tb):             # <<<<<<<<<<<<<<
 *         if t is None:
 *             try:
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.__exit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":877
 *             self.kill((t, v, tb))
 * 
 *     def __report_result(self, result):             # <<<<<<<<<<<<<<
 *         self._exc_info = (None, None, None)
 *         self.value = result
*/

static CYTHON_INLINE PyObject *__pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__Greenlet__report_result(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, PyObject *__pyx_v_result) {
  struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *__pyx_v_hub = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  size_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_Greenlet__report_result", 0);

  /* "src/gevent/greenlet.py":878
 * 
 *     def __report_result(self, result):
 *         self._exc_info = (None, None, None)             # <<<<<<<<<<<<<<
 *         self.value = result
 *         if self._links and not self._notifier:
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_tuple[0]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[0]);
  __Pyx_GOTREF(__pyx_v_self->_exc_info);
  __Pyx_DECREF(__pyx_v_self->_exc_info);
  __pyx_v_self->_exc_info = __pyx_mstate_global->__pyx_tuple[0];

  /* "src/gevent/greenlet.py":879
 *     def __report_result(self, result):
 *         self._exc_info = (None, None, None)
 *         self.value = result             # <<<<<<<<<<<<<<
 *         if self._links and not self._notifier:
 *             hub = get_my_hub(self) # pylint:disable=undefined-variable
*/
  __Pyx_INCREF(__pyx_v_result);
  __Pyx_GIVEREF(__pyx_v_result);
  __Pyx_GOTREF(__pyx_v_self->value);
  __Pyx_DECREF(__pyx_v_self->value);
  __pyx_v_self->value = __pyx_v_result;

  /* "src/gevent/greenlet.py":880
 *         self._exc_info = (None, None, None)
 *         self.value = result
 *         if self._links and not self._notifier:             # <<<<<<<<<<<<<<
 *             hub = get_my_hub(self) # pylint:disable=undefined-variable
 *             self._notifier = hub.loop.run_callback(self._notify_links)
*/
  if (__pyx_v_self->_links == Py_None) __pyx_t_2 = 0;
  else
  {
    Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_self->_links);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 880, __pyx_L1_error)
    __pyx_t_2 = (__pyx_temp != 0);
  }

  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_self->_notifier); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 880, __pyx_L1_error)
  __pyx_t_3 = (!__pyx_t_2);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "src/gevent/greenlet.py":881
 *         self.value = result
 *         if self._links and not self._notifier:
 *             hub = get_my_hub(self) # pylint:disable=undefined-variable             # <<<<<<<<<<<<<<
 *             self._notifier = hub.loop.run_callback(self._notify_links)
 * 
*/
    __pyx_t_4 = ((PyObject *)__pyx_f_6gevent_17_gevent_cgreenlet_get_my_hub(((PyGreenlet *)__pyx_v_self))); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 881, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_hub = ((struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *)__pyx_t_4);
    __pyx_t_4 = 0;

    /* "src/gevent/greenlet.py":882
 *         if self._links and not self._notifier:
 *             hub = get_my_hub(self) # pylint:disable=undefined-variable
 *             self._notifier = hub.loop.run_callback(self._notify_links)             # <<<<<<<<<<<<<<
 * 
 *     def __report_error(self, exc_info):
*/
    __pyx_t_5 = __pyx_v_hub->loop;
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_notify_links); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 882, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_6};
      __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_run_callback, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 882, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_GIVEREF(__pyx_t_4);
    __Pyx_GOTREF(__pyx_v_self->_notifier);
    __Pyx_DECREF(__pyx_v_self->_notifier);
    __pyx_v_self->_notifier = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "src/gevent/greenlet.py":880
 *         self._exc_info = (None, None, None)
 *         self.value = result
 *         if self._links and not self._notifier:             # <<<<<<<<<<<<<<
 *             hub = get_my_hub(self) # pylint:disable=undefined-variable
 *             self._notifier = hub.loop.run_callback(self._notify_links)
*/
  }

  /* "src/gevent/greenlet.py":877
 *             self.kill((t, v, tb))
 * 
 *     def __report_result(self, result):             # <<<<<<<<<<<<<<
 *         self._exc_info = (None, None, None)
 *         self.value = result
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet._Greenlet__report_result", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_hub);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":884
 *             self._notifier = hub.loop.run_callback(self._notify_links)
 * 
 *     def __report_error(self, exc_info):             # <<<<<<<<<<<<<<
 *         if isinstance(exc_info[1], GreenletExit):
 *             self.__report_result(exc_info[1])
*/

static CYTHON_INLINE PyObject *__pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__Greenlet__report_error(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, PyObject *__pyx_v_exc_info) {
  PyObject *__pyx_v_tb = NULL;
  struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *__pyx_v_hub = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  size_t __pyx_t_9;
  int __pyx_t_10;
  int __pyx_t_11;
  int __pyx_t_12;
  int __pyx_t_13;
  char const *__pyx_t_14;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_Greenlet__report_error", 0);
  __Pyx_INCREF(__pyx_v_exc_info);

  /* "src/gevent/greenlet.py":885
 * 
 *     def __report_error(self, exc_info):
 *         if isinstance(exc_info[1], GreenletExit):             # <<<<<<<<<<<<<<
 *             self.__report_result(exc_info[1])
 *             return
*/
  if (unlikely(__pyx_v_exc_info == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 885, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v_exc_info, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 885, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_v_6gevent_17_gevent_cgreenlet_GreenletExit;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = PyObject_IsInstance(__pyx_t_1, __pyx_t_2); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(0, 885, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "src/gevent/greenlet.py":886
 *     def __report_error(self, exc_info):
 *         if isinstance(exc_info[1], GreenletExit):
 *             self.__report_result(exc_info[1])             # <<<<<<<<<<<<<<
 *             return
 * 
*/
    if (unlikely(__pyx_v_exc_info == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 886, __pyx_L1_error)
    }
    __pyx_t_2 = __Pyx_GetItemInt_Tuple(__pyx_v_exc_info, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 886, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__Greenlet__report_result(__pyx_v_self, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 886, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "src/gevent/greenlet.py":887
 *         if isinstance(exc_info[1], GreenletExit):
 *             self.__report_result(exc_info[1])
 *             return             # <<<<<<<<<<<<<<
 * 
 *         # Depending on the error, we may not be able to pickle it.
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "src/gevent/greenlet.py":885
 * 
 *     def __report_error(self, exc_info):
 *         if isinstance(exc_info[1], GreenletExit):             # <<<<<<<<<<<<<<
 *             self.__report_result(exc_info[1])
 *             return
*/
  }

  /* "src/gevent/greenlet.py":891
 *         # Depending on the error, we may not be able to pickle it.
 *         # In particular, RecursionError can be a problem.
 *         try:             # <<<<<<<<<<<<<<
 *             tb = dump_traceback(exc_info[2])
 *         except: # pylint:disable=bare-except
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    /*try:*/ {

      /* "src/gevent/greenlet.py":892
 *         # In particular, RecursionError can be a problem.
 *         try:
 *             tb = dump_traceback(exc_info[2])             # <<<<<<<<<<<<<<
 *         except: # pylint:disable=bare-except
 *             tb = None
*/
      __pyx_t_2 = NULL;
      __Pyx_INCREF(__pyx_v_6gevent_17_gevent_cgreenlet_dump_traceback);
      __pyx_t_7 = __pyx_v_6gevent_17_gevent_cgreenlet_dump_traceback; 
      if (unlikely(__pyx_v_exc_info == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 892, __pyx_L4_error)
      }
      __pyx_t_8 = __Pyx_GetItemInt_Tuple(__pyx_v_exc_info, 2, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 892, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_7);
        assert(__pyx_t_2);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
        __pyx_t_9 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_8};
        __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (__pyx_t_9*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 892, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __pyx_v_tb = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "src/gevent/greenlet.py":891
 *         # Depending on the error, we may not be able to pickle it.
 *         # In particular, RecursionError can be a problem.
 *         try:             # <<<<<<<<<<<<<<
 *             tb = dump_traceback(exc_info[2])
 *         except: # pylint:disable=bare-except
*/
    }
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L9_try_end;
    __pyx_L4_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "src/gevent/greenlet.py":893
 *         try:
 *             tb = dump_traceback(exc_info[2])
 *         except: # pylint:disable=bare-except             # <<<<<<<<<<<<<<
 *             tb = None
 *         self._exc_info = exc_info[0], exc_info[1], tb
*/
    /*except:*/ {
      __Pyx_ErrRestore(0,0,0);

      /* "src/gevent/greenlet.py":894
 *             tb = dump_traceback(exc_info[2])
 *         except: # pylint:disable=bare-except
 *             tb = None             # <<<<<<<<<<<<<<
 *         self._exc_info = exc_info[0], exc_info[1], tb
 * 
*/
      __Pyx_INCREF(Py_None);
      __Pyx_XDECREF_SET(__pyx_v_tb, Py_None);
      goto __pyx_L5_exception_handled;
    }
    __pyx_L5_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    __pyx_L9_try_end:;
  }

  /* "src/gevent/greenlet.py":895
 *         except: # pylint:disable=bare-except
 *             tb = None
 *         self._exc_info = exc_info[0], exc_info[1], tb             # <<<<<<<<<<<<<<
 * 
 *         hub = get_my_hub(self) # pylint:disable=undefined-variable
*/
  if (unlikely(__pyx_v_exc_info == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 895, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v_exc_info, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 895, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely(__pyx_v_exc_info == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 895, __pyx_L1_error)
  }
  __pyx_t_7 = __Pyx_GetItemInt_Tuple(__pyx_v_exc_info, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 895, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_8 = PyTuple_New(3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 895, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_1) != (0)) __PYX_ERR(0, 895, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_7);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_t_7) != (0)) __PYX_ERR(0, 895, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_tb);
  __Pyx_GIVEREF(__pyx_v_tb);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 2, __pyx_v_tb) != (0)) __PYX_ERR(0, 895, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_7 = 0;
  __Pyx_GIVEREF(__pyx_t_8);
  __Pyx_GOTREF(__pyx_v_self->_exc_info);
  __Pyx_DECREF(__pyx_v_self->_exc_info);
  __pyx_v_self->_exc_info = ((PyObject*)__pyx_t_8);
  __pyx_t_8 = 0;

  /* "src/gevent/greenlet.py":897
 *         self._exc_info = exc_info[0], exc_info[1], tb
 * 
 *         hub = get_my_hub(self) # pylint:disable=undefined-variable             # <<<<<<<<<<<<<<
 *         if self._links and not self._notifier:
 *             self._notifier = hub.loop.run_callback(self._notify_links)
*/
  __pyx_t_8 = ((PyObject *)__pyx_f_6gevent_17_gevent_cgreenlet_get_my_hub(((PyGreenlet *)__pyx_v_self))); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 897, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_v_hub = ((struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *)__pyx_t_8);
  __pyx_t_8 = 0;

  /* "src/gevent/greenlet.py":898
 * 
 *         hub = get_my_hub(self) # pylint:disable=undefined-variable
 *         if self._links and not self._notifier:             # <<<<<<<<<<<<<<
 *             self._notifier = hub.loop.run_callback(self._notify_links)
 * 
*/
  if (__pyx_v_self->_links == Py_None) __pyx_t_10 = 0;
  else
  {
    Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_self->_links);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 898, __pyx_L1_error)
    __pyx_t_10 = (__pyx_temp != 0);
  }

  if (__pyx_t_10) {
  } else {
    __pyx_t_3 = __pyx_t_10;
    goto __pyx_L13_bool_binop_done;
  }
  __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_v_self->_notifier); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 898, __pyx_L1_error)
  __pyx_t_11 = (!__pyx_t_10);
  __pyx_t_3 = __pyx_t_11;
  __pyx_L13_bool_binop_done:;
  if (__pyx_t_3) {

    /* "src/gevent/greenlet.py":899
 *         hub = get_my_hub(self) # pylint:disable=undefined-variable
 *         if self._links and not self._notifier:
 *             self._notifier = hub.loop.run_callback(self._notify_links)             # <<<<<<<<<<<<<<
 * 
 *         try:
*/
    __pyx_t_7 = __pyx_v_hub->loop;
    __Pyx_INCREF(__pyx_t_7);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_notify_links); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 899, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_9 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_1};
      __pyx_t_8 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_run_callback, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 899, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
    }
    __Pyx_GIVEREF(__pyx_t_8);
    __Pyx_GOTREF(__pyx_v_self->_notifier);
    __Pyx_DECREF(__pyx_v_self->_notifier);
    __pyx_v_self->_notifier = __pyx_t_8;
    __pyx_t_8 = 0;

    /* "src/gevent/greenlet.py":898
 * 
 *         hub = get_my_hub(self) # pylint:disable=undefined-variable
 *         if self._links and not self._notifier:             # <<<<<<<<<<<<<<
 *             self._notifier = hub.loop.run_callback(self._notify_links)
 * 
*/
  }

  /* "src/gevent/greenlet.py":901
 *             self._notifier = hub.loop.run_callback(self._notify_links)
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             hub.handle_error(self, *exc_info)
 *         finally:
*/
  /*try:*/ {

    /* "src/gevent/greenlet.py":902
 * 
 *         try:
 *             hub.handle_error(self, *exc_info)             # <<<<<<<<<<<<<<
 *         finally:
 *             del exc_info
*/
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_hub), __pyx_mstate_global->__pyx_n_u_handle_error); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 902, __pyx_L16_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 902, __pyx_L16_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF((PyObject *)__pyx_v_self);
    __Pyx_GIVEREF((PyObject *)__pyx_v_self);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self)) != (0)) __PYX_ERR(0, 902, __pyx_L16_error);
    if (unlikely(__pyx_v_exc_info == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(0, 902, __pyx_L16_error)
    }
    __pyx_t_7 = PyNumber_Add(__pyx_t_1, __pyx_v_exc_info); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 902, __pyx_L16_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_7, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 902, __pyx_L16_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "src/gevent/greenlet.py":904
 *             hub.handle_error(self, *exc_info)
 *         finally:
 *             del exc_info             # <<<<<<<<<<<<<<
 * 
 *     def run(self):
*/
  /*finally:*/ {
    /*normal exit:*/{
      __Pyx_DECREF(__pyx_v_exc_info); __pyx_v_exc_info = 0;
      goto __pyx_L17;
    }
    __pyx_L16_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_6 = 0; __pyx_t_5 = 0; __pyx_t_4 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
       __Pyx_ExceptionSwap(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17);
      if ( unlikely(__Pyx_GetException(&__pyx_t_6, &__pyx_t_5, &__pyx_t_4) < 0)) __Pyx_ErrFetch(&__pyx_t_6, &__pyx_t_5, &__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_15);
      __Pyx_XGOTREF(__pyx_t_16);
      __Pyx_XGOTREF(__pyx_t_17);
      __pyx_t_12 = __pyx_lineno; __pyx_t_13 = __pyx_clineno; __pyx_t_14 = __pyx_filename;
      {
        __Pyx_DECREF(__pyx_v_exc_info); __pyx_v_exc_info = 0;
      }
      __Pyx_XGIVEREF(__pyx_t_15);
      __Pyx_XGIVEREF(__pyx_t_16);
      __Pyx_XGIVEREF(__pyx_t_17);
      __Pyx_ExceptionReset(__pyx_t_15, __pyx_t_16, __pyx_t_17);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_ErrRestore(__pyx_t_6, __pyx_t_5, __pyx_t_4);
      __pyx_t_6 = 0; __pyx_t_5 = 0; __pyx_t_4 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0;
      __pyx_lineno = __pyx_t_12; __pyx_clineno = __pyx_t_13; __pyx_filename = __pyx_t_14;
      goto __pyx_L1_error;
    }
    __pyx_L17:;
  }

  /* "src/gevent/greenlet.py":884
 *             self._notifier = hub.loop.run_callback(self._notify_links)
 * 
 *     def __report_error(self, exc_info):             # <<<<<<<<<<<<<<
 *         if isinstance(exc_info[1], GreenletExit):
 *             self.__report_result(exc_info[1])
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet._Greenlet__report_error", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_tb);
  __Pyx_XDECREF((PyObject *)__pyx_v_hub);
  __Pyx_XDECREF(__pyx_v_exc_info);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":906
 *             del exc_info
 * 
 *     def run(self):             # <<<<<<<<<<<<<<
 *         try:
 *             self.__cancel_start()
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_43run(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_42run, "Greenlet.run(self)");
static PyMethodDef __pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_43run = {"run", (PyCFunction)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_43run, METH_NOARGS, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_42run};
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_43run(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("run (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_42run(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_42run(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self) {
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  size_t __pyx_t_10;
  int __pyx_t_11;
  int __pyx_t_12;
  char const *__pyx_t_13;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("run", 0);

  /* "src/gevent/greenlet.py":907
 * 
 *     def run(self):
 *         try:             # <<<<<<<<<<<<<<
 *             self.__cancel_start()
 *             self._start_event = _start_completed_event
*/
  /*try:*/ {

    /* "src/gevent/greenlet.py":908
 *     def run(self):
 *         try:
 *             self.__cancel_start()             # <<<<<<<<<<<<<<
 *             self._start_event = _start_completed_event
 * 
*/
    __pyx_t_1 = ((struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self->__pyx_vtab)->_Greenlet__cancel_start(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 908, __pyx_L4_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "src/gevent/greenlet.py":909
 *         try:
 *             self.__cancel_start()
 *             self._start_event = _start_completed_event             # <<<<<<<<<<<<<<
 * 
 *             try:
*/
    __Pyx_INCREF((PyObject *)__pyx_v_6gevent_17_gevent_cgreenlet__start_completed_event);
    __Pyx_GIVEREF((PyObject *)__pyx_v_6gevent_17_gevent_cgreenlet__start_completed_event);
    __Pyx_GOTREF(__pyx_v_self->_start_event);
    __Pyx_DECREF(__pyx_v_self->_start_event);
    __pyx_v_self->_start_event = ((PyObject *)__pyx_v_6gevent_17_gevent_cgreenlet__start_completed_event);

    /* "src/gevent/greenlet.py":911
 *             self._start_event = _start_completed_event
 * 
 *             try:             # <<<<<<<<<<<<<<
 *                 result = self._run(*self.args, **self.kwargs)
 *             except: # pylint:disable=bare-except
*/
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_2, &__pyx_t_3, &__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_2);
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_4);
      /*try:*/ {

        /* "src/gevent/greenlet.py":912
 * 
 *             try:
 *                 result = self._run(*self.args, **self.kwargs)             # <<<<<<<<<<<<<<
 *             except: # pylint:disable=bare-except
 *                 self.__report_error(sys_exc_info())
*/
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_run_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 912, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_1);
        if (unlikely(__pyx_v_self->args == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
          __PYX_ERR(0, 912, __pyx_L6_error)
        }
        if (unlikely(__pyx_v_self->kwargs == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "argument after ** must be a mapping, not NoneType");
          __PYX_ERR(0, 912, __pyx_L6_error)
        }
        __pyx_t_5 = PyDict_Copy(__pyx_v_self->kwargs); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 912, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_v_self->args, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 912, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_v_result = __pyx_t_6;
        __pyx_t_6 = 0;

        /* "src/gevent/greenlet.py":911
 *             self._start_event = _start_completed_event
 * 
 *             try:             # <<<<<<<<<<<<<<
 *                 result = self._run(*self.args, **self.kwargs)
 *             except: # pylint:disable=bare-except
*/
      }

      /* "src/gevent/greenlet.py":916
 *                 self.__report_error(sys_exc_info())
 *             else:
 *                 self.__report_result(result)             # <<<<<<<<<<<<<<
 *         finally:
 *             self.__free()
*/
      /*else:*/ {
        __pyx_t_6 = __pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__Greenlet__report_result(__pyx_v_self, __pyx_v_result); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 916, __pyx_L8_except_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      goto __pyx_L11_try_end;
      __pyx_L6_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "src/gevent/greenlet.py":913
 *             try:
 *                 result = self._run(*self.args, **self.kwargs)
 *             except: # pylint:disable=bare-except             # <<<<<<<<<<<<<<
 *                 self.__report_error(sys_exc_info())
 *             else:
*/
      /*except:*/ {
        __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.run", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_5, &__pyx_t_1) < 0) __PYX_ERR(0, 913, __pyx_L8_except_error)
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_5);
        __Pyx_XGOTREF(__pyx_t_1);

        /* "src/gevent/greenlet.py":914
 *                 result = self._run(*self.args, **self.kwargs)
 *             except: # pylint:disable=bare-except
 *                 self.__report_error(sys_exc_info())             # <<<<<<<<<<<<<<
 *             else:
 *                 self.__report_result(result)
*/
        __pyx_t_8 = NULL;
        __Pyx_INCREF(__pyx_v_6gevent_17_gevent_cgreenlet_sys_exc_info);
        __pyx_t_9 = __pyx_v_6gevent_17_gevent_cgreenlet_sys_exc_info; 
        __pyx_t_10 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_9))) {
          __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_9);
          assert(__pyx_t_8);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_9, __pyx__function);
          __pyx_t_10 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
          __pyx_t_7 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_9, __pyx_callargs+__pyx_t_10, (1-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 914, __pyx_L8_except_error)
          __Pyx_GOTREF(__pyx_t_7);
        }
        if (!(likely(PyTuple_CheckExact(__pyx_t_7))||((__pyx_t_7) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_t_7))) __PYX_ERR(0, 914, __pyx_L8_except_error)
        __pyx_t_9 = __pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__Greenlet__report_error(__pyx_v_self, ((PyObject*)__pyx_t_7)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 914, __pyx_L8_except_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L7_exception_handled;
      }

      /* "src/gevent/greenlet.py":911
 *             self._start_event = _start_completed_event
 * 
 *             try:             # <<<<<<<<<<<<<<
 *                 result = self._run(*self.args, **self.kwargs)
 *             except: # pylint:disable=bare-except
*/
      __pyx_L8_except_error:;
      __Pyx_XGIVEREF(__pyx_t_2);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
      goto __pyx_L4_error;
      __pyx_L7_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_2);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
      __pyx_L11_try_end:;
    }
  }

  /* "src/gevent/greenlet.py":918
 *                 self.__report_result(result)
 *         finally:
 *             self.__free()             # <<<<<<<<<<<<<<
 * 
 *     def __free(self):
*/
  /*finally:*/ {
    /*normal exit:*/{
      __pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__Greenlet__free(__pyx_v_self); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 918, __pyx_L1_error)
      goto __pyx_L5;
    }
    __pyx_L4_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_4 = 0; __pyx_t_3 = 0; __pyx_t_2 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
       __Pyx_ExceptionSwap(&__pyx_t_14, &__pyx_t_15, &__pyx_t_16);
      if ( unlikely(__Pyx_GetException(&__pyx_t_4, &__pyx_t_3, &__pyx_t_2) < 0)) __Pyx_ErrFetch(&__pyx_t_4, &__pyx_t_3, &__pyx_t_2);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_2);
      __Pyx_XGOTREF(__pyx_t_14);
      __Pyx_XGOTREF(__pyx_t_15);
      __Pyx_XGOTREF(__pyx_t_16);
      __pyx_t_11 = __pyx_lineno; __pyx_t_12 = __pyx_clineno; __pyx_t_13 = __pyx_filename;
      {
        __pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__Greenlet__free(__pyx_v_self); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 918, __pyx_L15_error)
      }
      __Pyx_XGIVEREF(__pyx_t_14);
      __Pyx_XGIVEREF(__pyx_t_15);
      __Pyx_XGIVEREF(__pyx_t_16);
      __Pyx_ExceptionReset(__pyx_t_14, __pyx_t_15, __pyx_t_16);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_2);
      __Pyx_ErrRestore(__pyx_t_4, __pyx_t_3, __pyx_t_2);
      __pyx_t_4 = 0; __pyx_t_3 = 0; __pyx_t_2 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0;
      __pyx_lineno = __pyx_t_11; __pyx_clineno = __pyx_t_12; __pyx_filename = __pyx_t_13;
      goto __pyx_L1_error;
      __pyx_L15_error:;
      __Pyx_XGIVEREF(__pyx_t_14);
      __Pyx_XGIVEREF(__pyx_t_15);
      __Pyx_XGIVEREF(__pyx_t_16);
      __Pyx_ExceptionReset(__pyx_t_14, __pyx_t_15, __pyx_t_16);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0;
      goto __pyx_L1_error;
    }
    __pyx_L5:;
  }

  /* "src/gevent/greenlet.py":906
 *             del exc_info
 * 
 *     def run(self):             # <<<<<<<<<<<<<<
 *         try:
 *             self.__cancel_start()
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.run", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":920
 *             self.__free()
 * 
 *     def __free(self):             # <<<<<<<<<<<<<<
 *         try:
 *             # It seems that Cython 0.29.13 sometimes miscompiles
*/

static CYTHON_INLINE void __pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__Greenlet__free(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_Greenlet__free", 0);

  /* "src/gevent/greenlet.py":921
 * 
 *     def __free(self):
 *         try:             # <<<<<<<<<<<<<<
 *             # It seems that Cython 0.29.13 sometimes miscompiles
 *             # self.__dict__.pop('_run', None) ? When we moved this out of the
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "src/gevent/greenlet.py":926
 *             # inline finally: block in run(), we started getting strange
 *             # exceptions from places that subclassed Greenlet.
 *             del self._run             # <<<<<<<<<<<<<<
 *         except AttributeError:
 *             pass
*/
      if (__Pyx_PyObject_DelAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_run_2) < (0)) __PYX_ERR(0, 926, __pyx_L3_error)

      /* "src/gevent/greenlet.py":921
 * 
 *     def __free(self):
 *         try:             # <<<<<<<<<<<<<<
 *             # It seems that Cython 0.29.13 sometimes miscompiles
 *             # self.__dict__.pop('_run', None) ? When we moved this out of the
*/
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;

    /* "src/gevent/greenlet.py":927
 *             # exceptions from places that subclassed Greenlet.
 *             del self._run
 *         except AttributeError:             # <<<<<<<<<<<<<<
 *             pass
 *         self.args = ()
*/
    __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_AttributeError))));
    if (__pyx_t_4) {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;

    /* "src/gevent/greenlet.py":921
 * 
 *     def __free(self):
 *         try:             # <<<<<<<<<<<<<<
 *             # It seems that Cython 0.29.13 sometimes miscompiles
 *             # self.__dict__.pop('_run', None) ? When we moved this out of the
*/
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    __pyx_L8_try_end:;
  }

  /* "src/gevent/greenlet.py":929
 *         except AttributeError:
 *             pass
 *         self.args = ()             # <<<<<<<<<<<<<<
 *         self.kwargs.clear()
 * 
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_empty_tuple);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_empty_tuple);
  __Pyx_GOTREF(__pyx_v_self->args);
  __Pyx_DECREF(__pyx_v_self->args);
  __pyx_v_self->args = __pyx_mstate_global->__pyx_empty_tuple;

  /* "src/gevent/greenlet.py":930
 *             pass
 *         self.args = ()
 *         self.kwargs.clear()             # <<<<<<<<<<<<<<
 * 
 *     def _run(self):
*/
  if (unlikely(__pyx_v_self->kwargs == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "clear");
    __PYX_ERR(0, 930, __pyx_L1_error)
  }
  __pyx_t_5 = __Pyx_PyDict_Clear(__pyx_v_self->kwargs); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 930, __pyx_L1_error)

  /* "src/gevent/greenlet.py":920
 *             self.__free()
 * 
 *     def __free(self):             # <<<<<<<<<<<<<<
 *         try:
 *             # It seems that Cython 0.29.13 sometimes miscompiles
*/

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet._Greenlet__free", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* "src/gevent/greenlet.py":932
 *         self.kwargs.clear()
 * 
 *     def _run(self):             # <<<<<<<<<<<<<<
 *         """
 *         Subclasses may override this method to take any number of
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_45_run(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_44_run, "Greenlet._run(self)\n\nSubclasses may override this method to take any number of\narguments and keyword arguments.\n\n.. versionadded:: 1.1a3\n    Previously, if no callable object was\n    passed to the constructor, the spawned greenlet would later\n    fail with an AttributeError.");
static PyMethodDef __pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_45_run = {"_run", (PyCFunction)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_45_run, METH_NOARGS, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_44_run};
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_45_run(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_run (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_44_run(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_44_run(CYTHON_UNUSED struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_run", 0);

  /* "src/gevent/greenlet.py":944
 *         # We usually override this in __init__
 *         # pylint: disable=method-hidden
 *         return             # <<<<<<<<<<<<<<
 * 
 *     def has_links(self):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;

  /* "src/gevent/greenlet.py":932
 *         self.kwargs.clear()
 * 
 *     def _run(self):             # <<<<<<<<<<<<<<
 *         """
 *         Subclasses may override this method to take any number of
*/

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":946
 *         return
 * 
 *     def has_links(self):             # <<<<<<<<<<<<<<
 *         return len(self._links)
 * 
*/

static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_47has_links(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet_has_links(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("has_links", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (
  #if !CYTHON_USE_TYPE_SLOTS
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet &&
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
  #else
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
  #endif
  ) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_has_links); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 946, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_47has_links)) {
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 946, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 946, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_6;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "src/gevent/greenlet.py":947
 * 
 *     def has_links(self):
 *         return len(self._links)             # <<<<<<<<<<<<<<
 * 
 *     def rawlink(self, callback):
*/
  __pyx_t_1 = __pyx_v_self->_links;
  __Pyx_INCREF(__pyx_t_1);
  if (unlikely(__pyx_t_1 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 947, __pyx_L1_error)
  }
  __pyx_t_7 = __Pyx_PyList_GET_SIZE(__pyx_t_1); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 947, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_7;
  goto __pyx_L0;

  /* "src/gevent/greenlet.py":946
 *         return
 * 
 *     def has_links(self):             # <<<<<<<<<<<<<<
 *         return len(self._links)
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.has_links", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_47has_links(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_46has_links, "Greenlet.has_links(self) -> bool");
static PyMethodDef __pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_47has_links = {"has_links", (PyCFunction)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_47has_links, METH_NOARGS, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_46has_links};
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_47has_links(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("has_links (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_46has_links(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_46has_links(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("has_links", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet_has_links(__pyx_v_self, 1); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 946, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 946, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.has_links", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":949
 *         return len(self._links)
 * 
 *     def rawlink(self, callback):             # <<<<<<<<<<<<<<
 *         """
 *         Register a callable to be executed when the greenlet finishes
*/

static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_49rawlink(PyObject *__pyx_v_self, PyObject *__pyx_v_callback); /*proto*/
static PyObject *__pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet_rawlink(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, PyObject *__pyx_v_callback, int __pyx_skip_dispatch) {
  struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *__pyx_v_hub = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rawlink", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (
  #if !CYTHON_USE_TYPE_SLOTS
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet &&
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
  #else
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
  #endif
  ) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_rawlink); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 949, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_49rawlink)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_callback};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 949, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "src/gevent/greenlet.py":964
 *             **MUST NOT** raise an exception.
 *         """
 *         if not callable(callback):             # <<<<<<<<<<<<<<
 *             raise TypeError('Expected callable: %r' % (callback, ))
 *         self._links.append(callback) # pylint:disable=no-member
*/
  __pyx_t_6 = __Pyx_PyCallable_Check(__pyx_v_callback); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 964, __pyx_L1_error)
  __pyx_t_7 = (!__pyx_t_6);
  if (unlikely(__pyx_t_7)) {

    /* "src/gevent/greenlet.py":965
 *         """
 *         if not callable(callback):
 *             raise TypeError('Expected callable: %r' % (callback, ))             # <<<<<<<<<<<<<<
 *         self._links.append(callback) # pylint:disable=no-member
 *         if self.ready() and self._links and not self._notifier:
*/
    __pyx_t_2 = NULL;
    __pyx_t_4 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_callback), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 965, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_Expected_callable, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 965, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_TypeError)), __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 965, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 965, __pyx_L1_error)

    /* "src/gevent/greenlet.py":964
 *             **MUST NOT** raise an exception.
 *         """
 *         if not callable(callback):             # <<<<<<<<<<<<<<
 *             raise TypeError('Expected callable: %r' % (callback, ))
 *         self._links.append(callback) # pylint:disable=no-member
*/
  }

  /* "src/gevent/greenlet.py":966
 *         if not callable(callback):
 *             raise TypeError('Expected callable: %r' % (callback, ))
 *         self._links.append(callback) # pylint:disable=no-member             # <<<<<<<<<<<<<<
 *         if self.ready() and self._links and not self._notifier:
 *             hub = get_my_hub(self) # pylint:disable=undefined-variable
*/
  if (unlikely(__pyx_v_self->_links == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
    __PYX_ERR(0, 966, __pyx_L1_error)
  }
  __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_self->_links, __pyx_v_callback); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 966, __pyx_L1_error)

  /* "src/gevent/greenlet.py":967
 *             raise TypeError('Expected callable: %r' % (callback, ))
 *         self._links.append(callback) # pylint:disable=no-member
 *         if self.ready() and self._links and not self._notifier:             # <<<<<<<<<<<<<<
 *             hub = get_my_hub(self) # pylint:disable=undefined-variable
 *             self._notifier = hub.loop.run_callback(self._notify_links)
*/
  __pyx_t_6 = ((struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self->__pyx_vtab)->ready(__pyx_v_self, 0); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 967, __pyx_L1_error)
  if (__pyx_t_6) {
  } else {
    __pyx_t_7 = __pyx_t_6;
    goto __pyx_L5_bool_binop_done;
  }
  if (__pyx_v_self->_links == Py_None) __pyx_t_6 = 0;
  else
  {
    Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_self->_links);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 967, __pyx_L1_error)
    __pyx_t_6 = (__pyx_temp != 0);
  }

  if (__pyx_t_6) {
  } else {
    __pyx_t_7 = __pyx_t_6;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_self->_notifier); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 967, __pyx_L1_error)
  __pyx_t_9 = (!__pyx_t_6);
  __pyx_t_7 = __pyx_t_9;
  __pyx_L5_bool_binop_done:;
  if (__pyx_t_7) {

    /* "src/gevent/greenlet.py":968
 *         self._links.append(callback) # pylint:disable=no-member
 *         if self.ready() and self._links and not self._notifier:
 *             hub = get_my_hub(self) # pylint:disable=undefined-variable             # <<<<<<<<<<<<<<
 *             self._notifier = hub.loop.run_callback(self._notify_links)
 * 
*/
    __pyx_t_1 = ((PyObject *)__pyx_f_6gevent_17_gevent_cgreenlet_get_my_hub(((PyGreenlet *)__pyx_v_self))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 968, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_hub = ((struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "src/gevent/greenlet.py":969
 *         if self.ready() and self._links and not self._notifier:
 *             hub = get_my_hub(self) # pylint:disable=undefined-variable
 *             self._notifier = hub.loop.run_callback(self._notify_links)             # <<<<<<<<<<<<<<
 * 
 *     def link(self, callback, SpawnedLink=SpawnedLink):
*/
    __pyx_t_3 = __pyx_v_hub->loop;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_notify_links); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 969, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_run_callback, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 969, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_v_self->_notifier);
    __Pyx_DECREF(__pyx_v_self->_notifier);
    __pyx_v_self->_notifier = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "src/gevent/greenlet.py":967
 *             raise TypeError('Expected callable: %r' % (callback, ))
 *         self._links.append(callback) # pylint:disable=no-member
 *         if self.ready() and self._links and not self._notifier:             # <<<<<<<<<<<<<<
 *             hub = get_my_hub(self) # pylint:disable=undefined-variable
 *             self._notifier = hub.loop.run_callback(self._notify_links)
*/
  }

  /* "src/gevent/greenlet.py":949
 *         return len(self._links)
 * 
 *     def rawlink(self, callback):             # <<<<<<<<<<<<<<
 *         """
 *         Register a callable to be executed when the greenlet finishes
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.rawlink", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_hub);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_49rawlink(PyObject *__pyx_v_self, PyObject *__pyx_v_callback); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_48rawlink, "Greenlet.rawlink(self, callback)\n\nRegister a callable to be executed when the greenlet finishes\nexecution.\n\nThe *callback* will be called with this instance as an\nargument.\n\nThe *callback* will be called even if linked after the greenlet\nis already ready().\n\n.. caution::\n    The *callback* will be called in the hub and\n    **MUST NOT** raise an exception.");
static PyMethodDef __pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_49rawlink = {"rawlink", (PyCFunction)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_49rawlink, METH_O, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_48rawlink};
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_49rawlink(PyObject *__pyx_v_self, PyObject *__pyx_v_callback) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rawlink (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_48rawlink(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self), ((PyObject *)__pyx_v_callback));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_48rawlink(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, PyObject *__pyx_v_callback) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rawlink", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet_rawlink(__pyx_v_self, __pyx_v_callback, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 949, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.rawlink", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":971
 *             self._notifier = hub.loop.run_callback(self._notify_links)
 * 
 *     def link(self, callback, SpawnedLink=SpawnedLink):             # <<<<<<<<<<<<<<
 *         """
 *         Link greenlet's completion to a callable.
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_51link(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_50link, "Greenlet.link(self, callback, SpawnedLink=SpawnedLink)\n\nLink greenlet's completion to a callable.\n\nThe *callback* will be called with this instance as an\nargument once this greenlet is dead. A callable is called in\nits own :class:`greenlet.greenlet` (*not* a\n:class:`Greenlet`).\n\nThe *callback* will be called even if linked after the greenlet\nis already ready().");
static PyMethodDef __pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_51link = {"link", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_51link, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_50link};
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_51link(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_callback = 0;
  PyObject *__pyx_v_SpawnedLink = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("link (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_callback,&__pyx_mstate_global->__pyx_n_u_SpawnedLink,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 971, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 971, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 971, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "link", 0) < (0)) __PYX_ERR(0, 971, __pyx_L3_error)
      if (!values[1]) values[1] = __Pyx_NewRef(__pyx_mstate_global->__pyx_k__13);
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("link", 0, 1, 2, i); __PYX_ERR(0, 971, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 971, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 971, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[1]) values[1] = __Pyx_NewRef(__pyx_mstate_global->__pyx_k__13);
    }
    __pyx_v_callback = values[0];
    __pyx_v_SpawnedLink = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("link", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 971, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.link", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_50link(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self), __pyx_v_callback, __pyx_v_SpawnedLink);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_50link(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, PyObject *__pyx_v_callback, PyObject *__pyx_v_SpawnedLink) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("link", 0);

  /* "src/gevent/greenlet.py":986
 *         # optimization, or do people use it? It's not documented
 *         # pylint:disable=redefined-outer-name
 *         self.rawlink(SpawnedLink(callback))             # <<<<<<<<<<<<<<
 * 
 *     def unlink(self, callback):
*/
  __pyx_t_2 = NULL;
  __Pyx_INCREF(__pyx_v_SpawnedLink);
  __pyx_t_3 = __pyx_v_SpawnedLink; 
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_callback};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 986, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_t_3 = ((struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self->__pyx_vtab)->rawlink(__pyx_v_self, __pyx_t_1, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "src/gevent/greenlet.py":971
 *             self._notifier = hub.loop.run_callback(self._notify_links)
 * 
 *     def link(self, callback, SpawnedLink=SpawnedLink):             # <<<<<<<<<<<<<<
 *         """
 *         Link greenlet's completion to a callable.
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.link", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":988
 *         self.rawlink(SpawnedLink(callback))
 * 
 *     def unlink(self, callback):             # <<<<<<<<<<<<<<
 *         """Remove the callback set by :meth:`link` or :meth:`rawlink`"""
 *         try:
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_53unlink(PyObject *__pyx_v_self, PyObject *__pyx_v_callback); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_52unlink, "Greenlet.unlink(self, callback)\n\nRemove the callback set by :meth:`link` or :meth:`rawlink`");
static PyMethodDef __pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_53unlink = {"unlink", (PyCFunction)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_53unlink, METH_O, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_52unlink};
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_53unlink(PyObject *__pyx_v_self, PyObject *__pyx_v_callback) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("unlink (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_52unlink(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self), ((PyObject *)__pyx_v_callback));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_52unlink(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, PyObject *__pyx_v_callback) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("unlink", 0);

  /* "src/gevent/greenlet.py":990
 *     def unlink(self, callback):
 *         """Remove the callback set by :meth:`link` or :meth:`rawlink`"""
 *         try:             # <<<<<<<<<<<<<<
 *             self._links.remove(callback) # pylint:disable=no-member
 *         except ValueError:
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "src/gevent/greenlet.py":991
 *         """Remove the callback set by :meth:`link` or :meth:`rawlink`"""
 *         try:
 *             self._links.remove(callback) # pylint:disable=no-member             # <<<<<<<<<<<<<<
 *         except ValueError:
 *             pass
*/
      __pyx_t_5 = __pyx_v_self->_links;
      __Pyx_INCREF(__pyx_t_5);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_callback};
        __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_remove, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 991, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "src/gevent/greenlet.py":990
 *     def unlink(self, callback):
 *         """Remove the callback set by :meth:`link` or :meth:`rawlink`"""
 *         try:             # <<<<<<<<<<<<<<
 *             self._links.remove(callback) # pylint:disable=no-member
 *         except ValueError:
*/
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "src/gevent/greenlet.py":992
 *         try:
 *             self._links.remove(callback) # pylint:disable=no-member
 *         except ValueError:             # <<<<<<<<<<<<<<
 *             pass
 * 
*/
    __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_ValueError))));
    if (__pyx_t_7) {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;

    /* "src/gevent/greenlet.py":990
 *     def unlink(self, callback):
 *         """Remove the callback set by :meth:`link` or :meth:`rawlink`"""
 *         try:             # <<<<<<<<<<<<<<
 *             self._links.remove(callback) # pylint:disable=no-member
 *         except ValueError:
*/
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    __pyx_L8_try_end:;
  }

  /* "src/gevent/greenlet.py":988
 *         self.rawlink(SpawnedLink(callback))
 * 
 *     def unlink(self, callback):             # <<<<<<<<<<<<<<
 *         """Remove the callback set by :meth:`link` or :meth:`rawlink`"""
 *         try:
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.unlink", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":995
 *             pass
 * 
 *     def unlink_all(self):             # <<<<<<<<<<<<<<
 *         """
 *         Remove all the callbacks.
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_55unlink_all(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_54unlink_all, "Greenlet.unlink_all(self)\n\nRemove all the callbacks.\n\n.. versionadded:: 1.3a2");
static PyMethodDef __pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_55unlink_all = {"unlink_all", (PyCFunction)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_55unlink_all, METH_NOARGS, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_54unlink_all};
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_55unlink_all(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("unlink_all (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_54unlink_all(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_54unlink_all(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("unlink_all", 0);

  /* "src/gevent/greenlet.py":1001
 *         .. versionadded:: 1.3a2
 *         """
 *         del self._links[:]             # <<<<<<<<<<<<<<
 * 
 *     def link_value(self, callback, SpawnedLink=SuccessSpawnedLink):
*/
  if (unlikely(__pyx_v_self->_links == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 1001, __pyx_L1_error)
  }
  if (__Pyx_PyObject_DelSlice(__pyx_v_self->_links, 0, 0, NULL, NULL, NULL, 0, 0, 1) < (0)) __PYX_ERR(0, 1001, __pyx_L1_error)

  /* "src/gevent/greenlet.py":995
 *             pass
 * 
 *     def unlink_all(self):             # <<<<<<<<<<<<<<
 *         """
 *         Remove all the callbacks.
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.unlink_all", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":1003
 *         del self._links[:]
 * 
 *     def link_value(self, callback, SpawnedLink=SuccessSpawnedLink):             # <<<<<<<<<<<<<<
 *         """
 *         Like :meth:`link` but *callback* is only notified when the greenlet
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_57link_value(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_56link_value, "Greenlet.link_value(self, callback, SpawnedLink=SuccessSpawnedLink)\n\nLike :meth:`link` but *callback* is only notified when the greenlet\nhas completed successfully.");
static PyMethodDef __pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_57link_value = {"link_value", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_57link_value, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_56link_value};
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_57link_value(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_callback = 0;
  PyObject *__pyx_v_SpawnedLink = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("link_value (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_callback,&__pyx_mstate_global->__pyx_n_u_SpawnedLink,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 1003, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1003, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1003, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "link_value", 0) < (0)) __PYX_ERR(0, 1003, __pyx_L3_error)
      if (!values[1]) values[1] = __Pyx_NewRef(__pyx_mstate_global->__pyx_k__14);
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("link_value", 0, 1, 2, i); __PYX_ERR(0, 1003, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1003, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1003, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[1]) values[1] = __Pyx_NewRef(__pyx_mstate_global->__pyx_k__14);
    }
    __pyx_v_callback = values[0];
    __pyx_v_SpawnedLink = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("link_value", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 1003, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.link_value", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_56link_value(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self), __pyx_v_callback, __pyx_v_SpawnedLink);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_56link_value(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, PyObject *__pyx_v_callback, PyObject *__pyx_v_SpawnedLink) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("link_value", 0);

  /* "src/gevent/greenlet.py":1009
 *         """
 *         # pylint:disable=redefined-outer-name
 *         self.link(callback, SpawnedLink=SpawnedLink)             # <<<<<<<<<<<<<<
 * 
 *     def link_exception(self, callback, SpawnedLink=FailureSpawnedLink):
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, __pyx_v_callback};
    __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1009, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_SpawnedLink, __pyx_v_SpawnedLink, __pyx_t_4, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1009, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_link, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1009, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "src/gevent/greenlet.py":1003
 *         del self._links[:]
 * 
 *     def link_value(self, callback, SpawnedLink=SuccessSpawnedLink):             # <<<<<<<<<<<<<<
 *         """
 *         Like :meth:`link` but *callback* is only notified when the greenlet
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.link_value", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":1011
 *         self.link(callback, SpawnedLink=SpawnedLink)
 * 
 *     def link_exception(self, callback, SpawnedLink=FailureSpawnedLink):             # <<<<<<<<<<<<<<
 *         """
 *         Like :meth:`link` but *callback* is only notified when the
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_59link_exception(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_58link_exception, "Greenlet.link_exception(self, callback, SpawnedLink=FailureSpawnedLink)\n\nLike :meth:`link` but *callback* is only notified when the\ngreenlet dies because of an unhandled exception.");
static PyMethodDef __pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_59link_exception = {"link_exception", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_59link_exception, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_58link_exception};
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_59link_exception(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_callback = 0;
  PyObject *__pyx_v_SpawnedLink = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("link_exception (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_callback,&__pyx_mstate_global->__pyx_n_u_SpawnedLink,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 1011, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1011, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1011, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "link_exception", 0) < (0)) __PYX_ERR(0, 1011, __pyx_L3_error)
      if (!values[1]) values[1] = __Pyx_NewRef(__pyx_mstate_global->__pyx_k__15);
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("link_exception", 0, 1, 2, i); __PYX_ERR(0, 1011, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1011, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1011, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[1]) values[1] = __Pyx_NewRef(__pyx_mstate_global->__pyx_k__15);
    }
    __pyx_v_callback = values[0];
    __pyx_v_SpawnedLink = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("link_exception", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 1011, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.link_exception", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_58link_exception(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self), __pyx_v_callback, __pyx_v_SpawnedLink);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_58link_exception(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, PyObject *__pyx_v_callback, PyObject *__pyx_v_SpawnedLink) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("link_exception", 0);

  /* "src/gevent/greenlet.py":1017
 *         """
 *         # pylint:disable=redefined-outer-name
 *         self.link(callback, SpawnedLink=SpawnedLink)             # <<<<<<<<<<<<<<
 * 
 *     def _notify_links(self):
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, __pyx_v_callback};
    __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1017, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_SpawnedLink, __pyx_v_SpawnedLink, __pyx_t_4, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1017, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_link, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1017, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "src/gevent/greenlet.py":1011
 *         self.link(callback, SpawnedLink=SpawnedLink)
 * 
 *     def link_exception(self, callback, SpawnedLink=FailureSpawnedLink):             # <<<<<<<<<<<<<<
 *         """
 *         Like :meth:`link` but *callback* is only notified when the
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.link_exception", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":1019
 *         self.link(callback, SpawnedLink=SpawnedLink)
 * 
 *     def _notify_links(self):             # <<<<<<<<<<<<<<
 *         while self._links:
 *             # Early links are allowed to remove later links
*/

static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_61_notify_links(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__notify_links(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_link = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_notify_links", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (
  #if !CYTHON_USE_TYPE_SLOTS
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet &&
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
  #else
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
  #endif
  ) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_notify_links); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1019, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_61_notify_links)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1019, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "src/gevent/greenlet.py":1020
 * 
 *     def _notify_links(self):
 *         while self._links:             # <<<<<<<<<<<<<<
 *             # Early links are allowed to remove later links
 *             # before we get to them, and they're also allowed to
*/
  while (1) {
    if (__pyx_v_self->_links == Py_None) __pyx_t_6 = 0;
    else
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_self->_links);
      if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 1020, __pyx_L1_error)
      __pyx_t_6 = (__pyx_temp != 0);
    }

    if (!__pyx_t_6) break;

    /* "src/gevent/greenlet.py":1028
 *             # manipulating it should be small. a deque is probably not justified.
 *             # Cython has optimizations to transform this into a memmove anyway.
 *             link = self._links.pop(0)             # <<<<<<<<<<<<<<
 *             try:
 *                 link(self)
*/
    if (unlikely(__pyx_v_self->_links == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "pop");
      __PYX_ERR(0, 1028, __pyx_L1_error)
    }
    __pyx_t_1 = __Pyx_PyList_PopIndex(__pyx_v_self->_links, __pyx_mstate_global->__pyx_int_0, 0, 1, Py_ssize_t, PyLong_FromSsize_t); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1028, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_link, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "src/gevent/greenlet.py":1029
 *             # Cython has optimizations to transform this into a memmove anyway.
 *             link = self._links.pop(0)
 *             try:             # <<<<<<<<<<<<<<
 *                 link(self)
 *             except: # pylint:disable=bare-except, undefined-variable
*/
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      /*try:*/ {

        /* "src/gevent/greenlet.py":1030
 *             link = self._links.pop(0)
 *             try:
 *                 link(self)             # <<<<<<<<<<<<<<
 *             except: # pylint:disable=bare-except, undefined-variable
 *                 get_my_hub(self).handle_error((link, self), *sys_exc_info())
*/
        __pyx_t_2 = NULL;
        __Pyx_INCREF(__pyx_v_link);
        __pyx_t_4 = __pyx_v_link; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_2);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_2, ((PyObject *)__pyx_v_self)};
          __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1030, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "src/gevent/greenlet.py":1029
 *             # Cython has optimizations to transform this into a memmove anyway.
 *             link = self._links.pop(0)
 *             try:             # <<<<<<<<<<<<<<
 *                 link(self)
 *             except: # pylint:disable=bare-except, undefined-variable
*/
      }
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      goto __pyx_L12_try_end;
      __pyx_L5_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "src/gevent/greenlet.py":1031
 *             try:
 *                 link(self)
 *             except: # pylint:disable=bare-except, undefined-variable             # <<<<<<<<<<<<<<
 *                 get_my_hub(self).handle_error((link, self), *sys_exc_info())
 * 
*/
      /*except:*/ {
        __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet._notify_links", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_4, &__pyx_t_2) < 0) __PYX_ERR(0, 1031, __pyx_L7_except_error)
        __Pyx_XGOTREF(__pyx_t_1);
        __Pyx_XGOTREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_t_2);

        /* "src/gevent/greenlet.py":1032
 *                 link(self)
 *             except: # pylint:disable=bare-except, undefined-variable
 *                 get_my_hub(self).handle_error((link, self), *sys_exc_info())             # <<<<<<<<<<<<<<
 * 
 * 
*/
        __pyx_t_3 = ((PyObject *)__pyx_f_6gevent_17_gevent_cgreenlet_get_my_hub(((PyGreenlet *)__pyx_v_self))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1032, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_handle_error); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1032, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1032, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_v_link);
        __Pyx_GIVEREF(__pyx_v_link);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_link) != (0)) __PYX_ERR(0, 1032, __pyx_L7_except_error);
        __Pyx_INCREF((PyObject *)__pyx_v_self);
        __Pyx_GIVEREF((PyObject *)__pyx_v_self);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, ((PyObject *)__pyx_v_self)) != (0)) __PYX_ERR(0, 1032, __pyx_L7_except_error);
        __pyx_t_11 = PyTuple_New(1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1032, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_GIVEREF(__pyx_t_3);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_3) != (0)) __PYX_ERR(0, 1032, __pyx_L7_except_error);
        __pyx_t_3 = 0;
        __pyx_t_12 = NULL;
        __Pyx_INCREF(__pyx_v_6gevent_17_gevent_cgreenlet_sys_exc_info);
        __pyx_t_13 = __pyx_v_6gevent_17_gevent_cgreenlet_sys_exc_info; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_13))) {
          __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_13);
          assert(__pyx_t_12);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_13);
          __Pyx_INCREF(__pyx_t_12);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_13, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_12, NULL};
          __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_13, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1032, __pyx_L7_except_error)
          __Pyx_GOTREF(__pyx_t_3);
        }
        __pyx_t_13 = __Pyx_PySequence_Tuple(__pyx_t_3); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1032, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = PyNumber_Add(__pyx_t_11, __pyx_t_13); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1032, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_3, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1032, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        goto __pyx_L6_exception_handled;
      }

      /* "src/gevent/greenlet.py":1029
 *             # Cython has optimizations to transform this into a memmove anyway.
 *             link = self._links.pop(0)
 *             try:             # <<<<<<<<<<<<<<
 *                 link(self)
 *             except: # pylint:disable=bare-except, undefined-variable
*/
      __pyx_L7_except_error:;
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      goto __pyx_L1_error;
      __pyx_L6_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      __pyx_L12_try_end:;
    }
  }

  /* "src/gevent/greenlet.py":1019
 *         self.link(callback, SpawnedLink=SpawnedLink)
 * 
 *     def _notify_links(self):             # <<<<<<<<<<<<<<
 *         while self._links:
 *             # Early links are allowed to remove later links
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet._notify_links", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_link);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_61_notify_links(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_60_notify_links, "Greenlet._notify_links(self)");
static PyMethodDef __pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_61_notify_links = {"_notify_links", (PyCFunction)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_61_notify_links, METH_NOARGS, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_60_notify_links};
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_61_notify_links(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_notify_links (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_60_notify_links(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_60_notify_links(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_notify_links", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__notify_links(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1019, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet._notify_links", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/_gevent_cgreenlet.pxd":129
 * 
 * cdef class Greenlet(greenlet):
 *     cdef readonly object value             # <<<<<<<<<<<<<<
 *     cdef readonly tuple args
 *     cdef readonly dict kwargs
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_5value_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_5value_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_5value___get__(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_5value___get__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->value);
  __pyx_r = __pyx_v_self->value;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/_gevent_cgreenlet.pxd":130
 * cdef class Greenlet(greenlet):
 *     cdef readonly object value
 *     cdef readonly tuple args             # <<<<<<<<<<<<<<
 *     cdef readonly dict kwargs
 *     cdef readonly object spawning_greenlet
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_4args_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_4args_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_4args___get__(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_4args___get__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->args);
  __pyx_r = __pyx_v_self->args;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/_gevent_cgreenlet.pxd":131
 *     cdef readonly object value
 *     cdef readonly tuple args
 *     cdef readonly dict kwargs             # <<<<<<<<<<<<<<
 *     cdef readonly object spawning_greenlet
 *     cdef readonly _Frame spawning_stack
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_6kwargs_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_6kwargs_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_6kwargs___get__(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_6kwargs___get__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->kwargs);
  __pyx_r = __pyx_v_self->kwargs;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/_gevent_cgreenlet.pxd":132
 *     cdef readonly tuple args
 *     cdef readonly dict kwargs
 *     cdef readonly object spawning_greenlet             # <<<<<<<<<<<<<<
 *     cdef readonly _Frame spawning_stack
 *     cdef public dict spawn_tree_locals
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_17spawning_greenlet_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_17spawning_greenlet_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_17spawning_greenlet___get__(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_17spawning_greenlet___get__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->spawning_greenlet);
  __pyx_r = __pyx_v_self->spawning_greenlet;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/_gevent_cgreenlet.pxd":133
 *     cdef readonly dict kwargs
 *     cdef readonly object spawning_greenlet
 *     cdef readonly _Frame spawning_stack             # <<<<<<<<<<<<<<
 *     cdef public dict spawn_tree_locals
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_14spawning_stack_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_14spawning_stack_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_14spawning_stack___get__(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_14spawning_stack___get__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->spawning_stack);
  __pyx_r = ((PyObject *)__pyx_v_self->spawning_stack);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/_gevent_cgreenlet.pxd":134
 *     cdef readonly object spawning_greenlet
 *     cdef readonly _Frame spawning_stack
 *     cdef public dict spawn_tree_locals             # <<<<<<<<<<<<<<
 * 
 *     cdef list _links
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_17spawn_tree_locals_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_17spawn_tree_locals_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_17spawn_tree_locals___get__(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_17spawn_tree_locals___get__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->spawn_tree_locals);
  __pyx_r = __pyx_v_self->spawn_tree_locals;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_17spawn_tree_locals_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_17spawn_tree_locals_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_17spawn_tree_locals_2__set__(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_17spawn_tree_locals_2__set__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PyDict_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("dict", __pyx_t_1))) __PYX_ERR(4, 134, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->spawn_tree_locals);
  __Pyx_DECREF(__pyx_v_self->spawn_tree_locals);
  __pyx_v_self->spawn_tree_locals = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.Greenlet.spawn_tree_locals.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_17spawn_tree_locals_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_17spawn_tree_locals_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_17spawn_tree_locals_4__del__(((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6gevent_17_gevent_cgreenlet_8Greenlet_17spawn_tree_locals_4__del__(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->spawn_tree_locals);
  __Pyx_DECREF(__pyx_v_self->spawn_tree_locals);
  __pyx_v_self->spawn_tree_locals = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":1038
 *     __slots__ = ('pending', 'active')
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self.pending = self.active = False
 * 
*/

/* Python wrapper */
static int __pyx_pw_6gevent_17_gevent_cgreenlet_12_dummy_event_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6gevent_17_gevent_cgreenlet_12_dummy_event_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("__init__", 1, 0, 0, __pyx_nargs); return -1; }
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return -1;
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("__init__", __pyx_kwds); return -1;}
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_12_dummy_event___init__(((struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6gevent_17_gevent_cgreenlet_12_dummy_event___init__(struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *__pyx_v_self) {
  int __pyx_r;

  /* "src/gevent/greenlet.py":1039
 * 
 *     def __init__(self):
 *         self.pending = self.active = False             # <<<<<<<<<<<<<<
 * 
 *     def stop(self):
*/
  __pyx_v_self->pending = 0;
  __pyx_v_self->active = 0;

  /* "src/gevent/greenlet.py":1038
 *     __slots__ = ('pending', 'active')
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self.pending = self.active = False
 * 
*/

  /* function exit code */
  __pyx_r = 0;
  return __pyx_r;
}

/* "src/gevent/greenlet.py":1041
 *         self.pending = self.active = False
 * 
 *     def stop(self):             # <<<<<<<<<<<<<<
 *         pass
 * 
*/

static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_12_dummy_event_3stop(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_6gevent_17_gevent_cgreenlet_12_dummy_event_stop(CYTHON_UNUSED struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *__pyx_v_self, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("stop", 0);

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_12_dummy_event_3stop(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_17_gevent_cgreenlet_12_dummy_event_2stop, "_dummy_event.stop(self)");
static PyMethodDef __pyx_mdef_6gevent_17_gevent_cgreenlet_12_dummy_event_3stop = {"stop", (PyCFunction)__pyx_pw_6gevent_17_gevent_cgreenlet_12_dummy_event_3stop, METH_NOARGS, __pyx_doc_6gevent_17_gevent_cgreenlet_12_dummy_event_2stop};
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_12_dummy_event_3stop(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("stop (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_12_dummy_event_2stop(((struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_12_dummy_event_2stop(struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("stop", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6gevent_17_gevent_cgreenlet_12_dummy_event_stop(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet._dummy_event.stop", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":1044
 *         pass
 * 
 *     def start(self, cb): # pylint:disable=unused-argument             # <<<<<<<<<<<<<<
 *         raise AssertionError("Cannot start the dummy event")
 * 
*/

static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_12_dummy_event_5start(PyObject *__pyx_v_self, PyObject *__pyx_v_cb); /*proto*/
static PyObject *__pyx_f_6gevent_17_gevent_cgreenlet_12_dummy_event_start(CYTHON_UNUSED struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_cb, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("start", 0);

  /* "src/gevent/greenlet.py":1045
 * 
 *     def start(self, cb): # pylint:disable=unused-argument
 *         raise AssertionError("Cannot start the dummy event")             # <<<<<<<<<<<<<<
 * 
 *     def close(self):
*/
  __pyx_t_2 = NULL;
  __pyx_t_3 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_Cannot_start_the_dummy_event};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_AssertionError)), __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1045, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(0, 1045, __pyx_L1_error)

  /* "src/gevent/greenlet.py":1044
 *         pass
 * 
 *     def start(self, cb): # pylint:disable=unused-argument             # <<<<<<<<<<<<<<
 *         raise AssertionError("Cannot start the dummy event")
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet._dummy_event.start", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_12_dummy_event_5start(PyObject *__pyx_v_self, PyObject *__pyx_v_cb); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_17_gevent_cgreenlet_12_dummy_event_4start, "_dummy_event.start(self, cb)");
static PyMethodDef __pyx_mdef_6gevent_17_gevent_cgreenlet_12_dummy_event_5start = {"start", (PyCFunction)__pyx_pw_6gevent_17_gevent_cgreenlet_12_dummy_event_5start, METH_O, __pyx_doc_6gevent_17_gevent_cgreenlet_12_dummy_event_4start};
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_12_dummy_event_5start(PyObject *__pyx_v_self, PyObject *__pyx_v_cb) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("start (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_12_dummy_event_4start(((struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *)__pyx_v_self), ((PyObject *)__pyx_v_cb));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_12_dummy_event_4start(struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *__pyx_v_self, PyObject *__pyx_v_cb) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("start", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6gevent_17_gevent_cgreenlet_12_dummy_event_start(__pyx_v_self, __pyx_v_cb, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1044, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet._dummy_event.start", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":1047
 *         raise AssertionError("Cannot start the dummy event")
 * 
 *     def close(self):             # <<<<<<<<<<<<<<
 *         pass
 * 
*/

static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_12_dummy_event_7close(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_6gevent_17_gevent_cgreenlet_12_dummy_event_close(CYTHON_UNUSED struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *__pyx_v_self, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("close", 0);

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_12_dummy_event_7close(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_17_gevent_cgreenlet_12_dummy_event_6close, "_dummy_event.close(self)");
static PyMethodDef __pyx_mdef_6gevent_17_gevent_cgreenlet_12_dummy_event_7close = {"close", (PyCFunction)__pyx_pw_6gevent_17_gevent_cgreenlet_12_dummy_event_7close, METH_NOARGS, __pyx_doc_6gevent_17_gevent_cgreenlet_12_dummy_event_6close};
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_12_dummy_event_7close(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("close (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_12_dummy_event_6close(((struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_12_dummy_event_6close(struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("close", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6gevent_17_gevent_cgreenlet_12_dummy_event_close(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1047, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet._dummy_event.close", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/_gevent_cgreenlet.pxd":202
 * @cython.internal
 * cdef class _dummy_event:
 *     cdef readonly bint pending             # <<<<<<<<<<<<<<
 *     cdef readonly bint active
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_12_dummy_event_7pending_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_12_dummy_event_7pending_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_12_dummy_event_7pending___get__(((struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_12_dummy_event_7pending___get__(struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->pending); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 202, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet._dummy_event.pending.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/_gevent_cgreenlet.pxd":203
 * cdef class _dummy_event:
 *     cdef readonly bint pending
 *     cdef readonly bint active             # <<<<<<<<<<<<<<
 * 
 *     cpdef stop(self)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_12_dummy_event_6active_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_12_dummy_event_6active_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_12_dummy_event_6active___get__(((struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_12_dummy_event_6active___get__(struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->active); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 203, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet._dummy_event.active.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":1056
 * # This is *only* called as a callback from the hub via Greenlet.kill(),
 * # and its first argument is the Greenlet. So we can be sure about the types.
 * def _kill(glet, exception, waiter):             # <<<<<<<<<<<<<<
 *     try:
 *         if isinstance(exception, tuple) and len(exception) == 3:
*/

static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_1_kill(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6gevent_17_gevent_cgreenlet__kill(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_glet, PyObject *__pyx_v_exception, PyObject *__pyx_v_waiter, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  size_t __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_kill", 0);

  /* "src/gevent/greenlet.py":1057
 * # and its first argument is the Greenlet. So we can be sure about the types.
 * def _kill(glet, exception, waiter):
 *     try:             # <<<<<<<<<<<<<<
 *         if isinstance(exception, tuple) and len(exception) == 3:
 *             glet.throw(*exception)
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "src/gevent/greenlet.py":1058
 * def _kill(glet, exception, waiter):
 *     try:
 *         if isinstance(exception, tuple) and len(exception) == 3:             # <<<<<<<<<<<<<<
 *             glet.throw(*exception)
 *         else:
*/
      __pyx_t_5 = PyTuple_Check(__pyx_v_exception); 
      if (__pyx_t_5) {
      } else {
        __pyx_t_4 = __pyx_t_5;
        goto __pyx_L10_bool_binop_done;
      }
      __pyx_t_6 = PyObject_Length(__pyx_v_exception); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1058, __pyx_L3_error)
      __pyx_t_5 = (__pyx_t_6 == 3);
      __pyx_t_4 = __pyx_t_5;
      __pyx_L10_bool_binop_done:;
      if (__pyx_t_4) {

        /* "src/gevent/greenlet.py":1059
 *     try:
 *         if isinstance(exception, tuple) and len(exception) == 3:
 *             glet.throw(*exception)             # <<<<<<<<<<<<<<
 *         else:
 *             glet.throw(exception)
*/
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_glet), __pyx_mstate_global->__pyx_n_u_throw); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1059, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_8 = __Pyx_PySequence_Tuple(__pyx_v_exception); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1059, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_8, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1059, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

        /* "src/gevent/greenlet.py":1058
 * def _kill(glet, exception, waiter):
 *     try:
 *         if isinstance(exception, tuple) and len(exception) == 3:             # <<<<<<<<<<<<<<
 *             glet.throw(*exception)
 *         else:
*/
        goto __pyx_L9;
      }

      /* "src/gevent/greenlet.py":1061
 *             glet.throw(*exception)
 *         else:
 *             glet.throw(exception)             # <<<<<<<<<<<<<<
 *     except: # pylint:disable=bare-except, undefined-variable
 *         # XXX do we need this here?
*/
      /*else*/ {
        __pyx_t_8 = ((PyObject *)__pyx_v_glet);
        __Pyx_INCREF(__pyx_t_8);
        __pyx_t_10 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_v_exception};
          __pyx_t_9 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_throw, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1061, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_9);
        }
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
      __pyx_L9:;

      /* "src/gevent/greenlet.py":1057
 * # and its first argument is the Greenlet. So we can be sure about the types.
 * def _kill(glet, exception, waiter):
 *     try:             # <<<<<<<<<<<<<<
 *         if isinstance(exception, tuple) and len(exception) == 3:
 *             glet.throw(*exception)
*/
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "src/gevent/greenlet.py":1062
 *         else:
 *             glet.throw(exception)
 *     except: # pylint:disable=bare-except, undefined-variable             # <<<<<<<<<<<<<<
 *         # XXX do we need this here?
 *         get_my_hub(glet).handle_error(glet, *sys_exc_info())
*/
    /*except:*/ {
      __Pyx_AddTraceback("gevent._gevent_cgreenlet._kill", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_9, &__pyx_t_8, &__pyx_t_7) < 0) __PYX_ERR(0, 1062, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_7);

      /* "src/gevent/greenlet.py":1064
 *     except: # pylint:disable=bare-except, undefined-variable
 *         # XXX do we need this here?
 *         get_my_hub(glet).handle_error(glet, *sys_exc_info())             # <<<<<<<<<<<<<<
 *     if waiter is not None:
 *         waiter.switch(None)
*/
      __pyx_t_11 = ((PyObject *)__pyx_f_6gevent_17_gevent_cgreenlet_get_my_hub(((PyGreenlet *)__pyx_v_glet))); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1064, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_handle_error); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1064, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_11 = PyTuple_New(1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1064, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_INCREF((PyObject *)__pyx_v_glet);
      __Pyx_GIVEREF((PyObject *)__pyx_v_glet);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_11, 0, ((PyObject *)__pyx_v_glet)) != (0)) __PYX_ERR(0, 1064, __pyx_L5_except_error);
      __pyx_t_14 = NULL;
      __Pyx_INCREF(__pyx_v_6gevent_17_gevent_cgreenlet_sys_exc_info);
      __pyx_t_15 = __pyx_v_6gevent_17_gevent_cgreenlet_sys_exc_info; 
      __pyx_t_10 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_15))) {
        __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_15);
        assert(__pyx_t_14);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_15);
        __Pyx_INCREF(__pyx_t_14);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_15, __pyx__function);
        __pyx_t_10 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_14, NULL};
        __pyx_t_13 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_15, __pyx_callargs+__pyx_t_10, (1-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1064, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_13);
      }
      __pyx_t_15 = __Pyx_PySequence_Tuple(__pyx_t_13); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 1064, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_15);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __pyx_t_13 = PyNumber_Add(__pyx_t_11, __pyx_t_15); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1064, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __pyx_t_15 = __Pyx_PyObject_Call(__pyx_t_12, __pyx_t_13, NULL); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 1064, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_15);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L4_exception_handled;
    }

    /* "src/gevent/greenlet.py":1057
 * # and its first argument is the Greenlet. So we can be sure about the types.
 * def _kill(glet, exception, waiter):
 *     try:             # <<<<<<<<<<<<<<
 *         if isinstance(exception, tuple) and len(exception) == 3:
 *             glet.throw(*exception)
*/
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    __pyx_L8_try_end:;
  }

  /* "src/gevent/greenlet.py":1065
 *         # XXX do we need this here?
 *         get_my_hub(glet).handle_error(glet, *sys_exc_info())
 *     if waiter is not None:             # <<<<<<<<<<<<<<
 *         waiter.switch(None)
 * 
*/
  __pyx_t_4 = (__pyx_v_waiter != Py_None);
  if (__pyx_t_4) {

    /* "src/gevent/greenlet.py":1066
 *         get_my_hub(glet).handle_error(glet, *sys_exc_info())
 *     if waiter is not None:
 *         waiter.switch(None)             # <<<<<<<<<<<<<<
 * 
 * 
*/
    __pyx_t_8 = __pyx_v_waiter;
    __Pyx_INCREF(__pyx_t_8);
    __pyx_t_10 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_8, Py_None};
      __pyx_t_7 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_switch, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1066, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
    }
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "src/gevent/greenlet.py":1065
 *         # XXX do we need this here?
 *         get_my_hub(glet).handle_error(glet, *sys_exc_info())
 *     if waiter is not None:             # <<<<<<<<<<<<<<
 *         waiter.switch(None)
 * 
*/
  }

  /* "src/gevent/greenlet.py":1056
 * # This is *only* called as a callback from the hub via Greenlet.kill(),
 * # and its first argument is the Greenlet. So we can be sure about the types.
 * def _kill(glet, exception, waiter):             # <<<<<<<<<<<<<<
 *     try:
 *         if isinstance(exception, tuple) and len(exception) == 3:
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet._kill", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_1_kill(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_17_gevent_cgreenlet__kill, "_kill(Greenlet glet, exception, waiter)");
static PyMethodDef __pyx_mdef_6gevent_17_gevent_cgreenlet_1_kill = {"_kill", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6gevent_17_gevent_cgreenlet_1_kill, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6gevent_17_gevent_cgreenlet__kill};
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_1_kill(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_glet = 0;
  PyObject *__pyx_v_exception = 0;
  PyObject *__pyx_v_waiter = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_kill (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_glet,&__pyx_mstate_global->__pyx_n_u_exception,&__pyx_mstate_global->__pyx_n_u_waiter,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 1056, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 1056, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1056, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1056, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_kill", 0) < (0)) __PYX_ERR(0, 1056, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_kill", 1, 3, 3, i); __PYX_ERR(0, 1056, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1056, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1056, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 1056, __pyx_L3_error)
    }
    __pyx_v_glet = ((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)values[0]);
    __pyx_v_exception = values[1];
    __pyx_v_waiter = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_kill", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 1056, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("gevent._gevent_cgreenlet._kill", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_glet), __pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, 1, "glet", 0))) __PYX_ERR(0, 1056, __pyx_L1_error)
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet__kill(__pyx_self, __pyx_v_glet, __pyx_v_exception, __pyx_v_waiter);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet__kill(CYTHON_UNUSED PyObject *__pyx_self, struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_glet, PyObject *__pyx_v_exception, PyObject *__pyx_v_waiter) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_kill", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6gevent_17_gevent_cgreenlet__kill(__pyx_v_glet, __pyx_v_exception, __pyx_v_waiter, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1056, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet._kill", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":1069
 * 
 * 
 * def joinall(greenlets, timeout=None, raise_error=False, count=None):             # <<<<<<<<<<<<<<
 *     """
 *     Wait for the ``greenlets`` to finish.
*/

static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_3joinall(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6gevent_17_gevent_cgreenlet_joinall(PyObject *__pyx_v_greenlets, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_opt_args_6gevent_17_gevent_cgreenlet_joinall *__pyx_optional_args) {
  PyObject *__pyx_v_timeout = ((PyObject *)Py_None);
  PyObject *__pyx_v_raise_error = ((PyObject *)Py_False);
  PyObject *__pyx_v_count = ((PyObject *)Py_None);
  PyObject *__pyx_v_done = 0;
  PyObject *__pyx_v_obj = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  Py_ssize_t __pyx_t_8;
  PyObject *(*__pyx_t_9)(PyObject *);
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("joinall", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_timeout = __pyx_optional_args->timeout;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_raise_error = __pyx_optional_args->raise_error;
        if (__pyx_optional_args->__pyx_n > 2) {
          __pyx_v_count = __pyx_optional_args->count;
        }
      }
    }
  }

  /* "src/gevent/greenlet.py":1084
 *         expired.
 *     """
 *     if not raise_error:             # <<<<<<<<<<<<<<
 *         return wait(greenlets, timeout=timeout, count=count)
 * 
*/
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_raise_error); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 1084, __pyx_L1_error)
  __pyx_t_2 = (!__pyx_t_1);
  if (__pyx_t_2) {

    /* "src/gevent/greenlet.py":1085
 *     """
 *     if not raise_error:
 *         return wait(greenlets, timeout=timeout, count=count)             # <<<<<<<<<<<<<<
 * 
 *     done = []
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = NULL;
    __Pyx_INCREF(__pyx_v_6gevent_17_gevent_cgreenlet_wait);
    __pyx_t_5 = __pyx_v_6gevent_17_gevent_cgreenlet_wait; 
    __pyx_t_6 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      assert(__pyx_t_4);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
      __pyx_t_6 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_4, __pyx_v_greenlets};
      __pyx_t_7 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1085, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_timeout, __pyx_v_timeout, __pyx_t_7, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1085, __pyx_L1_error)
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_count, __pyx_v_count, __pyx_t_7, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 1085, __pyx_L1_error)
      __pyx_t_3 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_7);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1085, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "src/gevent/greenlet.py":1084
 *         expired.
 *     """
 *     if not raise_error:             # <<<<<<<<<<<<<<
 *         return wait(greenlets, timeout=timeout, count=count)
 * 
*/
  }

  /* "src/gevent/greenlet.py":1087
 *         return wait(greenlets, timeout=timeout, count=count)
 * 
 *     done = []             # <<<<<<<<<<<<<<
 *     for obj in iwait(greenlets, timeout=timeout, count=count):
 *         if getattr(obj, 'exception', None) is not None:
*/
  __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1087, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_done = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "src/gevent/greenlet.py":1088
 * 
 *     done = []
 *     for obj in iwait(greenlets, timeout=timeout, count=count):             # <<<<<<<<<<<<<<
 *         if getattr(obj, 'exception', None) is not None:
 *             if hasattr(obj, '_raise_exception'):
*/
  __pyx_t_5 = NULL;
  __Pyx_INCREF(__pyx_v_6gevent_17_gevent_cgreenlet_iwait);
  __pyx_t_7 = __pyx_v_6gevent_17_gevent_cgreenlet_iwait; 
  __pyx_t_6 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
    assert(__pyx_t_5);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
    __Pyx_INCREF(__pyx_t_5);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
    __pyx_t_6 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_5, __pyx_v_greenlets};
    __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1088, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_timeout, __pyx_v_timeout, __pyx_t_4, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1088, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_count, __pyx_v_count, __pyx_t_4, __pyx_callargs+2, 1) < (0)) __PYX_ERR(0, 1088, __pyx_L1_error)
    __pyx_t_3 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1088, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
    __pyx_t_7 = __pyx_t_3; __Pyx_INCREF(__pyx_t_7);
    __pyx_t_8 = 0;
    __pyx_t_9 = NULL;
  } else {
    __pyx_t_8 = -1; __pyx_t_7 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1088, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_9 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_7); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1088, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  for (;;) {
    if (likely(!__pyx_t_9)) {
      if (likely(PyList_CheckExact(__pyx_t_7))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_7);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1088, __pyx_L1_error)
          #endif
          if (__pyx_t_8 >= __pyx_temp) break;
        }
        __pyx_t_3 = __Pyx_PyList_GetItemRefFast(__pyx_t_7, __pyx_t_8, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_8;
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_7);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1088, __pyx_L1_error)
          #endif
          if (__pyx_t_8 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_7, __pyx_t_8));
        #else
        __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_7, __pyx_t_8);
        #endif
        ++__pyx_t_8;
      }
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1088, __pyx_L1_error)
    } else {
      __pyx_t_3 = __pyx_t_9(__pyx_t_7);
      if (unlikely(!__pyx_t_3)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 1088, __pyx_L1_error)
          PyErr_Clear();
        }
        break;
      }
    }
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_XDECREF_SET(__pyx_v_obj, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "src/gevent/greenlet.py":1089
 *     done = []
 *     for obj in iwait(greenlets, timeout=timeout, count=count):
 *         if getattr(obj, 'exception', None) is not None:             # <<<<<<<<<<<<<<
 *             if hasattr(obj, '_raise_exception'):
 *                 obj._raise_exception()
*/
    __pyx_t_3 = __Pyx_GetAttr3(__pyx_v_obj, __pyx_mstate_global->__pyx_n_u_exception, Py_None); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1089, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = (__pyx_t_3 != Py_None);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_2) {

      /* "src/gevent/greenlet.py":1090
 *     for obj in iwait(greenlets, timeout=timeout, count=count):
 *         if getattr(obj, 'exception', None) is not None:
 *             if hasattr(obj, '_raise_exception'):             # <<<<<<<<<<<<<<
 *                 obj._raise_exception()
 *             else:
*/
      __pyx_t_2 = __Pyx_HasAttr(__pyx_v_obj, __pyx_mstate_global->__pyx_n_u_raise_exception); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1090, __pyx_L1_error)
      if (likely(__pyx_t_2)) {

        /* "src/gevent/greenlet.py":1091
 *         if getattr(obj, 'exception', None) is not None:
 *             if hasattr(obj, '_raise_exception'):
 *                 obj._raise_exception()             # <<<<<<<<<<<<<<
 *             else:
 *                 raise obj.exception
*/
        __pyx_t_4 = __pyx_v_obj;
        __Pyx_INCREF(__pyx_t_4);
        __pyx_t_6 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
          __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_raise_exception, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1091, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "src/gevent/greenlet.py":1090
 *     for obj in iwait(greenlets, timeout=timeout, count=count):
 *         if getattr(obj, 'exception', None) is not None:
 *             if hasattr(obj, '_raise_exception'):             # <<<<<<<<<<<<<<
 *                 obj._raise_exception()
 *             else:
*/
        goto __pyx_L7;
      }

      /* "src/gevent/greenlet.py":1093
 *                 obj._raise_exception()
 *             else:
 *                 raise obj.exception             # <<<<<<<<<<<<<<
 *         done.append(obj)
 *     return done
*/
      /*else*/ {
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_obj, __pyx_mstate_global->__pyx_n_u_exception); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1093, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_Raise(__pyx_t_3, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __PYX_ERR(0, 1093, __pyx_L1_error)
      }
      __pyx_L7:;

      /* "src/gevent/greenlet.py":1089
 *     done = []
 *     for obj in iwait(greenlets, timeout=timeout, count=count):
 *         if getattr(obj, 'exception', None) is not None:             # <<<<<<<<<<<<<<
 *             if hasattr(obj, '_raise_exception'):
 *                 obj._raise_exception()
*/
    }

    /* "src/gevent/greenlet.py":1094
 *             else:
 *                 raise obj.exception
 *         done.append(obj)             # <<<<<<<<<<<<<<
 *     return done
 * 
*/
    __pyx_t_10 = __Pyx_PyList_Append(__pyx_v_done, __pyx_v_obj); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 1094, __pyx_L1_error)

    /* "src/gevent/greenlet.py":1088
 * 
 *     done = []
 *     for obj in iwait(greenlets, timeout=timeout, count=count):             # <<<<<<<<<<<<<<
 *         if getattr(obj, 'exception', None) is not None:
 *             if hasattr(obj, '_raise_exception'):
*/
  }
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "src/gevent/greenlet.py":1095
 *                 raise obj.exception
 *         done.append(obj)
 *     return done             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_done);
  __pyx_r = __pyx_v_done;
  goto __pyx_L0;

  /* "src/gevent/greenlet.py":1069
 * 
 * 
 * def joinall(greenlets, timeout=None, raise_error=False, count=None):             # <<<<<<<<<<<<<<
 *     """
 *     Wait for the ``greenlets`` to finish.
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.joinall", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_done);
  __Pyx_XDECREF(__pyx_v_obj);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_3joinall(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_17_gevent_cgreenlet_2joinall, "joinall(greenlets, timeout=None, raise_error=False, count=None)\n\nWait for the ``greenlets`` to finish.\n\n:param greenlets: A sequence (supporting :func:`len`) of greenlets to wait for.\n:keyword float timeout: If given, the maximum number of seconds to wait.\n:keyword bool raise_error: If True, immediately raise the first exception\n    encountered in any greenlet. If False (default), exceptions are\n    stored in the greenlet and not raised.\n:keyword int count: If not `None`, then a number specifying the maximum number\n    of greenlets to wait for. If ``None`` (the default), all greenlets\n    are waited for.\n:return: A sequence of the greenlets that finished before the timeout (if any)\n    expired.");
static PyMethodDef __pyx_mdef_6gevent_17_gevent_cgreenlet_3joinall = {"joinall", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6gevent_17_gevent_cgreenlet_3joinall, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6gevent_17_gevent_cgreenlet_2joinall};
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_3joinall(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_greenlets = 0;
  PyObject *__pyx_v_timeout = 0;
  PyObject *__pyx_v_raise_error = 0;
  PyObject *__pyx_v_count = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("joinall (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_greenlets,&__pyx_mstate_global->__pyx_n_u_timeout,&__pyx_mstate_global->__pyx_n_u_raise_error,&__pyx_mstate_global->__pyx_n_u_count,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 1069, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 1069, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 1069, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1069, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1069, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "joinall", 0) < (0)) __PYX_ERR(0, 1069, __pyx_L3_error)
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_False));
      if (!values[3]) values[3] = __Pyx_NewRef(((PyObject *)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("joinall", 0, 1, 4, i); __PYX_ERR(0, 1069, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 1069, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 1069, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1069, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1069, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_False));
      if (!values[3]) values[3] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_greenlets = values[0];
    __pyx_v_timeout = values[1];
    __pyx_v_raise_error = values[2];
    __pyx_v_count = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("joinall", 0, 1, 4, __pyx_nargs); __PYX_ERR(0, 1069, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.joinall", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_2joinall(__pyx_self, __pyx_v_greenlets, __pyx_v_timeout, __pyx_v_raise_error, __pyx_v_count);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_2joinall(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_greenlets, PyObject *__pyx_v_timeout, PyObject *__pyx_v_raise_error, PyObject *__pyx_v_count) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_6gevent_17_gevent_cgreenlet_joinall __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("joinall", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 3;
  __pyx_t_2.timeout = __pyx_v_timeout;
  __pyx_t_2.raise_error = __pyx_v_raise_error;
  __pyx_t_2.count = __pyx_v_count;
  __pyx_t_1 = __pyx_f_6gevent_17_gevent_cgreenlet_joinall(__pyx_v_greenlets, 1, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1069, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.joinall", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":1098
 * 
 * 
 * def _killall3(greenlets, exception, waiter):             # <<<<<<<<<<<<<<
 *     diehards = []
 *     for g in greenlets:
*/

static PyObject *__pyx_f_6gevent_17_gevent_cgreenlet__killall3(PyObject *__pyx_v_greenlets, PyObject *__pyx_v_exception, PyObject *__pyx_v_waiter) {
  PyObject *__pyx_v_diehards = 0;
  PyObject *__pyx_v_g = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  size_t __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  int __pyx_t_17;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_killall3", 0);

  /* "src/gevent/greenlet.py":1099
 * 
 * def _killall3(greenlets, exception, waiter):
 *     diehards = []             # <<<<<<<<<<<<<<
 *     for g in greenlets:
 *         if not g.dead:
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1099, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_diehards = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "src/gevent/greenlet.py":1100
 * def _killall3(greenlets, exception, waiter):
 *     diehards = []
 *     for g in greenlets:             # <<<<<<<<<<<<<<
 *         if not g.dead:
 *             try:
*/
  if (unlikely(__pyx_v_greenlets == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 1100, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_v_greenlets; __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
      #if !CYTHON_ASSUME_SAFE_SIZE
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1100, __pyx_L1_error)
      #endif
      if (__pyx_t_2 >= __pyx_temp) break;
    }
    __pyx_t_3 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_2, __Pyx_ReferenceSharing_OwnStrongReference);
    ++__pyx_t_2;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1100, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_XDECREF_SET(__pyx_v_g, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "src/gevent/greenlet.py":1101
 *     diehards = []
 *     for g in greenlets:
 *         if not g.dead:             # <<<<<<<<<<<<<<
 *             try:
 *                 g.throw(exception)
*/
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_g, __pyx_mstate_global->__pyx_n_u_dead); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1101, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 1101, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_5 = (!__pyx_t_4);
    if (__pyx_t_5) {

      /* "src/gevent/greenlet.py":1102
 *     for g in greenlets:
 *         if not g.dead:
 *             try:             # <<<<<<<<<<<<<<
 *                 g.throw(exception)
 *             except: # pylint:disable=bare-except, undefined-variable
*/
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_7);
        __Pyx_XGOTREF(__pyx_t_8);
        /*try:*/ {

          /* "src/gevent/greenlet.py":1103
 *         if not g.dead:
 *             try:
 *                 g.throw(exception)             # <<<<<<<<<<<<<<
 *             except: # pylint:disable=bare-except, undefined-variable
 *                 get_my_hub(g).handle_error(g, *sys_exc_info())
*/
          __pyx_t_9 = __pyx_v_g;
          __Pyx_INCREF(__pyx_t_9);
          __pyx_t_10 = 0;
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_v_exception};
            __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_throw, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
            if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1103, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_3);
          }
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

          /* "src/gevent/greenlet.py":1102
 *     for g in greenlets:
 *         if not g.dead:
 *             try:             # <<<<<<<<<<<<<<
 *                 g.throw(exception)
 *             except: # pylint:disable=bare-except, undefined-variable
*/
        }
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L13_try_end;
        __pyx_L6_error:;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

        /* "src/gevent/greenlet.py":1104
 *             try:
 *                 g.throw(exception)
 *             except: # pylint:disable=bare-except, undefined-variable             # <<<<<<<<<<<<<<
 *                 get_my_hub(g).handle_error(g, *sys_exc_info())
 *             if not g.dead:
*/
        /*except:*/ {
          __Pyx_AddTraceback("gevent._gevent_cgreenlet._killall3", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_9, &__pyx_t_11) < 0) __PYX_ERR(0, 1104, __pyx_L8_except_error)
          __Pyx_XGOTREF(__pyx_t_3);
          __Pyx_XGOTREF(__pyx_t_9);
          __Pyx_XGOTREF(__pyx_t_11);

          /* "src/gevent/greenlet.py":1105
 *                 g.throw(exception)
 *             except: # pylint:disable=bare-except, undefined-variable
 *                 get_my_hub(g).handle_error(g, *sys_exc_info())             # <<<<<<<<<<<<<<
 *             if not g.dead:
 *                 diehards.append(g)
*/
          if (!(likely(((__pyx_v_g) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_g, __pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_greenlet))))) __PYX_ERR(0, 1105, __pyx_L8_except_error)
          __pyx_t_12 = ((PyObject *)__pyx_f_6gevent_17_gevent_cgreenlet_get_my_hub(((PyGreenlet *)__pyx_v_g))); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1105, __pyx_L8_except_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_mstate_global->__pyx_n_u_handle_error); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1105, __pyx_L8_except_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_t_12 = PyTuple_New(1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1105, __pyx_L8_except_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_INCREF(__pyx_v_g);
          __Pyx_GIVEREF(__pyx_v_g);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_v_g) != (0)) __PYX_ERR(0, 1105, __pyx_L8_except_error);
          __pyx_t_15 = NULL;
          __Pyx_INCREF(__pyx_v_6gevent_17_gevent_cgreenlet_sys_exc_info);
          __pyx_t_16 = __pyx_v_6gevent_17_gevent_cgreenlet_sys_exc_info; 
          __pyx_t_10 = 1;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_16))) {
            __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_16);
            assert(__pyx_t_15);
            PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_16);
            __Pyx_INCREF(__pyx_t_15);
            __Pyx_INCREF(__pyx__function);
            __Pyx_DECREF_SET(__pyx_t_16, __pyx__function);
            __pyx_t_10 = 0;
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_15, NULL};
            __pyx_t_14 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_16, __pyx_callargs+__pyx_t_10, (1-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
            __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
            if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1105, __pyx_L8_except_error)
            __Pyx_GOTREF(__pyx_t_14);
          }
          __pyx_t_16 = __Pyx_PySequence_Tuple(__pyx_t_14); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1105, __pyx_L8_except_error)
          __Pyx_GOTREF(__pyx_t_16);
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __pyx_t_14 = PyNumber_Add(__pyx_t_12, __pyx_t_16); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1105, __pyx_L8_except_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
          __pyx_t_16 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_t_14, NULL); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1105, __pyx_L8_except_error)
          __Pyx_GOTREF(__pyx_t_16);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          goto __pyx_L7_exception_handled;
        }

        /* "src/gevent/greenlet.py":1102
 *     for g in greenlets:
 *         if not g.dead:
 *             try:             # <<<<<<<<<<<<<<
 *                 g.throw(exception)
 *             except: # pylint:disable=bare-except, undefined-variable
*/
        __pyx_L8_except_error:;
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
        goto __pyx_L1_error;
        __pyx_L7_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
        __pyx_L13_try_end:;
      }

      /* "src/gevent/greenlet.py":1106
 *             except: # pylint:disable=bare-except, undefined-variable
 *                 get_my_hub(g).handle_error(g, *sys_exc_info())
 *             if not g.dead:             # <<<<<<<<<<<<<<
 *                 diehards.append(g)
 *     waiter.switch(diehards)
*/
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_g, __pyx_mstate_global->__pyx_n_u_dead); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1106, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1106, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_4 = (!__pyx_t_5);
      if (__pyx_t_4) {

        /* "src/gevent/greenlet.py":1107
 *                 get_my_hub(g).handle_error(g, *sys_exc_info())
 *             if not g.dead:
 *                 diehards.append(g)             # <<<<<<<<<<<<<<
 *     waiter.switch(diehards)
 * 
*/
        __pyx_t_17 = __Pyx_PyList_Append(__pyx_v_diehards, __pyx_v_g); if (unlikely(__pyx_t_17 == ((int)-1))) __PYX_ERR(0, 1107, __pyx_L1_error)

        /* "src/gevent/greenlet.py":1106
 *             except: # pylint:disable=bare-except, undefined-variable
 *                 get_my_hub(g).handle_error(g, *sys_exc_info())
 *             if not g.dead:             # <<<<<<<<<<<<<<
 *                 diehards.append(g)
 *     waiter.switch(diehards)
*/
      }

      /* "src/gevent/greenlet.py":1101
 *     diehards = []
 *     for g in greenlets:
 *         if not g.dead:             # <<<<<<<<<<<<<<
 *             try:
 *                 g.throw(exception)
*/
    }

    /* "src/gevent/greenlet.py":1100
 * def _killall3(greenlets, exception, waiter):
 *     diehards = []
 *     for g in greenlets:             # <<<<<<<<<<<<<<
 *         if not g.dead:
 *             try:
*/
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "src/gevent/greenlet.py":1108
 *             if not g.dead:
 *                 diehards.append(g)
 *     waiter.switch(diehards)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_11 = __pyx_v_waiter;
  __Pyx_INCREF(__pyx_t_11);
  __pyx_t_10 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_v_diehards};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_switch, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1108, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "src/gevent/greenlet.py":1098
 * 
 * 
 * def _killall3(greenlets, exception, waiter):             # <<<<<<<<<<<<<<
 *     diehards = []
 *     for g in greenlets:
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet._killall3", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_diehards);
  __Pyx_XDECREF(__pyx_v_g);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":1111
 * 
 * 
 * def _killall(greenlets, exception):             # <<<<<<<<<<<<<<
 *     for g in greenlets:
 *         if not g.dead:
*/

static PyObject *__pyx_f_6gevent_17_gevent_cgreenlet__killall(PyObject *__pyx_v_greenlets, PyObject *__pyx_v_exception) {
  PyObject *__pyx_v_g = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  size_t __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_killall", 0);

  /* "src/gevent/greenlet.py":1112
 * 
 * def _killall(greenlets, exception):
 *     for g in greenlets:             # <<<<<<<<<<<<<<
 *         if not g.dead:
 *             try:
*/
  if (unlikely(__pyx_v_greenlets == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 1112, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_v_greenlets; __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
      #if !CYTHON_ASSUME_SAFE_SIZE
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1112, __pyx_L1_error)
      #endif
      if (__pyx_t_2 >= __pyx_temp) break;
    }
    __pyx_t_3 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_2, __Pyx_ReferenceSharing_OwnStrongReference);
    ++__pyx_t_2;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1112, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_XDECREF_SET(__pyx_v_g, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "src/gevent/greenlet.py":1113
 * def _killall(greenlets, exception):
 *     for g in greenlets:
 *         if not g.dead:             # <<<<<<<<<<<<<<
 *             try:
 *                 g.throw(exception)
*/
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_g, __pyx_mstate_global->__pyx_n_u_dead); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1113, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 1113, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_5 = (!__pyx_t_4);
    if (__pyx_t_5) {

      /* "src/gevent/greenlet.py":1114
 *     for g in greenlets:
 *         if not g.dead:
 *             try:             # <<<<<<<<<<<<<<
 *                 g.throw(exception)
 *             except: # pylint:disable=bare-except, undefined-variable
*/
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_7);
        __Pyx_XGOTREF(__pyx_t_8);
        /*try:*/ {

          /* "src/gevent/greenlet.py":1115
 *         if not g.dead:
 *             try:
 *                 g.throw(exception)             # <<<<<<<<<<<<<<
 *             except: # pylint:disable=bare-except, undefined-variable
 *                 get_my_hub(g).handle_error(g, *sys_exc_info())
*/
          __pyx_t_9 = __pyx_v_g;
          __Pyx_INCREF(__pyx_t_9);
          __pyx_t_10 = 0;
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_v_exception};
            __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_throw, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
            if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1115, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_3);
          }
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

          /* "src/gevent/greenlet.py":1114
 *     for g in greenlets:
 *         if not g.dead:
 *             try:             # <<<<<<<<<<<<<<
 *                 g.throw(exception)
 *             except: # pylint:disable=bare-except, undefined-variable
*/
        }
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L13_try_end;
        __pyx_L6_error:;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

        /* "src/gevent/greenlet.py":1116
 *             try:
 *                 g.throw(exception)
 *             except: # pylint:disable=bare-except, undefined-variable             # <<<<<<<<<<<<<<
 *                 get_my_hub(g).handle_error(g, *sys_exc_info())
 * 
*/
        /*except:*/ {
          __Pyx_AddTraceback("gevent._gevent_cgreenlet._killall", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_9, &__pyx_t_11) < 0) __PYX_ERR(0, 1116, __pyx_L8_except_error)
          __Pyx_XGOTREF(__pyx_t_3);
          __Pyx_XGOTREF(__pyx_t_9);
          __Pyx_XGOTREF(__pyx_t_11);

          /* "src/gevent/greenlet.py":1117
 *                 g.throw(exception)
 *             except: # pylint:disable=bare-except, undefined-variable
 *                 get_my_hub(g).handle_error(g, *sys_exc_info())             # <<<<<<<<<<<<<<
 * 
 * 
*/
          if (!(likely(((__pyx_v_g) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_g, __pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_greenlet))))) __PYX_ERR(0, 1117, __pyx_L8_except_error)
          __pyx_t_12 = ((PyObject *)__pyx_f_6gevent_17_gevent_cgreenlet_get_my_hub(((PyGreenlet *)__pyx_v_g))); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1117, __pyx_L8_except_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_mstate_global->__pyx_n_u_handle_error); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1117, __pyx_L8_except_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_t_12 = PyTuple_New(1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1117, __pyx_L8_except_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_INCREF(__pyx_v_g);
          __Pyx_GIVEREF(__pyx_v_g);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_v_g) != (0)) __PYX_ERR(0, 1117, __pyx_L8_except_error);
          __pyx_t_15 = NULL;
          __Pyx_INCREF(__pyx_v_6gevent_17_gevent_cgreenlet_sys_exc_info);
          __pyx_t_16 = __pyx_v_6gevent_17_gevent_cgreenlet_sys_exc_info; 
          __pyx_t_10 = 1;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_16))) {
            __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_16);
            assert(__pyx_t_15);
            PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_16);
            __Pyx_INCREF(__pyx_t_15);
            __Pyx_INCREF(__pyx__function);
            __Pyx_DECREF_SET(__pyx_t_16, __pyx__function);
            __pyx_t_10 = 0;
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_15, NULL};
            __pyx_t_14 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_16, __pyx_callargs+__pyx_t_10, (1-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
            __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
            if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1117, __pyx_L8_except_error)
            __Pyx_GOTREF(__pyx_t_14);
          }
          __pyx_t_16 = __Pyx_PySequence_Tuple(__pyx_t_14); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1117, __pyx_L8_except_error)
          __Pyx_GOTREF(__pyx_t_16);
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __pyx_t_14 = PyNumber_Add(__pyx_t_12, __pyx_t_16); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1117, __pyx_L8_except_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
          __pyx_t_16 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_t_14, NULL); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1117, __pyx_L8_except_error)
          __Pyx_GOTREF(__pyx_t_16);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          goto __pyx_L7_exception_handled;
        }

        /* "src/gevent/greenlet.py":1114
 *     for g in greenlets:
 *         if not g.dead:
 *             try:             # <<<<<<<<<<<<<<
 *                 g.throw(exception)
 *             except: # pylint:disable=bare-except, undefined-variable
*/
        __pyx_L8_except_error:;
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
        goto __pyx_L1_error;
        __pyx_L7_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
        __pyx_L13_try_end:;
      }

      /* "src/gevent/greenlet.py":1113
 * def _killall(greenlets, exception):
 *     for g in greenlets:
 *         if not g.dead:             # <<<<<<<<<<<<<<
 *             try:
 *                 g.throw(exception)
*/
    }

    /* "src/gevent/greenlet.py":1112
 * 
 * def _killall(greenlets, exception):
 *     for g in greenlets:             # <<<<<<<<<<<<<<
 *         if not g.dead:
 *             try:
*/
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "src/gevent/greenlet.py":1111
 * 
 * 
 * def _killall(greenlets, exception):             # <<<<<<<<<<<<<<
 *     for g in greenlets:
 *         if not g.dead:
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet._killall", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_g);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":1120
 * 
 * 
 * def _call_spawn_callbacks(gr):             # <<<<<<<<<<<<<<
 *     if _spawn_callbacks is not None:
 *         for cb in _spawn_callbacks:
*/

static void __pyx_f_6gevent_17_gevent_cgreenlet__call_spawn_callbacks(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *__pyx_v_gr) {
  PyObject *__pyx_v_cb = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  size_t __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_call_spawn_callbacks", 0);

  /* "src/gevent/greenlet.py":1121
 * 
 * def _call_spawn_callbacks(gr):
 *     if _spawn_callbacks is not None:             # <<<<<<<<<<<<<<
 *         for cb in _spawn_callbacks:
 *             cb(gr)
*/
  __pyx_t_1 = (__pyx_v_6gevent_17_gevent_cgreenlet__spawn_callbacks != ((PyObject*)Py_None));
  if (__pyx_t_1) {

    /* "src/gevent/greenlet.py":1122
 * def _call_spawn_callbacks(gr):
 *     if _spawn_callbacks is not None:
 *         for cb in _spawn_callbacks:             # <<<<<<<<<<<<<<
 *             cb(gr)
 * 
*/
    __pyx_t_3 = 0;
    __pyx_t_6 = __Pyx_set_iterator(__pyx_v_6gevent_17_gevent_cgreenlet__spawn_callbacks, 1, (&__pyx_t_4), (&__pyx_t_5)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1122, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_2);
    __pyx_t_2 = __pyx_t_6;
    __pyx_t_6 = 0;
    while (1) {
      __pyx_t_7 = __Pyx_set_iter_next(__pyx_t_2, __pyx_t_4, &__pyx_t_3, &__pyx_t_6, __pyx_t_5);
      if (unlikely(__pyx_t_7 == 0)) break;
      if (unlikely(__pyx_t_7 == -1)) __PYX_ERR(0, 1122, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_XDECREF_SET(__pyx_v_cb, __pyx_t_6);
      __pyx_t_6 = 0;

      /* "src/gevent/greenlet.py":1123
 *     if _spawn_callbacks is not None:
 *         for cb in _spawn_callbacks:
 *             cb(gr)             # <<<<<<<<<<<<<<
 * 
 * 
*/
      __pyx_t_8 = NULL;
      __Pyx_INCREF(__pyx_v_cb);
      __pyx_t_9 = __pyx_v_cb; 
      __pyx_t_10 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_9);
        assert(__pyx_t_8);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_9, __pyx__function);
        __pyx_t_10 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_8, ((PyObject *)__pyx_v_gr)};
        __pyx_t_6 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_9, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1123, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "src/gevent/greenlet.py":1121
 * 
 * def _call_spawn_callbacks(gr):
 *     if _spawn_callbacks is not None:             # <<<<<<<<<<<<<<
 *         for cb in _spawn_callbacks:
 *             cb(gr)
*/
  }

  /* "src/gevent/greenlet.py":1120
 * 
 * 
 * def _call_spawn_callbacks(gr):             # <<<<<<<<<<<<<<
 *     if _spawn_callbacks is not None:
 *         for cb in _spawn_callbacks:
*/

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet._call_spawn_callbacks", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cb);
  __Pyx_RefNannyFinishContext();
}

/* "src/gevent/greenlet.py":1129
 * 
 * 
 * def killall(greenlets, exception=GreenletExit, block=True, timeout=None):             # <<<<<<<<<<<<<<
 *     """
 *     Forceably terminate all the *greenlets* by causing them to raise *exception*.
*/

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_12__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__Pyx_CyFunction_Defaults(struct __pyx_defaults, __pyx_self)->arg0);
  __Pyx_GIVEREF(__Pyx_CyFunction_Defaults(struct __pyx_defaults, __pyx_self)->arg0);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __Pyx_CyFunction_Defaults(struct __pyx_defaults, __pyx_self)->arg0) != (0)) __PYX_ERR(0, 1129, __pyx_L1_error);
  __Pyx_INCREF(((PyObject*)Py_True));
  __Pyx_GIVEREF(((PyObject*)Py_True));
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, ((PyObject*)Py_True)) != (0)) __PYX_ERR(0, 1129, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, Py_None) != (0)) __PYX_ERR(0, 1129, __pyx_L1_error);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1) != (0)) __PYX_ERR(0, 1129, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, Py_None) != (0)) __PYX_ERR(0, 1129, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_5killall(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6gevent_17_gevent_cgreenlet_4killall, "killall(greenlets, exception=GreenletExit, block=True, timeout=None)\n\nForceably terminate all the *greenlets* by causing them to raise *exception*.\n\n.. caution:: Use care when killing greenlets. If they are not prepared for exceptions,\n   this could result in corrupted state.\n\n:param greenlets: A **bounded** iterable of the non-None greenlets to terminate.\n   *All* the items in this iterable must be greenlets that belong to the same hub,\n   which should be the hub for this current thread. If this is a generator or iterator\n   that switches greenlets, the results are undefined.\n:keyword exception: The type of exception to raise in the greenlets. By default this is\n    :class:`GreenletExit`.\n:keyword bool block: If True (the default) then this function only returns when all the\n    greenlets are dead; the current greenlet is unscheduled during that process.\n    If greenlets ignore the initial exception raised in them,\n    then they will be joined (with :func:`gevent.joinall`) and allowed to die naturally.\n    If False, this function returns immediately and greenlets will raise\n    the exception asynchronously.\n:keyword float timeout: A time in seconds to wait for greenlets to die. If given, it is\n    only honored when ``block`` is True.\n:raise Timeout: If blocking and a timeout is given that elapses before\n    all the greenlets are dead.\n\n.. versionchanged:: 1.1a2\n    *greenlets* can be any iterable of greenlets, like an iterator or a set.\n    Previously it had to be a list or tuple.\n.. versionchanged:: 1.5a3\n    Any :class:`Greenlet` in the *greenlets* list that hadn't been switched to before\n    calling this method will never be switched to. This makes this function\n    behave like :meth:`Greenlet.kill`. This does not apply to raw greenlets.\n.. versionchanged:: 1.5a3\n    Now accepts raw greenlets created by :func:`gevent.spawn_raw`.");
static PyMethodDef __pyx_mdef_6gevent_17_gevent_cgreenlet_5killall = {"killall", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6gevent_17_gevent_cgreenlet_5killall, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6gevent_17_gevent_cgreenlet_4killall};
static PyObject *__pyx_pw_6gevent_17_gevent_cgreenlet_5killall(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_greenlets = 0;
  PyObject *__pyx_v_exception = 0;
  PyObject *__pyx_v_block = 0;
  PyObject *__pyx_v_timeout = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("killall (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_greenlets,&__pyx_mstate_global->__pyx_n_u_exception,&__pyx_mstate_global->__pyx_n_u_block,&__pyx_mstate_global->__pyx_n_u_timeout,0};
    struct __pyx_defaults *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(struct __pyx_defaults, __pyx_self);
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 1129, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 1129, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 1129, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1129, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1129, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "killall", 0) < (0)) __PYX_ERR(0, 1129, __pyx_L3_error)
      if (!values[1]) values[1] = __Pyx_NewRef(__pyx_dynamic_args->arg0);
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)((PyObject*)Py_True)));
      if (!values[3]) values[3] = __Pyx_NewRef(((PyObject *)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("killall", 0, 1, 4, i); __PYX_ERR(0, 1129, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 1129, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 1129, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1129, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1129, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[1]) values[1] = __Pyx_NewRef(__pyx_dynamic_args->arg0);
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)((PyObject*)Py_True)));
      if (!values[3]) values[3] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_greenlets = values[0];
    __pyx_v_exception = values[1];
    __pyx_v_block = values[2];
    __pyx_v_timeout = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("killall", 0, 1, 4, __pyx_nargs); __PYX_ERR(0, 1129, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.killall", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6gevent_17_gevent_cgreenlet_4killall(__pyx_self, __pyx_v_greenlets, __pyx_v_exception, __pyx_v_block, __pyx_v_timeout);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_17_gevent_cgreenlet_4killall(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_greenlets, PyObject *__pyx_v_exception, PyObject *__pyx_v_block, PyObject *__pyx_v_timeout) {
  PyObject *__pyx_v_need_killed = NULL;
  PyObject *__pyx_v_glet = NULL;
  PyObject *__pyx_v_cancel = NULL;
  PyObject *__pyx_v_loop = NULL;
  struct __pyx_obj_6gevent_16_gevent_c_waiter_Waiter *__pyx_v_waiter = NULL;
  PyObject *__pyx_v_t = NULL;
  PyObject *__pyx_v_alive = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  size_t __pyx_t_10;
  int __pyx_t_11;
  int __pyx_t_12;
  int __pyx_t_13;
  int __pyx_t_14;
  int __pyx_t_15;
  char const *__pyx_t_16;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("killall", 0);

  /* "src/gevent/greenlet.py":1164
 *     """
 * 
 *     need_killed = []             # <<<<<<<<<<<<<<
 *     for glet in greenlets:
 *         # Quick pass through to prevent any greenlet from
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_need_killed = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "src/gevent/greenlet.py":1165
 * 
 *     need_killed = []
 *     for glet in greenlets:             # <<<<<<<<<<<<<<
 *         # Quick pass through to prevent any greenlet from
 *         # actually being switched to if it hasn't already.
*/
  if (likely(PyList_CheckExact(__pyx_v_greenlets)) || PyTuple_CheckExact(__pyx_v_greenlets)) {
    __pyx_t_1 = __pyx_v_greenlets; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_greenlets); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1165, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1165, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1165, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        __pyx_t_4 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_2, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_2;
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1165, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2));
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2);
        #endif
        ++__pyx_t_2;
      }
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1165, __pyx_L1_error)
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 1165, __pyx_L1_error)
          PyErr_Clear();
        }
        break;
      }
    }
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_XDECREF_SET(__pyx_v_glet, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "src/gevent/greenlet.py":1173
 *         # We don't use glet.kill() here because we don't want to schedule
 *         # any callbacks in the loop; we're about to handle that more directly.
 *         try:             # <<<<<<<<<<<<<<
 *             cancel = glet._maybe_kill_before_start
 *         except AttributeError:
*/
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);
      /*try:*/ {

        /* "src/gevent/greenlet.py":1174
 *         # any callbacks in the loop; we're about to handle that more directly.
 *         try:
 *             cancel = glet._maybe_kill_before_start             # <<<<<<<<<<<<<<
 *         except AttributeError:
 *             need_killed.append(glet)
*/
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_glet, __pyx_mstate_global->__pyx_n_u_maybe_kill_before_start); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1174, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_XDECREF_SET(__pyx_v_cancel, __pyx_t_4);
        __pyx_t_4 = 0;

        /* "src/gevent/greenlet.py":1173
 *         # We don't use glet.kill() here because we don't want to schedule
 *         # any callbacks in the loop; we're about to handle that more directly.
 *         try:             # <<<<<<<<<<<<<<
 *             cancel = glet._maybe_kill_before_start
 *         except AttributeError:
*/
      }

      /* "src/gevent/greenlet.py":1178
 *             need_killed.append(glet)
 *         else:
 *             if not cancel(exception):             # <<<<<<<<<<<<<<
 *                 need_killed.append(glet)
 * 
*/
      /*else:*/ {
        __pyx_t_8 = NULL;
        __Pyx_INCREF(__pyx_v_cancel);
        __pyx_t_9 = __pyx_v_cancel; 
        __pyx_t_10 = 1;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_9))) {
          __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_9);
          assert(__pyx_t_8);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_9, __pyx__function);
          __pyx_t_10 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_v_exception};
          __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_9, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1178, __pyx_L7_except_error)
          __Pyx_GOTREF(__pyx_t_4);
        }
        __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 1178, __pyx_L7_except_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_12 = (!__pyx_t_11);
        if (__pyx_t_12) {

          /* "src/gevent/greenlet.py":1179
 *         else:
 *             if not cancel(exception):
 *                 need_killed.append(glet)             # <<<<<<<<<<<<<<
 * 
 *     if not need_killed:
*/
          __pyx_t_13 = __Pyx_PyList_Append(__pyx_v_need_killed, __pyx_v_glet); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 1179, __pyx_L7_except_error)

          /* "src/gevent/greenlet.py":1178
 *             need_killed.append(glet)
 *         else:
 *             if not cancel(exception):             # <<<<<<<<<<<<<<
 *                 need_killed.append(glet)
 * 
*/
        }
      }
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L12_try_end;
      __pyx_L5_error:;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "src/gevent/greenlet.py":1175
 *         try:
 *             cancel = glet._maybe_kill_before_start
 *         except AttributeError:             # <<<<<<<<<<<<<<
 *             need_killed.append(glet)
 *         else:
*/
      __pyx_t_14 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_AttributeError))));
      if (__pyx_t_14) {
        __Pyx_AddTraceback("gevent._gevent_cgreenlet.killall", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_9, &__pyx_t_8) < 0) __PYX_ERR(0, 1175, __pyx_L7_except_error)
        __Pyx_XGOTREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_t_9);
        __Pyx_XGOTREF(__pyx_t_8);

        /* "src/gevent/greenlet.py":1176
 *             cancel = glet._maybe_kill_before_start
 *         except AttributeError:
 *             need_killed.append(glet)             # <<<<<<<<<<<<<<
 *         else:
 *             if not cancel(exception):
*/
        __pyx_t_13 = __Pyx_PyList_Append(__pyx_v_need_killed, __pyx_v_glet); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 1176, __pyx_L7_except_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L6_exception_handled;
      }
      goto __pyx_L7_except_error;

      /* "src/gevent/greenlet.py":1173
 *         # We don't use glet.kill() here because we don't want to schedule
 *         # any callbacks in the loop; we're about to handle that more directly.
 *         try:             # <<<<<<<<<<<<<<
 *             cancel = glet._maybe_kill_before_start
 *         except AttributeError:
*/
      __pyx_L7_except_error:;
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
      goto __pyx_L1_error;
      __pyx_L6_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
      __pyx_L12_try_end:;
    }

    /* "src/gevent/greenlet.py":1165
 * 
 *     need_killed = []
 *     for glet in greenlets:             # <<<<<<<<<<<<<<
 *         # Quick pass through to prevent any greenlet from
 *         # actually being switched to if it hasn't already.
*/
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "src/gevent/greenlet.py":1181
 *                 need_killed.append(glet)
 * 
 *     if not need_killed:             # <<<<<<<<<<<<<<
 *         return
 * 
*/
  {
    Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_need_killed);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 1181, __pyx_L1_error)
    __pyx_t_12 = (__pyx_temp != 0);
  }

  __pyx_t_11 = (!__pyx_t_12);
  if (__pyx_t_11) {

    /* "src/gevent/greenlet.py":1182
 * 
 *     if not need_killed:
 *         return             # <<<<<<<<<<<<<<
 * 
 *     loop = glet.loop # pylint:disable=undefined-loop-variable
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "src/gevent/greenlet.py":1181
 *                 need_killed.append(glet)
 * 
 *     if not need_killed:             # <<<<<<<<<<<<<<
 *         return
 * 
*/
  }

  /* "src/gevent/greenlet.py":1184
 *         return
 * 
 *     loop = glet.loop # pylint:disable=undefined-loop-variable             # <<<<<<<<<<<<<<
 *     if block:
 *         waiter = Waiter() # pylint:disable=undefined-variable
*/
  if (unlikely(!__pyx_v_glet)) { __Pyx_RaiseUnboundLocalError("glet"); __PYX_ERR(0, 1184, __pyx_L1_error) }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_glet, __pyx_mstate_global->__pyx_n_u_loop); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1184, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_loop = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "src/gevent/greenlet.py":1185
 * 
 *     loop = glet.loop # pylint:disable=undefined-loop-variable
 *     if block:             # <<<<<<<<<<<<<<
 *         waiter = Waiter() # pylint:disable=undefined-variable
 *         loop.run_callback(_killall3, need_killed, exception, waiter)
*/
  __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_v_block); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 1185, __pyx_L1_error)
  if (__pyx_t_11) {

    /* "src/gevent/greenlet.py":1186
 *     loop = glet.loop # pylint:disable=undefined-loop-variable
 *     if block:
 *         waiter = Waiter() # pylint:disable=undefined-variable             # <<<<<<<<<<<<<<
 *         loop.run_callback(_killall3, need_killed, exception, waiter)
 *         t = Timeout._start_new_or_dummy(timeout)
*/
    __pyx_t_8 = NULL;
    __pyx_t_10 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6gevent_16_gevent_c_waiter_Waiter, __pyx_callargs+__pyx_t_10, (1-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1186, __pyx_L1_error)
      __Pyx_GOTREF((PyObject *)__pyx_t_1);
    }
    __pyx_v_waiter = ((struct __pyx_obj_6gevent_16_gevent_c_waiter_Waiter *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "src/gevent/greenlet.py":1187
 *     if block:
 *         waiter = Waiter() # pylint:disable=undefined-variable
 *         loop.run_callback(_killall3, need_killed, exception, waiter)             # <<<<<<<<<<<<<<
 *         t = Timeout._start_new_or_dummy(timeout)
 *         try:
*/
    __pyx_t_8 = __pyx_v_loop;
    __Pyx_INCREF(__pyx_t_8);
    __pyx_t_9 = __Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter(__pyx_f_6gevent_17_gevent_cgreenlet__killall3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1187, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_10 = 0;
    {
      PyObject *__pyx_callargs[5] = {__pyx_t_8, __pyx_t_9, __pyx_v_need_killed, __pyx_v_exception, ((PyObject *)__pyx_v_waiter)};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_run_callback, __pyx_callargs+__pyx_t_10, (5-__pyx_t_10) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1187, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "src/gevent/greenlet.py":1188
 *         waiter = Waiter() # pylint:disable=undefined-variable
 *         loop.run_callback(_killall3, need_killed, exception, waiter)
 *         t = Timeout._start_new_or_dummy(timeout)             # <<<<<<<<<<<<<<
 *         try:
 *             alive = waiter.get()
*/
    __pyx_t_9 = __pyx_v_6gevent_17_gevent_cgreenlet_Timeout;
    __Pyx_INCREF(__pyx_t_9);
    __pyx_t_10 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_v_timeout};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_start_new_or_dummy, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1188, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_v_t = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "src/gevent/greenlet.py":1189
 *         loop.run_callback(_killall3, need_killed, exception, waiter)
 *         t = Timeout._start_new_or_dummy(timeout)
 *         try:             # <<<<<<<<<<<<<<
 *             alive = waiter.get()
 *             if alive:
*/
    /*try:*/ {

      /* "src/gevent/greenlet.py":1190
 *         t = Timeout._start_new_or_dummy(timeout)
 *         try:
 *             alive = waiter.get()             # <<<<<<<<<<<<<<
 *             if alive:
 *                 joinall(alive, raise_error=False)
*/
      __pyx_t_1 = ((struct __pyx_vtabstruct_6gevent_16_gevent_c_waiter_Waiter *)__pyx_v_waiter->__pyx_vtab)->get(__pyx_v_waiter, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1190, __pyx_L20_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_alive = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "src/gevent/greenlet.py":1191
 *         try:
 *             alive = waiter.get()
 *             if alive:             # <<<<<<<<<<<<<<
 *                 joinall(alive, raise_error=False)
 *         finally:
*/
      __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_v_alive); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 1191, __pyx_L20_error)
      if (__pyx_t_11) {

        /* "src/gevent/greenlet.py":1192
 *             alive = waiter.get()
 *             if alive:
 *                 joinall(alive, raise_error=False)             # <<<<<<<<<<<<<<
 *         finally:
 *             t.cancel()
*/
        __pyx_t_9 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_joinall); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1192, __pyx_L20_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_10 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
          assert(__pyx_t_9);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_8, __pyx__function);
          __pyx_t_10 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_9, __pyx_v_alive};
          __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1192, __pyx_L20_error)
          __Pyx_GOTREF(__pyx_t_4);
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_raise_error, Py_False, __pyx_t_4, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1192, __pyx_L20_error)
          __pyx_t_1 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_8, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1192, __pyx_L20_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "src/gevent/greenlet.py":1191
 *         try:
 *             alive = waiter.get()
 *             if alive:             # <<<<<<<<<<<<<<
 *                 joinall(alive, raise_error=False)
 *         finally:
*/
      }
    }

    /* "src/gevent/greenlet.py":1194
 *                 joinall(alive, raise_error=False)
 *         finally:
 *             t.cancel()             # <<<<<<<<<<<<<<
 *     else:
 *         loop.run_callback(_killall, need_killed, exception)
*/
    /*finally:*/ {
      /*normal exit:*/{
        __pyx_t_8 = __pyx_v_t;
        __Pyx_INCREF(__pyx_t_8);
        __pyx_t_10 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
          __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_cancel, __pyx_callargs+__pyx_t_10, (1-__pyx_t_10) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1194, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L21;
      }
      __pyx_L20_error:;
      /*exception exit:*/{
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __pyx_t_7 = 0; __pyx_t_6 = 0; __pyx_t_5 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
         __Pyx_ExceptionSwap(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19);
        if ( unlikely(__Pyx_GetException(&__pyx_t_7, &__pyx_t_6, &__pyx_t_5) < 0)) __Pyx_ErrFetch(&__pyx_t_7, &__pyx_t_6, &__pyx_t_5);
        __Pyx_XGOTREF(__pyx_t_7);
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_5);
        __Pyx_XGOTREF(__pyx_t_17);
        __Pyx_XGOTREF(__pyx_t_18);
        __Pyx_XGOTREF(__pyx_t_19);
        __pyx_t_14 = __pyx_lineno; __pyx_t_15 = __pyx_clineno; __pyx_t_16 = __pyx_filename;
        {
          __pyx_t_8 = __pyx_v_t;
          __Pyx_INCREF(__pyx_t_8);
          __pyx_t_10 = 0;
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
            __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_cancel, __pyx_callargs+__pyx_t_10, (1-__pyx_t_10) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1194, __pyx_L24_error)
            __Pyx_GOTREF(__pyx_t_1);
          }
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        }
        __Pyx_XGIVEREF(__pyx_t_17);
        __Pyx_XGIVEREF(__pyx_t_18);
        __Pyx_XGIVEREF(__pyx_t_19);
        __Pyx_ExceptionReset(__pyx_t_17, __pyx_t_18, __pyx_t_19);
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_ErrRestore(__pyx_t_7, __pyx_t_6, __pyx_t_5);
        __pyx_t_7 = 0; __pyx_t_6 = 0; __pyx_t_5 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0;
        __pyx_lineno = __pyx_t_14; __pyx_clineno = __pyx_t_15; __pyx_filename = __pyx_t_16;
        goto __pyx_L1_error;
        __pyx_L24_error:;
        __Pyx_XGIVEREF(__pyx_t_17);
        __Pyx_XGIVEREF(__pyx_t_18);
        __Pyx_XGIVEREF(__pyx_t_19);
        __Pyx_ExceptionReset(__pyx_t_17, __pyx_t_18, __pyx_t_19);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0;
        goto __pyx_L1_error;
      }
      __pyx_L21:;
    }

    /* "src/gevent/greenlet.py":1185
 * 
 *     loop = glet.loop # pylint:disable=undefined-loop-variable
 *     if block:             # <<<<<<<<<<<<<<
 *         waiter = Waiter() # pylint:disable=undefined-variable
 *         loop.run_callback(_killall3, need_killed, exception, waiter)
*/
    goto __pyx_L18;
  }

  /* "src/gevent/greenlet.py":1196
 *             t.cancel()
 *     else:
 *         loop.run_callback(_killall, need_killed, exception)             # <<<<<<<<<<<<<<
 * 
 * def _init():
*/
  /*else*/ {
    __pyx_t_8 = __pyx_v_loop;
    __Pyx_INCREF(__pyx_t_8);
    __pyx_t_4 = __Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception(__pyx_f_6gevent_17_gevent_cgreenlet__killall); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1196, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_10 = 0;
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_8, __pyx_t_4, __pyx_v_need_killed, __pyx_v_exception};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_run_callback, __pyx_callargs+__pyx_t_10, (4-__pyx_t_10) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1196, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L18:;

  /* "src/gevent/greenlet.py":1129
 * 
 * 
 * def killall(greenlets, exception=GreenletExit, block=True, timeout=None):             # <<<<<<<<<<<<<<
 *     """
 *     Forceably terminate all the *greenlets* by causing them to raise *exception*.
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("gevent._gevent_cgreenlet.killall", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_need_killed);
  __Pyx_XDECREF(__pyx_v_glet);
  __Pyx_XDECREF(__pyx_v_cancel);
  __Pyx_XDECREF(__pyx_v_loop);
  __Pyx_XDECREF((PyObject *)__pyx_v_waiter);
  __Pyx_XDECREF(__pyx_v_t);
  __Pyx_XDECREF(__pyx_v_alive);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "src/gevent/greenlet.py":1198
 *         loop.run_callback(_killall, need_killed, exception)
 * 
 * def _init():             # <<<<<<<<<<<<<<
 *     greenlet_init() # pylint:disable=undefined-variable
 * 
*/

static void __pyx_f_6gevent_17_gevent_cgreenlet__init(void) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;

  /* "src/gevent/greenlet.py":1199
 * 
 * def _init():
 *     greenlet_init() # pylint:disable=undefined-variable             # <<<<<<<<<<<<<<
 * 
 * _init()
*/
  __pyx_f_6gevent_17_gevent_cgreenlet_greenlet_init(); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1199, __pyx_L1_error)

  /* "src/gevent/greenlet.py":1198
 *         loop.run_callback(_killall, need_killed, exception)
 * 
 * def _init():             # <<<<<<<<<<<<<<
 *     greenlet_init() # pylint:disable=undefined-variable
 * 
*/

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("gevent._gevent_cgreenlet._init", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
}
/* #### Code section: module_exttypes ### */

static PyObject *__pyx_tp_new_6gevent_17_gevent_cgreenlet_SpawnedLink(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink *p;
  PyObject *o;
  o = __Pyx_AllocateExtensionType(t, 0);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink *)o);
  p->callback = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6gevent_17_gevent_cgreenlet_SpawnedLink(PyObject *o) {
  struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink *p = (struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6gevent_17_gevent_cgreenlet_SpawnedLink) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->callback);
  PyTypeObject *tp = Py_TYPE(o);
  #if CYTHON_USE_TYPE_SLOTS
  (*tp->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  Py_DECREF(tp);
  #endif
}

static int __pyx_tp_traverse_6gevent_17_gevent_cgreenlet_SpawnedLink(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink *p = (struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->callback) {
    e = (*v)(p->callback, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6gevent_17_gevent_cgreenlet_SpawnedLink(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink *p = (struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink *)o;
  tmp = ((PyObject*)p->callback);
  p->callback = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_tp_getattro_6gevent_17_gevent_cgreenlet_SpawnedLink(PyObject *o, PyObject *n) {
  PyObject *v = PyObject_GenericGetAttr(o, n);
  if (!v && PyErr_ExceptionMatches(PyExc_AttributeError)) {
    PyErr_Clear();
    v = __pyx_pw_6gevent_17_gevent_cgreenlet_11SpawnedLink_13__getattr__(o, n);
  }
  return v;
}

static PyObject *__pyx_tp_richcompare_6gevent_17_gevent_cgreenlet_SpawnedLink(PyObject *o1, PyObject *o2, int op) {
  switch (op) {
    case Py_EQ: {
      return __pyx_pw_6gevent_17_gevent_cgreenlet_11SpawnedLink_7__eq__(o1, o2);
    }
    case Py_NE: {
      PyObject *ret;
      ret = __pyx_pw_6gevent_17_gevent_cgreenlet_11SpawnedLink_7__eq__(o1, o2);
      if (likely(ret && ret != Py_NotImplemented)) {
        int b = __Pyx_PyObject_IsTrue(ret);
        Py_DECREF(ret);
        if (unlikely(b < 0)) return NULL;
        ret = (b) ? Py_False : Py_True;
        Py_INCREF(ret);
      }
      return ret;
    }
    default: {
      return __Pyx_NewRef(Py_NotImplemented);
    }
  }
}

static PyObject *__pyx_getprop_6gevent_17_gevent_cgreenlet_11SpawnedLink_callback(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6gevent_17_gevent_cgreenlet_11SpawnedLink_8callback_1__get__(o);
}

static int __pyx_setprop_6gevent_17_gevent_cgreenlet_11SpawnedLink_callback(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6gevent_17_gevent_cgreenlet_11SpawnedLink_8callback_3__set__(o, v);
  }
  else {
    return __pyx_pw_6gevent_17_gevent_cgreenlet_11SpawnedLink_8callback_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_6gevent_17_gevent_cgreenlet_SpawnedLink[] = {
  {"__getattr__", (PyCFunction)__pyx_pw_6gevent_17_gevent_cgreenlet_11SpawnedLink_13__getattr__, METH_O|METH_COEXIST, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6gevent_17_gevent_cgreenlet_SpawnedLink[] = {
  {"callback", __pyx_getprop_6gevent_17_gevent_cgreenlet_11SpawnedLink_callback, __pyx_setprop_6gevent_17_gevent_cgreenlet_11SpawnedLink_callback, PyDoc_STR("callback: object"), 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6gevent_17_gevent_cgreenlet_SpawnedLink_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6gevent_17_gevent_cgreenlet_SpawnedLink},
  {Py_tp_repr, (void *)__pyx_pw_6gevent_17_gevent_cgreenlet_11SpawnedLink_11__repr__},
  {Py_tp_hash, (void *)__pyx_pw_6gevent_17_gevent_cgreenlet_11SpawnedLink_5__hash__},
  {Py_tp_call, (void *)__pyx_pw_6gevent_17_gevent_cgreenlet_11SpawnedLink_3__call__},
  {Py_tp_str, (void *)__pyx_pw_6gevent_17_gevent_cgreenlet_11SpawnedLink_9__str__},
  {Py_tp_getattro, (void *)__pyx_tp_getattro_6gevent_17_gevent_cgreenlet_SpawnedLink},
  {Py_tp_doc, (void *)PyDoc_STR("SpawnedLink(callback)\n\nA wrapper around link that calls it in another greenlet.\n\nCan be called only from main loop.")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6gevent_17_gevent_cgreenlet_SpawnedLink},
  {Py_tp_clear, (void *)__pyx_tp_clear_6gevent_17_gevent_cgreenlet_SpawnedLink},
  {Py_tp_richcompare, (void *)__pyx_tp_richcompare_6gevent_17_gevent_cgreenlet_SpawnedLink},
  {Py_tp_methods, (void *)__pyx_methods_6gevent_17_gevent_cgreenlet_SpawnedLink},
  {Py_tp_getset, (void *)__pyx_getsets_6gevent_17_gevent_cgreenlet_SpawnedLink},
  {Py_tp_init, (void *)__pyx_pw_6gevent_17_gevent_cgreenlet_11SpawnedLink_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6gevent_17_gevent_cgreenlet_SpawnedLink},
  {0, 0},
};
static PyType_Spec __pyx_type_6gevent_17_gevent_cgreenlet_SpawnedLink_spec = {
  "gevent._gevent_cgreenlet.SpawnedLink",
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6gevent_17_gevent_cgreenlet_SpawnedLink_slots,
};
#else

static PyTypeObject __pyx_type_6gevent_17_gevent_cgreenlet_SpawnedLink = {
  PyVarObject_HEAD_INIT(0, 0)
  "gevent._gevent_cgreenlet.""SpawnedLink", /*tp_name*/
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SpawnedLink), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6gevent_17_gevent_cgreenlet_SpawnedLink, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  __pyx_pw_6gevent_17_gevent_cgreenlet_11SpawnedLink_11__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  __pyx_pw_6gevent_17_gevent_cgreenlet_11SpawnedLink_5__hash__, /*tp_hash*/
  __pyx_pw_6gevent_17_gevent_cgreenlet_11SpawnedLink_3__call__, /*tp_call*/
  __pyx_pw_6gevent_17_gevent_cgreenlet_11SpawnedLink_9__str__, /*tp_str*/
  __pyx_tp_getattro_6gevent_17_gevent_cgreenlet_SpawnedLink, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("SpawnedLink(callback)\n\nA wrapper around link that calls it in another greenlet.\n\nCan be called only from main loop."), /*tp_doc*/
  __pyx_tp_traverse_6gevent_17_gevent_cgreenlet_SpawnedLink, /*tp_traverse*/
  __pyx_tp_clear_6gevent_17_gevent_cgreenlet_SpawnedLink, /*tp_clear*/
  __pyx_tp_richcompare_6gevent_17_gevent_cgreenlet_SpawnedLink, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6gevent_17_gevent_cgreenlet_SpawnedLink, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6gevent_17_gevent_cgreenlet_SpawnedLink, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6gevent_17_gevent_cgreenlet_11SpawnedLink_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6gevent_17_gevent_cgreenlet_SpawnedLink, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyMethodDef __pyx_methods_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink[] = {
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6gevent_17_gevent_cgreenlet_SpawnedLink},
  {Py_tp_call, (void *)__pyx_pw_6gevent_17_gevent_cgreenlet_18SuccessSpawnedLink_1__call__},
  {Py_tp_doc, (void *)PyDoc_STR("A wrapper around link that calls it in another greenlet only if source succeed.\n\n    Can be called only from main loop.\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6gevent_17_gevent_cgreenlet_SpawnedLink},
  {Py_tp_clear, (void *)__pyx_tp_clear_6gevent_17_gevent_cgreenlet_SpawnedLink},
  {Py_tp_methods, (void *)__pyx_methods_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink},
  {Py_tp_new, (void *)__pyx_tp_new_6gevent_17_gevent_cgreenlet_SpawnedLink},
  {0, 0},
};
static PyType_Spec __pyx_type_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink_spec = {
  "gevent._gevent_cgreenlet.SuccessSpawnedLink",
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink_slots,
};
#else

static PyTypeObject __pyx_type_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink = {
  PyVarObject_HEAD_INIT(0, 0)
  "gevent._gevent_cgreenlet.""SuccessSpawnedLink", /*tp_name*/
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6gevent_17_gevent_cgreenlet_SpawnedLink, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6gevent_17_gevent_cgreenlet_11SpawnedLink_11__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  __pyx_pw_6gevent_17_gevent_cgreenlet_18SuccessSpawnedLink_1__call__, /*tp_call*/
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6gevent_17_gevent_cgreenlet_11SpawnedLink_9__str__, /*tp_str*/
  #else
  0, /*tp_str*/
  #endif
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("A wrapper around link that calls it in another greenlet only if source succeed.\n\n    Can be called only from main loop.\n    "), /*tp_doc*/
  __pyx_tp_traverse_6gevent_17_gevent_cgreenlet_SpawnedLink, /*tp_traverse*/
  __pyx_tp_clear_6gevent_17_gevent_cgreenlet_SpawnedLink, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6gevent_17_gevent_cgreenlet_11SpawnedLink_1__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6gevent_17_gevent_cgreenlet_SpawnedLink, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyMethodDef __pyx_methods_6gevent_17_gevent_cgreenlet_FailureSpawnedLink[] = {
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6gevent_17_gevent_cgreenlet_FailureSpawnedLink_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6gevent_17_gevent_cgreenlet_SpawnedLink},
  {Py_tp_call, (void *)__pyx_pw_6gevent_17_gevent_cgreenlet_18FailureSpawnedLink_1__call__},
  {Py_tp_doc, (void *)PyDoc_STR("A wrapper around link that calls it in another greenlet only if source failed.\n\n    Can be called only from main loop.\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6gevent_17_gevent_cgreenlet_SpawnedLink},
  {Py_tp_clear, (void *)__pyx_tp_clear_6gevent_17_gevent_cgreenlet_SpawnedLink},
  {Py_tp_methods, (void *)__pyx_methods_6gevent_17_gevent_cgreenlet_FailureSpawnedLink},
  {Py_tp_new, (void *)__pyx_tp_new_6gevent_17_gevent_cgreenlet_SpawnedLink},
  {0, 0},
};
static PyType_Spec __pyx_type_6gevent_17_gevent_cgreenlet_FailureSpawnedLink_spec = {
  "gevent._gevent_cgreenlet.FailureSpawnedLink",
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet_FailureSpawnedLink),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6gevent_17_gevent_cgreenlet_FailureSpawnedLink_slots,
};
#else

static PyTypeObject __pyx_type_6gevent_17_gevent_cgreenlet_FailureSpawnedLink = {
  PyVarObject_HEAD_INIT(0, 0)
  "gevent._gevent_cgreenlet.""FailureSpawnedLink", /*tp_name*/
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet_FailureSpawnedLink), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6gevent_17_gevent_cgreenlet_SpawnedLink, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6gevent_17_gevent_cgreenlet_11SpawnedLink_11__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  __pyx_pw_6gevent_17_gevent_cgreenlet_18FailureSpawnedLink_1__call__, /*tp_call*/
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6gevent_17_gevent_cgreenlet_11SpawnedLink_9__str__, /*tp_str*/
  #else
  0, /*tp_str*/
  #endif
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("A wrapper around link that calls it in another greenlet only if source failed.\n\n    Can be called only from main loop.\n    "), /*tp_doc*/
  __pyx_tp_traverse_6gevent_17_gevent_cgreenlet_SpawnedLink, /*tp_traverse*/
  __pyx_tp_clear_6gevent_17_gevent_cgreenlet_SpawnedLink, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6gevent_17_gevent_cgreenlet_FailureSpawnedLink, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6gevent_17_gevent_cgreenlet_11SpawnedLink_1__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6gevent_17_gevent_cgreenlet_SpawnedLink, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_6gevent_17_gevent_cgreenlet__Frame(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *p;
  PyObject *o;
  o = __Pyx_AllocateExtensionType(t, 1);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *)o);
  p->f_code = ((__pyx_t_6gevent_17_gevent_cgreenlet_CodeType)Py_None); Py_INCREF(Py_None);
  p->f_back = ((struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6gevent_17_gevent_cgreenlet__Frame(PyObject *o) {
  struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *p = (struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->f_code);
  Py_CLEAR(p->f_back);
  PyTypeObject *tp = Py_TYPE(o);
  #if CYTHON_USE_TYPE_SLOTS
  (*tp->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  Py_DECREF(tp);
  #endif
}

static int __pyx_tp_traverse_6gevent_17_gevent_cgreenlet__Frame(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *p = (struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->f_code) {
    e = (*v)(((PyObject *)p->f_code), a); if (e) return e;
  }
  if (p->f_back) {
    e = (*v)(((PyObject *)p->f_back), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6gevent_17_gevent_cgreenlet__Frame(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *p = (struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *)o;
  tmp = ((PyObject*)p->f_code);
  p->f_code = ((__pyx_t_6gevent_17_gevent_cgreenlet_CodeType)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->f_back);
  p->f_back = ((struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6gevent_17_gevent_cgreenlet_6_Frame_f_globals(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6gevent_17_gevent_cgreenlet_6_Frame_9f_globals_1__get__(o);
}

static PyObject *__pyx_getprop_6gevent_17_gevent_cgreenlet_6_Frame_f_code(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6gevent_17_gevent_cgreenlet_6_Frame_6f_code_1__get__(o);
}

static PyObject *__pyx_getprop_6gevent_17_gevent_cgreenlet_6_Frame_f_lineno(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6gevent_17_gevent_cgreenlet_6_Frame_8f_lineno_1__get__(o);
}

static PyObject *__pyx_getprop_6gevent_17_gevent_cgreenlet_6_Frame_f_back(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6gevent_17_gevent_cgreenlet_6_Frame_6f_back_1__get__(o);
}

static PyMethodDef __pyx_methods_6gevent_17_gevent_cgreenlet__Frame[] = {
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6gevent_17_gevent_cgreenlet__Frame[] = {
  {"f_globals", __pyx_getprop_6gevent_17_gevent_cgreenlet_6_Frame_f_globals, 0, 0, 0},
  {"f_code", __pyx_getprop_6gevent_17_gevent_cgreenlet_6_Frame_f_code, 0, 0, 0},
  {"f_lineno", __pyx_getprop_6gevent_17_gevent_cgreenlet_6_Frame_f_lineno, 0, 0, 0},
  {"f_back", __pyx_getprop_6gevent_17_gevent_cgreenlet_6_Frame_f_back, 0, 0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6gevent_17_gevent_cgreenlet__Frame_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6gevent_17_gevent_cgreenlet__Frame},
  {Py_tp_doc, (void *)PyDoc_STR("_Frame()")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6gevent_17_gevent_cgreenlet__Frame},
  {Py_tp_clear, (void *)__pyx_tp_clear_6gevent_17_gevent_cgreenlet__Frame},
  {Py_tp_methods, (void *)__pyx_methods_6gevent_17_gevent_cgreenlet__Frame},
  {Py_tp_getset, (void *)__pyx_getsets_6gevent_17_gevent_cgreenlet__Frame},
  {Py_tp_init, (void *)__pyx_pw_6gevent_17_gevent_cgreenlet_6_Frame_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6gevent_17_gevent_cgreenlet__Frame},
  {0, 0},
};
static PyType_Spec __pyx_type_6gevent_17_gevent_cgreenlet__Frame_spec = {
  "gevent._gevent_cgreenlet._Frame",
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6gevent_17_gevent_cgreenlet__Frame_slots,
};
#else

static PyTypeObject __pyx_type_6gevent_17_gevent_cgreenlet__Frame = {
  PyVarObject_HEAD_INIT(0, 0)
  "gevent._gevent_cgreenlet.""_Frame", /*tp_name*/
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6gevent_17_gevent_cgreenlet__Frame, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("_Frame()"), /*tp_doc*/
  __pyx_tp_traverse_6gevent_17_gevent_cgreenlet__Frame, /*tp_traverse*/
  __pyx_tp_clear_6gevent_17_gevent_cgreenlet__Frame, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6gevent_17_gevent_cgreenlet__Frame, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6gevent_17_gevent_cgreenlet__Frame, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6gevent_17_gevent_cgreenlet_6_Frame_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6gevent_17_gevent_cgreenlet__Frame, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet_Greenlet __pyx_vtable_6gevent_17_gevent_cgreenlet_Greenlet;

static PyObject *__pyx_tp_new_6gevent_17_gevent_cgreenlet_Greenlet(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *p;
  PyObject *o = __Pyx_PyType_GetSlot(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_greenlet, tp_new, newfunc)(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)o);
  p->__pyx_vtab = __pyx_vtabptr_6gevent_17_gevent_cgreenlet_Greenlet;
  p->value = Py_None; Py_INCREF(Py_None);
  p->args = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->kwargs = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->spawning_greenlet = Py_None; Py_INCREF(Py_None);
  p->spawning_stack = ((struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *)Py_None); Py_INCREF(Py_None);
  p->spawn_tree_locals = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_links = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_exc_info = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_notifier = Py_None; Py_INCREF(Py_None);
  p->_start_event = Py_None; Py_INCREF(Py_None);
  p->_formatted_info = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_ident = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6gevent_17_gevent_cgreenlet_Greenlet(PyObject *o) {
  struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *p = (struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6gevent_17_gevent_cgreenlet_Greenlet) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->value);
  Py_CLEAR(p->args);
  Py_CLEAR(p->kwargs);
  Py_CLEAR(p->spawning_greenlet);
  Py_CLEAR(p->spawning_stack);
  Py_CLEAR(p->spawn_tree_locals);
  Py_CLEAR(p->_links);
  Py_CLEAR(p->_exc_info);
  Py_CLEAR(p->_notifier);
  Py_CLEAR(p->_start_event);
  Py_CLEAR(p->_formatted_info);
  Py_CLEAR(p->_ident);
  if (PyType_IS_GC(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_greenlet)) PyObject_GC_Track(o);
  #if !CYTHON_USE_MODULE_STATE
  if (likely(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_greenlet)) __Pyx_PyType_GetSlot(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_greenlet, tp_dealloc, destructor)(o); else
  #endif
  __Pyx_call_next_tp_dealloc(o, __pyx_tp_dealloc_6gevent_17_gevent_cgreenlet_Greenlet);
}

static int __pyx_tp_traverse_6gevent_17_gevent_cgreenlet_Greenlet(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *p = (struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)o;
  #if !CYTHON_USE_MODULE_STATE
  e = 0;
  if (likely(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_greenlet)) {
    traverseproc traverse = __Pyx_PyType_GetSlot(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_greenlet, tp_traverse, traverseproc);
    if (traverse) { e = traverse(o, v, a); }
  } else
  #endif
  { e = __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_6gevent_17_gevent_cgreenlet_Greenlet); }
  if (e) return e;
  {
    e = __Pyx_call_type_traverse(o, 0, v, a);
    if (e) return e;
  }
  if (p->value) {
    e = (*v)(p->value, a); if (e) return e;
  }
  if (p->args) {
    e = (*v)(p->args, a); if (e) return e;
  }
  if (p->kwargs) {
    e = (*v)(p->kwargs, a); if (e) return e;
  }
  if (p->spawning_greenlet) {
    e = (*v)(p->spawning_greenlet, a); if (e) return e;
  }
  if (p->spawning_stack) {
    e = (*v)(((PyObject *)p->spawning_stack), a); if (e) return e;
  }
  if (p->spawn_tree_locals) {
    e = (*v)(p->spawn_tree_locals, a); if (e) return e;
  }
  if (p->_links) {
    e = (*v)(p->_links, a); if (e) return e;
  }
  if (p->_exc_info) {
    e = (*v)(p->_exc_info, a); if (e) return e;
  }
  if (p->_notifier) {
    e = (*v)(p->_notifier, a); if (e) return e;
  }
  if (p->_start_event) {
    e = (*v)(p->_start_event, a); if (e) return e;
  }
  if (p->_ident) {
    e = (*v)(p->_ident, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6gevent_17_gevent_cgreenlet_Greenlet(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *p = (struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)o;
  #if !CYTHON_USE_MODULE_STATE
  if (likely(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_greenlet)) {
    inquiry clear = __Pyx_PyType_GetSlot(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_greenlet, tp_clear, inquiry);
    if (clear) clear(o);
  } else
  #endif
  { __Pyx_call_next_tp_clear(o, __pyx_tp_clear_6gevent_17_gevent_cgreenlet_Greenlet); }
  tmp = ((PyObject*)p->value);
  p->value = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->args);
  p->args = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->kwargs);
  p->kwargs = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->spawning_greenlet);
  p->spawning_greenlet = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->spawning_stack);
  p->spawning_stack = ((struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->spawn_tree_locals);
  p->spawn_tree_locals = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_links);
  p->_links = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_exc_info);
  p->_exc_info = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_notifier);
  p->_notifier = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_start_event);
  p->_start_event = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_ident);
  p->_ident = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6gevent_17_gevent_cgreenlet_8Greenlet_minimal_ident(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_13minimal_ident_1__get__(o);
}

static PyObject *__pyx_getprop_6gevent_17_gevent_cgreenlet_8Greenlet_loop(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_4loop_1__get__(o);
}

static PyObject *__pyx_getprop_6gevent_17_gevent_cgreenlet_8Greenlet_dead(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_4dead_1__get__(o);
}

static PyObject *__pyx_getprop_6gevent_17_gevent_cgreenlet_8Greenlet_started(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_7started_1__get__(o);
}

static PyObject *__pyx_getprop_6gevent_17_gevent_cgreenlet_8Greenlet_exception(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_9exception_1__get__(o);
}

static PyObject *__pyx_getprop_6gevent_17_gevent_cgreenlet_8Greenlet_exc_info(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_8exc_info_1__get__(o);
}

static PyObject *__pyx_getprop_6gevent_17_gevent_cgreenlet_8Greenlet_value(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_5value_1__get__(o);
}

static PyObject *__pyx_getprop_6gevent_17_gevent_cgreenlet_8Greenlet_args(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_4args_1__get__(o);
}

static PyObject *__pyx_getprop_6gevent_17_gevent_cgreenlet_8Greenlet_kwargs(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_6kwargs_1__get__(o);
}

static PyObject *__pyx_getprop_6gevent_17_gevent_cgreenlet_8Greenlet_spawning_greenlet(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_17spawning_greenlet_1__get__(o);
}

static PyObject *__pyx_getprop_6gevent_17_gevent_cgreenlet_8Greenlet_spawning_stack(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_14spawning_stack_1__get__(o);
}

static PyObject *__pyx_getprop_6gevent_17_gevent_cgreenlet_8Greenlet_spawn_tree_locals(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_17spawn_tree_locals_1__get__(o);
}

static int __pyx_setprop_6gevent_17_gevent_cgreenlet_8Greenlet_spawn_tree_locals(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_17spawn_tree_locals_3__set__(o, v);
  }
  else {
    return __pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_17spawn_tree_locals_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_6gevent_17_gevent_cgreenlet_Greenlet[] = {
  {"name", (PyCFunction)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_3name, METH_NOARGS, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_2name},
  {"_raise_exception", (PyCFunction)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_5_raise_exception, METH_NOARGS, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_4_raise_exception},
  {"throw", (PyCFunction)(void(*)(void))(PyCFunctionWithKeywords)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_17throw, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_16throw},
  {"start", (PyCFunction)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_19start, METH_NOARGS, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_18start},
  {"start_later", (PyCFunction)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_21start_later, METH_O, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_20start_later},
  {"add_spawn_callback", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_23add_spawn_callback, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_22add_spawn_callback},
  {"remove_spawn_callback", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_25remove_spawn_callback, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_24remove_spawn_callback},
  {"spawn", (PyCFunction)(void(*)(void))(PyCFunctionWithKeywords)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_27spawn, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_26spawn},
  {"spawn_later", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_29spawn_later, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_28spawn_later},
  {"get", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_35get, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_34get},
  {"__enter__", (PyCFunction)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_39__enter__, METH_NOARGS, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_38__enter__},
  {"__exit__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_41__exit__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_40__exit__},
  {"run", (PyCFunction)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_43run, METH_NOARGS, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_42run},
  {"_run", (PyCFunction)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_45_run, METH_NOARGS, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_44_run},
  {"link", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_51link, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_50link},
  {"unlink", (PyCFunction)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_53unlink, METH_O, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_52unlink},
  {"unlink_all", (PyCFunction)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_55unlink_all, METH_NOARGS, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_54unlink_all},
  {"link_value", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_57link_value, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_56link_value},
  {"link_exception", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_59link_exception, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet_58link_exception},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6gevent_17_gevent_cgreenlet_Greenlet[] = {
  {"minimal_ident", __pyx_getprop_6gevent_17_gevent_cgreenlet_8Greenlet_minimal_ident, 0, PyDoc_STR("\n        A small, unique non-negative integer that identifies this object.\n\n        This is similar to :attr:`threading.Thread.ident` (and `id`)\n        in that as long as this object is alive, no other greenlet *in\n        this hub* will have the same id, but it makes a stronger\n        guarantee that the assigned values will be small and\n        sequential. Sometime after this object has died, the value\n        will be available for reuse.\n\n        To get ids that are unique across all hubs, combine this with\n        the hub's (``self.parent``) ``minimal_ident``.\n\n        Accessing this property from threads other than the thread running\n        this greenlet is not defined.\n\n        .. versionadded:: 1.3a2\n\n        "), 0},
  {"loop", __pyx_getprop_6gevent_17_gevent_cgreenlet_8Greenlet_loop, 0, 0, 0},
  {"dead", __pyx_getprop_6gevent_17_gevent_cgreenlet_8Greenlet_dead, 0, PyDoc_STR("\n            Boolean indicating that the greenlet is dead and will not run again.\n\n            This is true if:\n\n            1. We were never started, but were :meth:`killed <kill>`\n               immediately after creation (not possible with :meth:`spawn`); OR\n            2. We were started, but were killed before running; OR\n            3. We have run and terminated (by raising an exception out of the\n               started function or by reaching the end of the started function).\n            "), 0},
  {"started", __pyx_getprop_6gevent_17_gevent_cgreenlet_8Greenlet_started, 0, 0, 0},
  {"exception", __pyx_getprop_6gevent_17_gevent_cgreenlet_8Greenlet_exception, 0, PyDoc_STR("\n        Holds the exception instance raised by the function if the\n        greenlet has finished with an error. Otherwise ``None``.\n        "), 0},
  {"exc_info", __pyx_getprop_6gevent_17_gevent_cgreenlet_8Greenlet_exc_info, 0, PyDoc_STR("\n        Holds the exc_info three-tuple raised by the function if the\n        greenlet finished with an error. Otherwise a false value.\n\n        .. note:: This is a provisional API and may change.\n\n        .. versionadded:: 1.1\n        "), 0},
  {"value", __pyx_getprop_6gevent_17_gevent_cgreenlet_8Greenlet_value, 0, 0, 0},
  {"args", __pyx_getprop_6gevent_17_gevent_cgreenlet_8Greenlet_args, 0, 0, 0},
  {"kwargs", __pyx_getprop_6gevent_17_gevent_cgreenlet_8Greenlet_kwargs, 0, 0, 0},
  {"spawning_greenlet", __pyx_getprop_6gevent_17_gevent_cgreenlet_8Greenlet_spawning_greenlet, 0, 0, 0},
  {"spawning_stack", __pyx_getprop_6gevent_17_gevent_cgreenlet_8Greenlet_spawning_stack, 0, 0, 0},
  {"spawn_tree_locals", __pyx_getprop_6gevent_17_gevent_cgreenlet_8Greenlet_spawn_tree_locals, __pyx_setprop_6gevent_17_gevent_cgreenlet_8Greenlet_spawn_tree_locals, PyDoc_STR("spawn_tree_locals: dict"), 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6gevent_17_gevent_cgreenlet_Greenlet_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6gevent_17_gevent_cgreenlet_Greenlet},
  {Py_tp_repr, (void *)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_13__repr__},
  {Py_nb_bool, (void *)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_7__bool__},
  {Py_tp_doc, (void *)PyDoc_STR("Greenlet(run=None, *args, **kwargs)\n\nA light-weight cooperatively-scheduled execution unit.")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6gevent_17_gevent_cgreenlet_Greenlet},
  {Py_tp_clear, (void *)__pyx_tp_clear_6gevent_17_gevent_cgreenlet_Greenlet},
  {Py_tp_methods, (void *)__pyx_methods_6gevent_17_gevent_cgreenlet_Greenlet},
  {Py_tp_getset, (void *)__pyx_getsets_6gevent_17_gevent_cgreenlet_Greenlet},
  {Py_tp_init, (void *)__pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6gevent_17_gevent_cgreenlet_Greenlet},
  {0, 0},
};
static PyType_Spec __pyx_type_6gevent_17_gevent_cgreenlet_Greenlet_spec = {
  "gevent._gevent_cgreenlet.Greenlet",
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6gevent_17_gevent_cgreenlet_Greenlet_slots,
};
#else

static PyNumberMethods __pyx_tp_as_number_Greenlet = {
  0, /*nb_add*/
  0, /*nb_subtract*/
  0, /*nb_multiply*/
  0, /*nb_remainder*/
  0, /*nb_divmod*/
  0, /*nb_power*/
  0, /*nb_negative*/
  0, /*nb_positive*/
  0, /*nb_absolute*/
  __pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_7__bool__, /*nb_bool*/
  0, /*nb_invert*/
  0, /*nb_lshift*/
  0, /*nb_rshift*/
  0, /*nb_and*/
  0, /*nb_xor*/
  0, /*nb_or*/
  0, /*nb_int*/
  0, /*nb_long (reserved)*/
  0, /*nb_float*/
  0, /*nb_inplace_add*/
  0, /*nb_inplace_subtract*/
  0, /*nb_inplace_multiply*/
  0, /*nb_inplace_remainder*/
  0, /*nb_inplace_power*/
  0, /*nb_inplace_lshift*/
  0, /*nb_inplace_rshift*/
  0, /*nb_inplace_and*/
  0, /*nb_inplace_xor*/
  0, /*nb_inplace_or*/
  0, /*nb_floor_divide*/
  0, /*nb_true_divide*/
  0, /*nb_inplace_floor_divide*/
  0, /*nb_inplace_true_divide*/
  0, /*nb_index*/
  0, /*nb_matrix_multiply*/
  0, /*nb_inplace_matrix_multiply*/
};

static PyTypeObject __pyx_type_6gevent_17_gevent_cgreenlet_Greenlet = {
  PyVarObject_HEAD_INIT(0, 0)
  "gevent._gevent_cgreenlet.""Greenlet", /*tp_name*/
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6gevent_17_gevent_cgreenlet_Greenlet, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  __pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_13__repr__, /*tp_repr*/
  &__pyx_tp_as_number_Greenlet, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("Greenlet(run=None, *args, **kwargs)\n\nA light-weight cooperatively-scheduled execution unit."), /*tp_doc*/
  __pyx_tp_traverse_6gevent_17_gevent_cgreenlet_Greenlet, /*tp_traverse*/
  __pyx_tp_clear_6gevent_17_gevent_cgreenlet_Greenlet, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6gevent_17_gevent_cgreenlet_Greenlet, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6gevent_17_gevent_cgreenlet_Greenlet, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6gevent_17_gevent_cgreenlet_8Greenlet_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6gevent_17_gevent_cgreenlet_Greenlet, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6gevent_17_gevent_cgreenlet__dummy_event __pyx_vtable_6gevent_17_gevent_cgreenlet__dummy_event;

static PyObject *__pyx_tp_new_6gevent_17_gevent_cgreenlet__dummy_event(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *p;
  PyObject *o;
  o = __Pyx_AllocateExtensionType(t, 1);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *)o);
  p->__pyx_vtab = __pyx_vtabptr_6gevent_17_gevent_cgreenlet__dummy_event;
  return o;
}

static void __pyx_tp_dealloc_6gevent_17_gevent_cgreenlet__dummy_event(PyObject *o) {
  PyTypeObject *tp = Py_TYPE(o);
  #if CYTHON_USE_TYPE_SLOTS
  (*tp->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  Py_DECREF(tp);
  #endif
}

static PyObject *__pyx_getprop_6gevent_17_gevent_cgreenlet_12_dummy_event_pending(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6gevent_17_gevent_cgreenlet_12_dummy_event_7pending_1__get__(o);
}

static PyObject *__pyx_getprop_6gevent_17_gevent_cgreenlet_12_dummy_event_active(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6gevent_17_gevent_cgreenlet_12_dummy_event_6active_1__get__(o);
}

static PyMethodDef __pyx_methods_6gevent_17_gevent_cgreenlet__dummy_event[] = {
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6gevent_17_gevent_cgreenlet__dummy_event[] = {
  {"pending", __pyx_getprop_6gevent_17_gevent_cgreenlet_12_dummy_event_pending, 0, 0, 0},
  {"active", __pyx_getprop_6gevent_17_gevent_cgreenlet_12_dummy_event_active, 0, 0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6gevent_17_gevent_cgreenlet__dummy_event_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6gevent_17_gevent_cgreenlet__dummy_event},
  {Py_tp_doc, (void *)PyDoc_STR("_dummy_event()")},
  {Py_tp_methods, (void *)__pyx_methods_6gevent_17_gevent_cgreenlet__dummy_event},
  {Py_tp_getset, (void *)__pyx_getsets_6gevent_17_gevent_cgreenlet__dummy_event},
  {Py_tp_init, (void *)__pyx_pw_6gevent_17_gevent_cgreenlet_12_dummy_event_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6gevent_17_gevent_cgreenlet__dummy_event},
  {0, 0},
};
static PyType_Spec __pyx_type_6gevent_17_gevent_cgreenlet__dummy_event_spec = {
  "gevent._gevent_cgreenlet._dummy_event",
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER,
  __pyx_type_6gevent_17_gevent_cgreenlet__dummy_event_slots,
};
#else

static PyTypeObject __pyx_type_6gevent_17_gevent_cgreenlet__dummy_event = {
  PyVarObject_HEAD_INIT(0, 0)
  "gevent._gevent_cgreenlet.""_dummy_event", /*tp_name*/
  sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6gevent_17_gevent_cgreenlet__dummy_event, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER, /*tp_flags*/
  PyDoc_STR("_dummy_event()"), /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6gevent_17_gevent_cgreenlet__dummy_event, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6gevent_17_gevent_cgreenlet__dummy_event, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6gevent_17_gevent_cgreenlet_12_dummy_event_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6gevent_17_gevent_cgreenlet__dummy_event, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_6gevent_17_gevent_cgreenlet___pyx_defaults(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  o = __Pyx_AllocateExtensionType(t, 1);
  if (unlikely(!o)) return 0;
  return o;
}

static void __pyx_tp_dealloc_6gevent_17_gevent_cgreenlet___pyx_defaults(PyObject *o) {
  struct __pyx_defaults *p = (struct __pyx_defaults *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6gevent_17_gevent_cgreenlet___pyx_defaults) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->arg0);
  PyTypeObject *tp = Py_TYPE(o);
  #if CYTHON_USE_TYPE_SLOTS
  (*tp->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  Py_DECREF(tp);
  #endif
}

static int __pyx_tp_traverse_6gevent_17_gevent_cgreenlet___pyx_defaults(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_defaults *p = (struct __pyx_defaults *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->arg0) {
    e = (*v)(p->arg0, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6gevent_17_gevent_cgreenlet___pyx_defaults(PyObject *o) {
  PyObject* tmp;
  struct __pyx_defaults *p = (struct __pyx_defaults *)o;
  tmp = ((PyObject*)p->arg0);
  p->arg0 = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6gevent_17_gevent_cgreenlet___pyx_defaults_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6gevent_17_gevent_cgreenlet___pyx_defaults},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6gevent_17_gevent_cgreenlet___pyx_defaults},
  {Py_tp_clear, (void *)__pyx_tp_clear_6gevent_17_gevent_cgreenlet___pyx_defaults},
  {Py_tp_new, (void *)__pyx_tp_new_6gevent_17_gevent_cgreenlet___pyx_defaults},
  {0, 0},
};
static PyType_Spec __pyx_type_6gevent_17_gevent_cgreenlet___pyx_defaults_spec = {
  "gevent._gevent_cgreenlet.__pyx_defaults",
  sizeof(struct __pyx_defaults),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6gevent_17_gevent_cgreenlet___pyx_defaults_slots,
};
#else

static PyTypeObject __pyx_type_6gevent_17_gevent_cgreenlet___pyx_defaults = {
  PyVarObject_HEAD_INIT(0, 0)
  "gevent._gevent_cgreenlet.""__pyx_defaults", /*tp_name*/
  sizeof(struct __pyx_defaults), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6gevent_17_gevent_cgreenlet___pyx_defaults, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6gevent_17_gevent_cgreenlet___pyx_defaults, /*tp_traverse*/
  __pyx_tp_clear_6gevent_17_gevent_cgreenlet___pyx_defaults, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6gevent_17_gevent_cgreenlet___pyx_defaults, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter > 0) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, __pyx_mstate_global->__pyx_ptype___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter, sizeof(struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter))))
  {
    o = (PyObject*)__pyx_mstate_global->__pyx_freelist___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter[--__pyx_mstate_global->__pyx_freecount___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter];
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(Py_TYPE(o));
    #endif
    memset(o, 0, sizeof(struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter));
    #if CYTHON_COMPILING_IN_LIMITED_API
    (void) PyObject_Init(o, t);
    #else
    (void) PyObject_INIT(o, t);
    #endif
  } else
  #endif
  {
    o = __Pyx_AllocateExtensionType(t, 1);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter(PyObject *o) {
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && (!PyType_IS_GC(Py_TYPE(o)) || !__Pyx_PyObject_GC_IsFinalized(o))) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter < 8) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(Py_TYPE(o), __pyx_mstate_global->__pyx_ptype___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter, sizeof(struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter))))
  {
    __pyx_mstate_global->__pyx_freelist___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter[__pyx_mstate_global->__pyx_freecount___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter++] = ((struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter *)o);
  } else
  #endif
  {
    PyTypeObject *tp = Py_TYPE(o);
    #if CYTHON_USE_TYPE_SLOTS
    (*tp->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(tp);
    #endif
  }
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter},
  {Py_tp_new, (void *)__pyx_tp_new___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter},
  {0, 0},
};
static PyType_Spec __pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter_spec = {
  "gevent._gevent_cgreenlet.__pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter",
  sizeof(struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER,
  __pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter_slots,
};
#else

static PyTypeObject __pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter = {
  PyVarObject_HEAD_INIT(0, 0)
  "gevent._gevent_cgreenlet.""__pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter", /*tp_name*/
  sizeof(struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception > 0) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, __pyx_mstate_global->__pyx_ptype___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception, sizeof(struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception))))
  {
    o = (PyObject*)__pyx_mstate_global->__pyx_freelist___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception[--__pyx_mstate_global->__pyx_freecount___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception];
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(Py_TYPE(o));
    #endif
    memset(o, 0, sizeof(struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception));
    #if CYTHON_COMPILING_IN_LIMITED_API
    (void) PyObject_Init(o, t);
    #else
    (void) PyObject_INIT(o, t);
    #endif
  } else
  #endif
  {
    o = __Pyx_AllocateExtensionType(t, 1);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception(PyObject *o) {
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && (!PyType_IS_GC(Py_TYPE(o)) || !__Pyx_PyObject_GC_IsFinalized(o))) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception < 8) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(Py_TYPE(o), __pyx_mstate_global->__pyx_ptype___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception, sizeof(struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception))))
  {
    __pyx_mstate_global->__pyx_freelist___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception[__pyx_mstate_global->__pyx_freecount___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception++] = ((struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception *)o);
  } else
  #endif
  {
    PyTypeObject *tp = Py_TYPE(o);
    #if CYTHON_USE_TYPE_SLOTS
    (*tp->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(tp);
    #endif
  }
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception},
  {Py_tp_new, (void *)__pyx_tp_new___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception},
  {0, 0},
};
static PyType_Spec __pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_spec = {
  "gevent._gevent_cgreenlet.__pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception",
  sizeof(struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER,
  __pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_slots,
};
#else

static PyTypeObject __pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception = {
  PyVarObject_HEAD_INIT(0, 0)
  "gevent._gevent_cgreenlet.""__pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception", /*tp_name*/
  sizeof(struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};
/* #### Code section: initfunc_declarations ### */
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitConstants(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_CreateCodeObjects(__pyx_mstatetype *__pyx_mstate); /*proto*/
/* #### Code section: init_module ### */

static int __Pyx_modinit_global_init_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __pyx_v_6gevent_17_gevent_cgreenlet_sys_getframe = Py_None; Py_INCREF(Py_None);
  __pyx_v_6gevent_17_gevent_cgreenlet_sys_exc_info = Py_None; Py_INCREF(Py_None);
  __pyx_v_6gevent_17_gevent_cgreenlet_Timeout = Py_None; Py_INCREF(Py_None);
  __pyx_v_6gevent_17_gevent_cgreenlet_GreenletExit = Py_None; Py_INCREF(Py_None);
  __pyx_v_6gevent_17_gevent_cgreenlet_InvalidSwitchError = Py_None; Py_INCREF(Py_None);
  __pyx_v_6gevent_17_gevent_cgreenlet__greenlet__init__ = Py_None; Py_INCREF(Py_None);
  __pyx_v_6gevent_17_gevent_cgreenlet__threadlocal = Py_None; Py_INCREF(Py_None);
  __pyx_v_6gevent_17_gevent_cgreenlet_get_hub_class = Py_None; Py_INCREF(Py_None);
  __pyx_v_6gevent_17_gevent_cgreenlet_wref = Py_None; Py_INCREF(Py_None);
  __pyx_v_6gevent_17_gevent_cgreenlet_dump_traceback = Py_None; Py_INCREF(Py_None);
  __pyx_v_6gevent_17_gevent_cgreenlet_load_traceback = Py_None; Py_INCREF(Py_None);
  __pyx_v_6gevent_17_gevent_cgreenlet_wait = Py_None; Py_INCREF(Py_None);
  __pyx_v_6gevent_17_gevent_cgreenlet_iwait = Py_None; Py_INCREF(Py_None);
  __pyx_v_6gevent_17_gevent_cgreenlet_reraise = Py_None; Py_INCREF(Py_None);
  __pyx_v_6gevent_17_gevent_cgreenlet_GEVENT_CONFIG = Py_None; Py_INCREF(Py_None);
  __pyx_v_6gevent_17_gevent_cgreenlet__cancelled_start_event = ((struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *)Py_None); Py_INCREF(Py_None);
  __pyx_v_6gevent_17_gevent_cgreenlet__start_completed_event = ((struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *)Py_None); Py_INCREF(Py_None);
  __pyx_v_6gevent_17_gevent_cgreenlet__spawn_callbacks = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  {
    __pyx_t_1 = __Pyx_ApiExport_GetApiDict(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_export_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_PyObject_int_struct___pyx_obj_6g);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_export_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_export_name = __pyx_export_signature + 92;
    void *const __pyx_export_pointers[] = {(void *)&__pyx_v_6gevent_17_gevent_cgreenlet_GEVENT_CONFIG, (void *)&__pyx_v_6gevent_17_gevent_cgreenlet_GreenletExit, (void *)&__pyx_v_6gevent_17_gevent_cgreenlet_InvalidSwitchError, (void *)&__pyx_v_6gevent_17_gevent_cgreenlet_Timeout, (void *)&__pyx_v_6gevent_17_gevent_cgreenlet__greenlet__init__, (void *)&__pyx_v_6gevent_17_gevent_cgreenlet__spawn_callbacks, (void *)&__pyx_v_6gevent_17_gevent_cgreenlet__threadlocal, (void *)&__pyx_v_6gevent_17_gevent_cgreenlet_dump_traceback, (void *)&__pyx_v_6gevent_17_gevent_cgreenlet_get_hub_class, (void *)&__pyx_v_6gevent_17_gevent_cgreenlet_iwait, (void *)&__pyx_v_6gevent_17_gevent_cgreenlet_load_traceback, (void *)&__pyx_v_6gevent_17_gevent_cgreenlet_reraise, (void *)&__pyx_v_6gevent_17_gevent_cgreenlet_sys_exc_info, (void *)&__pyx_v_6gevent_17_gevent_cgreenlet_sys_getframe, (void *)&__pyx_v_6gevent_17_gevent_cgreenlet_wait, (void *)&__pyx_v_6gevent_17_gevent_cgreenlet_wref, (void *)&__pyx_v_6gevent_17_gevent_cgreenlet__PYPY, (void *)&__pyx_v_6gevent_17_gevent_cgreenlet__greenlet_imported, (void *)&__pyx_v_6gevent_17_gevent_cgreenlet__cancelled_start_event, (void *)&__pyx_v_6gevent_17_gevent_cgreenlet__start_completed_event, (void *) NULL};
    void *const *__pyx_export_pointer = __pyx_export_pointers;
    const char *__pyx_export_current_signature = __pyx_export_signature;
    while (*__pyx_export_pointer) {
      if (__Pyx_ExportVoidPtr(__pyx_t_1, __pyx_export_name, *__pyx_export_pointer, __pyx_export_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_export_pointer;
      __pyx_export_name = strchr(__pyx_export_name, '\0') + 1;
      __pyx_export_signature = strchr(__pyx_export_signature, '\0') + 1;
      if (*__pyx_export_signature != '\0') __pyx_export_current_signature = __pyx_export_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_function_export_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  {
    __pyx_t_1 = __Pyx_ApiExport_GetApiDict(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_export_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_PyObject_PyObject_PyObject_PyObj);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_export_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_export_name = __pyx_export_signature + 461;
    void (*const __pyx_export_pointers[])(void) = {(void (*)(void))&__pyx_f_6gevent_17_gevent_cgreenlet__killall, (void (*)(void))&__pyx_f_6gevent_17_gevent_cgreenlet__killall3, (void (*)(void))&__pyx_f_6gevent_17_gevent_cgreenlet_joinall, (void (*)(void))&__pyx_f_6gevent_17_gevent_cgreenlet__kill, (void (*)(void))&__pyx_f_6gevent_17_gevent_cgreenlet__extract_stack, (void (*)(void))&__pyx_f_6gevent_17_gevent_cgreenlet__call_spawn_callbacks, (void (*)(void))&__pyx_f_6gevent_17_gevent_cgreenlet__init, (void (*)(void)) NULL};
    void (*const *__pyx_export_pointer)(void) = __pyx_export_pointers;
    const char *__pyx_export_current_signature = __pyx_export_signature;
    while (*__pyx_export_pointer) {
      if (__Pyx_ExportFunction(__pyx_t_1, __pyx_export_name, *__pyx_export_pointer, __pyx_export_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_export_pointer;
      __pyx_export_name = strchr(__pyx_export_name, '\0') + 1;
      __pyx_export_signature = strchr(__pyx_export_signature, '\0') + 1;
      if (*__pyx_export_signature != '\0') __pyx_export_current_signature = __pyx_export_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_init_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  __pyx_t_1 = PyImport_ImportModule("greenlet"); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_greenlet = __Pyx_ImportType_3_2_4(__pyx_t_1, "greenlet", "greenlet",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyGreenlet),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(PyGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyGreenlet),
  #else
  sizeof(PyGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyGreenlet),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_greenlet) __PYX_ERR(4, 20, __pyx_L1_error)
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_SpawnedLink = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6gevent_17_gevent_cgreenlet_SpawnedLink_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_SpawnedLink)) __PYX_ERR(0, 69, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6gevent_17_gevent_cgreenlet_SpawnedLink_spec, __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_SpawnedLink) < (0)) __PYX_ERR(0, 69, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_SpawnedLink = &__pyx_type_6gevent_17_gevent_cgreenlet_SpawnedLink;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_SpawnedLink) < (0)) __PYX_ERR(0, 69, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_SpawnedLink);
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_SpawnedLink, (PyObject *) __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_SpawnedLink) < (0)) __PYX_ERR(0, 69, __pyx_L1_error)
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_2 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_SpawnedLink); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink_spec, __pyx_t_2);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink)) __PYX_ERR(0, 103, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink_spec, __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink) < (0)) __PYX_ERR(0, 103, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink = &__pyx_type_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink->tp_base = __pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_SpawnedLink;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink) < (0)) __PYX_ERR(0, 103, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink->tp_dictoffset && __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_SuccessSpawnedLink, (PyObject *) __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink) < (0)) __PYX_ERR(0, 103, __pyx_L1_error)
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_2 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_SpawnedLink); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_FailureSpawnedLink = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6gevent_17_gevent_cgreenlet_FailureSpawnedLink_spec, __pyx_t_2);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_FailureSpawnedLink)) __PYX_ERR(0, 115, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6gevent_17_gevent_cgreenlet_FailureSpawnedLink_spec, __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_FailureSpawnedLink) < (0)) __PYX_ERR(0, 115, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_FailureSpawnedLink = &__pyx_type_6gevent_17_gevent_cgreenlet_FailureSpawnedLink;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_FailureSpawnedLink->tp_base = __pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_SpawnedLink;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_FailureSpawnedLink) < (0)) __PYX_ERR(0, 115, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_FailureSpawnedLink);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_FailureSpawnedLink->tp_dictoffset && __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_FailureSpawnedLink->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_FailureSpawnedLink->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_FailureSpawnedLink, (PyObject *) __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_FailureSpawnedLink) < (0)) __PYX_ERR(0, 115, __pyx_L1_error)
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet__Frame = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6gevent_17_gevent_cgreenlet__Frame_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet__Frame)) __PYX_ERR(0, 126, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6gevent_17_gevent_cgreenlet__Frame_spec, __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet__Frame) < (0)) __PYX_ERR(0, 126, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet__Frame = &__pyx_type_6gevent_17_gevent_cgreenlet__Frame;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet__Frame) < (0)) __PYX_ERR(0, 126, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet__Frame);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet__Frame->tp_dictoffset && __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet__Frame->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet__Frame->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_Frame, (PyObject *) __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet__Frame) < (0)) __PYX_ERR(0, 126, __pyx_L1_error)
  __pyx_vtabptr_6gevent_17_gevent_cgreenlet_Greenlet = &__pyx_vtable_6gevent_17_gevent_cgreenlet_Greenlet;
  __pyx_vtable_6gevent_17_gevent_cgreenlet_Greenlet.has_links = (int (*)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, int __pyx_skip_dispatch))__pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet_has_links;
  __pyx_vtable_6gevent_17_gevent_cgreenlet_Greenlet.join = (PyObject *(*)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, int __pyx_skip_dispatch, struct __pyx_opt_args_6gevent_17_gevent_cgreenlet_8Greenlet_join *__pyx_optional_args))__pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet_join;
  __pyx_vtable_6gevent_17_gevent_cgreenlet_Greenlet.kill = (PyObject *(*)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, int __pyx_skip_dispatch, struct __pyx_opt_args_6gevent_17_gevent_cgreenlet_8Greenlet_kill *__pyx_optional_args))__pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet_kill;
  __pyx_vtable_6gevent_17_gevent_cgreenlet_Greenlet.ready = (int (*)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, int __pyx_skip_dispatch))__pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet_ready;
  __pyx_vtable_6gevent_17_gevent_cgreenlet_Greenlet.successful = (int (*)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, int __pyx_skip_dispatch))__pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet_successful;
  __pyx_vtable_6gevent_17_gevent_cgreenlet_Greenlet.rawlink = (PyObject *(*)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, PyObject *, int __pyx_skip_dispatch))__pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet_rawlink;
  __pyx_vtable_6gevent_17_gevent_cgreenlet_Greenlet._formatinfo = (PyObject *(*)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, int __pyx_skip_dispatch))__pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__formatinfo;
  __pyx_vtable_6gevent_17_gevent_cgreenlet_Greenlet._maybe_kill_before_start = (int (*)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, PyObject *, int __pyx_skip_dispatch))__pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__maybe_kill_before_start;
  __pyx_vtable_6gevent_17_gevent_cgreenlet_Greenlet._get_minimal_ident = (PyObject *(*)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *))__pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__get_minimal_ident;
  __pyx_vtable_6gevent_17_gevent_cgreenlet_Greenlet._Greenlet__started_but_aborted = (int (*)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *))__pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__Greenlet__started_but_aborted;
  __pyx_vtable_6gevent_17_gevent_cgreenlet_Greenlet._Greenlet__start_cancelled_by_kill = (int (*)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *))__pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__Greenlet__start_cancelled_by_kill;
  __pyx_vtable_6gevent_17_gevent_cgreenlet_Greenlet._Greenlet__start_pending = (int (*)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *))__pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__Greenlet__start_pending;
  __pyx_vtable_6gevent_17_gevent_cgreenlet_Greenlet._Greenlet__never_started_or_killed = (int (*)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *))__pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__Greenlet__never_started_or_killed;
  __pyx_vtable_6gevent_17_gevent_cgreenlet_Greenlet._Greenlet__start_completed = (int (*)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *))__pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__Greenlet__start_completed;
  __pyx_vtable_6gevent_17_gevent_cgreenlet_Greenlet._Greenlet__handle_death_before_start = (PyObject *(*)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, PyObject *))__pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__Greenlet__handle_death_before_start;
  __pyx_vtable_6gevent_17_gevent_cgreenlet_Greenlet._Greenlet__free = (void (*)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *))__pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__Greenlet__free;
  __pyx_vtable_6gevent_17_gevent_cgreenlet_Greenlet._Greenlet__cancel_start = (PyObject *(*)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *))__pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__Greenlet__cancel_start;
  __pyx_vtable_6gevent_17_gevent_cgreenlet_Greenlet._Greenlet__report_result = (PyObject *(*)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, PyObject *))__pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__Greenlet__report_result;
  __pyx_vtable_6gevent_17_gevent_cgreenlet_Greenlet._Greenlet__report_error = (PyObject *(*)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, PyObject *))__pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__Greenlet__report_error;
  __pyx_vtable_6gevent_17_gevent_cgreenlet_Greenlet._notify_links = (PyObject *(*)(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, int __pyx_skip_dispatch))__pyx_f_6gevent_17_gevent_cgreenlet_8Greenlet__notify_links;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_2 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_greenlet); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 177, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6gevent_17_gevent_cgreenlet_Greenlet_spec, __pyx_t_2);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet)) __PYX_ERR(0, 177, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6gevent_17_gevent_cgreenlet_Greenlet_spec, __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet) < (0)) __PYX_ERR(0, 177, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet = &__pyx_type_6gevent_17_gevent_cgreenlet_Greenlet;
  #endif
  if (sizeof(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet) != sizeof(PyGreenlet)) {
    if (__Pyx_validate_extern_base(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_greenlet) < (0)) __PYX_ERR(0, 177, __pyx_L1_error)
  }
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet->tp_base = __pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_greenlet;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet) < (0)) __PYX_ERR(0, 177, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet->tp_dictoffset && __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  #if CYTHON_UPDATE_DESCRIPTOR_DOC
  {
    PyObject *wrapper = PyObject_GetAttrString((PyObject *)__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, "__init__"); if (unlikely(!wrapper)) __PYX_ERR(0, 177, __pyx_L1_error)
    if (__Pyx_IS_TYPE(wrapper, &PyWrapperDescr_Type)) {
      __pyx_wrapperbase_6gevent_17_gevent_cgreenlet_8Greenlet___init__ = *((PyWrapperDescrObject *)wrapper)->d_base;
      __pyx_wrapperbase_6gevent_17_gevent_cgreenlet_8Greenlet___init__.doc = __pyx_doc_6gevent_17_gevent_cgreenlet_8Greenlet___init__;
      ((PyWrapperDescrObject *)wrapper)->d_base = &__pyx_wrapperbase_6gevent_17_gevent_cgreenlet_8Greenlet___init__;
    }
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, __pyx_vtabptr_6gevent_17_gevent_cgreenlet_Greenlet) < (0)) __PYX_ERR(0, 177, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet) < (0)) __PYX_ERR(0, 177, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_Greenlet_2, (PyObject *) __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet) < (0)) __PYX_ERR(0, 177, __pyx_L1_error)
  __pyx_vtabptr_6gevent_17_gevent_cgreenlet__dummy_event = &__pyx_vtable_6gevent_17_gevent_cgreenlet__dummy_event;
  __pyx_vtable_6gevent_17_gevent_cgreenlet__dummy_event.stop = (PyObject *(*)(struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *, int __pyx_skip_dispatch))__pyx_f_6gevent_17_gevent_cgreenlet_12_dummy_event_stop;
  __pyx_vtable_6gevent_17_gevent_cgreenlet__dummy_event.start = (PyObject *(*)(struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *, PyObject *, int __pyx_skip_dispatch))__pyx_f_6gevent_17_gevent_cgreenlet_12_dummy_event_start;
  __pyx_vtable_6gevent_17_gevent_cgreenlet__dummy_event.close = (PyObject *(*)(struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *, int __pyx_skip_dispatch))__pyx_f_6gevent_17_gevent_cgreenlet_12_dummy_event_close;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet__dummy_event = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6gevent_17_gevent_cgreenlet__dummy_event_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet__dummy_event)) __PYX_ERR(0, 1035, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6gevent_17_gevent_cgreenlet__dummy_event_spec, __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet__dummy_event) < (0)) __PYX_ERR(0, 1035, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet__dummy_event = &__pyx_type_6gevent_17_gevent_cgreenlet__dummy_event;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet__dummy_event) < (0)) __PYX_ERR(0, 1035, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet__dummy_event);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet__dummy_event->tp_dictoffset && __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet__dummy_event->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet__dummy_event->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet__dummy_event, __pyx_vtabptr_6gevent_17_gevent_cgreenlet__dummy_event) < (0)) __PYX_ERR(0, 1035, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet__dummy_event) < (0)) __PYX_ERR(0, 1035, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_dummy_event, (PyObject *) __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet__dummy_event) < (0)) __PYX_ERR(0, 1035, __pyx_L1_error)
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet___pyx_defaults = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6gevent_17_gevent_cgreenlet___pyx_defaults_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet___pyx_defaults)) __PYX_ERR(0, 1129, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6gevent_17_gevent_cgreenlet___pyx_defaults_spec, __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet___pyx_defaults) < (0)) __PYX_ERR(0, 1129, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet___pyx_defaults = &__pyx_type_6gevent_17_gevent_cgreenlet___pyx_defaults;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet___pyx_defaults) < (0)) __PYX_ERR(0, 1129, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet___pyx_defaults);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet___pyx_defaults->tp_dictoffset && __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet___pyx_defaults->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6gevent_17_gevent_cgreenlet___pyx_defaults->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter)) __PYX_ERR(1, 65, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter_spec, __pyx_mstate->__pyx_ptype___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter) < (0)) __PYX_ERR(1, 65, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter = &__pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter) < (0)) __PYX_ERR(1, 65, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter->tp_dictoffset && __pyx_mstate->__pyx_ptype___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype___pyx_scope_struct____Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception)) __PYX_ERR(1, 65, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_spec, __pyx_mstate->__pyx_ptype___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception) < (0)) __PYX_ERR(1, 65, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception = &__pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception) < (0)) __PYX_ERR(1, 65, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception->tp_dictoffset && __pyx_mstate->__pyx_ptype___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype___pyx_scope_struct____Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __pyx_t_1 = PyImport_ImportModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_7cpython_4type_type = __Pyx_ImportType_3_2_4(__pyx_t_1, __Pyx_BUILTIN_MODULE_NAME, "type",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyTypeObject), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyTypeObject),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  0, 0,
  #else
  sizeof(PyHeapTypeObject), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyHeapTypeObject),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_7cpython_4type_type) __PYX_ERR(5, 9, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("weakref"); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_6gevent_15_gevent_c_ident_ref = __Pyx_ImportType_3_2_4(__pyx_t_1, "weakref", "ref",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyWeakReference), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyWeakReference),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(PyWeakReference), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyWeakReference),
  #else
  sizeof(PyWeakReference), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyWeakReference),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_15_gevent_c_ident_ref) __PYX_ERR(6, 5, __pyx_L1_error)
  __pyx_t_2 = PyImport_ImportModule("gevent._gevent_c_ident"); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 13, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_mstate->__pyx_ptype_6gevent_15_gevent_c_ident_ValuedWeakRef = __Pyx_ImportType_3_2_4(__pyx_t_2, "gevent._gevent_c_ident", "ValuedWeakRef",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_15_gevent_c_ident_ValuedWeakRef), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_15_gevent_c_ident_ValuedWeakRef),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_15_gevent_c_ident_ValuedWeakRef), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_15_gevent_c_ident_ValuedWeakRef),
  #else
  sizeof(struct __pyx_obj_6gevent_15_gevent_c_ident_ValuedWeakRef), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_15_gevent_c_ident_ValuedWeakRef),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_15_gevent_c_ident_ValuedWeakRef) __PYX_ERR(6, 13, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6gevent_15_gevent_c_ident_IdentRegistry = __Pyx_ImportType_3_2_4(__pyx_t_2, "gevent._gevent_c_ident", "IdentRegistry",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_15_gevent_c_ident_IdentRegistry), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_15_gevent_c_ident_IdentRegistry),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_15_gevent_c_ident_IdentRegistry), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_15_gevent_c_ident_IdentRegistry),
  #else
  sizeof(struct __pyx_obj_6gevent_15_gevent_c_ident_IdentRegistry), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_15_gevent_c_ident_IdentRegistry),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_15_gevent_c_ident_IdentRegistry) __PYX_ERR(6, 18, __pyx_L1_error)
  __pyx_vtabptr_6gevent_15_gevent_c_ident_IdentRegistry = (struct __pyx_vtabstruct_6gevent_15_gevent_c_ident_IdentRegistry*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6gevent_15_gevent_c_ident_IdentRegistry); if (unlikely(!__pyx_vtabptr_6gevent_15_gevent_c_ident_IdentRegistry)) __PYX_ERR(6, 18, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyImport_ImportModule("greenlet"); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_mstate->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_greenlet = __Pyx_ImportType_3_2_4(__pyx_t_2, "greenlet", "greenlet",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyGreenlet),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(PyGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyGreenlet),
  #else
  sizeof(PyGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyGreenlet),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_greenlet) __PYX_ERR(2, 12, __pyx_L1_error)
  __pyx_t_1 = PyImport_ImportModule("gevent._gevent_c_greenlet_primitives"); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet = __Pyx_ImportType_3_2_4(__pyx_t_1, "gevent._gevent_c_greenlet_primitives", "TrackedRawGreenlet",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet),
  #else
  sizeof(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_TrackedRawGreenlet) __PYX_ERR(2, 37, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop = __Pyx_ImportType_3_2_4(__pyx_t_1, "gevent._gevent_c_greenlet_primitives", "SwitchOutGreenletWithLoop",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop),
  #else
  sizeof(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop) __PYX_ERR(2, 40, __pyx_L1_error)
  __pyx_vtabptr_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop = (struct __pyx_vtabstruct_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop); if (unlikely(!__pyx_vtabptr_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop)) __PYX_ERR(2, 40, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("greenlet"); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_6gevent_16_gevent_c_waiter_greenlet = __Pyx_ImportType_3_2_4(__pyx_t_1, "greenlet", "greenlet",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyGreenlet),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(PyGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyGreenlet),
  #else
  sizeof(PyGreenlet), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyGreenlet),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_16_gevent_c_waiter_greenlet) __PYX_ERR(3, 15, __pyx_L1_error)
  __pyx_t_2 = PyImport_ImportModule("gevent._gevent_c_waiter"); if (unlikely(!__pyx_t_2)) __PYX_ERR(3, 33, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_mstate->__pyx_ptype_6gevent_16_gevent_c_waiter_Waiter = __Pyx_ImportType_3_2_4(__pyx_t_2, "gevent._gevent_c_waiter", "Waiter",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_16_gevent_c_waiter_Waiter), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_16_gevent_c_waiter_Waiter),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_16_gevent_c_waiter_Waiter), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_16_gevent_c_waiter_Waiter),
  #else
  sizeof(struct __pyx_obj_6gevent_16_gevent_c_waiter_Waiter), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_16_gevent_c_waiter_Waiter),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_16_gevent_c_waiter_Waiter) __PYX_ERR(3, 33, __pyx_L1_error)
  __pyx_vtabptr_6gevent_16_gevent_c_waiter_Waiter = (struct __pyx_vtabstruct_6gevent_16_gevent_c_waiter_Waiter*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6gevent_16_gevent_c_waiter_Waiter); if (unlikely(!__pyx_vtabptr_6gevent_16_gevent_c_waiter_Waiter)) __PYX_ERR(3, 33, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_6gevent_16_gevent_c_waiter_MultipleWaiter = __Pyx_ImportType_3_2_4(__pyx_t_2, "gevent._gevent_c_waiter", "MultipleWaiter",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_6gevent_16_gevent_c_waiter_MultipleWaiter), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_16_gevent_c_waiter_MultipleWaiter),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_6gevent_16_gevent_c_waiter_MultipleWaiter), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_16_gevent_c_waiter_MultipleWaiter),
  #else
  sizeof(struct __pyx_obj_6gevent_16_gevent_c_waiter_MultipleWaiter), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_6gevent_16_gevent_c_waiter_MultipleWaiter),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_6gevent_16_gevent_c_waiter_MultipleWaiter) __PYX_ERR(3, 45, __pyx_L1_error)
  __pyx_vtabptr_6gevent_16_gevent_c_waiter_MultipleWaiter = (struct __pyx_vtabstruct_6gevent_16_gevent_c_waiter_MultipleWaiter*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_6gevent_16_gevent_c_waiter_MultipleWaiter); if (unlikely(!__pyx_vtabptr_6gevent_16_gevent_c_waiter_MultipleWaiter)) __PYX_ERR(3, 45, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_variable_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  {
    __pyx_t_1 = PyImport_ImportModule("gevent._gevent_c_ident"); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_import_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_PyObject_WeakKeyDictionary_heapp);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_import_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_import_name = __pyx_import_signature + 13;
    void **const __pyx_import_pointers[] = {(void **)&__pyx_vp_6gevent_15_gevent_c_ident_WeakKeyDictionary, (void **)&__pyx_vp_6gevent_15_gevent_c_ident_heappop, (void **)&__pyx_vp_6gevent_15_gevent_c_ident_heappush, (void **) NULL};
    void **const *__pyx_import_pointer = __pyx_import_pointers;
    const char *__pyx_import_current_signature = __pyx_import_signature;
    while (*__pyx_import_pointer) {
      if (__Pyx_ImportVoidPtr_3_2_4(__pyx_t_1, __pyx_import_name, *__pyx_import_pointer, __pyx_import_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_import_pointer;
      __pyx_import_name = strchr(__pyx_import_name, '\0') + 1;
      __pyx_import_signature = strchr(__pyx_import_signature, '\0') + 1;
      if (*__pyx_import_signature != '\0') __pyx_import_current_signature = __pyx_import_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  {
    __pyx_t_1 = PyImport_ImportModule("gevent._gevent_c_greenlet_primitives"); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_import_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_PyObject_PyTypeObject_int_Blocki);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_import_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_import_name = __pyx_import_signature + 33;
    void **const __pyx_import_pointers[] = {(void **)&__pyx_vp_6gevent_29_gevent_c_greenlet_primitives_BlockingSwitchOutError, (void **)&__pyx_vp_6gevent_29_gevent_c_greenlet_primitives_get_objects, (void **)&__pyx_vp_6gevent_29_gevent_c_greenlet_primitives_wref, (void **)&__pyx_vp_6gevent_29_gevent_c_greenlet_primitives__buffer, (void **)&__pyx_vp_6gevent_29_gevent_c_greenlet_primitives__memoryview, (void **)&__pyx_vp_6gevent_29_gevent_c_greenlet_primitives__greenlet_imported, (void **) NULL};
    void **const *__pyx_import_pointer = __pyx_import_pointers;
    const char *__pyx_import_current_signature = __pyx_import_signature;
    while (*__pyx_import_pointer) {
      if (__Pyx_ImportVoidPtr_3_2_4(__pyx_t_1, __pyx_import_name, *__pyx_import_pointer, __pyx_import_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_import_pointer;
      __pyx_import_name = strchr(__pyx_import_name, '\0') + 1;
      __pyx_import_signature = strchr(__pyx_import_signature, '\0') + 1;
      if (*__pyx_import_signature != '\0') __pyx_import_current_signature = __pyx_import_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  {
    __pyx_t_1 = PyImport_ImportModule("gevent._gevent_c_hub_local"); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_import_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_PyObject__threadlocal);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_import_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_import_name = __pyx_import_signature + 11;
    void **const __pyx_import_pointers[] = {(void **)&__pyx_vp_6gevent_19_gevent_c_hub_local__threadlocal, (void **) NULL};
    void **const *__pyx_import_pointer = __pyx_import_pointers;
    const char *__pyx_import_current_signature = __pyx_import_signature;
    while (*__pyx_import_pointer) {
      if (__Pyx_ImportVoidPtr_3_2_4(__pyx_t_1, __pyx_import_name, *__pyx_import_pointer, __pyx_import_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_import_pointer;
      __pyx_import_name = strchr(__pyx_import_name, '\0') + 1;
      __pyx_import_signature = strchr(__pyx_import_signature, '\0') + 1;
      if (*__pyx_import_signature != '\0') __pyx_import_current_signature = __pyx_import_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  {
    __pyx_t_1 = PyImport_ImportModule("gevent._gevent_c_waiter"); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_import_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_PyObject_int_ConcurrentObjectUse);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_import_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_import_name = __pyx_import_signature + 17;
    void **const __pyx_import_pointers[] = {(void **)&__pyx_vp_6gevent_16_gevent_c_waiter_ConcurrentObjectUseError, (void **)&__pyx_vp_6gevent_16_gevent_c_waiter__NONE, (void **)&__pyx_vp_6gevent_16_gevent_c_waiter_sys, (void **)&__pyx_vp_6gevent_16_gevent_c_waiter__greenlet_imported, (void **) NULL};
    void **const *__pyx_import_pointer = __pyx_import_pointers;
    const char *__pyx_import_current_signature = __pyx_import_signature;
    while (*__pyx_import_pointer) {
      if (__Pyx_ImportVoidPtr_3_2_4(__pyx_t_1, __pyx_import_name, *__pyx_import_pointer, __pyx_import_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_import_pointer;
      __pyx_import_name = strchr(__pyx_import_name, '\0') + 1;
      __pyx_import_signature = strchr(__pyx_import_signature, '\0') + 1;
      if (*__pyx_import_signature != '\0') __pyx_import_current_signature = __pyx_import_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_function_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  {
    __pyx_t_1 = PyImport_ImportModule("gevent._gevent_c_hub_local"); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_import_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_struct___pyx_obj_6gevent_29_geve);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_import_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_import_name = __pyx_import_signature + 110;
    void (**const __pyx_import_pointers[])(void) = {(void (**)(void))&__pyx_f_6gevent_19_gevent_c_hub_local_get_hub_noargs, (void (**)(void)) NULL};
    void (**const *__pyx_import_pointer)(void) = __pyx_import_pointers;
    const char *__pyx_import_current_signature = __pyx_import_signature;
    while (*__pyx_import_pointer) {
      if (__Pyx_ImportFunction_3_2_4(__pyx_t_1, __pyx_import_name, *__pyx_import_pointer, __pyx_import_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_import_pointer;
      __pyx_import_name = strchr(__pyx_import_name, '\0') + 1;
      __pyx_import_signature = strchr(__pyx_import_signature, '\0') + 1;
      if (*__pyx_import_signature != '\0') __pyx_import_current_signature = __pyx_import_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec__gevent_cgreenlet(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec__gevent_cgreenlet},
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
  {Py_mod_gil, __Pyx_FREETHREADING_COMPATIBLE},
  #endif
  #if PY_VERSION_HEX >= 0x030C0000 && CYTHON_USE_MODULE_STATE
  {Py_mod_multiple_interpreters, Py_MOD_MULTIPLE_INTERPRETERS_NOT_SUPPORTED},
  #endif
  {0, NULL}
};
#endif

#ifdef __cplusplus
namespace {
  struct PyModuleDef __pyx_moduledef =
  #else
  static struct PyModuleDef __pyx_moduledef =
  #endif
  {
      PyModuleDef_HEAD_INIT,
      "_gevent_cgreenlet",
      0, /* m_doc */
    #if CYTHON_USE_MODULE_STATE
      sizeof(__pyx_mstatetype), /* m_size */
    #else
      (CYTHON_PEP489_MULTI_PHASE_INIT) ? 0 : -1, /* m_size */
    #endif
      __pyx_methods /* m_methods */,
    #if CYTHON_PEP489_MULTI_PHASE_INIT
      __pyx_moduledef_slots, /* m_slots */
    #else
      NULL, /* m_reload */
    #endif
    #if CYTHON_USE_MODULE_STATE
      __pyx_m_traverse, /* m_traverse */
      __pyx_m_clear, /* m_clear */
      NULL /* m_free */
    #else
      NULL, /* m_traverse */
      NULL, /* m_clear */
      NULL /* m_free */
    #endif
  };
  #ifdef __cplusplus
} /* anonymous namespace */
#endif

/* PyModInitFuncType */
#ifndef CYTHON_NO_PYINIT_EXPORT
  #define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#else
  #ifdef __cplusplus
  #define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
  #else
  #define __Pyx_PyMODINIT_FUNC PyObject *
  #endif
#endif

__Pyx_PyMODINIT_FUNC PyInit__gevent_cgreenlet(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit__gevent_cgreenlet(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
/* ModuleCreationPEP489 */
#include "src/gevent/_generated_include/ModuleCreationPEP489_impl_e8e48a7033664eca332c0112edbc6a62057c1d998b2c8eee547bdd9088e6ab4c.h"

static CYTHON_SMALL_CODE int __pyx_pymod_exec__gevent_cgreenlet(PyObject *__pyx_pyinit_module)
#endif
{
  int stringtab_initialized = 0;
  #if CYTHON_USE_MODULE_STATE
  int pystate_addmodule_run = 0;
  #endif
  __pyx_mstatetype *__pyx_mstate = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  size_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module '_gevent_cgreenlet' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #else
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_t_1 = __pyx_pyinit_module;
  Py_INCREF(__pyx_t_1);
  #else
  __pyx_t_1 = PyModule_Create(&__pyx_moduledef); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #if CYTHON_USE_MODULE_STATE
  {
    int add_module_result = __Pyx_State_AddModule(__pyx_t_1, &__pyx_moduledef);
    __pyx_t_1 = 0; /* transfer ownership from __pyx_t_1 to "_gevent_cgreenlet" pseudovariable */
    if (unlikely((add_module_result < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    pystate_addmodule_run = 1;
  }
  #else
  __pyx_m = __pyx_t_1;
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
  PyUnstable_Module_SetGIL(__pyx_m, Py_MOD_GIL_USED);
  #endif
  __pyx_mstate = __pyx_mstate_global;
  CYTHON_UNUSED_VAR(__pyx_t_1);
  __pyx_mstate->__pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_mstate->__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_mstate->__pyx_d);
  __pyx_mstate->__pyx_b = __Pyx_PyImport_AddModuleRef(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_mstate->__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_cython_runtime = __Pyx_PyImport_AddModuleRef("cython_runtime"); if (unlikely(!__pyx_mstate->__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_mstate->__pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /* ImportRefnannyAPI */
  #if CYTHON_REFNANNY
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
  if (!__Pyx_RefNanny) {
    PyErr_Clear();
    __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
    if (!__Pyx_RefNanny)
        Py_FatalError("failed to import 'refnanny' module");
  }
  #endif
  
__Pyx_RefNannySetupContext("PyInit__gevent_cgreenlet", 0);
  __Pyx_init_runtime_version();
  if (__Pyx_check_binary_version(__PYX_LIMITED_VERSION_HEX, __Pyx_get_runtime_version(), CYTHON_COMPILING_IN_LIMITED_API) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_mstate->__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_mstate->__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_mstate->__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Library function declarations ---*/
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitConstants(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  stringtab_initialized = 1;
  if (__Pyx_InitGlobals() < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__pyx_module_is_main_gevent___gevent_cgreenlet) {
    if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_name, __pyx_mstate_global->__pyx_n_u_main) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "gevent._gevent_cgreenlet")) {
      if (unlikely((PyDict_SetItemString(modules, "gevent._gevent_cgreenlet", __pyx_m) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_CreateCodeObjects(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code(__pyx_mstate);
  if (unlikely((__Pyx_modinit_variable_export_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely((__Pyx_modinit_function_export_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely((__Pyx_modinit_type_init_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely((__Pyx_modinit_type_import_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely((__Pyx_modinit_variable_import_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely((__Pyx_modinit_function_import_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Execution code ---*/

  /* "src/gevent/greenlet.py":6
 * from __future__ import absolute_import, print_function, division
 * 
 * from sys import _getframe as sys_getframe             # <<<<<<<<<<<<<<
 * from sys import exc_info as sys_exc_info
 * from weakref import ref as wref
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_getframe};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_sys, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_getframe};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6gevent_17_gevent_cgreenlet_sys_getframe);
        __Pyx_DECREF_SET(__pyx_v_6gevent_17_gevent_cgreenlet_sys_getframe, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/greenlet.py":7
 * 
 * from sys import _getframe as sys_getframe
 * from sys import exc_info as sys_exc_info             # <<<<<<<<<<<<<<
 * from weakref import ref as wref
 * 
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_exc_info};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_sys, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_exc_info};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6gevent_17_gevent_cgreenlet_sys_exc_info);
        __Pyx_DECREF_SET(__pyx_v_6gevent_17_gevent_cgreenlet_sys_exc_info, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/greenlet.py":8
 * from sys import _getframe as sys_getframe
 * from sys import exc_info as sys_exc_info
 * from weakref import ref as wref             # <<<<<<<<<<<<<<
 * 
 * # XXX: How to get cython to let us rename this as RawGreenlet
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_ref};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_weakref, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 8, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_ref};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 8, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6gevent_17_gevent_cgreenlet_wref);
        __Pyx_DECREF_SET(__pyx_v_6gevent_17_gevent_cgreenlet_wref, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/greenlet.py":12
 * # XXX: How to get cython to let us rename this as RawGreenlet
 * # like we prefer?
 * from greenlet import greenlet             # <<<<<<<<<<<<<<
 * from greenlet import GreenletExit
 * 
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_greenlet};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_greenlet, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 12, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/greenlet.py":13
 * # like we prefer?
 * from greenlet import greenlet
 * from greenlet import GreenletExit             # <<<<<<<<<<<<<<
 * 
 * from gevent._compat import reraise
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_GreenletExit};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_greenlet, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 13, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_GreenletExit};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 13, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6gevent_17_gevent_cgreenlet_GreenletExit);
        __Pyx_DECREF_SET(__pyx_v_6gevent_17_gevent_cgreenlet_GreenletExit, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/greenlet.py":15
 * from greenlet import GreenletExit
 * 
 * from gevent._compat import reraise             # <<<<<<<<<<<<<<
 * from gevent._compat import PYPY as _PYPY
 * from gevent._tblib import dump_traceback
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_reraise};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_gevent__compat, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 15, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_reraise};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 15, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6gevent_17_gevent_cgreenlet_reraise);
        __Pyx_DECREF_SET(__pyx_v_6gevent_17_gevent_cgreenlet_reraise, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/greenlet.py":16
 * 
 * from gevent._compat import reraise
 * from gevent._compat import PYPY as _PYPY             # <<<<<<<<<<<<<<
 * from gevent._tblib import dump_traceback
 * from gevent._tblib import load_traceback
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_PYPY};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_gevent__compat, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 16, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_PYPY};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 16, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 16, __pyx_L1_error)
        __pyx_v_6gevent_17_gevent_cgreenlet__PYPY = __pyx_t_5;
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/greenlet.py":17
 * from gevent._compat import reraise
 * from gevent._compat import PYPY as _PYPY
 * from gevent._tblib import dump_traceback             # <<<<<<<<<<<<<<
 * from gevent._tblib import load_traceback
 * 
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_dump_traceback};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_gevent__tblib, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 17, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_dump_traceback};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 17, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6gevent_17_gevent_cgreenlet_dump_traceback);
        __Pyx_DECREF_SET(__pyx_v_6gevent_17_gevent_cgreenlet_dump_traceback, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/greenlet.py":18
 * from gevent._compat import PYPY as _PYPY
 * from gevent._tblib import dump_traceback
 * from gevent._tblib import load_traceback             # <<<<<<<<<<<<<<
 * 
 * from gevent.exceptions import InvalidSwitchError
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_load_traceback};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_gevent__tblib, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 18, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_load_traceback};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 18, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6gevent_17_gevent_cgreenlet_load_traceback);
        __Pyx_DECREF_SET(__pyx_v_6gevent_17_gevent_cgreenlet_load_traceback, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/greenlet.py":20
 * from gevent._tblib import load_traceback
 * 
 * from gevent.exceptions import InvalidSwitchError             # <<<<<<<<<<<<<<
 * 
 * from gevent._hub_primitives import iwait_on_objects as iwait
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_InvalidSwitchError};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_gevent_exceptions, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 20, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_InvalidSwitchError};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 20, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6gevent_17_gevent_cgreenlet_InvalidSwitchError);
        __Pyx_DECREF_SET(__pyx_v_6gevent_17_gevent_cgreenlet_InvalidSwitchError, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/greenlet.py":22
 * from gevent.exceptions import InvalidSwitchError
 * 
 * from gevent._hub_primitives import iwait_on_objects as iwait             # <<<<<<<<<<<<<<
 * from gevent._hub_primitives import wait_on_objects as wait
 * 
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_iwait_on_objects};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_gevent__hub_primitives, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 22, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_iwait_on_objects};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 22, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6gevent_17_gevent_cgreenlet_iwait);
        __Pyx_DECREF_SET(__pyx_v_6gevent_17_gevent_cgreenlet_iwait, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/greenlet.py":23
 * 
 * from gevent._hub_primitives import iwait_on_objects as iwait
 * from gevent._hub_primitives import wait_on_objects as wait             # <<<<<<<<<<<<<<
 * 
 * from gevent.timeout import Timeout
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_wait_on_objects};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_gevent__hub_primitives, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 23, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_wait_on_objects};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 23, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6gevent_17_gevent_cgreenlet_wait);
        __Pyx_DECREF_SET(__pyx_v_6gevent_17_gevent_cgreenlet_wait, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/greenlet.py":25
 * from gevent._hub_primitives import wait_on_objects as wait
 * 
 * from gevent.timeout import Timeout             # <<<<<<<<<<<<<<
 * 
 * from gevent._config import config as GEVENT_CONFIG
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Timeout};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_gevent_timeout, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 25, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Timeout};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 25, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6gevent_17_gevent_cgreenlet_Timeout);
        __Pyx_DECREF_SET(__pyx_v_6gevent_17_gevent_cgreenlet_Timeout, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/greenlet.py":27
 * from gevent.timeout import Timeout
 * 
 * from gevent._config import config as GEVENT_CONFIG             # <<<<<<<<<<<<<<
 * from gevent._util import readproperty
 * from gevent._hub_local import get_hub_noargs as get_hub
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_config};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_gevent__config, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 27, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_config};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 27, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_v_6gevent_17_gevent_cgreenlet_GEVENT_CONFIG);
        __Pyx_DECREF_SET(__pyx_v_6gevent_17_gevent_cgreenlet_GEVENT_CONFIG, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/greenlet.py":28
 * 
 * from gevent._config import config as GEVENT_CONFIG
 * from gevent._util import readproperty             # <<<<<<<<<<<<<<
 * from gevent._hub_local import get_hub_noargs as get_hub
 * from gevent import _waiter
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_readproperty};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_gevent__util, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 28, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_readproperty};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 28, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 28, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/greenlet.py":29
 * from gevent._config import config as GEVENT_CONFIG
 * from gevent._util import readproperty
 * from gevent._hub_local import get_hub_noargs as get_hub             # <<<<<<<<<<<<<<
 * from gevent import _waiter
 * 
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_get_hub_noargs};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_gevent__hub_local, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 29, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_get_hub_noargs};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 29, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_get_hub_noargs, __pyx_t_4) < (0)) __PYX_ERR(0, 29, __pyx_L1_error)
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/greenlet.py":30
 * from gevent._util import readproperty
 * from gevent._hub_local import get_hub_noargs as get_hub
 * from gevent import _waiter             # <<<<<<<<<<<<<<
 * 
 * 
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_waiter_2};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_gevent, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 30, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_waiter_2};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 30, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 30, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/greenlet.py":33
 * 
 * 
 * __all__ = [             # <<<<<<<<<<<<<<
 *     'Greenlet',
 *     'joinall',
*/
  __pyx_t_2 = __Pyx_PyList_Pack(3, __pyx_mstate_global->__pyx_n_u_Greenlet_2, __pyx_mstate_global->__pyx_n_u_joinall, __pyx_mstate_global->__pyx_n_u_killall); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 33, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_all, __pyx_t_2) < (0)) __PYX_ERR(0, 33, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/greenlet.py":44
 * # is assignment) without generating a 'lvalue is not valid target'
 * # error.
 * locals()['getcurrent'] = __import__('greenlet').getcurrent             # <<<<<<<<<<<<<<
 * locals()['greenlet_init'] = lambda: None
 * locals()['Waiter'] = _waiter.Waiter
*/
  __pyx_t_4 = NULL;
  __pyx_t_6 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_mstate_global->__pyx_n_u_greenlet};
    __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin___import__, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 44, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_getcurrent); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_Globals(); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (unlikely((PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_getcurrent, __pyx_t_4) < 0))) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/greenlet.py":45
 * # error.
 * locals()['getcurrent'] = __import__('greenlet').getcurrent
 * locals()['greenlet_init'] = lambda: None             # <<<<<<<<<<<<<<
 * locals()['Waiter'] = _waiter.Waiter
 * # With Cython, this raises a TypeError if the parent is *not*
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_17_gevent_cgreenlet_6lambda, 0, __pyx_mstate_global->__pyx_n_u_lambda, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_cgreenlet, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[2])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  __pyx_t_2 = __Pyx_Globals(); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (unlikely((PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_greenlet_init, __pyx_t_4) < 0))) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/greenlet.py":46
 * locals()['getcurrent'] = __import__('greenlet').getcurrent
 * locals()['greenlet_init'] = lambda: None
 * locals()['Waiter'] = _waiter.Waiter             # <<<<<<<<<<<<<<
 * # With Cython, this raises a TypeError if the parent is *not*
 * # the hub (SwitchOutGreenletWithLoop); in pure-Python, we will
*/
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_waiter_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 46, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_Waiter); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 46, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_Globals(); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 46, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (unlikely((PyDict_SetItem(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_Waiter, __pyx_t_2) < 0))) __PYX_ERR(0, 46, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/greenlet.py":53
 * # This must ONLY be called when we know that `s` is not None and is in fact a greenlet
 * # object (e.g., when called on `self`)
 * locals()['get_my_hub'] = lambda s: s.parent             # <<<<<<<<<<<<<<
 * # This must also ONLY be called when we know that S is not None and is in fact a greenlet
 * # object (including the result of getcurrent())
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_17_gevent_cgreenlet_7lambda1, 0, __pyx_mstate_global->__pyx_n_u_lambda, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_cgreenlet, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[3])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 53, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  __pyx_t_4 = __Pyx_Globals(); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 53, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (unlikely((PyDict_SetItem(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_get_my_hub, __pyx_t_2) < 0))) __PYX_ERR(0, 53, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/greenlet.py":56
 * # This must also ONLY be called when we know that S is not None and is in fact a greenlet
 * # object (including the result of getcurrent())
 * locals()['get_generic_parent'] = lambda s: s.parent             # <<<<<<<<<<<<<<
 * 
 * # Frame access
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_17_gevent_cgreenlet_8lambda2, 0, __pyx_mstate_global->__pyx_n_u_lambda, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_cgreenlet, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[4])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 56, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  __pyx_t_4 = __Pyx_Globals(); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 56, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (unlikely((PyDict_SetItem(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_get_generic_parent, __pyx_t_2) < 0))) __PYX_ERR(0, 56, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/greenlet.py":59
 * 
 * # Frame access
 * locals()['Gevent_PyFrame_GetCode'] = lambda frame: frame.f_code             # <<<<<<<<<<<<<<
 * locals()['Gevent_PyFrame_GetLineNumber'] = lambda frame: frame.f_lineno
 * locals()['Gevent_PyFrame_GetBack'] = lambda frame: frame.f_back
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_17_gevent_cgreenlet_9lambda3, 0, __pyx_mstate_global->__pyx_n_u_lambda, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_cgreenlet, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[5])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 59, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  __pyx_t_4 = __Pyx_Globals(); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 59, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (unlikely((PyDict_SetItem(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_Gevent_PyFrame_GetCode, __pyx_t_2) < 0))) __PYX_ERR(0, 59, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/greenlet.py":60
 * # Frame access
 * locals()['Gevent_PyFrame_GetCode'] = lambda frame: frame.f_code
 * locals()['Gevent_PyFrame_GetLineNumber'] = lambda frame: frame.f_lineno             # <<<<<<<<<<<<<<
 * locals()['Gevent_PyFrame_GetBack'] = lambda frame: frame.f_back
 * 
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_17_gevent_cgreenlet_10lambda4, 0, __pyx_mstate_global->__pyx_n_u_lambda, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_cgreenlet, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[6])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 60, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  __pyx_t_4 = __Pyx_Globals(); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 60, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (unlikely((PyDict_SetItem(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_Gevent_PyFrame_GetLineNumber, __pyx_t_2) < 0))) __PYX_ERR(0, 60, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/greenlet.py":61
 * locals()['Gevent_PyFrame_GetCode'] = lambda frame: frame.f_code
 * locals()['Gevent_PyFrame_GetLineNumber'] = lambda frame: frame.f_lineno
 * locals()['Gevent_PyFrame_GetBack'] = lambda frame: frame.f_back             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_17_gevent_cgreenlet_11lambda5, 0, __pyx_mstate_global->__pyx_n_u_lambda, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_cgreenlet, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[7])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 61, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  __pyx_t_4 = __Pyx_Globals(); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 61, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (unlikely((PyDict_SetItem(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_Gevent_PyFrame_GetBack, __pyx_t_2) < 0))) __PYX_ERR(0, 61, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "src/gevent/greenlet.py":64
 * 
 * 
 * if _PYPY:             # <<<<<<<<<<<<<<
 *     import _continuation # pylint:disable=import-error
 *     _continulet = _continuation.continulet
*/
  if (__pyx_v_6gevent_17_gevent_cgreenlet__PYPY) {

    /* "src/gevent/greenlet.py":65
 * 
 * if _PYPY:
 *     import _continuation # pylint:disable=import-error             # <<<<<<<<<<<<<<
 *     _continulet = _continuation.continulet
 * 
*/
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_continuation, 0, 0, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 65, __pyx_L1_error)
    __pyx_t_2 = __pyx_t_1;
    __Pyx_GOTREF(__pyx_t_2);
    if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_continuation, __pyx_t_2) < (0)) __PYX_ERR(0, 65, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "src/gevent/greenlet.py":66
 * if _PYPY:
 *     import _continuation # pylint:disable=import-error
 *     _continulet = _continuation.continulet             # <<<<<<<<<<<<<<
 * 
 * 
*/
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_continuation); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 66, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_continulet); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 66, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_continulet_2, __pyx_t_4) < (0)) __PYX_ERR(0, 66, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "src/gevent/greenlet.py":64
 * 
 * 
 * if _PYPY:             # <<<<<<<<<<<<<<
 *     import _continuation # pylint:disable=import-error
 *     _continulet = _continuation.continulet
*/
  }

  /* "src/gevent/greenlet.py":75
 *     Can be called only from main loop.
 *     """
 *     __slots__ = ['callback']             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, callback):
*/
  __pyx_t_4 = __Pyx_PyList_Pack(1, __pyx_mstate_global->__pyx_n_u_callback); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 75, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_SpawnedLink, __pyx_mstate_global->__pyx_n_u_slots, __pyx_t_4) < (0)) __PYX_ERR(0, 75, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/greenlet.py":108
 *     Can be called only from main loop.
 *     """
 *     __slots__ = []             # <<<<<<<<<<<<<<
 * 
 *     def __call__(self, source):
*/
  __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 108, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink, __pyx_mstate_global->__pyx_n_u_slots, __pyx_t_4) < (0)) __PYX_ERR(0, 108, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/greenlet.py":120
 *     Can be called only from main loop.
 *     """
 *     __slots__ = []             # <<<<<<<<<<<<<<
 * 
 *     def __call__(self, source):
*/
  __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_FailureSpawnedLink, __pyx_mstate_global->__pyx_n_u_slots, __pyx_t_4) < (0)) __PYX_ERR(0, 120, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/greenlet.py":128
 * class _Frame(object):
 * 
 *     __slots__ = ('f_code', 'f_lineno', 'f_back')             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self):
*/
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet__Frame, __pyx_mstate_global->__pyx_n_u_slots, __pyx_mstate_global->__pyx_tuple[1]) < (0)) __PYX_ERR(0, 128, __pyx_L1_error)

  /* "src/gevent/greenlet.py":175
 * 
 * 
 * _greenlet__init__ = greenlet.__init__             # <<<<<<<<<<<<<<
 * 
 * class Greenlet(greenlet):
*/
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_greenlet), __pyx_mstate_global->__pyx_n_u_init); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 175, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_XGOTREF(__pyx_v_6gevent_17_gevent_cgreenlet__greenlet__init__);
  __Pyx_DECREF_SET(__pyx_v_6gevent_17_gevent_cgreenlet__greenlet__init__, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_t_4 = 0;

  /* "src/gevent/greenlet.py":183
 *     # pylint:disable=too-many-public-methods,too-many-instance-attributes
 * 
 *     spawning_stack_limit = 10             # <<<<<<<<<<<<<<
 * 
 *     # pylint:disable=keyword-arg-before-vararg,super-init-not-called
*/
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, __pyx_mstate_global->__pyx_n_u_spawning_stack_limit, __pyx_mstate_global->__pyx_int_10) < (0)) __PYX_ERR(0, 183, __pyx_L1_error)

  /* "src/gevent/greenlet.py":356
 *         return self._ident
 * 
 *     @readproperty             # <<<<<<<<<<<<<<
 *     def name(self):
 *         """
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_3name, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Greenlet_name, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_cgreenlet, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[8])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, __pyx_mstate_global->__pyx_n_u_name_2, __pyx_t_4) < (0)) __PYX_ERR(0, 356, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_readproperty); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GetNameInClass(__pyx_t_8, (PyObject*)__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_6 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_8};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 356, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, __pyx_mstate_global->__pyx_n_u_name_2, __pyx_t_4) < (0)) __PYX_ERR(0, 356, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/greenlet.py":372
 *         return 'Greenlet-%d' % (self.minimal_ident,)
 * 
 *     def _raise_exception(self):             # <<<<<<<<<<<<<<
 *         reraise(*self.exc_info)
 * 
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_5_raise_exception, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Greenlet__raise_exception, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_cgreenlet, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[9])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 372, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, __pyx_mstate_global->__pyx_n_u_raise_exception, __pyx_t_4) < (0)) __PYX_ERR(0, 372, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/greenlet.py":386
 *     ### Lifecycle
 * 
 *     if _PYPY:             # <<<<<<<<<<<<<<
 *         # oops - pypy's .dead relies on __nonzero__ which we overriden above
 *         @property
*/
  if (__pyx_v_6gevent_17_gevent_cgreenlet__PYPY) {

    /* "src/gevent/greenlet.py":401
 *             return self._greenlet__started and not _continulet.is_pending(self)
 *     else:
 *         @property             # <<<<<<<<<<<<<<
 *         def dead(self):
 *             """
*/
    goto __pyx_L3;
  }
  /*else*/ {
  }
  __pyx_L3:;

  /* "src/gevent/greenlet.py":504
 *         return bool(self)
 * 
 *     def ready(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return a true value if and only if the greenlet has finished
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_9ready, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Greenlet_ready, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_cgreenlet, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[10])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, __pyx_mstate_global->__pyx_n_u_ready, __pyx_t_4) < (0)) __PYX_ERR(0, 504, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/greenlet.py":515
 *         return self.dead or self._exc_info is not None
 * 
 *     def successful(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return a true value if and only if the greenlet has finished execution
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_11successful, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Greenlet_successful, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_cgreenlet, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[11])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, __pyx_mstate_global->__pyx_n_u_successful, __pyx_t_4) < (0)) __PYX_ERR(0, 515, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/greenlet.py":545
 * 
 * 
 *     def _formatinfo(self):             # <<<<<<<<<<<<<<
 *         info = self._formatted_info
 *         if info is not None:
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_15_formatinfo, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Greenlet__formatinfo, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_cgreenlet, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[12])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, __pyx_mstate_global->__pyx_n_u_formatinfo, __pyx_t_4) < (0)) __PYX_ERR(0, 545, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/greenlet.py":600
 *             )
 * 
 *     def throw(self, *args):             # <<<<<<<<<<<<<<
 *         """Immediately switch into the greenlet and raise an exception in it.
 * 
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_17throw, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Greenlet_throw, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_cgreenlet, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[13])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 600, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, __pyx_mstate_global->__pyx_n_u_throw, __pyx_t_4) < (0)) __PYX_ERR(0, 600, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/greenlet.py":622
 *             self.__handle_death_before_start(args)
 * 
 *     def start(self):             # <<<<<<<<<<<<<<
 *         """Schedule the greenlet to run in this loop iteration"""
 *         if self._start_event is None:
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_19start, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Greenlet_start, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_cgreenlet, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[14])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 622, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, __pyx_mstate_global->__pyx_n_u_start, __pyx_t_4) < (0)) __PYX_ERR(0, 622, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/greenlet.py":629
 *             self._start_event = hub.loop.run_callback(self.switch)
 * 
 *     def start_later(self, seconds):             # <<<<<<<<<<<<<<
 *         """
 *         start_later(seconds) -> None
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_21start_later, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Greenlet_start_later, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_cgreenlet, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[15])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 629, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, __pyx_mstate_global->__pyx_n_u_start_later, __pyx_t_4) < (0)) __PYX_ERR(0, 629, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/greenlet.py":642
 *             self._start_event.start(self.switch)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def add_spawn_callback(callback):
 *         """
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_23add_spawn_callback, __Pyx_CYFUNCTION_STATICMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Greenlet_add_spawn_callback, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_cgreenlet, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[16])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 642, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, __pyx_mstate_global->__pyx_n_u_add_spawn_callback, __pyx_t_4) < (0)) __PYX_ERR(0, 642, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_7 = NULL;
  __Pyx_GetNameInClass(__pyx_t_8, (PyObject*)__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, __pyx_mstate_global->__pyx_n_u_add_spawn_callback); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 642, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_6 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_8};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_staticmethod, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 642, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, __pyx_mstate_global->__pyx_n_u_add_spawn_callback, __pyx_t_4) < (0)) __PYX_ERR(0, 642, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/greenlet.py":661
 *         _spawn_callbacks.add(callback)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def remove_spawn_callback(callback):
 *         """
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_25remove_spawn_callback, __Pyx_CYFUNCTION_STATICMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Greenlet_remove_spawn_callback, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_cgreenlet, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[17])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, __pyx_mstate_global->__pyx_n_u_remove_spawn_callback, __pyx_t_4) < (0)) __PYX_ERR(0, 661, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_8 = NULL;
  __Pyx_GetNameInClass(__pyx_t_7, (PyObject*)__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, __pyx_mstate_global->__pyx_n_u_remove_spawn_callback); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_7};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_staticmethod, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 661, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, __pyx_mstate_global->__pyx_n_u_remove_spawn_callback, __pyx_t_4) < (0)) __PYX_ERR(0, 661, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/greenlet.py":678
 *                 _spawn_callbacks = None
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def spawn(cls, *args, **kwargs):
 *         """
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_27spawn, __Pyx_CYFUNCTION_CLASSMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Greenlet_spawn, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_cgreenlet, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[18])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, __pyx_mstate_global->__pyx_n_u_spawn, __pyx_t_4) < (0)) __PYX_ERR(0, 678, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_GetNameInClass(__pyx_t_4, (PyObject*)__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, __pyx_mstate_global->__pyx_n_u_spawn); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = __Pyx_Method_ClassMethod(__pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, __pyx_mstate_global->__pyx_n_u_spawn, __pyx_t_7) < (0)) __PYX_ERR(0, 678, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "src/gevent/greenlet.py":696
 *         return g
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def spawn_later(cls, seconds, *args, **kwargs):
 *         """
*/
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_29spawn_later, __Pyx_CYFUNCTION_CLASSMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Greenlet_spawn_later, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_cgreenlet, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[19])); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 696, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_7);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, __pyx_mstate_global->__pyx_n_u_spawn_later, __pyx_t_7) < (0)) __PYX_ERR(0, 696, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_GetNameInClass(__pyx_t_7, (PyObject*)__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, __pyx_mstate_global->__pyx_n_u_spawn_later); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 696, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_4 = __Pyx_Method_ClassMethod(__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 696, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, __pyx_mstate_global->__pyx_n_u_spawn_later, __pyx_t_4) < (0)) __PYX_ERR(0, 696, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/greenlet.py":719
 *         return g
 * 
 *     def _maybe_kill_before_start(self, exception):             # <<<<<<<<<<<<<<
 *         # Helper for Greenlet.kill(), and also for killall()
 *         self.__cancel_start()
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_31_maybe_kill_before_start, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Greenlet__maybe_kill_before_star, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_cgreenlet, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[20])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 719, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, __pyx_mstate_global->__pyx_n_u_maybe_kill_before_start, __pyx_t_4) < (0)) __PYX_ERR(0, 719, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/greenlet.py":732
 *         return dead
 * 
 *     def kill(self, exception=GreenletExit, block=True, timeout=None):             # <<<<<<<<<<<<<<
 *         """
 *         Raise the ``exception`` in the greenlet.
*/
  __Pyx_INCREF(__pyx_v_6gevent_17_gevent_cgreenlet_GreenletExit);
  __pyx_mstate_global->__pyx_k__12 = __pyx_v_6gevent_17_gevent_cgreenlet_GreenletExit;
  __Pyx_GIVEREF(__pyx_v_6gevent_17_gevent_cgreenlet_GreenletExit);
  __pyx_t_4 = PyTuple_Pack(3, __pyx_v_6gevent_17_gevent_cgreenlet_GreenletExit, Py_True, Py_None); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 732, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_33kill, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Greenlet_kill, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_cgreenlet, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[21])); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 732, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_7);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, __pyx_mstate_global->__pyx_n_u_kill, __pyx_t_7) < (0)) __PYX_ERR(0, 732, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "src/gevent/greenlet.py":793
 *                 self.join(timeout)
 * 
 *     def get(self, block=True, timeout=None):             # <<<<<<<<<<<<<<
 *         """
 *         get(block=True, timeout=None) -> object
*/
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_35get, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Greenlet_get, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_cgreenlet, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[22])); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 793, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_7);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_mstate_global->__pyx_tuple[2]);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, __pyx_mstate_global->__pyx_n_u_get_2, __pyx_t_7) < (0)) __PYX_ERR(0, 793, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "src/gevent/greenlet.py":837
 *             self._raise_exception()
 * 
 *     def join(self, timeout=None):             # <<<<<<<<<<<<<<
 *         """
 *         join(timeout=None) -> None
*/
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_37join, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Greenlet_join, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_cgreenlet, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[23])); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 837, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_7);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_mstate_global->__pyx_tuple[3]);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, __pyx_mstate_global->__pyx_n_u_join, __pyx_t_7) < (0)) __PYX_ERR(0, 837, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "src/gevent/greenlet.py":865
 *             raise
 * 
 *     def __enter__(self):             # <<<<<<<<<<<<<<
 *         return self
 * 
*/
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_39__enter__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Greenlet___enter, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_cgreenlet, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[24])); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 865, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_7);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, __pyx_mstate_global->__pyx_n_u_enter, __pyx_t_7) < (0)) __PYX_ERR(0, 865, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "src/gevent/greenlet.py":868
 *         return self
 * 
 *     def __exit__(self, t, v, tb):             # <<<<<<<<<<<<<<
 *         if t is None:
 *             try:
*/
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_41__exit__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Greenlet___exit, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_cgreenlet, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[25])); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_7);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, __pyx_mstate_global->__pyx_n_u_exit, __pyx_t_7) < (0)) __PYX_ERR(0, 868, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "src/gevent/greenlet.py":906
 *             del exc_info
 * 
 *     def run(self):             # <<<<<<<<<<<<<<
 *         try:
 *             self.__cancel_start()
*/
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_43run, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Greenlet_run, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_cgreenlet, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[26])); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 906, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_7);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, __pyx_mstate_global->__pyx_n_u_run, __pyx_t_7) < (0)) __PYX_ERR(0, 906, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "src/gevent/greenlet.py":932
 *         self.kwargs.clear()
 * 
 *     def _run(self):             # <<<<<<<<<<<<<<
 *         """
 *         Subclasses may override this method to take any number of
*/
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_45_run, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Greenlet__run, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_cgreenlet, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[27])); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 932, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_7);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, __pyx_mstate_global->__pyx_n_u_run_2, __pyx_t_7) < (0)) __PYX_ERR(0, 932, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "src/gevent/greenlet.py":946
 *         return
 * 
 *     def has_links(self):             # <<<<<<<<<<<<<<
 *         return len(self._links)
 * 
*/
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_47has_links, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Greenlet_has_links, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_cgreenlet, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[28])); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 946, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_7);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, __pyx_mstate_global->__pyx_n_u_has_links, __pyx_t_7) < (0)) __PYX_ERR(0, 946, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "src/gevent/greenlet.py":949
 *         return len(self._links)
 * 
 *     def rawlink(self, callback):             # <<<<<<<<<<<<<<
 *         """
 *         Register a callable to be executed when the greenlet finishes
*/
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_49rawlink, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Greenlet_rawlink, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_cgreenlet, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[29])); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 949, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_7);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, __pyx_mstate_global->__pyx_n_u_rawlink, __pyx_t_7) < (0)) __PYX_ERR(0, 949, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "src/gevent/greenlet.py":971
 *             self._notifier = hub.loop.run_callback(self._notify_links)
 * 
 *     def link(self, callback, SpawnedLink=SpawnedLink):             # <<<<<<<<<<<<<<
 *         """
 *         Link greenlet's completion to a callable.
*/
  __Pyx_INCREF((PyObject *)__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_SpawnedLink);
  __pyx_mstate_global->__pyx_k__13 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_SpawnedLink);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_SpawnedLink);
  __pyx_t_7 = PyTuple_Pack(1, ((PyObject *)__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_SpawnedLink)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 971, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_51link, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Greenlet_link, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_cgreenlet, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[30])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 971, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, __pyx_mstate_global->__pyx_n_u_link, __pyx_t_4) < (0)) __PYX_ERR(0, 971, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/greenlet.py":988
 *         self.rawlink(SpawnedLink(callback))
 * 
 *     def unlink(self, callback):             # <<<<<<<<<<<<<<
 *         """Remove the callback set by :meth:`link` or :meth:`rawlink`"""
 *         try:
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_53unlink, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Greenlet_unlink, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_cgreenlet, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[31])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 988, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, __pyx_mstate_global->__pyx_n_u_unlink, __pyx_t_4) < (0)) __PYX_ERR(0, 988, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/greenlet.py":995
 *             pass
 * 
 *     def unlink_all(self):             # <<<<<<<<<<<<<<
 *         """
 *         Remove all the callbacks.
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_55unlink_all, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Greenlet_unlink_all, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_cgreenlet, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[32])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 995, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, __pyx_mstate_global->__pyx_n_u_unlink_all, __pyx_t_4) < (0)) __PYX_ERR(0, 995, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/greenlet.py":1003
 *         del self._links[:]
 * 
 *     def link_value(self, callback, SpawnedLink=SuccessSpawnedLink):             # <<<<<<<<<<<<<<
 *         """
 *         Like :meth:`link` but *callback* is only notified when the greenlet
*/
  __Pyx_INCREF((PyObject *)__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink);
  __pyx_mstate_global->__pyx_k__14 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink);
  __pyx_t_4 = PyTuple_Pack(1, ((PyObject *)__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_SuccessSpawnedLink)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1003, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_57link_value, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Greenlet_link_value, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_cgreenlet, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[33])); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1003, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_7);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, __pyx_mstate_global->__pyx_n_u_link_value, __pyx_t_7) < (0)) __PYX_ERR(0, 1003, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "src/gevent/greenlet.py":1011
 *         self.link(callback, SpawnedLink=SpawnedLink)
 * 
 *     def link_exception(self, callback, SpawnedLink=FailureSpawnedLink):             # <<<<<<<<<<<<<<
 *         """
 *         Like :meth:`link` but *callback* is only notified when the
*/
  __Pyx_INCREF((PyObject *)__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_FailureSpawnedLink);
  __pyx_mstate_global->__pyx_k__15 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_FailureSpawnedLink);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_FailureSpawnedLink);
  __pyx_t_7 = PyTuple_Pack(1, ((PyObject *)__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_FailureSpawnedLink)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1011, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_59link_exception, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Greenlet_link_exception, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_cgreenlet, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[34])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1011, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, __pyx_mstate_global->__pyx_n_u_link_exception, __pyx_t_4) < (0)) __PYX_ERR(0, 1011, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/greenlet.py":1019
 *         self.link(callback, SpawnedLink=SpawnedLink)
 * 
 *     def _notify_links(self):             # <<<<<<<<<<<<<<
 *         while self._links:
 *             # Early links are allowed to remove later links
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_17_gevent_cgreenlet_8Greenlet_61_notify_links, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Greenlet__notify_links, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_cgreenlet, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[35])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1019, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet_Greenlet, __pyx_mstate_global->__pyx_n_u_notify_links, __pyx_t_4) < (0)) __PYX_ERR(0, 1019, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/greenlet.py":1036
 * 
 * class _dummy_event(object):
 *     __slots__ = ('pending', 'active')             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self):
*/
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet__dummy_event, __pyx_mstate_global->__pyx_n_u_slots, __pyx_mstate_global->__pyx_tuple[4]) < (0)) __PYX_ERR(0, 1036, __pyx_L1_error)

  /* "src/gevent/greenlet.py":1041
 *         self.pending = self.active = False
 * 
 *     def stop(self):             # <<<<<<<<<<<<<<
 *         pass
 * 
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_17_gevent_cgreenlet_12_dummy_event_3stop, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_dummy_event_stop, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_cgreenlet, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[36])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet__dummy_event, __pyx_mstate_global->__pyx_n_u_stop, __pyx_t_4) < (0)) __PYX_ERR(0, 1041, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/greenlet.py":1044
 *         pass
 * 
 *     def start(self, cb): # pylint:disable=unused-argument             # <<<<<<<<<<<<<<
 *         raise AssertionError("Cannot start the dummy event")
 * 
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_17_gevent_cgreenlet_12_dummy_event_5start, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_dummy_event_start, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_cgreenlet, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[37])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1044, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet__dummy_event, __pyx_mstate_global->__pyx_n_u_start, __pyx_t_4) < (0)) __PYX_ERR(0, 1044, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/greenlet.py":1047
 *         raise AssertionError("Cannot start the dummy event")
 * 
 *     def close(self):             # <<<<<<<<<<<<<<
 *         pass
 * 
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_17_gevent_cgreenlet_12_dummy_event_7close, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_dummy_event_close, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_cgreenlet, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[38])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1047, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet__dummy_event, __pyx_mstate_global->__pyx_n_u_close, __pyx_t_4) < (0)) __PYX_ERR(0, 1047, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/greenlet.py":1050
 *         pass
 * 
 * _cancelled_start_event = _dummy_event()             # <<<<<<<<<<<<<<
 * _start_completed_event = _dummy_event()
 * 
*/
  __pyx_t_7 = NULL;
  __pyx_t_6 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet__dummy_event, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1050, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_4);
  }
  __Pyx_XGOTREF((PyObject *)__pyx_v_6gevent_17_gevent_cgreenlet__cancelled_start_event);
  __Pyx_DECREF_SET(__pyx_v_6gevent_17_gevent_cgreenlet__cancelled_start_event, ((struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *)__pyx_t_4));
  __Pyx_GIVEREF((PyObject *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "src/gevent/greenlet.py":1051
 * 
 * _cancelled_start_event = _dummy_event()
 * _start_completed_event = _dummy_event()             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_7 = NULL;
  __pyx_t_6 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet__dummy_event, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1051, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_4);
  }
  __Pyx_XGOTREF((PyObject *)__pyx_v_6gevent_17_gevent_cgreenlet__start_completed_event);
  __Pyx_DECREF_SET(__pyx_v_6gevent_17_gevent_cgreenlet__start_completed_event, ((struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *)__pyx_t_4));
  __Pyx_GIVEREF((PyObject *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "src/gevent/greenlet.py":1056
 * # This is *only* called as a callback from the hub via Greenlet.kill(),
 * # and its first argument is the Greenlet. So we can be sure about the types.
 * def _kill(glet, exception, waiter):             # <<<<<<<<<<<<<<
 *     try:
 *         if isinstance(exception, tuple) and len(exception) == 3:
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_17_gevent_cgreenlet_1_kill, 0, __pyx_mstate_global->__pyx_n_u_kill_2, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_cgreenlet, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[39])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1056, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_kill_2, __pyx_t_4) < (0)) __PYX_ERR(0, 1056, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/greenlet.py":1069
 * 
 * 
 * def joinall(greenlets, timeout=None, raise_error=False, count=None):             # <<<<<<<<<<<<<<
 *     """
 *     Wait for the ``greenlets`` to finish.
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_17_gevent_cgreenlet_3joinall, 0, __pyx_mstate_global->__pyx_n_u_joinall, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_cgreenlet, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[40])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1069, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_mstate_global->__pyx_tuple[5]);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_joinall, __pyx_t_4) < (0)) __PYX_ERR(0, 1069, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/greenlet.py":1126
 * 
 * 
 * _spawn_callbacks = None             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_INCREF(Py_None);
  __Pyx_XGOTREF(__pyx_v_6gevent_17_gevent_cgreenlet__spawn_callbacks);
  __Pyx_DECREF_SET(__pyx_v_6gevent_17_gevent_cgreenlet__spawn_callbacks, ((PyObject*)Py_None));
  __Pyx_GIVEREF(Py_None);

  /* "src/gevent/greenlet.py":1129
 * 
 * 
 * def killall(greenlets, exception=GreenletExit, block=True, timeout=None):             # <<<<<<<<<<<<<<
 *     """
 *     Forceably terminate all the *greenlets* by causing them to raise *exception*.
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_17_gevent_cgreenlet_5killall, 0, __pyx_mstate_global->__pyx_n_u_killall, NULL, __pyx_mstate_global->__pyx_n_u_gevent__gevent_cgreenlet, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[41])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_4, __pyx_mstate_global->__pyx_ptype_6gevent_17_gevent_cgreenlet___pyx_defaults)) __PYX_ERR(0, 1129, __pyx_L1_error)
  __Pyx_INCREF(__pyx_v_6gevent_17_gevent_cgreenlet_GreenletExit);
  __Pyx_CyFunction_Defaults(struct __pyx_defaults, __pyx_t_4)->arg0 = __pyx_v_6gevent_17_gevent_cgreenlet_GreenletExit;
  __Pyx_GIVEREF(__pyx_v_6gevent_17_gevent_cgreenlet_GreenletExit);
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_4, __pyx_pf_6gevent_17_gevent_cgreenlet_12__defaults__);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_killall, __pyx_t_4) < (0)) __PYX_ERR(0, 1129, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/greenlet.py":1201
 *     greenlet_init() # pylint:disable=undefined-variable
 * 
 * _init()             # <<<<<<<<<<<<<<
 * 
 * from gevent._util import import_c_accel
*/
  __pyx_f_6gevent_17_gevent_cgreenlet__init(); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1201, __pyx_L1_error)

  /* "src/gevent/greenlet.py":1203
 * _init()
 * 
 * from gevent._util import import_c_accel             # <<<<<<<<<<<<<<
 * import_c_accel(globals(), 'gevent._greenlet')
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_import_c_accel};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_gevent__util, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1203, __pyx_L1_error)
  }
  __pyx_t_4 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_4);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_import_c_accel};
    __pyx_t_3 = 0; {
      __pyx_t_7 = __Pyx_ImportFrom(__pyx_t_4, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1203, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_7) < (0)) __PYX_ERR(0, 1203, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/greenlet.py":1204
 * 
 * from gevent._util import import_c_accel
 * import_c_accel(globals(), 'gevent._greenlet')             # <<<<<<<<<<<<<<
*/
  __pyx_t_7 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_import_c_accel); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1204, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_2 = __Pyx_Globals(); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1204, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = 1;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_7, __pyx_t_2, __pyx_mstate_global->__pyx_kp_u_gevent__greenlet};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_8, __pyx_callargs+__pyx_t_6, (3-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1204, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "src/gevent/greenlet.py":1
 * # Copyright (c) 2009-2012 Denis Bilenko. See LICENSE for details.             # <<<<<<<<<<<<<<
 * # cython: auto_pickle=False,embedsignature=True,always_allow_keywords=False
 * # pylint:disable=too-many-lines
*/
  __pyx_t_4 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_test, __pyx_t_4) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  if (__pyx_m) {
    if (__pyx_mstate->__pyx_d && stringtab_initialized) {
      __Pyx_AddTraceback("init gevent._gevent_cgreenlet", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    #if !CYTHON_USE_MODULE_STATE
    Py_CLEAR(__pyx_m);
    #else
    Py_DECREF(__pyx_m);
    if (pystate_addmodule_run) {
      PyObject *tp, *value, *tb;
      PyErr_Fetch(&tp, &value, &tb);
      PyState_RemoveModule(&__pyx_moduledef);
      PyErr_Restore(tp, value, tb);
    }
    #endif
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init gevent._gevent_cgreenlet");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #else
  return __pyx_m;
  #endif
}
/* #### Code section: pystring_table ### */
/* #### Code section: cached_builtins ### */

static int __Pyx_InitCachedBuiltins(__pyx_mstatetype *__pyx_mstate) {
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __pyx_builtin___import__ = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_import); if (!__pyx_builtin___import__) __PYX_ERR(0, 44, __pyx_L1_error)
  __pyx_builtin_staticmethod = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_staticmethod); if (!__pyx_builtin_staticmethod) __PYX_ERR(0, 642, __pyx_L1_error)
  __pyx_builtin_id = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_id); if (!__pyx_builtin_id) __PYX_ERR(0, 538, __pyx_L1_error)

  /* Cached unbound methods */
  __pyx_mstate->__pyx_umethod_PyDict_Type_items.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_items.method_name = &__pyx_mstate->__pyx_n_u_items;
  __pyx_mstate->__pyx_umethod_PyDict_Type_pop.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_pop.method_name = &__pyx_mstate->__pyx_n_u_pop;
  __pyx_mstate->__pyx_umethod_PyDict_Type_values.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_values.method_name = &__pyx_mstate->__pyx_n_u_values;
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cached_constants ### */

static int __Pyx_InitCachedConstants(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "src/gevent/greenlet.py":878
 * 
 *     def __report_result(self, result):
 *         self._exc_info = (None, None, None)             # <<<<<<<<<<<<<<
 *         self.value = result
 *         if self._links and not self._notifier:
*/
  __pyx_mstate_global->__pyx_tuple[0] = PyTuple_Pack(3, Py_None, Py_None, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_tuple[0])) __PYX_ERR(0, 878, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[0]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[0]);

  /* "src/gevent/greenlet.py":128
 * class _Frame(object):
 * 
 *     __slots__ = ('f_code', 'f_lineno', 'f_back')             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self):
*/
  __pyx_mstate_global->__pyx_tuple[1] = PyTuple_Pack(3, __pyx_mstate_global->__pyx_n_u_f_code, __pyx_mstate_global->__pyx_n_u_f_lineno, __pyx_mstate_global->__pyx_n_u_f_back); if (unlikely(!__pyx_mstate_global->__pyx_tuple[1])) __PYX_ERR(0, 128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[1]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[1]);

  /* "src/gevent/greenlet.py":793
 *                 self.join(timeout)
 * 
 *     def get(self, block=True, timeout=None):             # <<<<<<<<<<<<<<
 *         """
 *         get(block=True, timeout=None) -> object
*/
  __pyx_mstate_global->__pyx_tuple[2] = PyTuple_Pack(2, Py_True, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_tuple[2])) __PYX_ERR(0, 793, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[2]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[2]);

  /* "src/gevent/greenlet.py":837
 *             self._raise_exception()
 * 
 *     def join(self, timeout=None):             # <<<<<<<<<<<<<<
 *         """
 *         join(timeout=None) -> None
*/
  __pyx_mstate_global->__pyx_tuple[3] = PyTuple_Pack(1, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_tuple[3])) __PYX_ERR(0, 837, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[3]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[3]);

  /* "src/gevent/greenlet.py":1036
 * 
 * class _dummy_event(object):
 *     __slots__ = ('pending', 'active')             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self):
*/
  __pyx_mstate_global->__pyx_tuple[4] = PyTuple_Pack(2, __pyx_mstate_global->__pyx_n_u_pending, __pyx_mstate_global->__pyx_n_u_active); if (unlikely(!__pyx_mstate_global->__pyx_tuple[4])) __PYX_ERR(0, 1036, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[4]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[4]);

  /* "src/gevent/greenlet.py":1069
 * 
 * 
 * def joinall(greenlets, timeout=None, raise_error=False, count=None):             # <<<<<<<<<<<<<<
 *     """
 *     Wait for the ``greenlets`` to finish.
*/
  __pyx_mstate_global->__pyx_tuple[5] = PyTuple_Pack(3, Py_None, Py_False, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_tuple[5])) __PYX_ERR(0, 1069, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[5]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[5]);
  #if CYTHON_IMMORTAL_CONSTANTS
  {
    PyObject **table = __pyx_mstate->__pyx_tuple;
    for (Py_ssize_t i=0; i<6; ++i) {
      #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
      #if PY_VERSION_HEX < 0x030E0000
      if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
      #else
      if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
      #endif
      {
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
      }
      #else
      Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
      #endif
    }
  }
  #endif
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}
/* #### Code section: init_constants ### */

static int __Pyx_InitConstants(__pyx_mstatetype *__pyx_mstate) {
  CYTHON_UNUSED_VAR(__pyx_mstate);
  {
    const struct { const unsigned int length: 10; } index[] = {{1},{28},{19},{9},{36},{37},{4},{179},{46},{2},{1},{1},{1},{2},{2},{1},{2},{1},{0},{1},{1},{8},{3},{11},{7},{6},{2},{16},{9},{22},{18},{6},{22},{22},{28},{12},{8},{18},{17},{20},{33},{22},{25},{13},{27},{12},{18},{13},{13},{13},{23},{19},{13},{16},{14},{30},{12},{14},{20},{14},{20},{19},{14},{15},{19},{18},{4},{121},{113},{20},{11},{18},{7},{6},{6},{18},{5},{7},{4},{18},{5},{8},{8},{6},{2},{11},{9},{18},{5},{3},{6},{13},{10},{11},{5},{1},{4},{8},{12},{18},{18},{17},{14},{9},{8},{9},{8},{6},{6},{8},{11},{5},{8},{1},{7},{3},{18},{14},{10},{10},{9},{6},{14},{14},{24},{17},{22},{13},{12},{17},{14},{4},{8},{13},{9},{12},{9},{3},{2},{14},{10},{14},{8},{13},{5},{16},{4},{7},{4},{5},{7},{6},{8},{4},{14},{10},{14},{4},{8},{24},{13},{10},{8},{4},{11},{13},{6},{7},{3},{12},{14},{12},{11},{16},{7},{12},{5},{3},{6},{21},{7},{6},{3},{4},{12},{1},{7},{8},{4},{12},{10},{9},{6},{5},{11},{17},{20},{5},{11},{19},{12},{4},{10},{6},{3},{1},{2},{8},{5},{7},{5},{19},{6},{10},{1},{6},{15},{6},{7},{7},{4},{536},{111},{47},{23},{70},{358},{6},{6},{172},{138},{117},{101},{20},{6},{7},{2},{41},{47},{60},{61},{87},{14},{31},{27},{13},{38},{76},{46},{53},{11},{7},{13},{15},{68},{11},{13},{220},{21},{29},{19},{4},{20},{83},{6},{182},{20},{124}};
    #if (CYTHON_COMPRESS_STRINGS) == 3 && __PYX_LIMITED_VERSION_HEX >= 0x030e0000 /* compression: zstd (2823 bytes) */
const char* const cstring = "(\265/\375`%\026\355W\000\032pd\027G\360\2608\007\314\300\244\025[\005S'\236$\256\030q\323`\032R\2204q\357\251\352\327[\212\264\225\335\264d\032%\211\322\311\263\236gX\356\240\317r\354p\364\217cpT\266tx\024c\217AQTC=\365\236\377\330\035K\001:\001\201\001(\036\212\212\277\260\370\014g1\303b\346\332{]j<\034Y\366\346\344\321\303\3709n\244\237\377\216\005[\035\375\313\242\027\244\341\217\230\346\244\034\217\342s\217+\275\370\363\226W\375?\345\337Wu\374S-\nZ/\254\231\202\327z\356\341\273\347\n\2161\377\235e\321\341\250\210\3740\336\232q\230\007\351}q\235\260\232\350>dQ\261\346\357\370U\372\322\022O\027.p\027w\270\252\374\244\342T\341\343\332\265D\267\371\304\205\243\307\275w\035\225\360\001\204\306\301\203VR\242\235B\234h\025>\245e<\202~\362\276k\265\034>8\252.\325\302\361\332\234\036\177\364\345w\352\255\235f\242\n\253\207\266fj\362X\0131\025?\324F\333\322<\022\332\t\277\330\312ZX\363W\307\224\346Y\r?\306\364\343R#\326\260\214\277Z\027R-EC\212\205\031\227\031-\274\365f\254\265\276\317\364~\252~\337i\270j\241\315\311-\026-\323\3176\346C\033\023V+C\343p\"!\277\352dsX\265\034.W\026\326\272\372\321\235\220\204\205\374_\370\177a4\016\377\245\350\367QN\353>s/\316p\311\341\357\274\326\002\301\261\323>'k\371\322\214\265l\303\220\262h\001\367=oLy\346\375ee\371UY\036eDd/\266l\262,\303Y\206\342\331\211\326U\273\223\235d'\266N\320\262h9\254U\250\235\213U\007k9\254\331\211VA\302\004M\2465\343\321g9\336\271\371~vOe\334\331\234\374 W\363\265\316\372\320?\377\277\371\271;\332l?\232\335q\367\030{8\336\374\215\370\257\327\312\367E{\305\217\216\253\024\315;\356U\244\234(\252\302\332\205/\216\235\365\217\202\240S\320]\264\366\353\250\375@\320.\005\322\317\003\013\207\326+\006?W\307\356\034u._+\202\325\275u3\256\252\277]\355\352\373\177\035\256\252\234\252_*\343\n\326+R\021\264\334\0359\033zj\314\021\235\253\367\303\374*w\367l\350\336w\236{.\212\366\344\235{\327\345p\264\334\350\252\352\205\226\303\037\367\330~\237=\254\356\236\342\276\347B\312\271\353\244\360\207\365Z\356d+\027\2660\305""\252\353\037\2457y\264\017V\233\032\357Q\344\031\037S[R\236\006\256\243\"\275\254\023\010\374Q\316~\036N\367s\245\254\014\276\301\361\006w.?\256\227\316|\356)\353\234\257l\236\301]\003J(\036\004=(\236\317K\305\204A~J\023$\355\342\022}d\241\236\315D\001\235.\272\324\251^5J\221\322\204$\221'6jO\320\006\024\220\031\266\2122\344\314\237\256g\365j`n\014N\006\240\023\206\342\264\310(\206\"!\204\234\250=j\252Y&s\245TA\212\266\2126\351\025\027\001S\304\374(=\310\026\243K\300F\315\000f\213\234\261K\350\315\243#k\320C_\014\314\315\301\351 ;E1\322\310D\343O\r\027\310\036\321\244Q\254\005\316\211c\241\002\311IR\202\221H\223\275\242CF\260\2179R\272$\030\301(\214\234\002\364\010\245Gl\014\233$&\n\301h\364N\350#+\320\263m\005\240\223d\236 '\304P\372\306%\n\305\266\322\306\026\260Wzd\004\022\202\321\ra\277\350R\010\366)W\244I\310\tC\363\242`\276 )\234p\205\264\210&y\300V\260\225+\305E\000\024\373\360\200m\256\314#\000\024\333H\023\271\262\025\214`\246M\332\031tv\201\204b\253M7K\217\204`#\020\030i\333\350\003!\330\200\217l\324\363\321\036.\017\020\314\244C:\262\317K\317\366\262Q6 M\331\211*\267\222\204D\221\033I\262\377\313\236\013\263,\313\262,\313\262\014\206\304K\214\014\213\333\304\270\250p\201\311\\bdb\374q\212\320\262t\364s\360(\322\317\311Z\367K\334t\237\261\276\356\264\256\005\037\364,\242\265&rr\275\361\r\030V\345\005\320I\022\341\2608Y\214`\024\204\244\207\222\0056\002\320I_\007^ J\252\013\250\\,\322\313E\251\n\371\310\002\320\235\322\001\350\013\345E\300\\\225,#\244\016\207\016\020\354\303C\"?\"Ry\002:q\000\300Q3\301\354T\273\003\201\020\003\333A\350\244\245\210\322#iZv\t\215q\306\3009qj\316\234\003\007G\007\016\225\327\233\"L\257\244)K\nh\t\241LA\226H\033\003\373\263[4\211\346\205z\201^5.\310\235XF\355\033}@D5\212\326P\206\310\010\333\200G\317\246CTR\260.\351\013\241t~L\023\344F\312\320\230\245\026\262\204L\261K\261\017\010Y\002\265\025\350\217\216\205\244\034.^+\314\235\022E)\"UHF\261n\263J\"\223\356\\\005b\224dm\272\003\354\004\244l@\317J\247\304J\010F1\023\016\374*an&""\200\033\032\333\266ex6\362\301\010\266\215\330\013B\260\215\204\021iY\271DD\240\215\300\243d\263\354\005\004\316\001(\022Dj \347\350#[`\246\230\246\016\023d\266x\220-\033\264k\266mZYp\316h\260\242\232F/p} \320\327\305\202\332\033\351eb\276\224\240\274S\366\211\306%e\213\212-Z\225\264\014`zu&\215)*UH\000\2446:G&\023Y\263ox\304P<4\373\301\306\032\205\356\210\351\032\027\006\024O\202g\250\"\263\222\006\031R%\"\"I\222d\030\003B\020\010\024\215\306\211&K{\342\3614\2151\310\024\211\210\004\243\240$E%\251\221a\014+\320\2404F3\313\242\010\\\320p=\364\224vF\357\025\351\324\013\206\320K)\214|t\333Dl@\251'[\301\304\243\303\224iL7\303\013\303\201u\272A\311\350\332\365\003 k\342r\272Q\327\005\301A\017\220\031\362O\025O\005\232H0\255\023)\"\335\260v\265j\023\370f\305 \000`\343\250^Ub\321\002\355/\2126{\007 r$\315B\217r8K\320I03Tr\256\304\313\235\024\246OhL\260\016\333PFK\224J\311\265\254\346,\235\221\225\332\244\311!\252[\354\204\220N_\241M\202Q5\216\231_j6\376\\\372\233]9\342\353\236\272qr\371\2242<c\311%\266\271\253?\301\360 \035\177\276\304\327C@\250\000q\346\027\304\0276/\025!\235kQq\302Q\254J\"p\020&\310\326\323$_u#\317\316\0132-\0236\034\003S\355\357\271\330\220r\237\345\030\265@=5\204:\317\233\003\204E\317\203B\205\221\240\307\311\261\210P'\341\020g\201\017\253}\250M\272\3370RC\262\033y\314\t\261\236M \246\365\324\343O4ZaF\330\010\264n\334Op\201\032r\375r\005G\201L\024b\211\311\374\337\005\272\310]\036\225c\250\342\367X\"uai\026T\351\0224\201\032\205\265.\355\371\034\346\031\277\353\302{\007^\2609\317~m\255\031\271\267#B\374\2210\300\214\253\260:\314li 2V5\204\353\037\363\305\303\350g\276l\310\366\242\277R\224\342\250\242\362\353!\304A\r\004\314#v\033\354e\376\306\223H\334%\235\nM\"\300]\347:\005\037'\230\r\254\340\346\005\346\002\235V\004\350n3\234\236J\366d\312e\026\"qUE\013\334\377\273AM\037\345\207\257\213\225\024@\356\254o*J5\205\214F\371cPS\010\263\002\252K\201\007\030\r\376\t\2673t\210\035\"\276\001\301\n\303\203+^\245\366\023J\302\203\246p\020M&\017$\246\301m\277""\352\356\274\226Z\2061\017[\303\325\244Zd\364O\252\214:\202\036c~\237\234p\251\263_\320\350\344.\353\005\356\242|K9\215&\254\265\304,d'l\007\343\214/\366@\267E\017\357@\237\356\254\302\347{\310\305\364\253\262U\356\303\325\346\254/{\032\344z\373%\035~\342\206bR\027\212(u\301RtD\027\225B\346\266?@.\364\2734t#d>\006J\275\021\036x\343\016( \367T\313[\316\223Cm\245z\250\335\344\034\017\"-q\000\t)\232\230\337x\022t\361\211\222\260\302\236\017\312\025_d*\303\200\320\217\225J(\227\tN\262\216`{M\314\242%\351\363\247\000K\253\303\363\352c\365\031G\213\237\202\343\371\257IlbUK\262\376\236&\337\177\235\364o\030n'\026\241!T3\314\365e \356\260\320\223f\255\023\023,|\2431u8ZO\346\376\265\225\032ZG!t\025\004\351\001\345\254M\307#\240uT7tB\277BS\324\324?2g}w\277@2\2227\331\343\367\373\317Shk'\210\316]\311(\251\312\221\200Ft\324VE\217\000\271\022l4\225l\3307\373\037E\316\201\210\334\215Q\206fwI'\242G\001L\021?9\312'\265\320d@5\215Z4\200H\034,k\266?y\004Xt\330\336\341\322\2309\030)\331\034\023\342 k\272\207\005\355\247\341\000\271\320\365\206\234\355\237\016\032\006\217V\0376\037\334\210\275\334\360\235\244\273wQ\366\246\233\215#n\022K\253\031\330y\311\021B\254\241|\0019\304\022-S\350\252b0\220\326\247H<\336q\217\020\277\021\005\202S\212\256y\2360y\216)f<\317\036\217\336\211\034\312\225\357-\233\336\311\2222\337A\217\243\203\227\312*\306\311\3035O\330\007\247,>\341\275\326\203\376\205\330f>\017\350c\014\024w\244@\241\240W\240\330\225\305\325\340~\231P.\230\344i\374\215\035\r\207\357\305\232\265\255\230$^\277p\225\026\360\235\271j\217\356\200+j\255\271\200\217\312\335\037z\337\322d\013\230\274^\340\247\031\363f.\264\243\317i\250[GL\205\261\233\314b^{\307U\207\026\246\270\003\352\331\304\276\361U\244C\3400\275Z\366}b\301T\247d\212d\377\311((>8\361\031\201E\0334L\316\231\253}\220$\236\223\245NJ\372\351et\242\344\367}b%#+\375\202!J\027\332\250<b\030\302\273\020\243\270\214Q\202\323\031v\264wh\345\037u\300\357{K5<\017\035\013Ez\214\350{\022ml\236\271\331\200\014\264\272\314 \252\250\207""\004Z\n\375\0170\365y\242\370\203\r\301\323h\237\314a\262\331\330\007\260(\"\330\235[(\003\250\224V";
    PyObject *data = __Pyx_DecompressString(cstring, 2823, 3);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #elif (CYTHON_COMPRESS_STRINGS) == 2 /* compression: bz2 (2915 bytes) */
const char* const cstring = "BZh91AY&SY\264\355\016\301\000\001\\\377\377\357\377\377\377\375\377\277\377\277\357\377\377\377\377\377\375@@@@@@@@@@@@@\000@\000`\013Vw\322\356\364\357n\274\025\350\275\n\t\262\232;aM\316q\243\334@}\360\032\020\224m(=5\033Pa\202m&$\360S\364M\252m@\323\311\251\350F\324\36514\320\032\003A\247\251\241\351\014j=M4\365\006\232Ba1#\t4\332\250\375(\315&\324\364\231\036\2406\240\000\001\240\000\000\000\032h\000\000\000h\t\241$\364\2434\320\232OML'\244\304\3155\033S52d\323#\000\201\210\332\230\rL\233@h!\220\366\210\232a&\244\232!2S\324z\217\324\324\302=M\r\000\320\320\014\232\000h\001\220\000\001\243 \000\003 \000\252\023L\000\003SL&\002bcS \300##\r\002d\321\352` \302bd`\214\000\004\301\"D\3110 A\242bd\302\236\251\371$\365\037\252i\221\223C@\000\000\000\000\000\000\r\000\016\002P\222\t\351o7f\335\231r]\226\330+\362Fg\206\311\331\205\321\246\257\354i\016\360\027\230\214\351\023\244;\372Zq\243\345\363\233T\351\334\207\370\036\261\036\235KD\376\232\330T\244\272:z\214\022)\370a\340\327=Q\200k.\003P\306\003\rph\206\252\027\331\377\017q\200ch\n\004\246Q\\AW\025\315\377\3603\347\317y\376\334\013\246:\215C \253\010\250\200\214\212\211\341R\267\230!\035\306\003KG\240\032KI\246\304W((\260\3016\003j\"\252\021B(.L\321\234\230\220\314\330\303\002v{'@e\253\0006&y|\306\213\001tX\220sbl\030\310\254`\261q\202\227*\241zQ\tF\030\177\357m\201\3343\023!Qi{\322!\316P\2442\203\325\252\024Dm\311v-\020\016/\322\037V\201a\243\347:\207X\037[qpt\241\013C\234I\203\016+!0\367oHh1=\0020\264\251\234&\356\035\340\243\013@a-\265\221B\255\230\272p\361\306\224@BJ\320\210K{_)n(\303h?M\220a\001mIE\377%M\351\256s\341\375\212\rh\235\265\246t=k1\002Q \310\321s(\276=\276FYe\215\220\220\331l\304\236J\260\312\017vo\225\223\314k!,=\267#0/\371;\tC\316\333\370\231\345\3261C3\030\370\331B\033\357)\212\354\200\024\013,\031\360\210\361Z\225\333M^\364\374\231{\003\354\353\347\336\302\200\271\332:Z\t\316\023\336*\265\361\344\340\357\367&\341P\351\247'\223\275\342b\231R\325\031U\206\254\333%u\370\253\nY\273\0366\215.\323""\257\372T\2019V\345\306`\326\223\316D\003\223\350\221B\222\335\032N\362\341ax\333\003k\032\270g \245Dxd\240W\004\014:\360a6A\001!0\261A\241\205\260#\240$+\352\0241\222:\000Y|\010\2142\270\356\233\001H\340\205\261\212\300\343\303\347\335s\367\330\325R\226\213RI\307*W@T\370C\356\371/\261+\320*#U\035b\354\346\207=\252\326\360\271`\026\245\203\235\003g\220\351\265\303\024\335 \021\320\247V_(\340\376\232\\i\261\243e\003\327\347\032\274\223\\\206y\356\000\302\201+A19G\312\267R\340\030\006\231\026K\302\311\";\202H+\004\333\225H)\220f\246\r\367\005ir\250b\006\265\315\251\263\237\330\357ng\200\356\253\256W%.\317\231}\271\302\027\234\006mc\032\36376}Rbw\224s\327\351\333\001\367Gf*\231\001P\007\027\354\006l\0231E\361\354\036\231de\025B\214t9!)M\020\265t\0270\357n\004\212\270\r\305\324\334\332tS}\361\344=\202\214\223%\216\373-\"rQUW\263\226\023\277(\313\271alf+1\242F\371\312\331\033\363'\031\250a\033\363\003E\205uM\352\214,\322\234\262q\255\222\031-h0{]\240\025\0256\363\224D\275W\243\321D\261\340c&<\220g\214CRo\020hi*\320E,p\306\300e|\252\016\026\302\206f@\227\t\270\342\201\2510B\216\272\346>\360\"\002G\007(\213@\212\021)\223\246\220\311\254t\231(8\032\014\236f\246N\273\014o\352\347\2673F\215\257\033Q=g\351jR\204\020j\330S\313\246b\366_\342\250\340\027\350\334\326l\343_\320k\303\242]E\302Z\326\345`ir\227\3232A\213\333\\\335\256\337\346QY\221\3469\r\354\365\262/\340H\307\023+Z\335+\346\261\260\"\273G\263\236\205\211+\017)\340\017\317\363\377\314Js\210<'\346,\273\014\021\221\220\330\366\270\016\t\231m\363\212\222\357\261\276\004z)\003G\252,8m\273n\343\207\256\013\033\3551\320^\246h\030\020\272 \327\216i\243]\345\340c%\327\177u\300b\"\335\002\305\244\332&T}yk\332\302V\335\031\323\035\027 m\021\310M\r\r!\225\366\355\305\304\253\321K\006R\r\255\216\014X[\225\2164\324\305\350\227\004\324\255N\353JX.\377\035OG3\307\315\343\336\344\350{`\331\331\313F\351\277\303\033\306\236I*\226\300ZI\224\274\337\241R\350\204v\365de\314\213\317h\204gl\005\205\370\250Q\222\262dB\022_\323#2D\364\305""\036\006\n\261\252\372\321FU\303*s\310BU/\326X\322Ri\0301\021\034DI\271\206 t\342\032Z(E1\273AM\030\305\204R\216\340\263FzKs\200\003\275\031UP\244A\203j)4\215Z\2523J\033W0\001Q8\010\031F\005\227wf\216\";\264u)\306\177.\006\223\036>\317\211\205\031u\2668\363\312\340\215\026\r\313K5\ra\314\300sy1\016j\271\230\203\036\000d\273Z\215\032\346\267\276\221\037\263\366\201j\013\361v\343K\202\2018P8\216\"9R\355;{v\332\225\031\224=\226\311z\233HJ\230\n\275;\013i\374:\345\033\213\006\313l\340\353\264\361\017\224G'~\355a\311Q9\240e\003\330\251\370\271\304\264\223\242\331]\301`\021\202E\n\004\364r\034| \223\025\300\301b\260\235\361\230X\341\\t{9\217H\333\203\330\245\321\001?6\305v\206\264\370\270\322\026\206r\023\316\352kD\r\340\324\014\030\306\023\243.cd\251/N5(\026\373\254\301\233\347\"\324lU\013'\217\230.\026\002\372L\235\223!\\\220\211\264\017\212\r\254*\257\352\212\310.\275\347\266\325\034\016>\014\354\t*\344\257\200m4\323L\007|C[%\244\256\241\345\352e\231\266\342\031\260\301\302\214p\272\\\244\026Q\202\207\023Ew\341I+*\020r\223D\270\367\n\217E`\345\001B\242%\344S@Ja\002*\253\003R\277z\332\207\231\n\017\231BP\320\316h\232oas\\\250\027@\230\020\2234\301\243!\304\3262\367r\311Pi\266\002&\302jD\ryC\263\311\250'\027H2 \274D\001\351\354\360\333n\247\326\275\001P\246\010\270a\242~\014\222k\263\016\215\203\323\304\356!f\341\3466h(\215:\rF-G\r8\367\325\303\265A\221\2713R\231\225sjLG\254\231K\372\365\312W:\352\351\204L\274\362T\315\r\252\363X\222\346;\272\316P~\020\250\226\355l`a\\>E^\324aKMKqu\032\221\202\210\233r&\230\371}T3\261KO6\356\302\343\244\363\251\307\315\227\244\204r0\006\010\214K+\247\307\243=<\2078\317\025\266I-1\207!!\324Pj5\236\374*\255V\014M8n\321aZ-\305ey,d\226\306\350\276\367\257\321Y\030\317n$\031\\:\345\254LX\022\"\212\177\244\330\206Z*\032\030\030\300\242\020\272\372]\310X d\222\366\004/\312\331_\244)\211\n4\322\320\313E\306d\223E\006\366Z\356!\254|\314\223\324?v\321&\212VI\273\255:\215\355Sgn\250\353\002\22051f\204\226\232\355[\333\3566b( \212$\005QE3%6\\\330[""\013p\263\336\367\001-R\366l\326r\"\256e\231\323]&\201\322 \210`@\306\325G*\307}D\257\331\272\302\323$\321\006\207B\353\231*Rn\n\016\006\353b\2318\305\226\033Q\033\3657\335o-\237\217\035S(`\265\"\036Q\013\t\031\031\347Q\344bi'$Y\256\t\244\241\210\220\320U\366\253\2538\331\312\032\200JjNS=\372\377VlA@G\n\213B^\234C\257\236\3227W\277\252\2104\n\207k|gW\035\232\214\270\216N\271\373\241\234mp\234[Bg\223\230\240\361\001\021\007\223\250\354\256w\2077u\327;\264>/M\335\275\275#\224\037\"\003\213qq\207F\223|5mIj\021\3341\262\311\345\273{\326\247\034.V \205J\013I\210\027\006C\322\211\265\226\031\321m\371>\000\250@\031\030\206\203kn^\375\345\232\214\365P\321g\274d\352Z\370\030}\247\306\247\312s\r\340\311\341\305Q\2076\230\221c\352\2779\306y\222{\017\331R\215\370\224\316Z\n5\263j\004Q6\216\036\326!\345&\361\367Ru\345\272\206\"k8<\277Y\341}x1C\023\221}\364\244\256V\355\271\264T\275\312\234\340\303\261\225l\326\001\251\005oN\346XVy%\304\272J\037G3\006\312\244\222\326\344\203!\251\270\322\220u\031\344Q)h\026\344\245\031}N\322\2253y\223\002\345\350\372/\177M\202\336{\032<!9O\3340\251\333\275.:\010t5\224\3202\3716t5\324\017}\370\244\323W\0306>{\200;J\222;u\252\212\025[|(\360\037h\030\0250\n\313\252\224\3136\365\360\243\373\327\320\2503L\\{\2134k\001\234\206\243\276\364\371\002\241\212B\237\237\036\233\035\243&\210\3338\364'\030\242\372\311\273|N\237\242\341\232r\246\241M\2632\020\314\234\257\346\213I\016n\245\221.5\237\216Y\350X\265,1\023\257]\361\207\004|A\203\276\343\277\262\3111\252\202'\226Ec\021\243\030\213\033\254\346\351\304\253\002\357z\337\024Q\0360\365egl\361\237D=\376;UUOa\354\020\342\267\223\020S\207\221\016\3064\031\357\302e\204!C\016\251\367L\330\003u\004\232\32798vb\207\201gLa\220\212x\007r\361\001\250\240\000%\010\"\357\020v\202\346?\343h\215l1\203\231\237\211\\J(\336\204\223\214U7\206\006\330\377\260Gw\231\033!\204\t\016\301\301\316KEC`q\010\231\346\004\204\236\025\311\325\r\003\211,\322b\003\010\244RW\326b\n\204\201\362*vIh\030\222s\006\326$\344d\306'&zQ\221\322""\016?+\252\362xS\231\251\240F\026!\n\031\031\301\274\275\342\356H\247\n\022\026\235\241\330 ";
    PyObject *data = __Pyx_DecompressString(cstring, 2915, 2);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #elif (CYTHON_COMPRESS_STRINGS) != 0 /* compression: zlib (2816 bytes) */
const char* const cstring = "x\332\255X\315s\023G\026\037Ud\260\203\004\0226\0371\204\214\010\265\216\tqJ\261\215\t\233eK\030\333\241 \306\306\004\026\222\335Nk\246%O<\232\221\346\303B\233\324\226\217:\316q\216s\234\343\034u\344\230\243\216:\352O\360\237\260\357u\217F#>\302f+\024\314t\367\274~\375>~\357\367Z\310\353\3240LG\266\035j9\262\263\317d\325m4:2;d\206\263\361\262\311\024\207\251\262Bu\235Vuv[\336\262\0303t\346|q\3378\244\272\246\312v[s\224}Y3\0343\371\270Tg\316g\213\267\345\337\225\371\331\324\014\024\3326\r\266m:\014\016\247\216\274\336q\366MC\326lYe\272Ve\026u\230\336\001\363,\r,\261P\310\220w6v\276X\271\265\"SC\225-\3663\330h\313\266[Utj\333\314\226\315\232\\u5\335\321\014\331\3514\231\275$\337\257\311\035\323\225\r\006\276\200\rM\220Ko\000\267\r\331f\302\377\005\036\020\352h\246A`\273f\324\027dU\263\340\020\355\220\341\356M\252\333l\351\t\210Z\256!S\253\3566 V\262i\201\n\275\266Dp\265\341\332\216\\eI\340n\310\213\177_\222\257^\225\277\271-\337\371\333gTU\t\034\302\300a\245\346\032\312\222c\222fG\325l\224e\006>\353J\235\347`\211\324\343\210i\266\370\242\332\226\362\245\370\370\345\350\333R\263\263I5\335\265\330^\223\266\r\246>\324\214\003\262i\321\006\333\342\222d\247\303gd\2139w\251r\360\346\352\272\251\276E\026\364\260m\267\001\211\030%n\343\245\346\214\306I2\t\201}\314\"$\275\002\202\351\205\232i5 \254F\315\034\2575h\247\312\310\201\246\353\244\312@\200\021\016\304\261\000DI\253u\210\016\356\330\343U\213B0\340\000\20551O\251\017\356x\202A\2661\032\004\263PE\247S\370L\306\373\324~M=\"3\231\240m\311\004\345&&o\261\201/\003\356]\226,\031\230\206\321\304\242\355\t5\026\243j'5k\230\207\354]v\247\335\343\"\2233\242C\265X\343\265\211P\362\331\353\022\256\2420\333\256\271c\027\235}\313l'3\327\230\260UL\t\230\025\227\366\036\257\354\r\3132\255\235\347;\317\t@\347%Y\337\004H\223\325\345\332\362\362-Bn\n\250\222\362\032\211G\312\010\265\304\254b\361\022\242\357P\013V4\033\306\314Q\010/\007\362\365H\316&_'q&7\333T\003\037\226\276\321M\210\217}g\251m\321f\372`\252*\267j\325?\375\340\267\035""\270\323\271\007\264D\266\331K\3471\253\245JoO\0046\265\362Dk0\323u\236q\343)'\2237\001\n!\205\344c|\341a\325mjw\014E3\227\024\323\202\275P\212v\025\2148 |\003I\266)\324P\230\256TS\\\002\037\221\334\360\005\333\210\006\\\006\2472.\255\2336St[1\215\232V'\360\002\315.'\274x\214\021\032\017\025\3235\034U\005s\tQ\321]xa\217 \"\250\251\361\022W=\261\"P7\271b6a\336\034\033\224\220\007\304\232 ?\214\223\035\223H\215\240\\\r\214RY\r\253\225\031f\212Oj\234\255\010zOH\035\376\202\375\370\300w\235\031\014z\007ib\242\371\312\276[\005Z\301\360\342\014\354\202\005\030)\256\205\022\270\217\353\023\230\031\221\260b6\23245\303\320%\004\375\032\272F\353x\020\307Lz\241ii\r\r\263o\217V\235*4\272\321\004\262<\022O\2420\222t\004\204\352x\304\350\250\021\2405CK&6\364HU\007~\304\262L\350\r\016\327TMEK-V\007\304[\000\022\255\3214!?\2437\024\017\340\026\220\205\352 \317\232M\022\350\001n\033\266\206\305G 1\242\200l\244J\374\007@\344$\216\017\374\207\3636\206\370\033\2356\252*\275\203&L\022\346\230'u\023\240\225\240A7M\250\256\006\005\310\222w\365\207\006\330\327\240:\021\356\220\206\251\002PA\234\030\034\010\370\304^\31772u\242\211\010\0344\231\241Bgo\342QM(d\20565\334\217\343C\007\273,\316Z.\325\205\306\270\341`@_o>1\237#\2157-\263\311,\247\303)\335b5A\346o\245t\213q5\026\263]\335\001Z\307\316\205\257\321w\270\227\000\310T(`\274T\214\237N\354\"\214\240\024(l\206\261n:(h\272\026\220\016\036\223\352\006b\350\0004\004\026m\276\000\276c$\241\366t\204#\017j\252A\210(\023\203\265\t8\314\253\327\306+\221\322`p=S\261\204\307\255C\334\356l\220p\200u\035\206\\\312\273H\214W|Y\230\336\203\344*\303\355\021\315d\334R\0169\030\354\327\020&\330\236\210W\233Q\210\\\r\tx\247\363\210\013\310\327?\033\017o\310\343\361\242\364^\221\377I\034n\255\262\000\206}\2405\201\001!\200\340\357\r\274\223\272\312\350\233\331t8c\377n\327\211+E\276\236\354\001\374\000\214q\343\304\371\223\252\253?\377\256\326Qw~\267o\357tbQ\372C'\211\013%\330\007\352\026\245C\023\256\366\377\257\251\243\355\370\\\224H\314\031\311`Y\212c%V$(""7D\220#@+\211\3767YQ\266\304Yk\354\265$AH\237\300\017\200\361\002\330-\335\305\016\n\370\027W\227G\256\303o/R=\271\025\330R\0330&\221\252[\2531K\"\r\250_\253s\250\261\2664\006\260 L\246N\034\367\014\340\371\200\361;\001&\326\352H\373\2146\201d\304\333\265\367S\342X#\300\023\274('\264\240\221\353\320\213E?\022\037\276\267\2310\223l?\332\336\220\240\330\336g\313\304\037T\371\007S\235j\331\250ok\343\351\306\366\023\262\376h{\363\376\226\224\376- \275y\025\224\342\313N\312\306\270\243Ho&-\025\006i\362^ \215\2725\277\312H\274\367H\223\315B\212y\024#\222\\\037\370d\324\306%\276Kd\024\257\250o\211\033\302\t/P\330*\004\361q\267\245x\202\255\037\304\341#_\366\347\203rP\t\346\303rX\351K\245\340J\370k\257|\274\231\221\246f\275\322 ;\335\235\3662\307\005i\346\303A\356\234\367\304/\016\316\024\006\271\013^\333\247~k\230;\323u\274\233~\321/\r\n\227\374\265\240\024\224\207\331\223GN\267<\230\236\031fOuW\272\255\001,\264\006\323E\357\274\007\257\\\367;\020\377<\370g\364yo\027\247[\375\331\205\240\025f`\303 7\347m\372\327|:\000\275\255A\341\202\327\362O\372\277\206\345a.\337}\346U\206\361\356\353\301wQ\261\237\275\344\227\217OK398\344\320\333\035\344\362C8d\336\377\312\347z\277\365*\260\210J\013\336\311\376\205\317\321?\220\031\024>\342\036o\204\027\242\314\2400\353\255\371\013Aq07\337\237\277\001\001\370\342E\377\305\017\303B\321\273\340\203Eg\272\277\200g\250\000,\311\240U\266\267\000!(\024\207\343\305|_\372\244\377I9\372\270G\217\257HS\323\302{\014L\331{\340\277\014:\321\211\210b,\312\030\315\223]\027\014\373!\230\016g\242\363\021\004\344Tw\315+y\253~>x\032\256E%<\244\355Q\317\365+`]\177\366ZP\031\026\316{\n\234\212\301\002\235\225\001\352\352g?\356\177\\\216\256\364Z\307jF\004\301\351\317\202\013\341\356`\224\025n\3479\357\251\1773\270\204\316\237\365\256\373\025\237\177w\275\357\202b\260\020\236\017\177\351\305g\326\341\013\234\244b.\347\274\rLj?\273\034\225\217s\322L\276\273\341\025a\367\3030\023\374+Z\355e\216*\307\027\001\023G\225\243\n\272\360Uw\317\313\360\350\362\235\303""\370\005A\232\362\036{\266\377\251\277{\004\351C<\374\307\337\013@\264\004\307\227R&\025\372\0059\370 X\r\363\321n\244\366Jp@\234\333\367m8\021\322\260\205I\312\373O!\261\367B4\356\252\330k{\213\376\212\357\200T6\334\214\026zET\260\350\227!\270\020\315\365\256\345]\304\300\316t/{\273\036\305\254\265`\363\025\261\371\245\310/\337\320\277\274\026\265D\006\326\374\222_\036p_\016\275=?\353\337\203df\303{Q6J\307\030\355\331\013\246\000\350\245h%B\265\227\245\231B\377\214\034d\203\212\230}\010Z\372\247.\373\353>\330\177\025\274\233\276\010\352*\030+\374\234O\033x\036\n\"6\217\347\343\036\302\017&\347\307j\266\202\362 w\331\377\026\2529\306@yP\3704(\037\361\302y\204Fs\004\305\340D\027\312(\367o^\220\317\300\203\017\242r\364\240g\277*\361\332\033\026.\242\377\020h\001\253\370\3709<\036\264\r\261\266P\323\212\327:\376P*~\344\237\000Nh\007t\230lAp\234\356\252^\t\010$?\007\202m_E\216\210\221\002\005:,\314C8W\203|\3708<\214\376\321\373\361\267\242\330d\2108\304\207\016\361\345e\274K~%=y\020\264P\204\327\370\031\014\"\007Ef(\312|\316\377>\270\nx\230\211\346\242]\204\344#\200\307\303(\003\303\376\3345\214R\\\305\342\030\313\233\363\342\023m\250\310\225\321z\034\252U\224\034\344f\275\362\3614$R,\237E:\360\377\022\344B^\006\267\274e@\021\260ck\220?\347=\003\224\301\330A\270\rc\312<\014~\004k\366z\331^\245\267\213|U\344\036\n8\t\365\336=?\343\237\005\032{\022\314\005\337\207\327B\232|\2159\307\277\004\3645\027\356\206\265\350n\304z\253\257\246^\275\370\315\351\357\001w\375\324\377\211\306\211\305R\276\n\340\234\nv\203Zx7\244\200\202~\356\023?\301\321Y\341\306M\177\026\244N!\371\210\252\306\305\277\372u~\266\032]\007K\367^}\360\212\303H\260\251 \177h\004\210\265~v1,b\311\3449\345\376\020d\202\342Qf\220\235B3nCY\035\004\027\240<\326\303Vt\252\267\334\243\250\341\204W\3653C>\240\000\236\023\322\314l\314\201\273A=\374\021\312\024zF\273[G\002?\215/\217\206wz\347z\264\237\275\350\237\016\350\361|\212\366\317ps)B\026B\3151\000\\\221\304\214\247\350\317\350\014\317\373\317_\304\235\001\250)""_L\370\177\030s\301;m\351g\277\014[\257\321\350;o/_}\235\334^\306\255}\374+\233$\367\274\321\245\345\231\346\354?\204\037\231\342\036\373\366k\361\344\377\023\374\027\262\334\333\026";
    PyObject *data = __Pyx_DecompressString(cstring, 2816, 1);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #else /* compression: none (5925 bytes) */
const char* const bytes = " Cannot start the dummy eventExpected callable: Greenlet-Invalid switch into Greenlet.get(): Invalid switch into Greenlet.join(): NoneNote that Cython is deliberately stricter than PEP-484 and rejects subclasses of builtin types. If you need to pass subclasses then set the 'annotation_typing' directive to False.The run argument or self._run must be callable, )?. \"\" <: >=(add_noteat cfunc.to_pydisableenablegcgevent._greenletisenabledsrc/gevent/greenlet.pyFailureSpawnedLink_FrameGevent_PyFrame_GetBackGevent_PyFrame_GetCodeGevent_PyFrame_GetLineNumberGreenletExitGreenletGreenlet.__enter__Greenlet.__exit__Greenlet._formatinfoGreenlet._maybe_kill_before_startGreenlet._notify_linksGreenlet._raise_exceptionGreenlet._runGreenlet.add_spawn_callbackGreenlet.getGreenlet.has_linksGreenlet.joinGreenlet.killGreenlet.linkGreenlet.link_exceptionGreenlet.link_valueGreenlet.nameGreenlet.rawlinkGreenlet.readyGreenlet.remove_spawn_callbackGreenlet.runGreenlet.spawnGreenlet.spawn_laterGreenlet.startGreenlet.start_laterGreenlet.successfulGreenlet.throwGreenlet.unlinkGreenlet.unlink_allInvalidSwitchErrorPYPY__Pyx_CFunc_53f338__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception_6waiter.<locals>.wrap__Pyx_CFunc_adc8fb__6gevent_17_gevent_cgreenlet_object__lParenlist__etc_to_py_9greenlets_9exception.<locals>.wrap__Pyx_PyDict_NextRefSpawnedLinkSuccessSpawnedLinkTimeoutWaiteractiveadd_spawn_callbackalive__all__argsasyncio.coroutinesblock__call__callbackcancelcbcfunc.to_py__class__cline_in_tracebackcloseclsconfig_continuationcontinulet_continuletcountddead__dict___dummy_event_dummy_event.close_dummy_event.start_dummy_event.stopdump_traceback__enter__exc_infoexception__exit__f_backf_codef_lineno_formatinfoframe__func__g__get__getget_generic_parentget_hub_noargsget_my_hubgetcurrent_getframegeventgevent._compatgevent._configgevent._gevent_cgreenletgevent._hub_localgevent._hub_primitivesgevent._tblibgevent._utilgevent.exceptionsgevent.timeoutgletgreenletgreenlet_initgr""eenletshandle_errorhas_linkshubidident_registry__import__import_c_accel__init___is_coroutineitemsiwait_on_objectsjoinjoinallkill_killkillallkwargs<lambda>linklink_exceptionlink_valueload_tracebackloop__main___maybe_kill_before_startminimal_ident__module____name__nameneed_killed_notify_linksparentpendingpop__pyx_capi____pyx_vtable____qualname__raise_error_raise_exceptionrawlinkreadpropertyreadyrefremoveremove_spawn_callbackreraiseresultrun_runrun_callbacksseconds__self__self__set_name__setdefault__slots__sourcespawnspawn_laterspawn_tree_localsspawning_stack_limitstartstart_later_start_new_or_dummystaticmethodstopsuccessfulswitchsysttb__test__throwtimeouttimertrack_greenlet_treeunlinkunlink_allvvalueswait_on_objectswaiter_waiterweakrefwrapPyObject *(PyObject *, PyObject *)\000PyObject *(PyObject *, PyObject *, PyObject *)\000PyObject *(PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_6gevent_17_gevent_cgreenlet_joinall *__pyx_optional_args)\000PyObject *(struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *, PyObject *, PyObject *, int __pyx_skip_dispatch)\000struct __pyx_obj_6gevent_17_gevent_cgreenlet__Frame *(int)\000void (struct __pyx_obj_6gevent_17_gevent_cgreenlet_Greenlet *)\000void (void)\000_killall\000_killall3\000joinall\000_kill\000_extract_stack\000_call_spawn_callbacks\000_initPyObject *\000\000\000PyTypeObject *\000\000int\000BlockingSwitchOutError\000get_objects\000wref\000_buffer\000_memoryview\000_greenlet_importedPyObject *\000\000\000WeakKeyDictionary\000heappop\000heappushPyObject *\000_threadlocalPyObject *\000\000\000int\000ConcurrentObjectUseError\000_NONE\000sys\000_greenlet_importedPyObject *\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000int\000\000struct __pyx_obj_6gevent_17_gevent_cgreenlet__dummy_event *\000\000GEVENT_CONFIG\000GreenletExit\000InvalidSwitchError\000Timeout\000_greenlet__init__\000_spawn_callbacks\000_threadlocal\000dump_traceback\000get_hub_class\000iwait\000load_traceback\000reraise\000sys_exc""_info\000sys_getframe\000wait\000wref\000_PYPY\000_greenlet_imported\000_cancelled_start_event\000_start_completed_event\230\032\2401\240A\240\032\2501\250A\320\000!\240\036\250|\2701\360F\001\000\005\023\220!\330\004\010\210\010\220\001\360\020\000\t\n\330\014\025\220T\230\021\330\017\020\330\014\027\220w\230a\230q\340\014\017\210t\2206\230\021\230!\330\020\033\2307\240!\2401\340\004\007\200t\2101\330\010\t\340\004\013\2104\210q\330\004\007\200q\330\010\021\220\026\220q\330\010\014\210M\230\021\230+\240]\260+\270Q\330\010\014\210G\320\023'\240q\250\001\330\010\t\330\014\024\220F\230$\230a\330\014\017\210q\330\020\027\220q\230\007\230|\2501\340\014\r\210W\220A\340\010\014\210M\230\021\230*\240M\260\021\320\004\033\2301\360\016\000\t\014\2104\210v\220Q\330\014\r\340\010\021\220\032\2302\230Q\330\010\014\210H\220A\220Q\330\010\t\330\014\020\220\007\320\027+\2501\250A\330\014\r\330\020\031\230\032\2401\240E\250\027\260\001\330\020\023\2207\230'\240\021\330\024\032\320\032,\250A\320-Z\320Z[\340\020\021\220\027\230\001\330\010\017\210{\230!\330\014\020\220\007\220q\230\001\330\014\017\210s\220'\230\021\330\020\021\340\014\020\220\007\220q\230\001\330\014\r\320\000\037\320\0371\260\035\270a\360\036\000\005\010\200t\2101\330\010\017\210t\2201\220K\230x\240y\260\006\260a\340\004\013\2101\330\004\010\210\007\210u\220A\220[\240\010\250\t\260\026\260q\330\010\013\2107\220!\2205\230\r\240V\2507\260!\330\014\017\210w\220a\220u\230A\330\020\023\320\023$\240A\340\020\026\220c\230\021\330\010\014\210G\2201\220A\330\004\013\2101\320\004\035\320\0351\260\036\270q\360d\001\000\t\014\2104\210t\320\023,\250A\250Q\330\014\017\210t\2206\230\021\330\020\021\340\014\025\220V\2306\240\033\250A\330\014\022\220*\230A\230Q\330\014\017\210u\220M\240\021\240'\250\026\250{\270!\330\014\017\210w\220g\230Q\330\020\026\220d\230!\330\020\024\220E\230\021\230!\320\0043\2601\360\014\000\t\r\210E\220\021\220*\230L\250\001\240^\2605\270\001\200A\360\030\000\t\n\200A\200A\330\010\013\2102\210S\220\001\330""\014\r\330\020\024\220E\230\021\340\020\024\220E\230\021\340\014\020\220\005\220R\220s\230#\230Q\200A\340\010\013\2104\210~\230S\240\001\330\014!\240\021\240!\330\014\022\220*\230A\230Q\330\014\020\320\020 \240\003\2405\250\r\260Q\260d\270!\200A\360\016\000\t\014\2104\210~\230S\240\001\330\014!\240\021\240!\330\014\022\220*\230A\230Q\330\014\020\320\020 \240\003\2405\250\006\250a\250q\330\014\020\220\r\230V\2401\240D\250\001\200A\360\"\000\t\014\2104\210s\220)\2304\230t\2405\250\004\250F\260'\270\021\330\014\022\220)\2301\230A\330\010\014\210C\210r\220\030\230\021\330\010\t\210\034\220Q\220a\330\010\017\210q\200A\360\036\000\t\014\2104\210x\220q\230\001\330\014\022\220)\2301\320\0347\260q\330\010\014\210G\2207\230!\2301\330\010\013\2104\210v\220S\230\004\230D\240\010\250\004\250D\260\004\260A\330\014\022\220*\230A\230Q\330\014\020\220\r\230S\240\005\240]\260!\2604\260q\200A\360\034\000\t\020\320\017 \240\004\240A\200A\360\034\000\t\n\330\010\013\320\013\034\230C\230q\330\014\"\240!\330\010\030\230\004\230A\230Q\200A\360\034\000\t\r\210C\210r\220\030\230\021\330\010\t\210\026\210q\330\010\017\210q\200A\360\014\000\t\r\210D\220\007\220q\200A\360\026\000\t\n\330\010\013\320\013\034\230G\2401\330\014\034\230H\240A\240Q\330\014\017\210t\2201\330\020#\2401\200A\340\010\014\210O\2301\330\010\014\210G\2201\330\010\017\210t\2201\330\010\013\2101\330\014\017\210z\230\021\230+\240W\250D\260\003\2601\260K\270s\300!\330\020\027\220q\340\020\030\230\001\330\014\020\320\020,\250A\250Q\330\010\017\210q\200A\360\024\000\t\r\210O\2301\340\010\t\330\014\017\210t\2204\220q\360\n\000\021\031\230\006\230a\230w\240a\340\014\020\320\020,\250A\250Q\200A\330\010\016\210d\220!\360\020\000\r\024\2204\220w\230d\240!\2401\330\014\r\330\020\024\220A\220Q\340\020\032\230!\2305\240\r\250R\250v\260X\270\\\310\021\200A\330\010\016\210n\230A\230Q\200A\330\010\017\210q\200A\340\010\017\210q\220\001\220\033\230A\200A\340\010\017\210q\220\001\220\033\230K\240q\200A\330\010\t\330\014\020\220\017\230q\330""\014\020\320\020 \240\001\340\014\r\330\020\031\230\024\230U\240\"\240D\250\t\260\024\260Q\340\020\024\220O\2401\240L\260\001\340\020\024\320\024$\240A\240Q\340\014\020\220\007\220q\200A\330\010\017\210r\220\024\220Q\200A\330\010\017\210s\220!\2204\220q\200A\330\010\017\210t\2201\330\010\013\2105\220\007\220q\330\014\023\2201\360\010\000\t\020\210t\2201\330\010\022\220'\230\021\230&\240\014\250A\330\010\013\2108\2203\220a\330\014\027\220q\330\r\025\220W\230A\330\014\027\220t\2301\230A\340\014\027\220w\230a\230v\240\\\260\024\260S\270\004\270A\270Q\340\010\021\220\021\330\010\017\210q\330\010\013\2104\210q\330\014\023\2201\220D\230\001\230\022\2302\230T\240\024\240U\250$\250a\330\010\013\2104\210q\330\014\020\220\007\220q\230\001\230\033\240E\250\024\250Q\250f\260B\260e\2705\300\005\300Z\310t\320SZ\320Z`\320`a\330\010\013\2101\330\014\026\220d\230\"\230D\240\005\240Q\240f\250B\250a\340\010\014\320\014\037\230q\330\010\017\210q\200A\360\022\000\t\020\210t\2206\230\023\230D\240\013\2507\260!\200A\360\030\000\t\020\210t\220;\230g\240U\250$\250d\260*\270A\270S\300\003\3001\200A\340\010\t\330\014\020\220\007\220w\230a\230q\330\017\020\230H\240A\320\004)\250\021\360\036\000\t\r\210H\220A\220[\240\001\240\021\200\001\330\004\005\330\010\013\210:\220Q\220k\240\027\250\004\250C\250q\260\013\2703\270a\330\014\020\220\006\220b\230\001\340\014\020\220\006\220a\220q\360\006\000\t\023\220!\2205\230\r\240Q\240g\250\\\270\021\330\004\007\200w\210g\220Q\330\010\016\210g\220Q\220a\250>\270\025\270a\320\004\030\230\016\240a\360\032\000\t\014\2104\210v\220Q\330\014\017\210t\220;\230a\330\020\027\220t\2301\330\014\020\320\020!\240\021\330\010\013\2104\210q\330\014\022\220'\230\021\340\010\021\220\032\2302\230Q\330\010\014\210H\220A\220Q\330\010\t\330\014\020\220\007\320\027+\2501\250A\330\014\r\330\020\031\230\032\2401\240E\250\027\260\001\330\020\023\2207\230'\240\021\330\024\032\320\032,\250A\320-Y\320YZ\340\020\021\220\027\230\001\360\016\000\r\021\220\007\220q\230\001\330\014\r\340""\010\013\2104\210v\220Q\330\014\017\210t\220;\230a\330\020\027\220t\2301\330\014\020\320\020!\240\021\320\004/\250q\360\014\000\t\r\210E\220\021\220*\230L\250\001struct __pyx_obj_6gevent_29_gevent_c_greenlet_primitives_SwitchOutGreenletWithLoop *(int __pyx_skip_dispatch)\000get_hub_noargs";
    PyObject *data = NULL;
    CYTHON_UNUSED_VAR(__Pyx_DecompressString);
    #endif
    PyObject **stringtab = __pyx_mstate->__pyx_string_tab;
    Py_ssize_t pos = 0;
    for (int i = 0; i < 221; i++) {
      Py_ssize_t bytes_length = index[i].length;
      PyObject *string = PyUnicode_DecodeUTF8(bytes + pos, bytes_length, NULL);
      if (likely(string) && i >= 30) PyUnicode_InternInPlace(&string);
      if (unlikely(!string)) {
        Py_XDECREF(data);
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
      stringtab[i] = string;
      pos += bytes_length;
    }
    for (int i = 221; i < 268; i++) {
      Py_ssize_t bytes_length = index[i].length;
      PyObject *string = PyBytes_FromStringAndSize(bytes + pos, bytes_length);
      stringtab[i] = string;
      pos += bytes_length;
      if (unlikely(!string)) {
        Py_XDECREF(data);
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
    }
    Py_XDECREF(data);
    for (Py_ssize_t i = 0; i < 268; i++) {
      if (unlikely(PyObject_Hash(stringtab[i]) == -1)) {
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
    }
    #if CYTHON_IMMORTAL_CONSTANTS
    {
      PyObject **table = stringtab + 221;
      for (Py_ssize_t i=0; i<47; ++i) {
        #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
        #if PY_VERSION_HEX < 0x030E0000
        if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
        #else
        if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
        #endif
        {
          Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
        }
        #else
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
        #endif
      }
    }
    #endif
  }
  {
    PyObject **numbertab = __pyx_mstate->__pyx_number_tab + 0;
    int8_t const cint_constants_1[] = {0,10};
    for (int i = 0; i < 2; i++) {
      numbertab[i] = PyLong_FromLong(cint_constants_1[i - 0]);
      if (unlikely(!numbertab[i])) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #if CYTHON_IMMORTAL_CONSTANTS
  {
    PyObject **table = __pyx_mstate->__pyx_number_tab;
    for (Py_ssize_t i=0; i<2; ++i) {
      #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
      #if PY_VERSION_HEX < 0x030E0000
      if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
      #else
      if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
      #endif
      {
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
      }
      #else
      Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
      #endif
    }
  }
  #endif
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: init_codeobjects ### */
typedef struct {
    unsigned int argcount : 3;
    unsigned int num_posonly_args : 1;
    unsigned int num_kwonly_args : 1;
    unsigned int nlocals : 4;
    unsigned int flags : 10;
    unsigned int first_line : 11;
} __Pyx_PyCode_New_function_description;
/* NewCodeObj.proto */
static PyObject* __Pyx_PyCode_New(
        const __Pyx_PyCode_New_function_description descr,
        PyObject * const *varnames,
        PyObject *filename,
        PyObject *funcname,
        PyObject *line_table,
        PyObject *tuple_dedup_map
);


static int __Pyx_CreateCodeObjects(__pyx_mstatetype *__pyx_mstate) {
  PyObject* tuple_dedup_map = PyDict_New();
  if (unlikely(!tuple_dedup_map)) return -1;
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 67};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_greenlets, __pyx_mstate->__pyx_n_u_exception, __pyx_mstate->__pyx_n_u_waiter};
    __pyx_mstate_global->__pyx_codeobj_tab[0] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_cfunc_to_py, __pyx_mstate->__pyx_n_u_wrap, __pyx_mstate->__pyx_kp_b_iso88591_A_q_Kq, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[0])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 67};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_greenlets, __pyx_mstate->__pyx_n_u_exception};
    __pyx_mstate_global->__pyx_codeobj_tab[1] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_cfunc_to_py, __pyx_mstate->__pyx_n_u_wrap, __pyx_mstate->__pyx_kp_b_iso88591_A_q_A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[1])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {0, 0, 0, 0, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 45};
    PyObject* const varnames[] = {0};
    __pyx_mstate_global->__pyx_codeobj_tab[2] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_greenlet_py, __pyx_mstate->__pyx_n_u_lambda, __pyx_mstate->__pyx_kp_b_iso88591_HA, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[2])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 53};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_s};
    __pyx_mstate_global->__pyx_codeobj_tab[3] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_greenlet_py, __pyx_mstate->__pyx_n_u_lambda, __pyx_mstate->__pyx_kp_b_iso88591_1A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[3])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 56};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_s};
    __pyx_mstate_global->__pyx_codeobj_tab[4] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_greenlet_py, __pyx_mstate->__pyx_n_u_lambda, __pyx_mstate->__pyx_kp_b_iso88591_1A_2, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[4])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 59};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_frame};
    __pyx_mstate_global->__pyx_codeobj_tab[5] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_greenlet_py, __pyx_mstate->__pyx_n_u_lambda, __pyx_mstate->__pyx_kp_b_iso88591_5, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[5])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 60};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_frame};
    __pyx_mstate_global->__pyx_codeobj_tab[6] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_greenlet_py, __pyx_mstate->__pyx_n_u_lambda, __pyx_mstate->__pyx_kp_b_iso88591_a, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[6])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 61};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_frame};
    __pyx_mstate_global->__pyx_codeobj_tab[7] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_greenlet_py, __pyx_mstate->__pyx_n_u_lambda, __pyx_mstate->__pyx_kp_b_iso88591_5, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[7])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 356};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self_2};
    __pyx_mstate_global->__pyx_codeobj_tab[8] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_greenlet_py, __pyx_mstate->__pyx_n_u_name_2, __pyx_mstate->__pyx_kp_b_iso88591_A_A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[8])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 372};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self_2};
    __pyx_mstate_global->__pyx_codeobj_tab[9] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_greenlet_py, __pyx_mstate->__pyx_n_u_raise_exception, __pyx_mstate->__pyx_kp_b_iso88591_A_r_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[9])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 504};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self_2};
    __pyx_mstate_global->__pyx_codeobj_tab[10] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_greenlet_py, __pyx_mstate->__pyx_n_u_ready, __pyx_mstate->__pyx_kp_b_iso88591_A_t6_D_7, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[10])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 515};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self_2};
    __pyx_mstate_global->__pyx_codeobj_tab[11] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_greenlet_py, __pyx_mstate->__pyx_n_u_successful, __pyx_mstate->__pyx_kp_b_iso88591_A_t_gU_d_AS_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[11])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 545};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self_2};
    __pyx_mstate_global->__pyx_codeobj_tab[12] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_greenlet_py, __pyx_mstate->__pyx_n_u_formatinfo, __pyx_mstate->__pyx_kp_b_iso88591_A_t1_5_q_1_t1_A_83a_q_WA_t1A_wav, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[12])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS), 600};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self_2, __pyx_mstate->__pyx_n_u_args};
    __pyx_mstate_global->__pyx_codeobj_tab[13] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_greenlet_py, __pyx_mstate->__pyx_n_u_throw, __pyx_mstate->__pyx_kp_b_iso88591_A_O1_t4q_awa_AQ, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[13])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 622};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self_2, __pyx_mstate->__pyx_n_u_hub};
    __pyx_mstate_global->__pyx_codeobj_tab[14] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_greenlet_py, __pyx_mstate->__pyx_n_u_start, __pyx_mstate->__pyx_kp_b_iso88591_A_4_S_AQ_5_Qd, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[14])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 629};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self_2, __pyx_mstate->__pyx_n_u_seconds, __pyx_mstate->__pyx_n_u_hub};
    __pyx_mstate_global->__pyx_codeobj_tab[15] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_greenlet_py, __pyx_mstate->__pyx_n_u_start_later, __pyx_mstate->__pyx_kp_b_iso88591_A_4_S_AQ_5_aq_V1D, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[15])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 642};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_callback};
    __pyx_mstate_global->__pyx_codeobj_tab[16] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_greenlet_py, __pyx_mstate->__pyx_n_u_add_spawn_callback, __pyx_mstate->__pyx_kp_b_iso88591_A_Cq_AQ, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[16])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 661};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_callback};
    __pyx_mstate_global->__pyx_codeobj_tab[17] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_greenlet_py, __pyx_mstate->__pyx_n_u_remove_spawn_callback, __pyx_mstate->__pyx_kp_b_iso88591_A_G1_HAQ_t1_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[17])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS|CO_VARKEYWORDS), 678};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_cls, __pyx_mstate->__pyx_n_u_args, __pyx_mstate->__pyx_n_u_kwargs, __pyx_mstate->__pyx_n_u_g};
    __pyx_mstate_global->__pyx_codeobj_tab[18] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_greenlet_py, __pyx_mstate->__pyx_n_u_spawn, __pyx_mstate->__pyx_kp_b_iso88591_A_Cr_q_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[18])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 5, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS|CO_VARKEYWORDS), 696};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_cls, __pyx_mstate->__pyx_n_u_seconds, __pyx_mstate->__pyx_n_u_args, __pyx_mstate->__pyx_n_u_kwargs, __pyx_mstate->__pyx_n_u_g};
    __pyx_mstate_global->__pyx_codeobj_tab[19] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_greenlet_py, __pyx_mstate->__pyx_n_u_spawn_later, __pyx_mstate->__pyx_kp_b_iso88591_A_4s_4t5_F_1A_Cr_Qa_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[19])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 719};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self_2, __pyx_mstate->__pyx_n_u_exception};
    __pyx_mstate_global->__pyx_codeobj_tab[20] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_greenlet_py, __pyx_mstate->__pyx_n_u_maybe_kill_before_start, __pyx_mstate->__pyx_kp_b_iso88591_A_O1_G1_t1_1_z_WD_1Ks_q_AQ_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[20])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {4, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 732};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self_2, __pyx_mstate->__pyx_n_u_exception, __pyx_mstate->__pyx_n_u_block, __pyx_mstate->__pyx_n_u_timeout};
    __pyx_mstate_global->__pyx_codeobj_tab[21] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_greenlet_py, __pyx_mstate->__pyx_n_u_kill, __pyx_mstate->__pyx_kp_b_iso88591_1_qd_4t_AQ_t6_V6_A_AQ_uM_wgQ_d, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[21])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 6, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 793};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self_2, __pyx_mstate->__pyx_n_u_block, __pyx_mstate->__pyx_n_u_timeout, __pyx_mstate->__pyx_n_u_switch, __pyx_mstate->__pyx_n_u_t, __pyx_mstate->__pyx_n_u_result};
    __pyx_mstate_global->__pyx_codeobj_tab[22] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_greenlet_py, __pyx_mstate->__pyx_n_u_get_2, __pyx_mstate->__pyx_kp_b_iso88591_a_4vQ_t_a_t1_4q_2Q_HAQ_1A_1E_7, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[22])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 837};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self_2, __pyx_mstate->__pyx_n_u_timeout};
    __pyx_mstate_global->__pyx_codeobj_tab[23] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_greenlet_py, __pyx_mstate->__pyx_n_u_join, __pyx_mstate->__pyx_kp_b_iso88591_1_4vQ_2Q_HAQ_1A_1E_7_A_ZZ_q_s_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[23])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 865};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self_2};
    __pyx_mstate_global->__pyx_codeobj_tab[24] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_greenlet_py, __pyx_mstate->__pyx_n_u_enter, __pyx_mstate->__pyx_kp_b_iso88591_A_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[24])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {4, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 868};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self_2, __pyx_mstate->__pyx_n_u_t, __pyx_mstate->__pyx_n_u_v, __pyx_mstate->__pyx_n_u_tb};
    __pyx_mstate_global->__pyx_codeobj_tab[25] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_greenlet_py, __pyx_mstate->__pyx_n_u_exit, __pyx_mstate->__pyx_kp_b_iso88591_A_2S_E_E_Rs_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[25])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 906};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self_2, __pyx_mstate->__pyx_n_u_result};
    __pyx_mstate_global->__pyx_codeobj_tab[26] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_greenlet_py, __pyx_mstate->__pyx_n_u_run, __pyx_mstate->__pyx_kp_b_iso88591_A_q_U_D_Q_O1L_AQ_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[26])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 932};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self_2};
    __pyx_mstate_global->__pyx_codeobj_tab[27] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_greenlet_py, __pyx_mstate->__pyx_n_u_run_2, __pyx_mstate->__pyx_kp_b_iso88591_A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[27])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 946};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self_2};
    __pyx_mstate_global->__pyx_codeobj_tab[28] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_greenlet_py, __pyx_mstate->__pyx_n_u_has_links, __pyx_mstate->__pyx_kp_b_iso88591_A_s_4q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[28])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 949};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self_2, __pyx_mstate->__pyx_n_u_callback};
    __pyx_mstate_global->__pyx_codeobj_tab[29] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_greenlet_py, __pyx_mstate->__pyx_n_u_rawlink, __pyx_mstate->__pyx_kp_b_iso88591_A_4xq_1_7q_G7_1_4vS_D_D_A_AQ_S_4, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[29])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 971};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self_2, __pyx_mstate->__pyx_n_u_callback, __pyx_mstate->__pyx_n_u_SpawnedLink};
    __pyx_mstate_global->__pyx_codeobj_tab[30] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_greenlet_py, __pyx_mstate->__pyx_n_u_link, __pyx_mstate->__pyx_kp_b_iso88591_HA_2, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[30])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 988};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self_2, __pyx_mstate->__pyx_n_u_callback};
    __pyx_mstate_global->__pyx_codeobj_tab[31] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_greenlet_py, __pyx_mstate->__pyx_n_u_unlink, __pyx_mstate->__pyx_kp_b_iso88591_A_waq, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[31])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 995};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self_2};
    __pyx_mstate_global->__pyx_codeobj_tab[32] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_greenlet_py, __pyx_mstate->__pyx_n_u_unlink_all, __pyx_mstate->__pyx_kp_b_iso88591_A_D_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[32])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1003};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self_2, __pyx_mstate->__pyx_n_u_callback, __pyx_mstate->__pyx_n_u_SpawnedLink};
    __pyx_mstate_global->__pyx_codeobj_tab[33] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_greenlet_py, __pyx_mstate->__pyx_n_u_link_value, __pyx_mstate->__pyx_kp_b_iso88591_q_E_L, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[33])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1011};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self_2, __pyx_mstate->__pyx_n_u_callback, __pyx_mstate->__pyx_n_u_SpawnedLink};
    __pyx_mstate_global->__pyx_codeobj_tab[34] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_greenlet_py, __pyx_mstate->__pyx_n_u_link_exception, __pyx_mstate->__pyx_kp_b_iso88591_31_E_L, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[34])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1019};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self_2};
    __pyx_mstate_global->__pyx_codeobj_tab[35] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_greenlet_py, __pyx_mstate->__pyx_n_u_notify_links, __pyx_mstate->__pyx_kp_b_iso88591_A_d_4wd_1_AQ_5_RvX, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[35])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1041};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self_2};
    __pyx_mstate_global->__pyx_codeobj_tab[36] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_greenlet_py, __pyx_mstate->__pyx_n_u_stop, __pyx_mstate->__pyx_kp_b_iso88591_A_2, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[36])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1044};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self_2, __pyx_mstate->__pyx_n_u_cb};
    __pyx_mstate_global->__pyx_codeobj_tab[37] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_greenlet_py, __pyx_mstate->__pyx_n_u_start, __pyx_mstate->__pyx_kp_b_iso88591_A_nAQ, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[37])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1047};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self_2};
    __pyx_mstate_global->__pyx_codeobj_tab[38] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_greenlet_py, __pyx_mstate->__pyx_n_u_close, __pyx_mstate->__pyx_kp_b_iso88591_A_2, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[38])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1056};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_glet, __pyx_mstate->__pyx_n_u_exception, __pyx_mstate->__pyx_n_u_waiter};
    __pyx_mstate_global->__pyx_codeobj_tab[39] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_greenlet_py, __pyx_mstate->__pyx_n_u_kill_2, __pyx_mstate->__pyx_kp_b_iso88591_Qk_Cq_3a_b_aq_5_Qg_wgQ_gQa, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[39])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {4, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1069};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_greenlets, __pyx_mstate->__pyx_n_u_timeout, __pyx_mstate->__pyx_n_u_raise_error, __pyx_mstate->__pyx_n_u_count};
    __pyx_mstate_global->__pyx_codeobj_tab[40] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_greenlet_py, __pyx_mstate->__pyx_n_u_joinall, __pyx_mstate->__pyx_kp_b_iso88591_1_a_t1_t1Kxy_a_1_uA_q_7_5_V7_wa, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[40])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {4, 0, 0, 11, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1129};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_greenlets, __pyx_mstate->__pyx_n_u_exception, __pyx_mstate->__pyx_n_u_block, __pyx_mstate->__pyx_n_u_timeout, __pyx_mstate->__pyx_n_u_need_killed, __pyx_mstate->__pyx_n_u_glet, __pyx_mstate->__pyx_n_u_cancel, __pyx_mstate->__pyx_n_u_loop, __pyx_mstate->__pyx_n_u_waiter, __pyx_mstate->__pyx_n_u_t, __pyx_mstate->__pyx_n_u_alive};
    __pyx_mstate_global->__pyx_codeobj_tab[41] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_greenlet_py, __pyx_mstate->__pyx_n_u_killall, __pyx_mstate->__pyx_kp_b_iso88591_1F_T_waq_t6_7_1_t1_4q_q_q_M_Q_G, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[41])) goto bad;
  }
  Py_DECREF(tuple_dedup_map);
  return 0;
  bad:
  Py_DECREF(tuple_dedup_map);
  return -1;
}
/* #### Code section: init_globals ### */

static int __Pyx_InitGlobals(void) {
  /* PythonCompatibility.init */
  if (likely(__Pyx_init_co_variables() == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CommonTypesMetaclass.init */
  if (likely(__pyx_CommonTypesMetaclass_init(__pyx_m) == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CachedMethodType.init */
  #if CYTHON_COMPILING_IN_LIMITED_API
  {
      PyObject *typesModule=NULL;
      typesModule = PyImport_ImportModule("types");
      if (typesModule) {
          __pyx_mstate_global->__Pyx_CachedMethodType = PyObject_GetAttrString(typesModule, "MethodType");
          Py_DECREF(typesModule);
      }
  } // error handling follows
  #endif
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CythonFunctionShared.init */
  if (likely(__pyx_CyFunction_init(__pyx_m) == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* AssertionsEnabled.init */
  if (likely(__Pyx_init_assertions_enabled() == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cleanup_globals ### */
/* #### Code section: cleanup_module ### */
/* #### Code section: main_method ### */
/* #### Code section: utility_code_pragmas ### */
#ifdef _MSC_VER
#pragma warning( push )
/* Warning 4127: conditional expression is constant
 * Cython uses constant conditional expressions to allow in inline functions to be optimized at
 * compile-time, so this warning is not useful
 */
#pragma warning( disable : 4127 )
#endif



/* #### Code section: utility_code_def ### */

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyErrExceptionMatches (used by PyObjectGetAttrStrNoError) */
#include "src/gevent/_generated_include/PyErrExceptionMatches_impl_7b4f377310190df92a521563db80ecc2f42d95506fc867b739186a972ce9c8f6.h"
/* PyErrFetchRestore (used by PyObjectGetAttrStrNoError) */
#include "src/gevent/_generated_include/PyErrFetchRestore_impl_83072c493b1583a48ff3aad9f8dc7ade3be268831a2ab8ada440fe395cf916ad.h"
/* PyObjectGetAttrStr (used by PyObjectGetAttrStrNoError) */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* PyObjectGetAttrStrNoError (used by GetBuiltinName) */
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
static void __Pyx_PyObject_GetAttrStr_ClearAttributeError(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (likely(__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        __Pyx_PyErr_Clear();
}
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name) {
    PyObject *result;
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    (void) PyObject_GetOptionalAttr(obj, attr_name, &result);
    return result;
#else
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_TYPE_SLOTS
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro == PyObject_GenericGetAttr)) {
        return _PyObject_GenericGetAttrWithDict(obj, attr_name, NULL, 1);
    }
#endif
    result = __Pyx_PyObject_GetAttrStr(obj, attr_name);
    if (unlikely(!result)) {
        __Pyx_PyObject_GetAttrStr_ClearAttributeError();
    }
    return result;
#endif
}

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStrNoError(__pyx_mstate_global->__pyx_b, name);
    if (unlikely(!result) && !PyErr_Occurred()) {
        PyErr_Format(PyExc_NameError,
            "name '%U' is not defined", name);
    }
    return result;
}

/* TupleAndListFromArray (used by fastcall) */
#include "src/gevent/_generated_include/TupleAndListFromArray_impl_d69ed499f68cd42feaee4b5942c18d0f8efd9989393e455f897298c58b9fa8dd.h"
/* BytesEquals (used by UnicodeEquals) */
#include "src/gevent/_generated_include/BytesEquals_impl_d48b3ef06490e9921f32936be4dcafdc3250ac7ef2252e904b8f20e24a665cc0.h"
/* UnicodeEquals (used by fastcall) */
#include "src/gevent/_generated_include/UnicodeEquals_impl_836cabebedcde255d7b2e14d2d3ec8ae093224d9992c111dd33f6f1ba2aecbef.h"
/* fastcall */
#include "src/gevent/_generated_include/fastcall_impl_2d371982e998467e5c3fa3d5d125a44afb3a07b23828be3d6b5d120f6be5ca37.h"
/* PyObjectCall (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = Py_TYPE(func)->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallMethO (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = __Pyx_CyOrPyCFunction_GET_FUNCTION(func);
    self = __Pyx_CyOrPyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectFastCall (used by PyObjectCallOneArg) */
#include "src/gevent/_generated_include/PyObjectFastCall_impl_49781168209ae59e1c56f88d63362765f980ea90cc34bbbe49d64735688b114b.h"
/* PyObjectCallOneArg (used by CallUnboundCMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *args[2] = {NULL, arg};
    return __Pyx_PyObject_FastCall(func, args+1, 1 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* UnpackUnboundCMethod (used by CallUnboundCMethod0) */
#include "src/gevent/_generated_include/UnpackUnboundCMethod_impl_73fbc94f885e37a7810c861231fd30d7a9eae7cde8890c6786a4ce1f346a7810.h"
/* CallUnboundCMethod0 */
#include "src/gevent/_generated_include/CallUnboundCMethod0_impl_506503ba83409bc78d50e6c2a64d54ddd95a836cba396a015c59c17bbf915db5.h"
/* py_dict_items (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Items(PyObject* d) {
    return __Pyx_CallUnboundCMethod0(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_items, d);
}

/* py_dict_values (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Values(PyObject* d) {
    return __Pyx_CallUnboundCMethod0(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_values, d);
}

/* OwnedDictNext (used by ParseKeywordsImpl) */
#if CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, PyObject **ppos, PyObject **pkey, PyObject **pvalue) {
    PyObject *next = NULL;
    if (!*ppos) {
        if (pvalue) {
            PyObject *dictview = pkey ? __Pyx_PyDict_Items(p) : __Pyx_PyDict_Values(p);
            if (unlikely(!dictview)) goto bad;
            *ppos = PyObject_GetIter(dictview);
            Py_DECREF(dictview);
        } else {
            *ppos = PyObject_GetIter(p);
        }
        if (unlikely(!*ppos)) goto bad;
    }
    next = PyIter_Next(*ppos);
    if (!next) {
        if (PyErr_Occurred()) goto bad;
        return 0;
    }
    if (pkey && pvalue) {
        *pkey = __Pyx_PySequence_ITEM(next, 0);
        if (unlikely(*pkey)) goto bad;
        *pvalue = __Pyx_PySequence_ITEM(next, 1);
        if (unlikely(*pvalue)) goto bad;
        Py_DECREF(next);
    } else if (pkey) {
        *pkey = next;
    } else {
        assert(pvalue);
        *pvalue = next;
    }
    return 1;
  bad:
    Py_XDECREF(next);
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d0000
    PyErr_FormatUnraisable("Exception ignored in __Pyx_PyDict_NextRef");
#else
    PyErr_WriteUnraisable(__pyx_mstate_global->__pyx_n_u_Pyx_PyDict_NextRef);
#endif
    if (pkey) *pkey = NULL;
    if (pvalue) *pvalue = NULL;
    return 0;
}
#else // !CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, Py_ssize_t *ppos, PyObject **pkey, PyObject **pvalue) {
    int result = PyDict_Next(p, ppos, pkey, pvalue);
    if (likely(result == 1)) {
        if (pkey) Py_INCREF(*pkey);
        if (pvalue) Py_INCREF(*pvalue);
    }
    return result;
}
#endif

/* RaiseDoubleKeywords (used by ParseKeywordsImpl) */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
}

/* CallUnboundCMethod2 */
#include "src/gevent/_generated_include/CallUnboundCMethod2_impl_15aa7f0a5154a4d6051e84dd189b6dc929e7450de4be5cb5e9cc003766aec24d.h"
/* ParseKeywordsImpl (used by ParseKeywords) */
static int __Pyx_ValidateDuplicatePosArgs(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    const char* function_name)
{
    PyObject ** const *name = argnames;
    while (name != first_kw_arg) {
        PyObject *key = **name;
        int found = PyDict_Contains(kwds, key);
        if (unlikely(found)) {
            if (found == 1) __Pyx_RaiseDoubleKeywordsError(function_name, key);
            goto bad;
        }
        name++;
    }
    return 0;
bad:
    return -1;
}
#if CYTHON_USE_UNICODE_INTERNALS
static CYTHON_INLINE int __Pyx_UnicodeKeywordsEqual(PyObject *s1, PyObject *s2) {
    int kind;
    Py_ssize_t len = PyUnicode_GET_LENGTH(s1);
    if (len != PyUnicode_GET_LENGTH(s2)) return 0;
    kind = PyUnicode_KIND(s1);
    if (kind != PyUnicode_KIND(s2)) return 0;
    const void *data1 = PyUnicode_DATA(s1);
    const void *data2 = PyUnicode_DATA(s2);
    return (memcmp(data1, data2, (size_t) len * (size_t) kind) == 0);
}
#endif
static int __Pyx_MatchKeywordArg_str(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    PyObject ** const *name;
    #if CYTHON_USE_UNICODE_INTERNALS
    Py_hash_t key_hash = ((PyASCIIObject*)key)->hash;
    if (unlikely(key_hash == -1)) {
        key_hash = PyObject_Hash(key);
        if (unlikely(key_hash == -1))
            goto bad;
    }
    #endif
    name = first_kw_arg;
    while (*name) {
        PyObject *name_str = **name;
        #if CYTHON_USE_UNICODE_INTERNALS
        if (key_hash == ((PyASCIIObject*)name_str)->hash && __Pyx_UnicodeKeywordsEqual(name_str, key)) {
            *index_found = (size_t) (name - argnames);
            return 1;
        }
        #else
        #if CYTHON_ASSUME_SAFE_SIZE
        if (PyUnicode_GET_LENGTH(name_str) == PyUnicode_GET_LENGTH(key))
        #endif
        {
            int cmp = PyUnicode_Compare(name_str, key);
            if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
            if (cmp == 0) {
                *index_found = (size_t) (name - argnames);
                return 1;
            }
        }
        #endif
        name++;
    }
    name = argnames;
    while (name != first_kw_arg) {
        PyObject *name_str = **name;
        #if CYTHON_USE_UNICODE_INTERNALS
        if (unlikely(key_hash == ((PyASCIIObject*)name_str)->hash)) {
            if (__Pyx_UnicodeKeywordsEqual(name_str, key))
                goto arg_passed_twice;
        }
        #else
        #if CYTHON_ASSUME_SAFE_SIZE
        if (PyUnicode_GET_LENGTH(name_str) == PyUnicode_GET_LENGTH(key))
        #endif
        {
            if (unlikely(name_str == key)) goto arg_passed_twice;
            int cmp = PyUnicode_Compare(name_str, key);
            if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
            if (cmp == 0) goto arg_passed_twice;
        }
        #endif
        name++;
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
bad:
    return -1;
}
static int __Pyx_MatchKeywordArg_nostr(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    PyObject ** const *name;
    if (unlikely(!PyUnicode_Check(key))) goto invalid_keyword_type;
    name = first_kw_arg;
    while (*name) {
        int cmp = PyObject_RichCompareBool(**name, key, Py_EQ);
        if (cmp == 1) {
            *index_found = (size_t) (name - argnames);
            return 1;
        }
        if (unlikely(cmp == -1)) goto bad;
        name++;
    }
    name = argnames;
    while (name != first_kw_arg) {
        int cmp = PyObject_RichCompareBool(**name, key, Py_EQ);
        if (unlikely(cmp != 0)) {
            if (cmp == 1) goto arg_passed_twice;
            else goto bad;
        }
        name++;
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
bad:
    return -1;
}
static CYTHON_INLINE int __Pyx_MatchKeywordArg(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    return likely(PyUnicode_CheckExact(key)) ?
        __Pyx_MatchKeywordArg_str(key, argnames, first_kw_arg, index_found, function_name) :
        __Pyx_MatchKeywordArg_nostr(key, argnames, first_kw_arg, index_found, function_name);
}
static void __Pyx_RejectUnknownKeyword(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    const char *function_name)
{
    #if CYTHON_AVOID_BORROWED_REFS
    PyObject *pos = NULL;
    #else
    Py_ssize_t pos = 0;
    #endif
    PyObject *key = NULL;
    __Pyx_BEGIN_CRITICAL_SECTION(kwds);
    while (
        #if CYTHON_AVOID_BORROWED_REFS
        __Pyx_PyDict_NextRef(kwds, &pos, &key, NULL)
        #else
        PyDict_Next(kwds, &pos, &key, NULL)
        #endif
    ) {
        PyObject** const *name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (!*name) {
            size_t index_found = 0;
            int cmp = __Pyx_MatchKeywordArg(key, argnames, first_kw_arg, &index_found, function_name);
            if (cmp != 1) {
                if (cmp == 0) {
                    PyErr_Format(PyExc_TypeError,
                        "%s() got an unexpected keyword argument '%U'",
                        function_name, key);
                }
                #if CYTHON_AVOID_BORROWED_REFS
                Py_DECREF(key);
                #endif
                break;
            }
        }
        #if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(key);
        #endif
    }
    __Pyx_END_CRITICAL_SECTION();
    #if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(pos);
    #endif
    assert(PyErr_Occurred());
}
static int __Pyx_ParseKeywordDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    PyObject** const *name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    Py_ssize_t extracted = 0;
#if !CYTHON_COMPILING_IN_PYPY || defined(PyArg_ValidateKeywordArguments)
    if (unlikely(!PyArg_ValidateKeywordArguments(kwds))) return -1;
#endif
    name = first_kw_arg;
    while (*name && num_kwargs > extracted) {
        PyObject * key = **name;
        PyObject *value;
        int found = 0;
        #if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
        found = PyDict_GetItemRef(kwds, key, &value);
        #else
        value = PyDict_GetItemWithError(kwds, key);
        if (value) {
            Py_INCREF(value);
            found = 1;
        } else {
            if (unlikely(PyErr_Occurred())) goto bad;
        }
        #endif
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
            extracted++;
        }
        name++;
    }
    if (num_kwargs > extracted) {
        if (ignore_unknown_kwargs) {
            if (unlikely(__Pyx_ValidateDuplicatePosArgs(kwds, argnames, first_kw_arg, function_name) == -1))
                goto bad;
        } else {
            __Pyx_RejectUnknownKeyword(kwds, argnames, first_kw_arg, function_name);
            goto bad;
        }
    }
    return 0;
bad:
    return -1;
}
static int __Pyx_ParseKeywordDictToDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject** const *name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    Py_ssize_t len;
#if !CYTHON_COMPILING_IN_PYPY || defined(PyArg_ValidateKeywordArguments)
    if (unlikely(!PyArg_ValidateKeywordArguments(kwds))) return -1;
#endif
    if (PyDict_Update(kwds2, kwds) < 0) goto bad;
    name = first_kw_arg;
    while (*name) {
        PyObject *key = **name;
        PyObject *value;
#if !CYTHON_COMPILING_IN_LIMITED_API && (PY_VERSION_HEX >= 0x030d00A2 || defined(PyDict_Pop))
        int found = PyDict_Pop(kwds2, key, &value);
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
        }
#elif __PYX_LIMITED_VERSION_HEX >= 0x030d0000
        int found = PyDict_GetItemRef(kwds2, key, &value);
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
            if (unlikely(PyDict_DelItem(kwds2, key) < 0)) goto bad;
        }
#else
    #if CYTHON_COMPILING_IN_CPYTHON
        value = _PyDict_Pop(kwds2, key, kwds2);
    #else
        value = __Pyx_CallUnboundCMethod2(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_pop, kwds2, key, kwds2);
    #endif
        if (value == kwds2) {
            Py_DECREF(value);
        } else {
            if (unlikely(!value)) goto bad;
            values[name-argnames] = value;
        }
#endif
        name++;
    }
    len = PyDict_Size(kwds2);
    if (len > 0) {
        return __Pyx_ValidateDuplicatePosArgs(kwds, argnames, first_kw_arg, function_name);
    } else if (unlikely(len == -1)) {
        goto bad;
    }
    return 0;
bad:
    return -1;
}
static int __Pyx_ParseKeywordsTuple(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    PyObject *key = NULL;
    PyObject** const * name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    for (Py_ssize_t pos = 0; pos < num_kwargs; pos++) {
#if CYTHON_AVOID_BORROWED_REFS
        key = __Pyx_PySequence_ITEM(kwds, pos);
#else
        key = __Pyx_PyTuple_GET_ITEM(kwds, pos);
#endif
#if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(!key)) goto bad;
#endif
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            PyObject *value = kwvalues[pos];
            values[name-argnames] = __Pyx_NewRef(value);
        } else {
            size_t index_found = 0;
            int cmp = __Pyx_MatchKeywordArg(key, argnames, first_kw_arg, &index_found, function_name);
            if (cmp == 1) {
                PyObject *value = kwvalues[pos];
                values[index_found] = __Pyx_NewRef(value);
            } else {
                if (unlikely(cmp == -1)) goto bad;
                if (kwds2) {
                    PyObject *value = kwvalues[pos];
                    if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
                } else if (!ignore_unknown_kwargs) {
                    goto invalid_keyword;
                }
            }
        }
        #if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(key);
        key = NULL;
        #endif
    }
    return 0;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    goto bad;
bad:
    #if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(key);
    #endif
    return -1;
}

/* ParseKeywords */
static int __Pyx_ParseKeywords(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    if (CYTHON_METH_FASTCALL && likely(PyTuple_Check(kwds)))
        return __Pyx_ParseKeywordsTuple(kwds, kwvalues, argnames, kwds2, values, num_pos_args, num_kwargs, function_name, ignore_unknown_kwargs);
    else if (kwds2)
        return __Pyx_ParseKeywordDictToDict(kwds, argnames, kwds2, values, num_pos_args, function_name);
    else
        return __Pyx_ParseKeywordDict(kwds, argnames, values, num_pos_args, num_kwargs, function_name, ignore_unknown_kwargs);
}

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* ArgTypeTestFunc (used by ArgTypeTest) */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact)
{
    __Pyx_TypeName type_name;
    __Pyx_TypeName obj_type_name;
    PyObject *extra_info = __pyx_mstate_global->__pyx_empty_unicode;
    int from_annotation_subclass = 0;
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    else if (!exact) {
        if (likely(__Pyx_TypeCheck(obj, type))) return 1;
    } else if (exact == 2) {
        if (__Pyx_TypeCheck(obj, type)) {
            from_annotation_subclass = 1;
            extra_info = __pyx_mstate_global->__pyx_kp_u_Note_that_Cython_is_deliberately;
        }
    }
    type_name = __Pyx_PyType_GetFullyQualifiedName(type);
    obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "Argument '%.200s' has incorrect type (expected " __Pyx_FMT_TYPENAME
        ", got " __Pyx_FMT_TYPENAME ")"
#if __PYX_LIMITED_VERSION_HEX < 0x030C0000
        "%s%U"
#endif
        , name, type_name, obj_type_name
#if __PYX_LIMITED_VERSION_HEX < 0x030C0000
        , (from_annotation_subclass ? ". " : ""), extra_info
#endif
        );
#if __PYX_LIMITED_VERSION_HEX >= 0x030C0000
    if (exact == 2 && from_annotation_subclass) {
        PyObject *res;
        PyObject *vargs[2];
        vargs[0] = PyErr_GetRaisedException();
        vargs[1] = extra_info;
        res = PyObject_VectorcallMethod(__pyx_mstate_global->__pyx_kp_u_add_note, vargs, 2, NULL);
        Py_XDECREF(res);
        PyErr_SetRaisedException(vargs[0]);
    }
#endif
    __Pyx_DECREF_TypeName(type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* dict_setdefault (used by FetchCommonType) */
static CYTHON_INLINE PyObject *__Pyx_PyDict_SetDefault(PyObject *d, PyObject *key, PyObject *default_value) {
    PyObject* value;
#if __PYX_LIMITED_VERSION_HEX >= 0x030F0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4)
    PyDict_SetDefaultRef(d, key, default_value, &value);
#elif CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX >= 0x030C0000
    PyObject *args[] = {d, key, default_value};
    value = PyObject_VectorcallMethod(__pyx_mstate_global->__pyx_n_u_setdefault, args, 3 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#elif CYTHON_COMPILING_IN_LIMITED_API
    value = PyObject_CallMethodObjArgs(d, __pyx_mstate_global->__pyx_n_u_setdefault, key, default_value, NULL);
#else
    value = PyDict_SetDefault(d, key, default_value);
    if (unlikely(!value)) return NULL;
    Py_INCREF(value);
#endif
    return value;
}

/* LimitedApiGetTypeDict (used by SetItemOnTypeDict) */
#include "src/gevent/_generated_include/LimitedApiGetTypeDict_impl_fd5385b0b7d81c54e35b8e8be86f2a48fa376c140ad1a251d94cb50d5e2fb049.h"
/* SetItemOnTypeDict (used by FixUpExtensionType) */
static int __Pyx__SetItemOnTypeDict(PyTypeObject *tp, PyObject *k, PyObject *v) {
    int result;
    PyObject *tp_dict;
#if CYTHON_COMPILING_IN_LIMITED_API
    tp_dict = __Pyx_GetTypeDict(tp);
    if (unlikely(!tp_dict)) return -1;
#else
    tp_dict = tp->tp_dict;
#endif
    result = PyDict_SetItem(tp_dict, k, v);
    if (likely(!result)) {
        PyType_Modified(tp);
        if (unlikely(PyObject_HasAttr(v, __pyx_mstate_global->__pyx_n_u_set_name))) {
            PyObject *setNameResult = PyObject_CallMethodObjArgs(v, __pyx_mstate_global->__pyx_n_u_set_name,  (PyObject *) tp, k, NULL);
            if (!setNameResult) return -1;
            Py_DECREF(setNameResult);
        }
    }
    return result;
}

/* FixUpExtensionType (used by FetchCommonType) */
#include "src/gevent/_generated_include/FixUpExtensionType_impl_968625585c074793d4236a363113043104c99af679f80b0b7d0ea5e03b43f419.h"
/* AddModuleRef (used by FetchSharedCythonModule) */
#include "src/gevent/_generated_include/AddModuleRef_impl_59efe7a55c2d1acdb632a2a6953f1ce31c634c9f98f262a8d338db6996845385.h"
/* FetchSharedCythonModule (used by FetchCommonType) */
static PyObject *__Pyx_FetchSharedCythonABIModule(void) {
    return __Pyx_PyImport_AddModuleRef(__PYX_ABI_MODULE_NAME);
}

/* FetchCommonType (used by CommonTypesMetaclass) */
#include "src/gevent/_generated_include/FetchCommonType_impl_8ddf5d6e0d45314935e4d87502d7fa32ec8f3d50d91ca9715a35d7f0fc2dda28.h"
/* CommonTypesMetaclass (used by CythonFunctionShared) */
#include "src/gevent/_generated_include/CommonTypesMetaclass_impl_5345023feb7cb35c8a99997be95973c1bfc904b959ef880ae7125f77d296af2b.h"
/* CallTypeTraverse (used by CythonFunctionShared) */
#if !CYTHON_USE_TYPE_SPECS || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x03090000)
#else
static int __Pyx_call_type_traverse(PyObject *o, int always_call, visitproc visit, void *arg) {
    #if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x03090000
    if (__Pyx_get_runtime_version() < 0x03090000) return 0;
    #endif
    if (!always_call) {
        PyTypeObject *base = __Pyx_PyObject_GetSlot(o, tp_base, PyTypeObject*);
        unsigned long flags = PyType_GetFlags(base);
        if (flags & Py_TPFLAGS_HEAPTYPE) {
            return 0;
        }
    }
    Py_VISIT((PyObject*)Py_TYPE(o));
    return 0;
}
#endif

/* PyMethodNew (used by CythonFunctionShared) */
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    PyObject *result;
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    #if __PYX_LIMITED_VERSION_HEX >= 0x030C0000
    {
        PyObject *args[] = {func, self};
        result = PyObject_Vectorcall(__pyx_mstate_global->__Pyx_CachedMethodType, args, 2, NULL);
    }
    #else
    result = PyObject_CallFunctionObjArgs(__pyx_mstate_global->__Pyx_CachedMethodType, func, self, NULL);
    #endif
    return result;
}
#else
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    return PyMethod_New(func, self);
}
#endif

/* PyVectorcallFastCallDict (used by CythonFunctionShared) */
#include "src/gevent/_generated_include/PyVectorcallFastCallDict_impl_3616dfa798c1c336b0933a7ec9d88cb291d491f6315b48f846f69828df4619eb.h"
/* CythonFunctionShared (used by CythonFunction) */
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunctionNoMethod(PyObject *func, void (*cfunc)(void)) {
    if (__Pyx_CyFunction_Check(func)) {
        return PyCFunction_GetFunction(((__pyx_CyFunctionObject*)func)->func) == (PyCFunction) cfunc;
    } else if (PyCFunction_Check(func)) {
        return PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void (*cfunc)(void)) {
    if ((PyObject*)Py_TYPE(func) == __pyx_mstate_global->__Pyx_CachedMethodType) {
        int result;
        PyObject *newFunc = PyObject_GetAttr(func, __pyx_mstate_global->__pyx_n_u_func);
        if (unlikely(!newFunc)) {
            PyErr_Clear(); // It's only an optimization, so don't throw an error
            return 0;
        }
        result = __Pyx__IsSameCyOrCFunctionNoMethod(newFunc, cfunc);
        Py_DECREF(newFunc);
        return result;
    }
    return __Pyx__IsSameCyOrCFunctionNoMethod(func, cfunc);
}
#else
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void (*cfunc)(void)) {
    if (PyMethod_Check(func)) {
        func = PyMethod_GET_FUNCTION(func);
    }
    return __Pyx_CyOrPyCFunction_Check(func) && __Pyx_CyOrPyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
}
#endif
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj) {
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    __Pyx_Py_XDECREF_SET(
        __Pyx_CyFunction_GetClassObj(f),
            ((classobj) ? __Pyx_NewRef(classobj) : NULL));
#else
    __Pyx_Py_XDECREF_SET(
        ((PyCMethodObject *) (f))->mm_class,
        (PyTypeObject*)((classobj) ? __Pyx_NewRef(classobj) : NULL));
#endif
}
static PyObject *
__Pyx_CyFunction_get_doc_locked(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_doc == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_doc = PyObject_GetAttrString(op->func, "__doc__");
        if (unlikely(!op->func_doc)) return NULL;
#else
        if (((PyCFunctionObject*)op)->m_ml->ml_doc) {
            op->func_doc = PyUnicode_FromString(((PyCFunctionObject*)op)->m_ml->ml_doc);
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
#endif
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, void *closure) {
    PyObject *result;
    CYTHON_UNUSED_VAR(closure);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_doc_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (value == NULL) {
        value = Py_None;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_doc, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name_locked(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_name == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_name = PyObject_GetAttrString(op->func, "__name__");
#else
        op->func_name = PyUnicode_InternFromString(((PyCFunctionObject*)op)->m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op, void *context)
{
    PyObject *result = NULL;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_name_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_name, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    PyObject *result;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    Py_INCREF(op->func_qualname);
    result = op->func_qualname;
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_qualname, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
#endif
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(op);
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op, void *context)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    int result = 0;
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    #else
    op->defaults_tuple = __Pyx_PySequence_ITEM(res, 0);
    if (unlikely(!op->defaults_tuple)) result = -1;
    else {
        op->defaults_kwdict = __Pyx_PySequence_ITEM(res, 1);
        if (unlikely(!op->defaults_kwdict)) result = -1;
    }
    #endif
    Py_DECREF(res);
    return result;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyTuple_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__defaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->defaults_tuple, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_tuple;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = NULL;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_defaults_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__kwdefaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->defaults_kwdict, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_kwdict;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_kwdefaults_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value || value == Py_None) {
        value = NULL;
    } else if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_annotations, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->func_annotations;
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op, void *context) {
    PyObject *result;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_annotations_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static PyObject *
__Pyx_CyFunction_get_is_coroutine_value(__pyx_CyFunctionObject *op) {
    int is_coroutine = op->flags & __Pyx_CYFUNCTION_COROUTINE;
    if (is_coroutine) {
        PyObject *is_coroutine_value, *module, *fromlist, *marker = __pyx_mstate_global->__pyx_n_u_is_coroutine;
        fromlist = PyList_New(1);
        if (unlikely(!fromlist)) return NULL;
        Py_INCREF(marker);
#if CYTHON_ASSUME_SAFE_MACROS
        PyList_SET_ITEM(fromlist, 0, marker);
#else
        if (unlikely(PyList_SetItem(fromlist, 0, marker) < 0)) {
            Py_DECREF(marker);
            Py_DECREF(fromlist);
            return NULL;
        }
#endif
        module = PyImport_ImportModuleLevelObject(__pyx_mstate_global->__pyx_n_u_asyncio_coroutines, NULL, NULL, fromlist, 0);
        Py_DECREF(fromlist);
        if (unlikely(!module)) goto ignore;
        is_coroutine_value = __Pyx_PyObject_GetAttrStr(module, marker);
        Py_DECREF(module);
        if (likely(is_coroutine_value)) {
            return is_coroutine_value;
        }
ignore:
        PyErr_Clear();
    }
    return __Pyx_PyBool_FromLong(is_coroutine);
}
static PyObject *
__Pyx_CyFunction_get_is_coroutine(__pyx_CyFunctionObject *op, void *context) {
    PyObject *result;
    CYTHON_UNUSED_VAR(context);
    if (op->func_is_coroutine) {
        return __Pyx_NewRef(op->func_is_coroutine);
    }
    result = __Pyx_CyFunction_get_is_coroutine_value(op);
    if (unlikely(!result))
        return NULL;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    if (op->func_is_coroutine) {
        Py_DECREF(result);
        result = __Pyx_NewRef(op->func_is_coroutine);
    } else {
        op->func_is_coroutine = __Pyx_NewRef(result);
    }
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static void __Pyx_CyFunction_raise_argument_count_error(__pyx_CyFunctionObject *func, const char* message, Py_ssize_t size) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_name = __Pyx_CyFunction_get_name(func, NULL);
    if (!py_name) return;
    PyErr_Format(PyExc_TypeError,
        "%.200S() %s (%" CYTHON_FORMAT_SSIZE_T "d given)",
        py_name, message, size);
    Py_DECREF(py_name);
#else
    const char* name = ((PyCFunctionObject*)func)->m_ml->ml_name;
    PyErr_Format(PyExc_TypeError,
        "%.200s() %s (%" CYTHON_FORMAT_SSIZE_T "d given)",
        name, message, size);
#endif
}
static void __Pyx_CyFunction_raise_type_error(__pyx_CyFunctionObject *func, const char* message) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_name = __Pyx_CyFunction_get_name(func, NULL);
    if (!py_name) return;
    PyErr_Format(PyExc_TypeError,
        "%.200S() %s",
        py_name, message);
    Py_DECREF(py_name);
#else
    const char* name = ((PyCFunctionObject*)func)->m_ml->ml_name;
    PyErr_Format(PyExc_TypeError,
        "%.200s() %s",
        name, message);
#endif
}
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *
__Pyx_CyFunction_get_module(__pyx_CyFunctionObject *op, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_GetAttrString(op->func, "__module__");
}
static int
__Pyx_CyFunction_set_module(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_SetAttrString(op->func, "__module__", value);
}
#endif
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {"func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {"__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {"func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {"__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {"__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
    {"func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)PyObject_GenericSetDict, 0, 0},
    {"__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)PyObject_GenericSetDict, 0, 0},
#else
    {"func_dict", (getter)PyObject_GenericGetDict, (setter)PyObject_GenericSetDict, 0, 0},
    {"__dict__", (getter)PyObject_GenericGetDict, (setter)PyObject_GenericSetDict, 0, 0},
#endif
    {"func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {"__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {"func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {"__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {"func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {"__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {"func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {"__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {"__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {"__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {"_is_coroutine", (getter)__Pyx_CyFunction_get_is_coroutine, 0, 0, 0},
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__module__", (getter)__Pyx_CyFunction_get_module, (setter)__Pyx_CyFunction_set_module, 0, 0},
#endif
    {0, 0, 0, 0, 0}
};
static PyMemberDef __pyx_CyFunction_members[] = {
#if !CYTHON_COMPILING_IN_LIMITED_API
    {"__module__", T_OBJECT, offsetof(PyCFunctionObject, m_module), 0, 0},
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    {"__dictoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_dict), READONLY, 0},
#endif
#if CYTHON_METH_FASTCALL
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__vectorcalloffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_vectorcall), READONLY, 0},
#else
    {"__vectorcalloffset__", T_PYSSIZET, offsetof(PyCFunctionObject, vectorcall), READONLY, 0},
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__weaklistoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_weakreflist), READONLY, 0},
#else
    {"__weaklistoffset__", T_PYSSIZET, offsetof(PyCFunctionObject, m_weakreflist), READONLY, 0},
#endif
#endif
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, PyObject *args)
{
    PyObject *result = NULL;
    CYTHON_UNUSED_VAR(args);
    __Pyx_BEGIN_CRITICAL_SECTION(m);
    Py_INCREF(m->func_qualname);
    result = m->func_qualname;
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {"__reduce__", (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
#if CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func_weakreflist)
#else
#define __Pyx_CyFunction_weakreflist(cyfunc) (((PyCFunctionObject*)cyfunc)->m_weakreflist)
#endif
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject *op, PyMethodDef *ml, int flags, PyObject* qualname,
                                       PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
#if !CYTHON_COMPILING_IN_LIMITED_API
    PyCFunctionObject *cf = (PyCFunctionObject*) op;
#endif
    if (unlikely(op == NULL))
        return NULL;
#if CYTHON_COMPILING_IN_LIMITED_API
    op->func = PyCFunction_NewEx(ml, (PyObject*)op, module);
    if (unlikely(!op->func)) return NULL;
#endif
    op->flags = flags;
    __Pyx_CyFunction_weakreflist(op) = NULL;
#if !CYTHON_COMPILING_IN_LIMITED_API
    cf->m_ml = ml;
    cf->m_self = (PyObject *) op;
#endif
    Py_XINCREF(closure);
    op->func_closure = closure;
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_XINCREF(module);
    cf->m_module = module;
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    op->func_dict = NULL;
#endif
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    op->func_classobj = NULL;
#else
    ((PyCMethodObject*)op)->mm_class = NULL;
#endif
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    op->func_is_coroutine = NULL;
#if CYTHON_METH_FASTCALL
    switch (ml->ml_flags & (METH_VARARGS | METH_FASTCALL | METH_NOARGS | METH_O | METH_KEYWORDS | METH_METHOD)) {
    case METH_NOARGS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_NOARGS;
        break;
    case METH_O:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_O;
        break;
    case METH_METHOD | METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD;
        break;
    case METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS;
        break;
    case METH_VARARGS | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = NULL;
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        Py_DECREF(op);
        return NULL;
    }
#endif
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_CLEAR(m->func);
#else
    Py_CLEAR(((PyCFunctionObject*)m)->m_module);
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    Py_CLEAR(m->func_dict);
#elif PY_VERSION_HEX < 0x030d0000
    _PyObject_ClearManagedDict((PyObject*)m);
#else
    PyObject_ClearManagedDict((PyObject*)m);
#endif
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
#if PY_VERSION_HEX < 0x030900B1
    Py_CLEAR(__Pyx_CyFunction_GetClassObj(m));
#else
    {
        PyObject *cls = (PyObject*) ((PyCMethodObject *) (m))->mm_class;
        ((PyCMethodObject *) (m))->mm_class = NULL;
        Py_XDECREF(cls);
    }
#endif
#endif
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    Py_CLEAR(m->func_is_coroutine);
    Py_CLEAR(m->defaults);
    return 0;
}
static void __Pyx__CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    if (__Pyx_CyFunction_weakreflist(m) != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    __Pyx_PyHeapTypeObject_GC_Del(m);
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    __Pyx__CyFunction_dealloc(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    {
        int e = __Pyx_call_type_traverse((PyObject*)m, 1, visit, arg);
        if (e) return e;
    }
    Py_VISIT(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(m->func);
#else
    Py_VISIT(((PyCFunctionObject*)m)->m_module);
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(m->func_dict);
#else
    {
        int e =
#if PY_VERSION_HEX < 0x030d0000
            _PyObject_VisitManagedDict
#else
            PyObject_VisitManagedDict
#endif
                ((PyObject*)m, visit, arg);
        if (e != 0) return e;
    }
#endif
    __Pyx_VISIT_CONST(m->func_name);
    __Pyx_VISIT_CONST(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    __Pyx_VISIT_CONST(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(__Pyx_CyFunction_GetClassObj(m));
#endif
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    Py_VISIT(m->func_is_coroutine);
    Py_VISIT(m->defaults);
    return 0;
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
    PyObject *repr;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    repr = PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
    __Pyx_END_CRITICAL_SECTION();
    return repr;
}
static PyObject * __Pyx_CyFunction_CallMethod(PyObject *func, PyObject *self, PyObject *arg, PyObject *kw) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *f = ((__pyx_CyFunctionObject*)func)->func;
    PyCFunction meth;
    int flags;
    meth = PyCFunction_GetFunction(f);
    if (unlikely(!meth)) return NULL;
    flags = PyCFunction_GetFlags(f);
    if (unlikely(flags < 0)) return NULL;
#else
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = f->m_ml->ml_meth;
    int flags = f->m_ml->ml_flags;
#endif
    Py_ssize_t size;
    switch (flags & (METH_VARARGS | METH_KEYWORDS | METH_NOARGS | METH_O)) {
    case METH_VARARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0))
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)(void(*)(void))meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_SIZE
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 0))
                return (*meth)(self, NULL);
            __Pyx_CyFunction_raise_argument_count_error(
                (__pyx_CyFunctionObject*)func,
                "takes no arguments", size);
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_SIZE
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 1)) {
                PyObject *result, *arg0;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                arg0 = PyTuple_GET_ITEM(arg, 0);
                #else
                arg0 = __Pyx_PySequence_ITEM(arg, 0); if (unlikely(!arg0)) return NULL;
                #endif
                result = (*meth)(self, arg0);
                #if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
                Py_DECREF(arg0);
                #endif
                return result;
            }
            __Pyx_CyFunction_raise_argument_count_error(
                (__pyx_CyFunctionObject*)func,
                "takes exactly one argument", size);
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        return NULL;
    }
    __Pyx_CyFunction_raise_type_error(
        (__pyx_CyFunctionObject*)func, "takes no keyword arguments");
    return NULL;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *self, *result;
#if CYTHON_COMPILING_IN_LIMITED_API
    self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)func)->func);
    if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
    self = ((PyCFunctionObject*)func)->m_self;
#endif
    result = __Pyx_CyFunction_CallMethod(func, self, arg, kw);
    return result;
}
static PyObject *__Pyx_CyFunction_CallAsMethod(PyObject *func, PyObject *args, PyObject *kw) {
    PyObject *result;
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
     __pyx_vectorcallfunc vc = __Pyx_CyFunction_func_vectorcall(cyfunc);
    if (vc) {
#if CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE
        return __Pyx_PyVectorcall_FastCallDict(func, vc, &PyTuple_GET_ITEM(args, 0), (size_t)PyTuple_GET_SIZE(args), kw);
#else
        (void) &__Pyx_PyVectorcall_FastCallDict;
        return PyVectorcall_Call(func, args, kw);
#endif
    }
#endif
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        Py_ssize_t argc;
        PyObject *new_args;
        PyObject *self;
#if CYTHON_ASSUME_SAFE_SIZE
        argc = PyTuple_GET_SIZE(args);
#else
        argc = PyTuple_Size(args);
        if (unlikely(argc < 0)) return NULL;
#endif
        new_args = PyTuple_GetSlice(args, 1, argc);
        if (unlikely(!new_args))
            return NULL;
        self = PyTuple_GetItem(args, 0);
        if (unlikely(!self)) {
            Py_DECREF(new_args);
            PyErr_Format(PyExc_TypeError,
                         "unbound method %.200S() needs an argument",
                         cyfunc->func_qualname);
            return NULL;
        }
        result = __Pyx_CyFunction_CallMethod(func, self, new_args, kw);
        Py_DECREF(new_args);
    } else {
        result = __Pyx_CyFunction_Call(func, args, kw);
    }
    return result;
}
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
static CYTHON_INLINE int __Pyx_CyFunction_Vectorcall_CheckArgs(__pyx_CyFunctionObject *cyfunc, Py_ssize_t nargs, PyObject *kwnames)
{
    int ret = 0;
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        if (unlikely(nargs < 1)) {
            __Pyx_CyFunction_raise_type_error(
                cyfunc, "needs an argument");
            return -1;
        }
        ret = 1;
    }
    if (unlikely(kwnames) && unlikely(__Pyx_PyTuple_GET_SIZE(kwnames))) {
        __Pyx_CyFunction_raise_type_error(
            cyfunc, "takes no keyword arguments");
        return -1;
    }
    return ret;
}
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 0)) {
        __Pyx_CyFunction_raise_argument_count_error(
            cyfunc, "takes no arguments", nargs);
        return NULL;
    }
    return meth(self, NULL);
}
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 1)) {
        __Pyx_CyFunction_raise_argument_count_error(
            cyfunc, "takes exactly one argument", nargs);
        return NULL;
    }
    return meth(self, args[0]);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    return ((__Pyx_PyCFunctionFastWithKeywords)(void(*)(void))meth)(self, args, nargs, kwnames);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyTypeObject *cls = (PyTypeObject *) __Pyx_CyFunction_GetClassObj(cyfunc);
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    #if PY_VERSION_HEX < 0x030e00A6
    size_t nargs_value = (size_t) nargs;
    #else
    Py_ssize_t nargs_value = nargs;
    #endif
    return ((__Pyx_PyCMethod)(void(*)(void))meth)(self, cls, args, nargs_value, kwnames);
}
#endif
static PyType_Slot __pyx_CyFunctionType_slots[] = {
    {Py_tp_dealloc, (void *)__Pyx_CyFunction_dealloc},
    {Py_tp_repr, (void *)__Pyx_CyFunction_repr},
    {Py_tp_call, (void *)__Pyx_CyFunction_CallAsMethod},
    {Py_tp_traverse, (void *)__Pyx_CyFunction_traverse},
    {Py_tp_clear, (void *)__Pyx_CyFunction_clear},
    {Py_tp_methods, (void *)__pyx_CyFunction_methods},
    {Py_tp_members, (void *)__pyx_CyFunction_members},
    {Py_tp_getset, (void *)__pyx_CyFunction_getsets},
    {Py_tp_descr_get, (void *)__Pyx_PyMethod_New},
    {0, 0},
};
static PyType_Spec __pyx_CyFunctionType_spec = {
    __PYX_TYPE_MODULE_PREFIX "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
#ifdef Py_TPFLAGS_METHOD_DESCRIPTOR
    Py_TPFLAGS_METHOD_DESCRIPTOR |
#endif
#if CYTHON_METH_FASTCALL
#if defined(Py_TPFLAGS_HAVE_VECTORCALL)
    Py_TPFLAGS_HAVE_VECTORCALL |
#elif defined(_Py_TPFLAGS_HAVE_VECTORCALL)
    _Py_TPFLAGS_HAVE_VECTORCALL |
#endif
#endif // CYTHON_METH_FASTCALL
#if PY_VERSION_HEX >= 0x030C0000 && !CYTHON_COMPILING_IN_LIMITED_API
    Py_TPFLAGS_MANAGED_DICT |
#endif
    Py_TPFLAGS_IMMUTABLETYPE | Py_TPFLAGS_DISALLOW_INSTANTIATION |
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    __pyx_CyFunctionType_slots
};
static int __pyx_CyFunction_init(PyObject *module) {
    __pyx_mstatetype *mstate = __Pyx_PyModule_GetState(module);
    mstate->__pyx_CyFunctionType = __Pyx_FetchCommonTypeFromSpec(
        mstate->__pyx_CommonTypesMetaclassType, module, &__pyx_CyFunctionType_spec, NULL);
    if (unlikely(mstate->__pyx_CyFunctionType == NULL)) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_InitDefaults(PyObject *func, PyTypeObject *defaults_type) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyObject_CallObject((PyObject*)defaults_type, NULL); // _PyObject_New(defaults_type);
    if (unlikely(!m->defaults))
        return NULL;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

/* CythonFunction */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    PyObject *op = __Pyx_CyFunction_Init(
        PyObject_GC_New(__pyx_CyFunctionObject, __pyx_mstate_global->__pyx_CyFunctionType),
        ml, flags, qualname, closure, module, globals, code
    );
    if (likely(op)) {
        PyObject_GC_Track(op);
    }
    return op;
}

/* ExtTypeTest */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type) {
    __Pyx_TypeName obj_type_name;
    __Pyx_TypeName type_name;
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (likely(__Pyx_TypeCheck(obj, type)))
        return 1;
    obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    type_name = __Pyx_PyType_GetFullyQualifiedName(type);
    PyErr_Format(PyExc_TypeError,
                 "Cannot convert " __Pyx_FMT_TYPENAME " to " __Pyx_FMT_TYPENAME,
                 obj_type_name, type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    __Pyx_DECREF_TypeName(type_name);
    return 0;
}

/* PyObjectFormatAndDecref */
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatSimpleAndDecref(PyObject* s, PyObject* f) {
    if (unlikely(!s)) return NULL;
    if (likely(PyUnicode_CheckExact(s))) return s;
    return __Pyx_PyObject_FormatAndDecref(s, f);
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatAndDecref(PyObject* s, PyObject* f) {
    PyObject *result;
    if (unlikely(!s)) return NULL;
    result = PyObject_Format(s, f);
    Py_DECREF(s);
    return result;
}

/* RaiseException */
#include "src/gevent/_generated_include/RaiseException_impl_5214b4470ab1cce407ca930811cfafb701053719a58763807254160af0a39f69.h"
/* PyObjectFastCallMethod */
#if !CYTHON_VECTORCALL || PY_VERSION_HEX < 0x03090000
static PyObject *__Pyx_PyObject_FastCallMethod(PyObject *name, PyObject *const *args, size_t nargsf) {
    PyObject *result;
    PyObject *attr = PyObject_GetAttr(args[0], name);
    if (unlikely(!attr))
        return NULL;
    result = __Pyx_PyObject_FastCall(attr, args+1, nargsf - 1);
    Py_DECREF(attr);
    return result;
}
#endif

/* GetAttr3 */
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
static PyObject *__Pyx_GetAttr3Default(PyObject *d) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (unlikely(!__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        return NULL;
    __Pyx_PyErr_Clear();
    Py_INCREF(d);
    return d;
}
#endif
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *o, PyObject *n, PyObject *d) {
    PyObject *r;
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    int res = PyObject_GetOptionalAttr(o, n, &r);
    return (res != 0) ? r : __Pyx_NewRef(d);
#else
  #if CYTHON_USE_TYPE_SLOTS
    if (likely(PyUnicode_Check(n))) {
        r = __Pyx_PyObject_GetAttrStrNoError(o, n);
        if (unlikely(!r) && likely(!PyErr_Occurred())) {
            r = __Pyx_NewRef(d);
        }
        return r;
    }
  #endif
    r = PyObject_GetAttr(o, n);
    return (likely(r)) ? r : __Pyx_GetAttr3Default(d);
#endif
}

/* GetAttr */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *o, PyObject *n) {
#if CYTHON_USE_TYPE_SLOTS
    if (likely(PyUnicode_Check(n)))
        return __Pyx_PyObject_GetAttrStr(o, n);
#endif
    return PyObject_GetAttr(o, n);
}

/* RejectKeywords */
static void __Pyx_RejectKeywords(const char* function_name, PyObject *kwds) {
    PyObject *key = NULL;
    if (CYTHON_METH_FASTCALL && likely(PyTuple_Check(kwds))) {
        key = __Pyx_PySequence_ITEM(kwds, 0);
    } else {
#if CYTHON_AVOID_BORROWED_REFS
        PyObject *pos = NULL;
#else
        Py_ssize_t pos = 0;
#endif
#if !CYTHON_COMPILING_IN_PYPY || defined(PyArg_ValidateKeywordArguments)
        if (unlikely(!PyArg_ValidateKeywordArguments(kwds))) return;
#endif
        __Pyx_PyDict_NextRef(kwds, &pos, &key, NULL);
#if CYTHON_AVOID_BORROWED_REFS
        Py_XDECREF(pos);
#endif
    }
    if (likely(key)) {
        PyErr_Format(PyExc_TypeError,
            "%s() got an unexpected keyword argument '%U'",
            function_name, key);
        Py_DECREF(key);
    }
}

/* GetTopmostException (used by SaveResetException) */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem *
__Pyx_PyErr_GetTopmostException(PyThreadState *tstate)
{
    _PyErr_StackItem *exc_info = tstate->exc_info;
    while ((exc_info->exc_value == NULL || exc_info->exc_value == Py_None) &&
           exc_info->previous_item != NULL)
    {
        exc_info = exc_info->previous_item;
    }
    return exc_info;
}
#endif

/* SaveResetException */
#include "src/gevent/_generated_include/SaveResetException_impl_b3e76ed9bc3819093e52b1558c2bbad485040cdc5a28b71844e50bfc92f51cf0.h"
/* PyObjectSetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
    return PyObject_SetAttr(obj, attr_name, value);
}
#endif

/* RaiseUnexpectedTypeError */
static int
__Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj)
{
    __Pyx_TypeName obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError, "Expected %s, got " __Pyx_FMT_TYPENAME,
                 expected, obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* GetException */
#include "src/gevent/_generated_include/GetException_impl_36bcd44414c3b1ebf6a1c0f320ee2c6e2baced19353f70d825d0fd0338e3c175.h"
/* GetItemInt */
#include "src/gevent/_generated_include/GetItemInt_impl_057d6f270e739b86c6eeceee664d75d3caab665a9ec308b52b1fc08c260ccd28.h"
/* PyDictVersioning */
#include "src/gevent/_generated_include/PyDictVersioning_impl_f179ad268abce9726a76569141f76d5dcd0550225ef9a9e9f73d478d7be0c345.h"
/* JoinPyUnicode */
#include "src/gevent/_generated_include/JoinPyUnicode_impl_199e5554049cf0e6f79c238bd653d59e48f3389f2b94c2dd9cad4227096f0038.h"
/* PyUnicode_Unicode */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Unicode(PyObject *obj) {
    if (unlikely(obj == Py_None))
        obj = __pyx_mstate_global->__pyx_kp_u_None;
    return __Pyx_NewRef(obj);
}

/* UnicodeConcatInPlace */
#include "src/gevent/_generated_include/UnicodeConcatInPlace_impl_562c014431196ad62211d7fe3859078657d5010503175be72cc5e948c99124f2.h"
/* PyUnicode_Substring */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Substring(
            PyObject* text, Py_ssize_t start, Py_ssize_t stop) {
    Py_ssize_t length;
    #if !CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(__Pyx_PyUnicode_READY(text) == -1)) return NULL;
    #endif
    length = __Pyx_PyUnicode_GET_LENGTH(text);
    #if !CYTHON_ASSUME_SAFE_SIZE
    if (unlikely(length < 0)) return NULL;
    #endif
    if (start < 0) {
        start += length;
        if (start < 0)
            start = 0;
    }
    if (stop < 0)
        stop += length;
    else if (stop > length)
        stop = length;
    if (stop <= start)
        return __Pyx_NewRef(__pyx_mstate_global->__pyx_empty_unicode);
    if (start == 0 && stop == length)
        return __Pyx_NewRef(text);
#if CYTHON_COMPILING_IN_LIMITED_API
    return PyUnicode_Substring(text, start, stop);
#else
    return PyUnicode_FromKindAndData(PyUnicode_KIND(text),
        PyUnicode_1BYTE_DATA(text) + start*PyUnicode_KIND(text), stop-start);
#endif
}

/* IterFinish (used by dict_iter) */
static CYTHON_INLINE int __Pyx_IterFinish(void) {
    PyObject* exc_type;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    exc_type = __Pyx_PyErr_CurrentExceptionType();
    if (unlikely(exc_type)) {
        if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)))
            return -1;
        __Pyx_PyErr_Clear();
        return 0;
    }
    return 0;
}

/* PyObjectCallNoArg (used by PyObjectCallMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
    PyObject *arg[2] = {NULL, NULL};
    return __Pyx_PyObject_FastCall(func, arg + 1, 0 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* PyObjectGetMethod (used by PyObjectCallMethod0) */
#include "src/gevent/_generated_include/PyObjectGetMethod_impl_e128eb9d3930413c3ed54abc40d4953c55ff9ea67a8c08ac7b5c2fd8494b6c00.h"
/* PyObjectCallMethod0 (used by dict_iter) */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name) {
#if CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000))
    PyObject *args[1] = {obj};
    (void) __Pyx_PyObject_CallOneArg;
    (void) __Pyx_PyObject_CallNoArg;
    return PyObject_VectorcallMethod(method_name, args, 1 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#else
    PyObject *method = NULL, *result = NULL;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_CallOneArg(method, obj);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) goto bad;
    result = __Pyx_PyObject_CallNoArg(method);
    Py_DECREF(method);
bad:
    return result;
#endif
}

/* RaiseNeedMoreValuesToUnpack (used by UnpackTuple2) */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%.1s to unpack",
                 index, (index == 1) ? "" : "s");
}

/* RaiseTooManyValuesToUnpack (used by UnpackItemEndCheck) */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

/* UnpackItemEndCheck (used by UnpackTuple2) */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    }
    return __Pyx_IterFinish();
}

/* RaiseNoneIterError (used by UnpackTupleError) */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
}

/* UnpackTupleError (used by UnpackTuple2) */
static void __Pyx_UnpackTupleError(PyObject *t, Py_ssize_t index) {
    if (t == Py_None) {
      __Pyx_RaiseNoneNotIterableError();
    } else {
      Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(t);
 #if !CYTHON_ASSUME_SAFE_SIZE
      if (unlikely(size < 0)) return;
 #endif
      if (size < index) {
        __Pyx_RaiseNeedMoreValuesError(size);
      } else {
        __Pyx_RaiseTooManyValuesError(index);
      }
    }
}

/* UnpackTuple2 (used by dict_iter) */
#include "src/gevent/_generated_include/UnpackTuple2_impl_2a9fba3d5d02c0857f856a572fabeaf6b2890c41e9ae9233a4ba12e3ba633488.h"
/* dict_iter */
#include "src/gevent/_generated_include/dict_iter_impl_29ea27b89a8b9bec194021fbce5f0da5d4b899d1c47b5cbe1cbe8d300e27d823.h"
/* SwapException */
#include "src/gevent/_generated_include/SwapException_impl_3529c43002b85b6a88333a1994598a58e361312e8462c9c4553bcc16b799892a.h"
/* pyfrozenset_new (used by py_set_discard_unhashable) */
#include "src/gevent/_generated_include/pyfrozenset_new_impl_6d0cc855b17b4f36fd34ea40b1c34574f76580b50d8a268289346dd0eb4aafb2.h"
/* py_set_discard_unhashable (used by py_set_discard) */
static int __Pyx_PySet_DiscardUnhashable(PyObject *set, PyObject *key) {
    PyObject *tmpkey;
    int rv;
    if (likely(!PySet_Check(key) || !PyErr_ExceptionMatches(PyExc_TypeError)))
        return -1;
    PyErr_Clear();
    tmpkey = __Pyx_PyFrozenSet_New(key);
    if (tmpkey == NULL)
        return -1;
    rv = PySet_Discard(set, tmpkey);
    Py_DECREF(tmpkey);
    return rv;
}

/* py_set_discard */
static CYTHON_INLINE int __Pyx_PySet_Discard(PyObject *set, PyObject *key) {
    int found = PySet_Discard(set, key);
    if (unlikely(found < 0)) {
        found = __Pyx_PySet_DiscardUnhashable(set, key);
    }
    return found;
}

/* KeywordStringCheck */
#include "src/gevent/_generated_include/KeywordStringCheck_impl_ab906f68bdf90466d372bd85a39d7cf8593483145096621667739080797c0f42.h"
/* GetModuleGlobalName */
#include "src/gevent/_generated_include/GetModuleGlobalName_impl_b2394fa294c641220c991c48f5c953347ba392e1233755a6228b28d5e679fef0.h"
/* RaiseUnboundLocalError */
static void __Pyx_RaiseUnboundLocalError(const char *varname) {
    PyErr_Format(PyExc_UnboundLocalError, "local variable '%s' referenced before assignment", varname);
}

/* SliceObject */
#include "src/gevent/_generated_include/SliceObject_impl_7d3e353524f10df6cbf3f5885a20d616a2b2d0cc2f393fb7542a218b38f2fae4.h"
/* PyObjectVectorCallKwBuilder (used by PyObjectVectorCallMethodKwBuilder) */
#include "src/gevent/_generated_include/PyObjectVectorCallKwBuilder_impl_fd859cdb6cbc3b35f6b10f5733f06af41f621c00f218f3658f8b944bf821c5f8.h"
/* PyObjectVectorCallMethodKwBuilder */
#if !CYTHON_VECTORCALL || PY_VERSION_HEX < 0x03090000
static PyObject *__Pyx_Object_VectorcallMethod_CallFromBuilder(PyObject *name, PyObject *const *args, size_t nargsf, PyObject *kwnames) {
    PyObject *result;
    PyObject *obj = PyObject_GetAttr(args[0], name);
    if (unlikely(!obj))
        return NULL;
    result = __Pyx_Object_Vectorcall_CallFromBuilder(obj, args+1, nargsf-1, kwnames);
    Py_DECREF(obj);
    return result;
}
#endif

/* PyObjectCall2Args (used by PyObjectCallMethod1) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2) {
    PyObject *args[3] = {NULL, arg1, arg2};
    return __Pyx_PyObject_FastCall(function, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* PyObjectCallMethod1 (used by pop_index) */
#include "src/gevent/_generated_include/PyObjectCallMethod1_impl_a9fa2b3d12e0557b4699af9743eada81ea3325e239ce0b5c7a77ad1579669f5a.h"
/* pop_index */
static PyObject* __Pyx__PyObject_PopNewIndex(PyObject* L, PyObject* py_ix) {
    PyObject *r;
    if (unlikely(!py_ix)) return NULL;
    r = __Pyx__PyObject_PopIndex(L, py_ix);
    Py_DECREF(py_ix);
    return r;
}
static PyObject* __Pyx__PyObject_PopIndex(PyObject* L, PyObject* py_ix) {
    return __Pyx_PyObject_CallMethod1(L, __pyx_mstate_global->__pyx_n_u_pop, py_ix);
}
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE
static PyObject* __Pyx__PyList_PopIndex(PyObject* L, PyObject* py_ix, Py_ssize_t ix) {
    Py_ssize_t size = PyList_GET_SIZE(L);
    if (likely(size > (((PyListObject*)L)->allocated >> 1))) {
        Py_ssize_t cix = ix;
        if (cix < 0) {
            cix += size;
        }
        if (likely(__Pyx_is_valid_index(cix, size))) {
            PyObject* v = PyList_GET_ITEM(L, cix);
            __Pyx_SET_SIZE(L, Py_SIZE(L) - 1);
            size -= 1;
            memmove(&PyList_GET_ITEM(L, cix), &PyList_GET_ITEM(L, cix+1), (size_t)(size-cix)*sizeof(PyObject*));
            return v;
        }
    }
    if (py_ix == Py_None) {
        return __Pyx__PyObject_PopNewIndex(L, PyLong_FromSsize_t(ix));
    } else {
        return __Pyx__PyObject_PopIndex(L, py_ix);
    }
}
#endif

/* HasAttr */
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *o, PyObject *n) {
    PyObject *r;
    if (unlikely(!PyUnicode_Check(n))) {
        PyErr_SetString(PyExc_TypeError,
                        "hasattr(): attribute name must be string");
        return -1;
    }
    r = __Pyx_PyObject_GetAttrStrNoError(o, n);
    if (!r) {
        return (unlikely(PyErr_Occurred())) ? -1 : 0;
    } else {
        Py_DECREF(r);
        return 1;
    }
}
#endif

/* set_iter */
#include "src/gevent/_generated_include/set_iter_impl_d61fe2b4e6517938f10037a6d46e74ff16a372e0c389a906f64367d1fcd77098.h"
/* AllocateExtensionType */
static PyObject *__Pyx_AllocateExtensionType(PyTypeObject *t, int is_final) {
    if (is_final || likely(!__Pyx_PyType_HasFeature(t, Py_TPFLAGS_IS_ABSTRACT))) {
        allocfunc alloc_func = __Pyx_PyType_GetSlot(t, tp_alloc, allocfunc);
        return alloc_func(t, 0);
    } else {
        newfunc tp_new = __Pyx_PyType_TryGetSlot(&PyBaseObject_Type, tp_new, newfunc);
    #if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
        if (!tp_new) {
            PyObject *new_str = PyUnicode_FromString("__new__");
            if (likely(new_str)) {
                PyObject *o = PyObject_CallMethodObjArgs((PyObject *)&PyBaseObject_Type, new_str, t, NULL);
                Py_DECREF(new_str);
                return o;
            } else
                return NULL;
        } else
    #endif
        return tp_new(t, __pyx_mstate_global->__pyx_empty_tuple, 0);
    }
}

/* CallNextTpDealloc */
static void __Pyx_call_next_tp_dealloc(PyObject* obj, destructor current_tp_dealloc) {
    PyTypeObject* type = Py_TYPE(obj);
    destructor tp_dealloc = NULL;
    while (type && __Pyx_PyType_GetSlot(type, tp_dealloc, destructor) != current_tp_dealloc)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    while (type && (tp_dealloc = __Pyx_PyType_GetSlot(type, tp_dealloc, destructor)) == current_tp_dealloc)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    if (type)
        tp_dealloc(obj);
}

/* CallNextTpTraverse */
static int __Pyx_call_next_tp_traverse(PyObject* obj, visitproc v, void *a, traverseproc current_tp_traverse) {
    PyTypeObject* type = Py_TYPE(obj);
    traverseproc tp_traverse = NULL;
    while (type && __Pyx_PyType_GetSlot(type, tp_traverse, traverseproc) != current_tp_traverse)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    while (type && (tp_traverse = __Pyx_PyType_GetSlot(type, tp_traverse, traverseproc)) == current_tp_traverse)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    if (type && tp_traverse)
        return tp_traverse(obj, v, a);
    return 0;
}

/* CallNextTpClear */
static void __Pyx_call_next_tp_clear(PyObject* obj, inquiry current_tp_clear) {
    PyTypeObject* type = Py_TYPE(obj);
    inquiry tp_clear = NULL;
    while (type && __Pyx_PyType_GetSlot(type, tp_clear, inquiry) != current_tp_clear)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    while (type && (tp_clear = __Pyx_PyType_GetSlot(type, tp_clear, inquiry)) == current_tp_clear)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    if (type && tp_clear)
        tp_clear(obj);
}

/* VoidPtrExport */
static int __Pyx_ExportVoidPtr(PyObject *api_dict, const char *name, void *p, const char *sig) {
    PyObject *cobj;
    cobj = PyCapsule_New(p, sig, 0);
    if (!cobj)
        goto bad;
    if (PyDict_SetItemString(api_dict, name, cobj) < 0)
        goto bad;
    Py_DECREF(cobj);
    return 0;
bad:
    Py_XDECREF(cobj);
    return -1;
}

/* GetApiDict */
static PyObject *__Pyx_ApiExport_GetApiDict(void) {
    PyObject *d;
    if (__Pyx_PyDict_GetItemRef(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_pyx_capi, &d) == -1)
        return NULL;
    if (!d) {
        d = PyDict_New();
        if (!d)
            goto bad;
        if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_pyx_capi, d) < 0)
            goto bad;
    }
    return d;
bad:
    Py_XDECREF(d);
    return NULL;
}

/* FunctionExport */
static int __Pyx_ExportFunction(PyObject *api_dict, const char *name, void (*f)(void), const char *sig) {
    PyObject *cobj;
    union {
        void (*fp)(void);
        void *p;
    } tmp;
    tmp.fp = f;
    cobj = PyCapsule_New(tmp.p, sig, 0);
    if (!cobj)
        goto bad;
    if (PyDict_SetItemString(api_dict, name, cobj) < 0)
        goto bad;
    Py_DECREF(cobj);
    return 0;
bad:
    Py_XDECREF(cobj);
    return -1;
}

/* TypeImport */
#include "src/gevent/_generated_include/TypeImport_impl_e30d056ae329ba5e94fee4709e4266a267c585bd5c229f7cd6121597afbfaa4e.h"
/* ValidateBasesTuple (used by PyType_Ready) */
#include "src/gevent/_generated_include/ValidateBasesTuple_impl_3b9fdcb5e55f23d97a6405040c32f85cd06688a92f7d1964c3b28bc807f560c9.h"
/* PyType_Ready */
CYTHON_UNUSED static int __Pyx_PyType_HasMultipleInheritance(PyTypeObject *t) {
    while (t) {
        PyObject *bases = __Pyx_PyType_GetSlot(t, tp_bases, PyObject*);
        if (bases) {
            return 1;
        }
        t = __Pyx_PyType_GetSlot(t, tp_base, PyTypeObject*);
    }
    return 0;
}
static int __Pyx_PyType_Ready(PyTypeObject *t) {
#if CYTHON_USE_TYPE_SPECS || !CYTHON_COMPILING_IN_CPYTHON || defined(PYSTON_MAJOR_VERSION)
    (void)__Pyx_PyObject_CallMethod0;
#if CYTHON_USE_TYPE_SPECS
    (void)__Pyx_validate_bases_tuple;
#endif
    return PyType_Ready(t);
#else
    int r;
    if (!__Pyx_PyType_HasMultipleInheritance(t)) {
        return PyType_Ready(t);
    }
    PyObject *bases = __Pyx_PyType_GetSlot(t, tp_bases, PyObject*);
    if (bases && unlikely(__Pyx_validate_bases_tuple(t->tp_name, t->tp_dictoffset, bases) == -1))
        return -1;
#if !defined(PYSTON_MAJOR_VERSION)
    {
        int gc_was_enabled;
    #if PY_VERSION_HEX >= 0x030A00b1
        gc_was_enabled = PyGC_Disable();
        (void)__Pyx_PyObject_CallMethod0;
    #else
        PyObject *ret, *py_status;
        PyObject *gc = NULL;
        #if (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM+0 >= 0x07030400) &&\
                !CYTHON_COMPILING_IN_GRAAL
        gc = PyImport_GetModule(__pyx_mstate_global->__pyx_kp_u_gc);
        #endif
        if (unlikely(!gc)) gc = PyImport_Import(__pyx_mstate_global->__pyx_kp_u_gc);
        if (unlikely(!gc)) return -1;
        py_status = __Pyx_PyObject_CallMethod0(gc, __pyx_mstate_global->__pyx_kp_u_isenabled);
        if (unlikely(!py_status)) {
            Py_DECREF(gc);
            return -1;
        }
        gc_was_enabled = __Pyx_PyObject_IsTrue(py_status);
        Py_DECREF(py_status);
        if (gc_was_enabled > 0) {
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_mstate_global->__pyx_kp_u_disable);
            if (unlikely(!ret)) {
                Py_DECREF(gc);
                return -1;
            }
            Py_DECREF(ret);
        } else if (unlikely(gc_was_enabled == -1)) {
            Py_DECREF(gc);
            return -1;
        }
    #endif
        t->tp_flags |= Py_TPFLAGS_HEAPTYPE;
#if PY_VERSION_HEX >= 0x030A0000
        t->tp_flags |= Py_TPFLAGS_IMMUTABLETYPE;
#endif
#else
        (void)__Pyx_PyObject_CallMethod0;
#endif
    r = PyType_Ready(t);
#if !defined(PYSTON_MAJOR_VERSION)
        t->tp_flags &= ~Py_TPFLAGS_HEAPTYPE;
    #if PY_VERSION_HEX >= 0x030A00b1
        if (gc_was_enabled)
            PyGC_Enable();
    #else
        if (gc_was_enabled) {
            PyObject *tp, *v, *tb;
            PyErr_Fetch(&tp, &v, &tb);
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_mstate_global->__pyx_kp_u_enable);
            if (likely(ret || r == -1)) {
                Py_XDECREF(ret);
                PyErr_Restore(tp, v, tb);
            } else {
                Py_XDECREF(tp);
                Py_XDECREF(v);
                Py_XDECREF(tb);
                r = -1;
            }
        }
        Py_DECREF(gc);
    #endif
    }
#endif
    return r;
#endif
}

/* FormatTypeName (used by ValidateExternBase) */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030d0000
static __Pyx_TypeName
__Pyx_PyType_GetFullyQualifiedName(PyTypeObject* tp)
{
    PyObject *module = NULL, *name = NULL, *result = NULL;
    #if __PYX_LIMITED_VERSION_HEX < 0x030b0000
    name = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_mstate_global->__pyx_n_u_qualname);
    #else
    name = PyType_GetQualName(tp);
    #endif
    if (unlikely(name == NULL) || unlikely(!PyUnicode_Check(name))) goto bad;
    module = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_mstate_global->__pyx_n_u_module);
    if (unlikely(module == NULL) || unlikely(!PyUnicode_Check(module))) goto bad;
    if (PyUnicode_CompareWithASCIIString(module, "builtins") == 0) {
        result = name;
        name = NULL;
        goto done;
    }
    result = PyUnicode_FromFormat("%U.%U", module, name);
    if (unlikely(result == NULL)) goto bad;
  done:
    Py_XDECREF(name);
    Py_XDECREF(module);
    return result;
  bad:
    PyErr_Clear();
    if (name) {
        result = name;
        name = NULL;
    } else {
        result = __Pyx_NewRef(__pyx_mstate_global->__pyx_kp_u__16);
    }
    goto done;
}
#endif

/* ValidateExternBase */
static int __Pyx_validate_extern_base(PyTypeObject *base) {
    Py_ssize_t itemsize;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_itemsize;
#endif
#if !CYTHON_COMPILING_IN_LIMITED_API
    itemsize = ((PyTypeObject *)base)->tp_itemsize;
#else
    py_itemsize = PyObject_GetAttrString((PyObject*)base, "__itemsize__");
    if (!py_itemsize)
        return -1;
    itemsize = PyLong_AsSsize_t(py_itemsize);
    Py_DECREF(py_itemsize);
    py_itemsize = 0;
    if (itemsize == (Py_ssize_t)-1 && PyErr_Occurred())
        return -1;
#endif
    if (itemsize) {
        __Pyx_TypeName b_name = __Pyx_PyType_GetFullyQualifiedName(base);
        PyErr_Format(PyExc_TypeError,
                "inheritance from PyVarObject types like '" __Pyx_FMT_TYPENAME "' not currently supported", b_name);
        __Pyx_DECREF_TypeName(b_name);
        return -1;
    }
    return 0;
}

/* SetVTable */
static int __Pyx_SetVtable(PyTypeObject *type, void *vtable) {
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
    if (unlikely(!ob))
        goto bad;
#if CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(PyObject_SetAttr((PyObject *) type, __pyx_mstate_global->__pyx_n_u_pyx_vtable, ob) < 0))
#else
    if (unlikely(PyDict_SetItem(type->tp_dict, __pyx_mstate_global->__pyx_n_u_pyx_vtable, ob) < 0))
#endif
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

/* GetVTable (used by MergeVTables) */
static void* __Pyx_GetVtable(PyTypeObject *type) {
    void* ptr;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *ob = PyObject_GetAttr((PyObject *)type, __pyx_mstate_global->__pyx_n_u_pyx_vtable);
#else
    PyObject *ob = PyObject_GetItem(type->tp_dict, __pyx_mstate_global->__pyx_n_u_pyx_vtable);
#endif
    if (!ob)
        goto bad;
    ptr = PyCapsule_GetPointer(ob, 0);
    if (!ptr && !PyErr_Occurred())
        PyErr_SetString(PyExc_RuntimeError, "invalid vtable found for imported type");
    Py_DECREF(ob);
    return ptr;
bad:
    Py_XDECREF(ob);
    return NULL;
}

/* MergeVTables */
#include "src/gevent/_generated_include/MergeVTables_impl_cc0b823a0ed067bdca31ab6afca82ec940b10d68e9ecebbaec0a3d49b6244e8c.h"
/* PxdImportShared (used by VoidPtrImport) */
#include "src/gevent/_generated_include/PxdImportShared_impl_df92e4b607edac2b8480e2c8668970e8115d694234fa83cf1c26cb7dc602ab00.h"
/* VoidPtrImport */
#ifndef __PYX_HAVE_RT_ImportVoidPtr_3_2_4
#define __PYX_HAVE_RT_ImportVoidPtr_3_2_4
static int __Pyx_ImportVoidPtr_3_2_4(PyObject *module, const char *name, void **p, const char *sig) {
    return __Pyx_ImportFromPxd_3_2_4(module, name, p, sig, "variable");
}
#endif

/* FunctionImport */
#ifndef __PYX_HAVE_RT_ImportFunction_3_2_4
#define __PYX_HAVE_RT_ImportFunction_3_2_4
static int __Pyx_ImportFunction_3_2_4(PyObject *module, const char *funcname, void (**f)(void), const char *sig) {
    union {
        void (*fp)(void);
        void *p;
    } tmp;
    int result = __Pyx_ImportFromPxd_3_2_4(module, funcname, &tmp.p, sig, "function");
    if (result == 0) {
        *f = tmp.fp;
    }
    return result;
}
#endif

/* ImportImpl (used by Import) */
#include "src/gevent/_generated_include/ImportImpl_impl_54add44d3961eb3adfb567f9d1292a4ce092acafbf7b2d11f026c8e90ea281d3.h"
/* Import */
static PyObject *__Pyx_Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, int level) {
    return __Pyx__Import(name, imported_names, len_imported_names, qualname, __pyx_mstate_global->__pyx_d, level);
}

/* ImportFrom */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        const char* module_name_str = 0;
        PyObject* module_name = 0;
        PyObject* module_dot = 0;
        PyObject* full_name = 0;
        PyErr_Clear();
        module_name_str = PyModule_GetName(module);
        if (unlikely(!module_name_str)) { goto modbad; }
        module_name = PyUnicode_FromString(module_name_str);
        if (unlikely(!module_name)) { goto modbad; }
        module_dot = PyUnicode_Concat(module_name, __pyx_mstate_global->__pyx_kp_u__17);
        if (unlikely(!module_dot)) { goto modbad; }
        full_name = PyUnicode_Concat(module_dot, name);
        if (unlikely(!full_name)) { goto modbad; }
        #if (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM  < 0x07030400) ||\
                CYTHON_COMPILING_IN_GRAAL
        {
            PyObject *modules = PyImport_GetModuleDict();
            if (unlikely(!modules))
                goto modbad;
            value = PyObject_GetItem(modules, full_name);
        }
        #else
        value = PyImport_GetModule(full_name);
        #endif
      modbad:
        Py_XDECREF(full_name);
        Py_XDECREF(module_dot);
        Py_XDECREF(module_name);
    }
    if (unlikely(!value)) {
        PyErr_Format(PyExc_ImportError, "cannot import name %S", name);
    }
    return value;
}

/* ListPack */
static PyObject *__Pyx_PyList_Pack(Py_ssize_t n, ...) {
    va_list va;
    PyObject *l = PyList_New(n);
    va_start(va, n);
    if (unlikely(!l)) goto end;
    for (Py_ssize_t i=0; i<n; ++i) {
        PyObject *arg = va_arg(va, PyObject*);
        Py_INCREF(arg);
        if (__Pyx_PyList_SET_ITEM(l, i, arg) != (0)) {
            Py_CLEAR(l);
            goto end;
        }
    }
    end:
    va_end(va);
    return l;
}

/* GetNameInClass */
static PyObject *__Pyx__GetNameInClass(PyObject *nmspace, PyObject *name) {
    PyObject *result;
    PyObject *dict;
    assert(PyType_Check(nmspace));
#if CYTHON_USE_TYPE_SLOTS
    dict = ((PyTypeObject*)nmspace)->tp_dict;
    Py_XINCREF(dict);
#else
    dict = PyObject_GetAttr(nmspace, __pyx_mstate_global->__pyx_n_u_dict);
#endif
    if (likely(dict)) {
        result = PyObject_GetItem(dict, name);
        Py_DECREF(dict);
        if (result) {
            return result;
        }
    }
    PyErr_Clear();
    __Pyx_GetModuleGlobalNameUncached(result, name);
    return result;
}

/* ClassMethod */
#include "src/gevent/_generated_include/ClassMethod_impl_8a2b0678c48bb15eaacdb78c2f51c22b6ab719a4e3b206c16f9f8ffa04d32116.h"
/* Globals */
static PyObject* __Pyx_Globals(void) {
    return __Pyx_NewRef(__pyx_mstate_global->__pyx_d);
}

/* CLineInTraceback (used by AddTraceback) */
#if CYTHON_CLINE_IN_TRACEBACK && CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
#define __Pyx_PyProbablyModule_GetDict(o) __Pyx_XNewRef(PyModule_GetDict(o))
#elif !CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyProbablyModule_GetDict(o) PyObject_GenericGetDict(o, NULL);
#else
PyObject* __Pyx_PyProbablyModule_GetDict(PyObject *o) {
    PyObject **dict_ptr = _PyObject_GetDictPtr(o);
    return dict_ptr ? __Pyx_XNewRef(*dict_ptr) : NULL;
}
#endif
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line) {
    PyObject *use_cline = NULL;
    PyObject *ptype, *pvalue, *ptraceback;
    PyObject *cython_runtime_dict;
    CYTHON_MAYBE_UNUSED_VAR(tstate);
    if (unlikely(!__pyx_mstate_global->__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
    cython_runtime_dict = __Pyx_PyProbablyModule_GetDict(__pyx_mstate_global->__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, cython_runtime_dict,
            __Pyx_PyDict_SetDefault(cython_runtime_dict, __pyx_mstate_global->__pyx_n_u_cline_in_traceback, Py_False))
    }
    if (use_cline == NULL || use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    Py_XDECREF(use_cline);
    Py_XDECREF(cython_runtime_dict);
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache (used by AddTraceback) */
#include "src/gevent/_generated_include/CodeObjectCache_impl_ffc81bf87e547a82e6009d64a2466eb1a5f6677afcbab3333a029ea24e45c012.h"
/* AddTraceback */
#include "src/gevent/_generated_include/AddTraceback_impl_5c53b964023228d90bdfcfa91919f5c3c484446268d5ef056f29421d654f5af4.h"
/* CIntFromPyVerify */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntToPy */
#include "src/gevent/_generated_include/CIntToPy_impl_04d273d7fd8d781e47c953336d9035c05b46b928eb9a876491735d34363bfe94.h"
/* CIntFromPy */
#include "src/gevent/_generated_include/CIntFromPy_impl_ceb8d340f976d387a193f777f2c34549caaafc1e59b58b253b09ec2b16efbddf.h"
/* CIntToPy */
#include "src/gevent/_generated_include/CIntToPy_impl_3a4503f42bed1a339a5a77cabbacbe22d845586eaf8fe2b8bf391ccbe75ae64a.h"
/* CIntFromPy */
#include "src/gevent/_generated_include/CIntFromPy_impl_b91de55768d50878c1454209403f531c1ef9ecfc0f5cfff0eb0b925c62c994e2.h"
/* FastTypeChecks */
#include "src/gevent/_generated_include/FastTypeChecks_impl_f9d18941833a215bcf3276e2b6a57d81e032bd85ed1fb021b834da49989898c9.h"
/* GetRuntimeVersion */
#if __PYX_LIMITED_VERSION_HEX < 0x030b0000
void __Pyx_init_runtime_version(void) {
    if (__Pyx_cached_runtime_version == 0) {
        const char* rt_version = Py_GetVersion();
        unsigned long version = 0;
        unsigned long factor = 0x01000000UL;
        unsigned int digit = 0;
        int i = 0;
        while (factor) {
            while ('0' <= rt_version[i] && rt_version[i] <= '9') {
                digit = digit * 10 + (unsigned int) (rt_version[i] - '0');
                ++i;
            }
            version += factor * digit;
            if (rt_version[i] != '.')
                break;
            digit = 0;
            factor >>= 8;
            ++i;
        }
        __Pyx_cached_runtime_version = version;
    }
}
#endif
static unsigned long __Pyx_get_runtime_version(void) {
#if __PYX_LIMITED_VERSION_HEX >= 0x030b0000
    return Py_Version & ~0xFFUL;
#else
    return __Pyx_cached_runtime_version;
#endif
}

/* CheckBinaryVersion */
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer) {
    const unsigned long MAJOR_MINOR = 0xFFFF0000UL;
    if ((rt_version & MAJOR_MINOR) == (ct_version & MAJOR_MINOR))
        return 0;
    if (likely(allow_newer && (rt_version & MAJOR_MINOR) > (ct_version & MAJOR_MINOR)))
        return 1;
    {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compile time Python version %d.%d "
                      "of module '%.100s' "
                      "%s "
                      "runtime version %d.%d",
                       (int) (ct_version >> 24), (int) ((ct_version >> 16) & 0xFF),
                       __Pyx_MODULE_NAME,
                       (allow_newer) ? "was newer than" : "does not match",
                       (int) (rt_version >> 24), (int) ((rt_version >> 16) & 0xFF)
       );
        return PyErr_WarnEx(NULL, message, 1);
    }
}

/* NewCodeObj */
#include "src/gevent/_generated_include/NewCodeObj_impl_a437ae594518b78f515ea800eae13a23abf85c5a9a57d6d2c88c6b9b215ff54c.h"
/* DecompressString */
#include "src/gevent/_generated_include/DecompressString_impl_08916ce6b33dc899db1820b9329c4da53ddc4f977613e2296edf3d94850c4279.h"
#include <string.h>
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s) {
    size_t len = strlen(s);
    if (unlikely(len > (size_t) PY_SSIZE_T_MAX)) {
        PyErr_SetString(PyExc_OverflowError, "byte string is too long");
        return -1;
    }
    return (Py_ssize_t) len;
}
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return __Pyx_PyUnicode_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return PyByteArray_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if CYTHON_COMPILING_IN_LIMITED_API
    {
        const char* result;
        Py_ssize_t unicode_length;
        CYTHON_MAYBE_UNUSED_VAR(unicode_length); // only for __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        #if __PYX_LIMITED_VERSION_HEX < 0x030A0000
        if (unlikely(PyArg_Parse(o, "s#", &result, length) < 0)) return NULL;
        #else
        result = PyUnicode_AsUTF8AndSize(o, length);
        #endif
        #if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        unicode_length = PyUnicode_GetLength(o);
        if (unlikely(unicode_length < 0)) return NULL;
        if (unlikely(unicode_length != *length)) {
            PyUnicode_AsASCIIString(o);
            return NULL;
        }
        #endif
        return result;
    }
#else
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
#endif
}
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
    if (PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
    if (PyByteArray_Check(o)) {
#if (CYTHON_ASSUME_SAFE_SIZE && CYTHON_ASSUME_SAFE_MACROS) || (CYTHON_COMPILING_IN_PYPY && (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE)))
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
#else
        *length = PyByteArray_Size(o);
        if (*length == -1) return NULL;
        return PyByteArray_AsString(o);
#endif
    } else
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_LongWrongResultType(PyObject* result) {
    __Pyx_TypeName result_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(result));
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ").  "
                "The ability to return an instance of a strict subclass of int is deprecated, "
                "and may be removed in a future version of Python.",
                result_type_name)) {
            __Pyx_DECREF_TypeName(result_type_name);
            Py_DECREF(result);
            return NULL;
        }
        __Pyx_DECREF_TypeName(result_type_name);
        return result;
    }
    PyErr_Format(PyExc_TypeError,
                 "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ")",
                 result_type_name);
    __Pyx_DECREF_TypeName(result_type_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Long(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  PyObject *res = NULL;
  if (likely(PyLong_Check(x)))
      return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  if (likely(m && m->nb_int)) {
      res = m->nb_int(x);
  }
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
      res = PyNumber_Long(x);
  }
#endif
  if (likely(res)) {
      if (unlikely(!PyLong_CheckExact(res))) {
          return __Pyx_PyNumber_LongWrongResultType(res);
      }
  }
  else if (!PyErr_Occurred()) {
      PyErr_SetString(PyExc_TypeError,
                      "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(__Pyx_PyLong_IsCompact(b))) {
        return __Pyx_PyLong_CompactValue(b);
    } else {
      const digit* digits = __Pyx_PyLong_Digits(b);
      const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(b);
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyLong_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject* o) {
  if (sizeof(Py_hash_t) == sizeof(Py_ssize_t)) {
    return (Py_hash_t) __Pyx_PyIndex_AsSsize_t(o);
  } else {
    Py_ssize_t ival;
    PyObject *x;
    x = PyNumber_Index(o);
    if (!x) return -1;
    ival = PyLong_AsLong(x);
    Py_DECREF(x);
    return ival;
  }
}
static CYTHON_INLINE PyObject *__Pyx_Owned_Py_None(int b) {
    CYTHON_UNUSED_VAR(b);
    return __Pyx_NewRef(Py_None);
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return __Pyx_NewRef(b ? Py_True: Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyLong_FromSize_t(size_t ival) {
    return PyLong_FromSize_t(ival);
}


/* MultiPhaseInitModuleState */
#include "src/gevent/_generated_include/MultiPhaseInitModuleState_impl_41d512917574f55c289a94dba0e3ef9c60f8de37a71dd41f0dd086494a351cae.h"
/* #### Code section: utility_code_pragmas_end ### */
#ifdef _MSC_VER
#pragma warning( pop )
#endif



/* #### Code section: end ### */
#endif /* Py_PYTHON_H */
