/* Generated by Cython 3.2.4 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "define_macros": [
            [
                "HAVE_NETDB_H",
                ""
            ],
            [
                "CYTHON_FAST_THREAD_STATE",
                "0"
            ]
        ],
        "depends": [
            "/usr/include/python3.14/Python.h"
        ],
        "include_dirs": [
            "/usr/include/python3.14",
            "/usr/include/python3.14",
            "/build/python-gevent/src/python-gevent/deps"
        ],
        "libraries": [
            "cares"
        ],
        "name": "gevent.resolver.cares",
        "sources": [
            "src/gevent/resolver/cares.pyx"
        ]
    },
    "module_name": "gevent.resolver.cares"
}
END: Cython Metadata */

#ifndef PY_SSIZE_T_CLEAN
#define PY_SSIZE_T_CLEAN
#endif /* PY_SSIZE_T_CLEAN */
/* InitLimitedAPI */
#if defined(Py_LIMITED_API)
  #if !defined(CYTHON_LIMITED_API)
  #define CYTHON_LIMITED_API 1
  #endif
#elif defined(CYTHON_LIMITED_API)
  #ifdef _MSC_VER
  #pragma message ("Limited API usage is enabled with 'CYTHON_LIMITED_API' but 'Py_LIMITED_API' does not define a Python target version. Consider setting 'Py_LIMITED_API' instead.")
  #else
  #warning Limited API usage is enabled with 'CYTHON_LIMITED_API' but 'Py_LIMITED_API' does not define a Python target version. Consider setting 'Py_LIMITED_API' instead.
  #endif
#endif

#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x03080000
    #error Cython requires Python 3.8+.
#else
#define __PYX_ABI_VERSION "3_2_4"
#define CYTHON_HEX_VERSION 0x030204F0
#define CYTHON_FUTURE_DIVISION 1
/* CModulePreamble */
#include "src/gevent/_generated_include/CModulePreamble_impl_67ff8da3bafbaee898fb2680a081f9cf07617f9b80d936bf5254c02966774c38.h"
/* CInitCode */
#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

/* PythonCompatibility */
#include "src/gevent/_generated_include/PythonCompatibility_impl_9f6bc6a154e6d1f4d1d9250f48a0e6d407560d70233eabffbe0fccfe1f684e75.h"
/* MathInitCode */
#if defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)
  #ifndef _USE_MATH_DEFINES
    #define _USE_MATH_DEFINES
  #endif
#endif
#include <math.h>
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#ifndef CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#define CYTHON_CLINE_IN_TRACEBACK_RUNTIME 0
#endif
#ifndef CYTHON_CLINE_IN_TRACEBACK
#define CYTHON_CLINE_IN_TRACEBACK CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#endif
#if CYTHON_CLINE_IN_TRACEBACK
#define __PYX_MARK_ERR_POS(f_index, lineno)  { __pyx_filename = __pyx_f[f_index]; (void) __pyx_filename; __pyx_lineno = lineno; (void) __pyx_lineno; __pyx_clineno = __LINE__; (void) __pyx_clineno; }
#else
#define __PYX_MARK_ERR_POS(f_index, lineno)  { __pyx_filename = __pyx_f[f_index]; (void) __pyx_filename; __pyx_lineno = lineno; (void) __pyx_lineno; (void) __pyx_clineno; }
#endif
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifdef CYTHON_EXTERN_C
    #undef __PYX_EXTERN_C
    #define __PYX_EXTERN_C CYTHON_EXTERN_C
#elif defined(__PYX_EXTERN_C)
    #ifdef _MSC_VER
    #pragma message ("Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.")
    #else
    #warning Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.
    #endif
#else
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__gevent__resolver__cares
#define __PYX_HAVE_API__gevent__resolver__cares
/* Early includes */
#include "ares.h"
#include <string.h>
#include <stdio.h>

    #define TIMEOUT 1
    #define EV_READ 1
    #define EV_WRITE 2
    

#ifdef CARES_EMBED
#include "ares_setup.h"
#endif

#ifdef HAVE_NETDB_H
#include <netdb.h>
#endif

    #ifndef EAI_ADDRFAMILY
    #define EAI_ADDRFAMILY -1
    #endif

    #ifndef EAI_BADHINTS
    #define EAI_BADHINTS -2
    #endif

    #ifndef EAI_NODATA
    #define EAI_NODATA -3
    #endif

    #ifndef EAI_OVERFLOW
    #define EAI_OVERFLOW -4
    #endif

    #ifndef EAI_PROTOCOL
    #define EAI_PROTOCOL -5
    #endif

    #ifndef EAI_SYSTEM
    #define EAI_SYSTEM
    #endif
#if defined(WIN32) || defined(_WIN32)
    static const char * hstrerror(int err)
    {
        return NULL;
    }
#endif
    
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

#ifdef CYTHON_FREETHREADING_COMPATIBLE
#if CYTHON_FREETHREADING_COMPATIBLE
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_NOT_USED
#else
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_USED
#endif
#else
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_USED
#endif
#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s);
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char*);
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyByteArray_AsString(s) PyByteArray_AS_STRING(s)
#else
    #define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AsString(s))
    #define __Pyx_PyByteArray_AsString(s) PyByteArray_AsString(s)
#endif
#define __Pyx_PyObject_AsWritableString(s)    ((char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
#define __Pyx_PyUnicode_FromOrdinal(o)       PyUnicode_FromOrdinal((int)o)
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
static CYTHON_INLINE PyObject *__Pyx_NewRef(PyObject *obj) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030a0000 || defined(Py_NewRef)
    return Py_NewRef(obj);
#else
    Py_INCREF(obj);
    return obj;
#endif
}
static CYTHON_INLINE PyObject *__Pyx_XNewRef(PyObject *obj) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030a0000 || defined(Py_XNewRef)
    return Py_XNewRef(obj);
#else
    Py_XINCREF(obj);
    return obj;
#endif
}
static CYTHON_INLINE PyObject *__Pyx_Owned_Py_None(int b);
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Long(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyLong_FromSize_t(size_t);
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject*);
#if CYTHON_ASSUME_SAFE_MACROS
#define __Pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#define __Pyx_PyFloat_AS_DOUBLE(x) PyFloat_AS_DOUBLE(x)
#else
#define __Pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#define __Pyx_PyFloat_AS_DOUBLE(x) PyFloat_AsDouble(x)
#endif
#define __Pyx_PyFloat_AsFloat(x) ((float) __Pyx_PyFloat_AsDouble(x))
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_VERSION_HEX >= 0x030C00A7
  #ifndef _PyLong_SIGN_MASK
    #define _PyLong_SIGN_MASK 3
  #endif
  #ifndef _PyLong_NON_SIZE_BITS
    #define _PyLong_NON_SIZE_BITS 3
  #endif
  #define __Pyx_PyLong_Sign(x)  (((PyLongObject*)x)->long_value.lv_tag & _PyLong_SIGN_MASK)
  #define __Pyx_PyLong_IsNeg(x)  ((__Pyx_PyLong_Sign(x) & 2) != 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (!__Pyx_PyLong_IsNeg(x))
  #define __Pyx_PyLong_IsZero(x)  (__Pyx_PyLong_Sign(x) & 1)
  #define __Pyx_PyLong_IsPos(x)  (__Pyx_PyLong_Sign(x) == 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  (__Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  ((Py_ssize_t) (((PyLongObject*)x)->long_value.lv_tag >> _PyLong_NON_SIZE_BITS))
  #define __Pyx_PyLong_SignedDigitCount(x)\
        ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * __Pyx_PyLong_DigitCount(x))
  #if defined(PyUnstable_Long_IsCompact) && defined(PyUnstable_Long_CompactValue)
    #define __Pyx_PyLong_IsCompact(x)     PyUnstable_Long_IsCompact((PyLongObject*) x)
    #define __Pyx_PyLong_CompactValue(x)  PyUnstable_Long_CompactValue((PyLongObject*) x)
  #else
    #define __Pyx_PyLong_IsCompact(x)     (((PyLongObject*)x)->long_value.lv_tag < (2 << _PyLong_NON_SIZE_BITS))
    #define __Pyx_PyLong_CompactValue(x)  ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * (Py_ssize_t) __Pyx_PyLong_Digits(x)[0])
  #endif
  typedef Py_ssize_t  __Pyx_compact_pylong;
  typedef size_t  __Pyx_compact_upylong;
  #else
  #define __Pyx_PyLong_IsNeg(x)  (Py_SIZE(x) < 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (Py_SIZE(x) >= 0)
  #define __Pyx_PyLong_IsZero(x)  (Py_SIZE(x) == 0)
  #define __Pyx_PyLong_IsPos(x)  (Py_SIZE(x) > 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  ((Py_SIZE(x) == 0) ? 0 : __Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  __Pyx_sst_abs(Py_SIZE(x))
  #define __Pyx_PyLong_SignedDigitCount(x)  Py_SIZE(x)
  #define __Pyx_PyLong_IsCompact(x)  (Py_SIZE(x) == 0 || Py_SIZE(x) == 1 || Py_SIZE(x) == -1)
  #define __Pyx_PyLong_CompactValue(x)\
        ((Py_SIZE(x) == 0) ? (sdigit) 0 : ((Py_SIZE(x) < 0) ? -(sdigit)__Pyx_PyLong_Digits(x)[0] : (sdigit)__Pyx_PyLong_Digits(x)[0]))
  typedef sdigit  __Pyx_compact_pylong;
  typedef digit  __Pyx_compact_upylong;
  #endif
  #if PY_VERSION_HEX >= 0x030C00A5
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->long_value.ob_digit)
  #else
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->ob_digit)
  #endif
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#elif __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeASCII(c_str, size, NULL)
#else
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
/* PretendToInitialize */
#ifdef __cplusplus
#if __cplusplus > 201103L
#include <type_traits>
#endif
template <typename T>
static void __Pyx_pretend_to_initialize(T* ptr) {
#if __cplusplus > 201103L
    if ((std::is_trivially_default_constructible<T>::value))
#endif
        *ptr = T();
    (void)ptr;
}
#else
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }
#endif


#if !CYTHON_USE_MODULE_STATE
static PyObject *__pyx_m = NULL;
#endif
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * const __pyx_cfilenm = __FILE__;
static const char *__pyx_filename;

/* #### Code section: filename_table ### */

static const char* const __pyx_f[] = {
  "src/gevent/resolver/cares.pyx",
  "cpython/type.pxd",
};
/* #### Code section: utility_code_proto_before_types ### */
/* Atomics.proto (used by UnpackUnboundCMethod) */
#include "src/gevent/_generated_include/Atomics_proto_3c6d386cad499e8bf66734864569013c6cb59adf2353bb94c6c6798eea3c07cc.h"
/* CriticalSectionsDefinition.proto (used by CriticalSections) */
#if !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyCriticalSection void*
#define __Pyx_PyCriticalSection2 void*
#define __Pyx_PyCriticalSection_End(cs)
#define __Pyx_PyCriticalSection2_End(cs)
#else
#define __Pyx_PyCriticalSection PyCriticalSection
#define __Pyx_PyCriticalSection2 PyCriticalSection2
#define __Pyx_PyCriticalSection_End PyCriticalSection_End
#define __Pyx_PyCriticalSection2_End PyCriticalSection2_End
#endif

/* CriticalSections.proto (used by ParseKeywordsImpl) */
#if !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyCriticalSection_Begin(cs, arg) (void)(cs)
#define __Pyx_PyCriticalSection2_Begin(cs, arg1, arg2) (void)(cs)
#else
#define __Pyx_PyCriticalSection_Begin PyCriticalSection_Begin
#define __Pyx_PyCriticalSection2_Begin PyCriticalSection2_Begin
#endif
#if PY_VERSION_HEX < 0x030d0000 || CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_BEGIN_CRITICAL_SECTION(o) {
#define __Pyx_END_CRITICAL_SECTION() }
#else
#define __Pyx_BEGIN_CRITICAL_SECTION Py_BEGIN_CRITICAL_SECTION
#define __Pyx_END_CRITICAL_SECTION Py_END_CRITICAL_SECTION
#endif

/* IncludeStructmemberH.proto (used by FixUpExtensionType) */
#include <structmember.h>

/* #### Code section: numeric_typedefs ### */
/* #### Code section: complex_type_declarations ### */
/* #### Code section: type_declarations ### */

/*--- Type declarations ---*/
struct __pyx_obj_6gevent_8resolver_5cares_Result;
struct __pyx_obj_6gevent_8resolver_5cares_channel;
struct __pyx_opt_args_6gevent_8resolver_5cares_7channel_set_servers;

/* "gevent/resolver/cares.pyx":435
 *         self.__destroy()
 * 
 *     cpdef set_servers(self, servers=None):             # <<<<<<<<<<<<<<
 *         if not self.channel:
 *             raise gaierror(cares.ARES_EDESTRUCTION, 'this ares channel has been destroyed')
*/
struct __pyx_opt_args_6gevent_8resolver_5cares_7channel_set_servers {
  int __pyx_n;
  PyObject *servers;
};

/* "gevent/resolver/cares.pyx":243
 * 
 * 
 * cdef class Result(object):             # <<<<<<<<<<<<<<
 *     cdef public object value
 *     cdef public object exception
*/
struct __pyx_obj_6gevent_8resolver_5cares_Result {
  PyObject_HEAD
  PyObject *value;
  PyObject *exception;
};


/* "gevent/resolver/cares.pyx":357
 * 
 * 
 * cdef class channel:             # <<<<<<<<<<<<<<
 *     cdef ares_channeldata* channel
 * 
*/
struct __pyx_obj_6gevent_8resolver_5cares_channel {
  PyObject_HEAD
  struct __pyx_vtabstruct_6gevent_8resolver_5cares_channel *__pyx_vtab;
  struct ares_channeldata *channel;
  PyObject *loop;
  PyObject *_watchers;
  PyObject *_timer;
};



struct __pyx_vtabstruct_6gevent_8resolver_5cares_channel {
  PyObject *(*_channel__destroy)(struct __pyx_obj_6gevent_8resolver_5cares_channel *);
  PyObject *(*set_servers)(struct __pyx_obj_6gevent_8resolver_5cares_channel *, int __pyx_skip_dispatch, struct __pyx_opt_args_6gevent_8resolver_5cares_7channel_set_servers *__pyx_optional_args);
  PyObject *(*_sock_state_callback)(struct __pyx_obj_6gevent_8resolver_5cares_channel *, int, int, int);
  void (*_gethostbyname_or_byaddr_cb)(void *, int, int, struct hostent *);
  PyObject *(*_getnameinfo)(struct __pyx_obj_6gevent_8resolver_5cares_channel *, PyObject *, PyObject *, int, int __pyx_skip_dispatch);
  int (*_convert_cares_ni_flags)(int);
  int (*_convert_cares_ai_flags)(int);
  void (*_getaddrinfo_cb)(void *, int, int, struct ares_addrinfo *);
};
static struct __pyx_vtabstruct_6gevent_8resolver_5cares_channel *__pyx_vtabptr_6gevent_8resolver_5cares_channel;
/* #### Code section: utility_code_proto ### */

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#include "src/gevent/_generated_include/Refnanny_proto_00d2ab1aa529311d487a88a16574063b4d3b8ffa11a25109d76165964b208920.h"
/* PyErrExceptionMatches.proto (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* PyThreadStateGet.proto (used by PyErrFetchRestore) */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#if PY_VERSION_HEX >= 0x030C00A6
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->current_exception != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->current_exception ? (PyObject*) Py_TYPE(__pyx_tstate->current_exception) : (PyObject*) NULL)
#else
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->curexc_type != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->curexc_type)
#endif
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  (PyErr_Occurred() != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto (used by PyObjectGetAttrStrNoError) */
#include "src/gevent/_generated_include/PyErrFetchRestore_proto_b219ba96ee79f73e7240a9715dc835e7e817ccd9f4f99ab4145b09780817bd8a.h"
/* PyObjectGetAttrStr.proto (used by PyObjectGetAttrStrNoError) */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* PyObjectGetAttrStrNoError.proto (used by GetBuiltinName) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name);

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* DictGetItem.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key);
#define __Pyx_PyObject_Dict_GetItem(obj, name)\
    (likely(PyDict_CheckExact(obj)) ?\
     __Pyx_PyDict_GetItem(obj, name) : PyObject_GetItem(obj, name))
#else
#define __Pyx_PyDict_GetItem(d, key) PyObject_GetItem(d, key)
#define __Pyx_PyObject_Dict_GetItem(obj, name)  PyObject_GetItem(obj, name)
#endif

/* GetTopmostException.proto (used by SaveResetException) */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem * __Pyx_PyErr_GetTopmostException(PyThreadState *tstate);
#endif

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* PyKeyError_Check.proto */
#define __Pyx_PyExc_KeyError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_KeyError)

/* GetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_GetException(type, value, tb)  __Pyx__GetException(__pyx_tstate, type, value, tb)
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* dict_getitem_default.proto */
static PyObject* __Pyx_PyDict_GetItemDefault(PyObject* d, PyObject* key, PyObject* default_value);

/* CallCFunction.proto (used by CallUnboundCMethod1) */
#define __Pyx_CallCFunction(cfunc, self, args)\
    ((PyCFunction)(void(*)(void))(cfunc)->func)(self, args)
#define __Pyx_CallCFunctionWithKeywords(cfunc, self, args, kwargs)\
    ((PyCFunctionWithKeywords)(void(*)(void))(cfunc)->func)(self, args, kwargs)
#define __Pyx_CallCFunctionFast(cfunc, self, args, nargs)\
    ((__Pyx_PyCFunctionFast)(void(*)(void))(PyCFunction)(cfunc)->func)(self, args, nargs)
#define __Pyx_CallCFunctionFastWithKeywords(cfunc, self, args, nargs, kwnames)\
    ((__Pyx_PyCFunctionFastWithKeywords)(void(*)(void))(PyCFunction)(cfunc)->func)(self, args, nargs, kwnames)

/* PyObjectCall.proto (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyObjectCallMethO.proto (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectFastCall.proto (used by PyObjectCall2Args) */
#define __Pyx_PyObject_FastCall(func, args, nargs)  __Pyx_PyObject_FastCallDict(func, args, (size_t)(nargs), NULL)
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject * const*args, size_t nargs, PyObject *kwargs);

/* PyObjectCall2Args.proto (used by CallUnboundCMethod1) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2);

/* UnpackUnboundCMethod.proto (used by CallUnboundCMethod1) */
typedef struct {
    PyObject *type;
    PyObject **method_name;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && CYTHON_ATOMICS
    __pyx_atomic_int_type initialized;
#endif
    PyCFunction func;
    PyObject *method;
    int flag;
} __Pyx_CachedCFunction;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
static CYTHON_INLINE int __Pyx_CachedCFunction_GetAndSetInitializing(__Pyx_CachedCFunction *cfunc) {
#if !CYTHON_ATOMICS
    return 1;
#else
    __pyx_nonatomic_int_type expected = 0;
    if (__pyx_atomic_int_cmp_exchange(&cfunc->initialized, &expected, 1)) {
        return 0;
    }
    return expected;
#endif
}
static CYTHON_INLINE void __Pyx_CachedCFunction_SetFinishedInitializing(__Pyx_CachedCFunction *cfunc) {
#if CYTHON_ATOMICS
    __pyx_atomic_store(&cfunc->initialized, 2);
#endif
}
#else
#define __Pyx_CachedCFunction_GetAndSetInitializing(cfunc) 2
#define __Pyx_CachedCFunction_SetFinishedInitializing(cfunc)
#endif

/* CallUnboundCMethod1.proto */
CYTHON_UNUSED
static PyObject* __Pyx__CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#else
#define __Pyx_CallUnboundCMethod1(cfunc, self, arg)  __Pyx__CallUnboundCMethod1(cfunc, self, arg)
#endif

/* CallUnboundCMethod2.proto */
CYTHON_UNUSED
static PyObject* __Pyx__CallUnboundCMethod2(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg1, PyObject* arg2);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject *__Pyx_CallUnboundCMethod2(__Pyx_CachedCFunction *cfunc, PyObject *self, PyObject *arg1, PyObject *arg2);
#else
#define __Pyx_CallUnboundCMethod2(cfunc, self, arg1, arg2)  __Pyx__CallUnboundCMethod2(cfunc, self, arg1, arg2)
#endif

/* PyObjectFormatAndDecref.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatSimpleAndDecref(PyObject* s, PyObject* f);
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatAndDecref(PyObject* s, PyObject* f);

/* IncludeStringH.proto (used by JoinPyUnicode) */
#include <string.h>

/* JoinPyUnicode.export */
static PyObject* __Pyx_PyUnicode_Join(PyObject** values, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char);

/* PyDictVersioning.proto (used by GetModuleGlobalName) */
#include "src/gevent/_generated_include/PyDictVersioning_proto_fc9ab32633f390bb88d05edfc7599e60bc4df8ea122afe432e3adec504912045.h"
/* GetModuleGlobalName.proto */
#include "src/gevent/_generated_include/GetModuleGlobalName_proto_35020a92d25e00989051b6cce92e00e13fc50c1cb05740bd074404c24babc545.h"
/* TupleAndListFromArray.proto (used by fastcall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n);
#endif
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject* __Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n);
#endif

/* BytesEquals.proto (used by UnicodeEquals) */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto (used by fastcall) */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* fastcall.proto */
#include "src/gevent/_generated_include/fastcall_proto_66690a1464eb22fa574c56237a11be9953f14c69fdee2df9c4141aa9c5e2a76d.h"
/* py_dict_items.proto (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Items(PyObject* d);

/* PyObjectCallOneArg.proto (used by CallUnboundCMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* CallUnboundCMethod0.proto */
CYTHON_UNUSED
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#else
#define __Pyx_CallUnboundCMethod0(cfunc, self)  __Pyx__CallUnboundCMethod0(cfunc, self)
#endif

/* py_dict_values.proto (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Values(PyObject* d);

/* OwnedDictNext.proto (used by ParseKeywordsImpl) */
#if CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, PyObject **ppos, PyObject **pkey, PyObject **pvalue);
#else
CYTHON_INLINE
static int __Pyx_PyDict_NextRef(PyObject *p, Py_ssize_t *ppos, PyObject **pkey, PyObject **pvalue);
#endif

/* RaiseDoubleKeywords.proto (used by ParseKeywordsImpl) */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywordsImpl.export */
static int __Pyx_ParseKeywordsTuple(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);
static int __Pyx_ParseKeywordDictToDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name
);
static int __Pyx_ParseKeywordDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);

/* ParseKeywords.proto */
static CYTHON_INLINE int __Pyx_ParseKeywords(
    PyObject *kwds, PyObject *const *kwvalues, PyObject ** const argnames[],
    PyObject *kwds2, PyObject *values[],
    Py_ssize_t num_pos_args, Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* RaiseException.export */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* PyObjectFastCallMethod.proto */
#if CYTHON_VECTORCALL && PY_VERSION_HEX >= 0x03090000
#define __Pyx_PyObject_FastCallMethod(name, args, nargsf) PyObject_VectorcallMethod(name, args, nargsf, NULL)
#else
static PyObject *__Pyx_PyObject_FastCallMethod(PyObject *name, PyObject *const *args, size_t nargsf);
#endif

/* PyObjectDelAttr.proto (used by PyObjectSetAttrStr) */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030d0000
#define __Pyx_PyObject_DelAttr(o, n) PyObject_SetAttr(o, n, NULL)
#else
#define __Pyx_PyObject_DelAttr(o, n) PyObject_DelAttr(o, n)
#endif

/* PyObjectSetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o, n, NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value);
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   __Pyx_PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

/* ListAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
        L->ob_item[len] = x;
        #else
        PyList_SET_ITEM(list, len, x);
        #endif
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

/* decode_c_string_utf16.proto (used by decode_c_string) */
static CYTHON_INLINE PyObject *__Pyx_PyUnicode_DecodeUTF16(const char *s, Py_ssize_t size, const char *errors) {
    int byteorder = 0;
    return PyUnicode_DecodeUTF16(s, size, errors, &byteorder);
}
static CYTHON_INLINE PyObject *__Pyx_PyUnicode_DecodeUTF16LE(const char *s, Py_ssize_t size, const char *errors) {
    int byteorder = -1;
    return PyUnicode_DecodeUTF16(s, size, errors, &byteorder);
}
static CYTHON_INLINE PyObject *__Pyx_PyUnicode_DecodeUTF16BE(const char *s, Py_ssize_t size, const char *errors) {
    int byteorder = 1;
    return PyUnicode_DecodeUTF16(s, size, errors, &byteorder);
}

/* decode_c_string.proto */
static CYTHON_INLINE PyObject* __Pyx_decode_c_string(
         const char* cstring, Py_ssize_t start, Py_ssize_t stop,
         const char* encoding, const char* errors,
         PyObject* (*decode_func)(const char *s, Py_ssize_t size, const char *errors));

/* RaiseTooManyValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

/* RaiseNeedMoreValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

/* RaiseNoneIterError.proto */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void);

/* ExtTypeTest.proto */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type);

/* pybytes_as_double.proto (used by pyobject_as_double) */
#include "src/gevent/_generated_include/pybytes_as_double_proto_616f618dbc06e6d97c447eead630b48a97f1926297ed68e8f471ff68eaa30498.h"
/* pyunicode_as_double.proto (used by pyobject_as_double) */
#include "src/gevent/_generated_include/pyunicode_as_double_proto_a658fae95cad8912448665204bb6879287613abf4f01db57dbb6d716b090a2aa.h"
/* pyobject_as_double.proto */
static double __Pyx__PyObject_AsDouble(PyObject* obj);
#if CYTHON_COMPILING_IN_PYPY
#define __Pyx_PyObject_AsDouble(obj)\
(likely(PyFloat_CheckExact(obj)) ? PyFloat_AS_DOUBLE(obj) :\
 likely(PyLong_CheckExact(obj)) ?\
 PyFloat_AsDouble(obj) : __Pyx__PyObject_AsDouble(obj))
#else
#define __Pyx_PyObject_AsDouble(obj)\
((likely(PyFloat_CheckExact(obj))) ?  __Pyx_PyFloat_AS_DOUBLE(obj) :\
 likely(PyLong_CheckExact(obj)) ?\
 PyLong_AsDouble(obj) : __Pyx__PyObject_AsDouble(obj))
#endif

/* FloatExceptionCheck.proto */
#define __PYX_CHECK_FLOAT_EXCEPTION(value, error_value)\
    ((error_value) == (error_value) ?\
     (value) == (error_value) :\
     (value) != (value))

/* py_dict_clear.proto */
#define __Pyx_PyDict_Clear(d) (PyDict_Clear(d), 0)

/* WriteUnraisableException.proto */
static void __Pyx_WriteUnraisable(const char *name, int clineno,
                                  int lineno, const char *filename,
                                  int full_traceback, int nogil);

/* PyValueError_Check.proto */
#define __Pyx_PyExc_ValueError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_ValueError)

/* SwapException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSwap(type, value, tb)  __Pyx__ExceptionSwap(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* py_dict_pop_ignore.proto */
static CYTHON_INLINE int __Pyx_PyDict_Pop_ignore(PyObject *d, PyObject *key, PyObject *default_value);

/* PyObjectVectorCallKwBuilder.proto (used by PyObjectVectorCallMethodKwBuilder) */
CYTHON_UNUSED static int __Pyx_VectorcallBuilder_AddArg_Check(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n);
#if CYTHON_VECTORCALL
#if PY_VERSION_HEX >= 0x03090000
#define __Pyx_Object_Vectorcall_CallFromBuilder PyObject_Vectorcall
#else
#define __Pyx_Object_Vectorcall_CallFromBuilder _PyObject_Vectorcall
#endif
#define __Pyx_MakeVectorcallBuilderKwds(n) PyTuple_New(n)
static int __Pyx_VectorcallBuilder_AddArg(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n);
static int __Pyx_VectorcallBuilder_AddArgStr(const char *key, PyObject *value, PyObject *builder, PyObject **args, int n);
#else
#define __Pyx_Object_Vectorcall_CallFromBuilder __Pyx_PyObject_FastCallDict
#define __Pyx_MakeVectorcallBuilderKwds(n) __Pyx_PyDict_NewPresized(n)
#define __Pyx_VectorcallBuilder_AddArg(key, value, builder, args, n) PyDict_SetItem(builder, key, value)
#define __Pyx_VectorcallBuilder_AddArgStr(key, value, builder, args, n) PyDict_SetItemString(builder, key, value)
#endif

/* PyObjectVectorCallMethodKwBuilder.proto */
#if CYTHON_VECTORCALL && PY_VERSION_HEX >= 0x03090000
#define __Pyx_Object_VectorcallMethod_CallFromBuilder PyObject_VectorcallMethod
#else
static PyObject *__Pyx_Object_VectorcallMethod_CallFromBuilder(PyObject *name, PyObject *const *args, size_t nargsf, PyObject *kwnames);
#endif

/* GetItemInt.proto */
#include "src/gevent/_generated_include/GetItemInt_proto_3b42f7f7de85b71eab2f8b6ae51ddc7168a53d31d56dd1f1e34c94c36c959f55.h"
/* PyTypeError_Check.proto */
#define __Pyx_PyExc_TypeError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_TypeError)

/* ArgTypeTestFunc.export */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact);

/* ArgTypeTest.proto */
#define __Pyx_ArgTypeTest(obj, type, none_allowed, name, exact)\
    ((likely(__Pyx_IS_TYPE(obj, type) | (none_allowed && (obj == Py_None)))) ? 1 :\
        __Pyx__ArgTypeTest(obj, type, name, exact))

/* RaiseUnboundLocalError.proto */
static void __Pyx_RaiseUnboundLocalError(const char *varname);

/* AllocateExtensionType.proto */
static PyObject *__Pyx_AllocateExtensionType(PyTypeObject *t, int is_final);

/* CallTypeTraverse.proto */
#if !CYTHON_USE_TYPE_SPECS || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x03090000)
#define __Pyx_call_type_traverse(o, always_call, visit, arg) 0
#else
static int __Pyx_call_type_traverse(PyObject *o, int always_call, visitproc visit, void *arg);
#endif

/* LimitedApiGetTypeDict.proto (used by SetItemOnTypeDict) */
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_GetTypeDict(PyTypeObject *tp);
#endif

/* SetItemOnTypeDict.proto (used by FixUpExtensionType) */
static int __Pyx__SetItemOnTypeDict(PyTypeObject *tp, PyObject *k, PyObject *v);
#define __Pyx_SetItemOnTypeDict(tp, k, v) __Pyx__SetItemOnTypeDict((PyTypeObject*)tp, k, v)

/* FixUpExtensionType.proto */
static CYTHON_INLINE int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type);

/* PyObjectCallNoArg.proto (used by PyObjectCallMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);

/* PyObjectGetMethod.proto (used by PyObjectCallMethod0) */
#if !(CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000)))
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method);
#endif

/* PyObjectCallMethod0.proto (used by PyType_Ready) */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name);

/* ValidateBasesTuple.proto (used by PyType_Ready) */
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_USE_TYPE_SPECS
static int __Pyx_validate_bases_tuple(const char *type_name, Py_ssize_t dictoffset, PyObject *bases);
#endif

/* PyType_Ready.proto */
CYTHON_UNUSED static int __Pyx_PyType_Ready(PyTypeObject *t);

/* SetVTable.proto */
static int __Pyx_SetVtable(PyTypeObject* typeptr , void* vtable);

/* GetVTable.proto (used by MergeVTables) */
static void* __Pyx_GetVtable(PyTypeObject *type);

/* MergeVTables.proto */
static int __Pyx_MergeVtables(PyTypeObject *type);

/* TypeImport.proto */
#ifndef __PYX_HAVE_RT_ImportType_proto_3_2_4
#define __PYX_HAVE_RT_ImportType_proto_3_2_4
#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#include <stdalign.h>
#endif
#if (defined (__STDC_VERSION__) && __STDC_VERSION__ >= 201112L) || __cplusplus >= 201103L
#define __PYX_GET_STRUCT_ALIGNMENT_3_2_4(s) alignof(s)
#else
#define __PYX_GET_STRUCT_ALIGNMENT_3_2_4(s) sizeof(void*)
#endif
enum __Pyx_ImportType_CheckSize_3_2_4 {
   __Pyx_ImportType_CheckSize_Error_3_2_4 = 0,
   __Pyx_ImportType_CheckSize_Warn_3_2_4 = 1,
   __Pyx_ImportType_CheckSize_Ignore_3_2_4 = 2
};
static PyTypeObject *__Pyx_ImportType_3_2_4(PyObject* module, const char *module_name, const char *class_name, size_t size, size_t alignment, enum __Pyx_ImportType_CheckSize_3_2_4 check_size);
#endif

/* HasAttr.proto (used by ImportImpl) */
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
#define __Pyx_HasAttr(o, n)  PyObject_HasAttrWithError(o, n)
#else
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *, PyObject *);
#endif

/* ImportImpl.export */
static PyObject *__Pyx__Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, PyObject *moddict, int level);

/* Import.proto */
static CYTHON_INLINE PyObject *__Pyx_Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, int level);

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* ListPack.proto */
static PyObject *__Pyx_PyList_Pack(Py_ssize_t n, ...);

/* Py3UpdateBases.proto */
static PyObject* __Pyx_PEP560_update_bases(PyObject *bases);

/* CalculateMetaclass.proto */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases);

/* PyObjectLookupSpecial.proto (used by Py3ClassCreate) */
#if CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_LookupSpecialNoError(obj, attr_name)  __Pyx__PyObject_LookupSpecial(obj, attr_name, 0)
#define __Pyx_PyObject_LookupSpecial(obj, attr_name)  __Pyx__PyObject_LookupSpecial(obj, attr_name, 1)
static CYTHON_INLINE PyObject* __Pyx__PyObject_LookupSpecial(PyObject* obj, PyObject* attr_name, int with_error);
#else
#define __Pyx_PyObject_LookupSpecialNoError(o,n) __Pyx_PyObject_GetAttrStrNoError(o,n)
#define __Pyx_PyObject_LookupSpecial(o,n) __Pyx_PyObject_GetAttrStr(o,n)
#endif

/* Py3ClassCreate.proto */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name, PyObject *qualname,
                                           PyObject *mkw, PyObject *modname, PyObject *doc);
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases, PyObject *dict,
                                      PyObject *mkw, int calculate_metaclass, int allow_py2_metaclass);

/* dict_setdefault.proto (used by FetchCommonType) */
static CYTHON_INLINE PyObject *__Pyx_PyDict_SetDefault(PyObject *d, PyObject *key, PyObject *default_value);

/* AddModuleRef.proto (used by FetchSharedCythonModule) */
#if ((CYTHON_COMPILING_IN_CPYTHON_FREETHREADING ) ||\
     __PYX_LIMITED_VERSION_HEX < 0x030d0000)
  static PyObject *__Pyx_PyImport_AddModuleRef(const char *name);
#else
  #define __Pyx_PyImport_AddModuleRef(name) PyImport_AddModuleRef(name)
#endif

/* FetchSharedCythonModule.proto (used by FetchCommonType) */
static PyObject *__Pyx_FetchSharedCythonABIModule(void);

/* FetchCommonType.proto (used by CommonTypesMetaclass) */
static PyTypeObject* __Pyx_FetchCommonTypeFromSpec(PyTypeObject *metaclass, PyObject *module, PyType_Spec *spec, PyObject *bases);

/* CommonTypesMetaclass.proto (used by CythonFunctionShared) */
static int __pyx_CommonTypesMetaclass_init(PyObject *module);
#define __Pyx_CommonTypesMetaclass_USED

/* PyMethodNew.proto (used by CythonFunctionShared) */
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ);

/* PyVectorcallFastCallDict.proto (used by CythonFunctionShared) */
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw);
#endif

/* CythonFunctionShared.proto (used by CythonFunction) */
#include "src/gevent/_generated_include/CythonFunctionShared_proto_cfd16e7b1cdcce8e6454094d94c7459b788326000c3b790f09af3662926ca152.h"
/* CythonFunction.proto */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);

/* SetNameInClass.proto (used by SetNewInClass) */
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? _PyDict_SetItem_KnownHash(ns, name, value, ((PyASCIIObject *) name)->hash) : PyObject_SetItem(ns, name, value))
#elif CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? PyDict_SetItem(ns, name, value) : PyObject_SetItem(ns, name, value))
#else
#define __Pyx_SetNameInClass(ns, name, value)  PyObject_SetItem(ns, name, value)
#endif

/* SetNewInClass.proto */
static int __Pyx_SetNewInClass(PyObject *ns, PyObject *name, PyObject *value);

/* CLineInTraceback.proto (used by AddTraceback) */
#if CYTHON_CLINE_IN_TRACEBACK && CYTHON_CLINE_IN_TRACEBACK_RUNTIME
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#else
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#endif

/* CodeObjectCache.proto (used by AddTraceback) */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject __Pyx_CachedCodeObjectType;
#else
typedef PyCodeObject __Pyx_CachedCodeObjectType;
#endif
typedef struct {
    __Pyx_CachedCodeObjectType* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_atomic_int_type accessor_count;
  #endif
};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static __Pyx_CachedCodeObjectType *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, __Pyx_CachedCodeObjectType* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* GCCDiagnostics.proto */
#if !defined(__INTEL_COMPILER) && defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6))
#define __Pyx_HAS_GCC_DIAGNOSTIC
#endif

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyLong_As_int(PyObject *);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_int(int value);

/* CIntFromPy.proto */
static CYTHON_INLINE unsigned short __Pyx_PyLong_As_unsigned_short(PyObject *);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_long(long value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_unsigned_int(unsigned int value);

/* FormatTypeName.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%U"
#define __Pyx_DECREF_TypeName(obj) Py_XDECREF(obj)
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
#define __Pyx_PyType_GetFullyQualifiedName PyType_GetFullyQualifiedName
#else
static __Pyx_TypeName __Pyx_PyType_GetFullyQualifiedName(PyTypeObject* tp);
#endif
#else  // !LIMITED_API
typedef const char *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%.200s"
#define __Pyx_PyType_GetFullyQualifiedName(tp) ((tp)->tp_name)
#define __Pyx_DECREF_TypeName(obj)
#endif

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyLong_As_long(PyObject *);

/* FastTypeChecks.proto */
#include "src/gevent/_generated_include/FastTypeChecks_proto_b6a1eb5ffa2a3fc9ebedcc671e034de99427399b8e4cbe35bbcd118ac87e0e6e.h"
/* GetRuntimeVersion.proto */
#if __PYX_LIMITED_VERSION_HEX < 0x030b0000
static unsigned long __Pyx_cached_runtime_version = 0;
static void __Pyx_init_runtime_version(void);
#else
#define __Pyx_init_runtime_version()
#endif
static unsigned long __Pyx_get_runtime_version(void);

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer);

/* DecompressString.proto */
static PyObject *__Pyx_DecompressString(const char *s, Py_ssize_t length, int algo);

/* MultiPhaseInitModuleState.proto */
#if CYTHON_PEP489_MULTI_PHASE_INIT && CYTHON_USE_MODULE_STATE
static PyObject *__Pyx_State_FindModule(void*);
static int __Pyx_State_AddModule(PyObject* module, void*);
static int __Pyx_State_RemoveModule(void*);
#elif CYTHON_USE_MODULE_STATE
#define __Pyx_State_FindModule PyState_FindModule
#define __Pyx_State_AddModule PyState_AddModule
#define __Pyx_State_RemoveModule PyState_RemoveModule
#endif

/* #### Code section: module_declarations ### */
/* CythonABIVersion.proto */
#include "src/gevent/_generated_include/CythonABIVersion_proto_6de230514e3c249dc5d32a29298796e6371a56c148e74d1832d78a4b882841b1.h"
static PyObject *__pyx_f_6gevent_8resolver_5cares_7channel__channel__destroy(struct __pyx_obj_6gevent_8resolver_5cares_channel *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6gevent_8resolver_5cares_7channel_set_servers(struct __pyx_obj_6gevent_8resolver_5cares_channel *__pyx_v_self, int __pyx_skip_dispatch, struct __pyx_opt_args_6gevent_8resolver_5cares_7channel_set_servers *__pyx_optional_args); /* proto*/
static PyObject *__pyx_f_6gevent_8resolver_5cares_7channel__sock_state_callback(struct __pyx_obj_6gevent_8resolver_5cares_channel *__pyx_v_self, int __pyx_v_socket, int __pyx_v_read, int __pyx_v_write); /* proto*/
static void __pyx_f_6gevent_8resolver_5cares_7channel__gethostbyname_or_byaddr_cb(void *__pyx_v_arg, int __pyx_v_status, CYTHON_UNUSED int __pyx_v_timeouts, struct hostent *__pyx_v_host); /* proto*/
static PyObject *__pyx_f_6gevent_8resolver_5cares_7channel__getnameinfo(struct __pyx_obj_6gevent_8resolver_5cares_channel *__pyx_v_self, PyObject *__pyx_v_callback, PyObject *__pyx_v_sockaddr, int __pyx_v_flags, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_6gevent_8resolver_5cares_7channel__convert_cares_ni_flags(int __pyx_v_flags); /* proto*/
static int __pyx_f_6gevent_8resolver_5cares_7channel__convert_cares_ai_flags(int __pyx_v_flags); /* proto*/
static void __pyx_f_6gevent_8resolver_5cares_7channel__getaddrinfo_cb(void *__pyx_v_arg, int __pyx_v_status, CYTHON_UNUSED int __pyx_v_timeouts, struct ares_addrinfo *__pyx_v_result); /* proto*/

/* Module declarations from "libcares" */

/* Module declarations from "cpython.version" */

/* Module declarations from "libc.string" */

/* Module declarations from "libc.stdio" */

/* Module declarations from "__builtin__" */

/* Module declarations from "cpython.type" */

/* Module declarations from "cpython" */

/* Module declarations from "cpython.object" */

/* Module declarations from "cpython.tuple" */

/* Module declarations from "cpython.getargs" */

/* Module declarations from "cpython.ref" */

/* Module declarations from "cpython.mem" */

/* Module declarations from "gevent.resolver.cares" */
static int __pyx_v_6gevent_8resolver_5cares_AI_NUMERICSERV;
static int __pyx_v_6gevent_8resolver_5cares_AI_CANONNAME;
static int __pyx_v_6gevent_8resolver_5cares_NI_NUMERICHOST;
static int __pyx_v_6gevent_8resolver_5cares_NI_NUMERICSERV;
static int __pyx_v_6gevent_8resolver_5cares_NI_NOFQDN;
static int __pyx_v_6gevent_8resolver_5cares_NI_NAMEREQD;
static int __pyx_v_6gevent_8resolver_5cares_NI_DGRAM;
static PyObject *__pyx_v_6gevent_8resolver_5cares__ares_errors = 0;
static PyObject *__pyx_v_6gevent_8resolver_5cares__ares_to_gai_system = 0;
static PyObject *__pyx_v_6gevent_8resolver_5cares__ares_to_host_system = 0;
static PyObject *__pyx_f_6gevent_8resolver_5cares__gevent_gai_strerror(PyObject *); /*proto*/
static PyObject *__pyx_f_6gevent_8resolver_5cares__gevent_gaierror_from_status(int); /*proto*/
static PyObject *__pyx_f_6gevent_8resolver_5cares__gevent_herror_strerror(PyObject *); /*proto*/
static PyObject *__pyx_f_6gevent_8resolver_5cares__gevent_herror_from_status(int); /*proto*/
static void __pyx_f_6gevent_8resolver_5cares_gevent_sock_state_callback(void *, int, int, int); /*proto*/
static PyObject *__pyx_f_6gevent_8resolver_5cares__parse_h_aliases(struct hostent *); /*proto*/
static PyObject *__pyx_f_6gevent_8resolver_5cares__parse_h_addr_list(struct hostent *); /*proto*/
static PyObject *__pyx_f_6gevent_8resolver_5cares__as_str(char const *); /*proto*/
static void __pyx_f_6gevent_8resolver_5cares_gevent_ares_nameinfo_callback(void *, int, int, char *, char *); /*proto*/
static int __pyx_f_6gevent_8resolver_5cares__make_sockaddr(char const *, int, int, int, struct sockaddr_in6 *); /*proto*/
/* #### Code section: typeinfo ### */
/* #### Code section: before_global_var ### */
#define __Pyx_MODULE_NAME "gevent.resolver.cares"
extern int __pyx_module_is_main_gevent__resolver__cares;
int __pyx_module_is_main_gevent__resolver__cares = 0;

/* Implementation of "gevent.resolver.cares" */
/* #### Code section: global_var ### */
static PyObject *__pyx_builtin_id;
/* #### Code section: string_decls ### */
/* #### Code section: decls ### */
static int __pyx_pf_6gevent_8resolver_5cares_6Result___init__(struct __pyx_obj_6gevent_8resolver_5cares_Result *__pyx_v_self, PyObject *__pyx_v_value, PyObject *__pyx_v_exception); /* proto */
static PyObject *__pyx_pf_6gevent_8resolver_5cares_6Result_2__repr__(struct __pyx_obj_6gevent_8resolver_5cares_Result *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_8resolver_5cares_6Result_4successful(struct __pyx_obj_6gevent_8resolver_5cares_Result *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_8resolver_5cares_6Result_6get(struct __pyx_obj_6gevent_8resolver_5cares_Result *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_8resolver_5cares_6Result_5value___get__(struct __pyx_obj_6gevent_8resolver_5cares_Result *__pyx_v_self); /* proto */
static int __pyx_pf_6gevent_8resolver_5cares_6Result_5value_2__set__(struct __pyx_obj_6gevent_8resolver_5cares_Result *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6gevent_8resolver_5cares_6Result_5value_4__del__(struct __pyx_obj_6gevent_8resolver_5cares_Result *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_8resolver_5cares_6Result_9exception___get__(struct __pyx_obj_6gevent_8resolver_5cares_Result *__pyx_v_self); /* proto */
static int __pyx_pf_6gevent_8resolver_5cares_6Result_9exception_2__set__(struct __pyx_obj_6gevent_8resolver_5cares_Result *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6gevent_8resolver_5cares_6Result_9exception_4__del__(struct __pyx_obj_6gevent_8resolver_5cares_Result *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_8resolver_5cares_16ares_host_result___new__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls, PyObject *__pyx_v_family, PyObject *__pyx_v_iterable); /* proto */
static PyObject *__pyx_pf_6gevent_8resolver_5cares_16ares_host_result_2__getnewargs__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static int __pyx_pf_6gevent_8resolver_5cares_7channel___init__(struct __pyx_obj_6gevent_8resolver_5cares_channel *__pyx_v_self, PyObject *__pyx_v_loop, PyObject *__pyx_v_flags, PyObject *__pyx_v_timeout, PyObject *__pyx_v_tries, PyObject *__pyx_v_ndots, PyObject *__pyx_v_udp_port, PyObject *__pyx_v_tcp_port, PyObject *__pyx_v_servers); /* proto */
static PyObject *__pyx_pf_6gevent_8resolver_5cares_7channel_2__repr__(struct __pyx_obj_6gevent_8resolver_5cares_channel *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_8resolver_5cares_7channel_4destroy(struct __pyx_obj_6gevent_8resolver_5cares_channel *__pyx_v_self); /* proto */
static void __pyx_pf_6gevent_8resolver_5cares_7channel_6__dealloc__(struct __pyx_obj_6gevent_8resolver_5cares_channel *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_8resolver_5cares_7channel_8set_servers(struct __pyx_obj_6gevent_8resolver_5cares_channel *__pyx_v_self, PyObject *__pyx_v_servers); /* proto */
static PyObject *__pyx_pf_6gevent_8resolver_5cares_7channel_10_on_timer(struct __pyx_obj_6gevent_8resolver_5cares_channel *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6gevent_8resolver_5cares_7channel_12_process_fd(struct __pyx_obj_6gevent_8resolver_5cares_channel *__pyx_v_self, int __pyx_v_events, PyObject *__pyx_v_watcher); /* proto */
static PyObject *__pyx_pf_6gevent_8resolver_5cares_7channel_14gethostbyname(struct __pyx_obj_6gevent_8resolver_5cares_channel *__pyx_v_self, PyObject *__pyx_v_callback, char *__pyx_v_name, int __pyx_v_family); /* proto */
static PyObject *__pyx_pf_6gevent_8resolver_5cares_7channel_16gethostbyaddr(struct __pyx_obj_6gevent_8resolver_5cares_channel *__pyx_v_self, PyObject *__pyx_v_callback, char *__pyx_v_addr); /* proto */
static PyObject *__pyx_pf_6gevent_8resolver_5cares_7channel_18_getnameinfo(struct __pyx_obj_6gevent_8resolver_5cares_channel *__pyx_v_self, PyObject *__pyx_v_callback, PyObject *__pyx_v_sockaddr, int __pyx_v_flags); /* proto */
static PyObject *__pyx_pf_6gevent_8resolver_5cares_7channel_20getnameinfo(struct __pyx_obj_6gevent_8resolver_5cares_channel *__pyx_v_self, PyObject *__pyx_v_callback, PyObject *__pyx_v_sockaddr, int __pyx_v_flags); /* proto */
static PyObject *__pyx_pf_6gevent_8resolver_5cares_7channel_22getaddrinfo(struct __pyx_obj_6gevent_8resolver_5cares_channel *__pyx_v_self, PyObject *__pyx_v_callback, char const *__pyx_v_name, PyObject *__pyx_v_service, int __pyx_v_family, int __pyx_v_type, int __pyx_v_proto, int __pyx_v_flags); /* proto */
static PyObject *__pyx_pf_6gevent_8resolver_5cares_7channel_4loop___get__(struct __pyx_obj_6gevent_8resolver_5cares_channel *__pyx_v_self); /* proto */
static PyObject *__pyx_tp_new_6gevent_8resolver_5cares_Result(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6gevent_8resolver_5cares_channel(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
/* #### Code section: late_includes ### */
/* #### Code section: module_state ### */
/* SmallCodeConfig */
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif

typedef struct {
  PyObject *__pyx_d;
  PyObject *__pyx_b;
  PyObject *__pyx_cython_runtime;
  PyObject *__pyx_empty_tuple;
  PyObject *__pyx_empty_bytes;
  PyObject *__pyx_empty_unicode;
  PyTypeObject *__pyx_ptype_7cpython_4type_type;
  PyObject *__pyx_type_6gevent_8resolver_5cares_Result;
  PyObject *__pyx_type_6gevent_8resolver_5cares_channel;
  PyTypeObject *__pyx_ptype_6gevent_8resolver_5cares_Result;
  PyTypeObject *__pyx_ptype_6gevent_8resolver_5cares_channel;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_get;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_items;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_pop;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_values;
  int __pyx_k__5;
  PyObject *__pyx_tuple[2];
  PyObject *__pyx_codeobj_tab[13];
  PyObject *__pyx_string_tab[170];
  PyObject *__pyx_number_tab[1];
/* #### Code section: module_state_contents ### */
/* CommonTypesMetaclass.module_state_decls */
PyTypeObject *__pyx_CommonTypesMetaclassType;

/* CachedMethodType.module_state_decls */
#if CYTHON_COMPILING_IN_LIMITED_API
PyObject *__Pyx_CachedMethodType;
#endif

/* CythonFunctionShared.module_state_decls */
PyTypeObject *__pyx_CyFunctionType;

/* CodeObjectCache.module_state_decls */
struct __Pyx_CodeObjectCache __pyx_code_cache;

/* #### Code section: module_state_end ### */
} __pyx_mstatetype;

#if CYTHON_USE_MODULE_STATE
#ifdef __cplusplus
namespace {
extern struct PyModuleDef __pyx_moduledef;
} /* anonymous namespace */
#else
static struct PyModuleDef __pyx_moduledef;
#endif

#define __pyx_mstate_global (__Pyx_PyModule_GetState(__Pyx_State_FindModule(&__pyx_moduledef)))

#define __pyx_m (__Pyx_State_FindModule(&__pyx_moduledef))
#else
static __pyx_mstatetype __pyx_mstate_global_static =
#ifdef __cplusplus
    {};
#else
    {0};
#endif
static __pyx_mstatetype * const __pyx_mstate_global = &__pyx_mstate_global_static;
#endif
/* #### Code section: constant_name_defines ### */
#define __pyx_kp_u_ __pyx_string_tab[0]
#define __pyx_kp_u_Failed_in_ares_inet_ntop __pyx_string_tab[1]
#define __pyx_kp_u_Note_that_Cython_is_deliberately __pyx_string_tab[2]
#define __pyx_kp_u__2 __pyx_string_tab[3]
#define __pyx_kp_u__3 __pyx_string_tab[4]
#define __pyx_kp_u__4 __pyx_string_tab[5]
#define __pyx_kp_u__6 __pyx_string_tab[6]
#define __pyx_kp_u__7 __pyx_string_tab[7]
#define __pyx_kp_u__8 __pyx_string_tab[8]
#define __pyx_kp_u_add_note __pyx_string_tab[9]
#define __pyx_kp_u_disable __pyx_string_tab[10]
#define __pyx_kp_u_enable __pyx_string_tab[11]
#define __pyx_kp_u_exception_2 __pyx_string_tab[12]
#define __pyx_kp_u_exception_3 __pyx_string_tab[13]
#define __pyx_kp_u_expected_a_tuple_got __pyx_string_tab[14]
#define __pyx_kp_u_gc __pyx_string_tab[15]
#define __pyx_kp_u_isenabled __pyx_string_tab[16]
#define __pyx_kp_u_s_at_0x_x__timer_r__watchers_s __pyx_string_tab[17]
#define __pyx_kp_u_src_gevent_resolver_cares_pyx __pyx_string_tab[18]
#define __pyx_kp_u_this_ares_channel_has_been_destr __pyx_string_tab[19]
#define __pyx_kp_u_value_2 __pyx_string_tab[20]
#define __pyx_n_u_AI_CANONNAME __pyx_string_tab[21]
#define __pyx_n_u_AI_NUMERICSERV __pyx_string_tab[22]
#define __pyx_n_u_ARES_EADDRGETNETWORKPARAMS __pyx_string_tab[23]
#define __pyx_n_u_ARES_EBADFAMILY __pyx_string_tab[24]
#define __pyx_n_u_ARES_EBADFLAGS __pyx_string_tab[25]
#define __pyx_n_u_ARES_EBADHINTS __pyx_string_tab[26]
#define __pyx_n_u_ARES_EBADNAME __pyx_string_tab[27]
#define __pyx_n_u_ARES_EBADQUERY __pyx_string_tab[28]
#define __pyx_n_u_ARES_EBADRESP __pyx_string_tab[29]
#define __pyx_n_u_ARES_EBADSTR __pyx_string_tab[30]
#define __pyx_n_u_ARES_ECANCELLED __pyx_string_tab[31]
#define __pyx_n_u_ARES_ECONNREFUSED __pyx_string_tab[32]
#define __pyx_n_u_ARES_EDESTRUCTION __pyx_string_tab[33]
#define __pyx_n_u_ARES_EFILE __pyx_string_tab[34]
#define __pyx_n_u_ARES_EFORMERR __pyx_string_tab[35]
#define __pyx_n_u_ARES_ELOADIPHLPAPI __pyx_string_tab[36]
#define __pyx_n_u_ARES_ENODATA __pyx_string_tab[37]
#define __pyx_n_u_ARES_ENOMEM __pyx_string_tab[38]
#define __pyx_n_u_ARES_ENONAME __pyx_string_tab[39]
#define __pyx_n_u_ARES_ENOTFOUND __pyx_string_tab[40]
#define __pyx_n_u_ARES_ENOTIMP __pyx_string_tab[41]
#define __pyx_n_u_ARES_ENOTINITIALIZED __pyx_string_tab[42]
#define __pyx_n_u_ARES_EOF __pyx_string_tab[43]
#define __pyx_n_u_ARES_EREFUSED __pyx_string_tab[44]
#define __pyx_n_u_ARES_ESERVFAIL __pyx_string_tab[45]
#define __pyx_n_u_ARES_ESERVICE __pyx_string_tab[46]
#define __pyx_n_u_ARES_ETIMEOUT __pyx_string_tab[47]
#define __pyx_n_u_ARES_SUCCESS __pyx_string_tab[48]
#define __pyx_n_u_InvalidIP __pyx_string_tab[49]
#define __pyx_n_u_MAC __pyx_string_tab[50]
#define __pyx_n_u_NI_DGRAM __pyx_string_tab[51]
#define __pyx_n_u_NI_NAMEREQD __pyx_string_tab[52]
#define __pyx_n_u_NI_NOFQDN __pyx_string_tab[53]
#define __pyx_n_u_NI_NUMERICHOST __pyx_string_tab[54]
#define __pyx_n_u_NI_NUMERICSERV __pyx_string_tab[55]
#define __pyx_n_u_Pyx_PyDict_NextRef __pyx_string_tab[56]
#define __pyx_n_u_Result __pyx_string_tab[57]
#define __pyx_n_u_Result_get __pyx_string_tab[58]
#define __pyx_n_u_Result_successful __pyx_string_tab[59]
#define __pyx_n_u_addr __pyx_string_tab[60]
#define __pyx_n_u_addr_packed __pyx_string_tab[61]
#define __pyx_n_u_again __pyx_string_tab[62]
#define __pyx_n_u_all __pyx_string_tab[63]
#define __pyx_n_u_ares_host_result __pyx_string_tab[64]
#define __pyx_n_u_ares_host_result___getnewargs __pyx_string_tab[65]
#define __pyx_n_u_ares_host_result___new __pyx_string_tab[66]
#define __pyx_n_u_arg __pyx_string_tab[67]
#define __pyx_n_u_ascii __pyx_string_tab[68]
#define __pyx_n_u_asyncio_coroutines __pyx_string_tab[69]
#define __pyx_n_u_callback __pyx_string_tab[70]
#define __pyx_n_u_channel __pyx_string_tab[71]
#define __pyx_n_u_channel__getnameinfo __pyx_string_tab[72]
#define __pyx_n_u_channel__on_timer __pyx_string_tab[73]
#define __pyx_n_u_channel__process_fd __pyx_string_tab[74]
#define __pyx_n_u_channel_destroy __pyx_string_tab[75]
#define __pyx_n_u_channel_getaddrinfo __pyx_string_tab[76]
#define __pyx_n_u_channel_gethostbyaddr __pyx_string_tab[77]
#define __pyx_n_u_channel_gethostbyname __pyx_string_tab[78]
#define __pyx_n_u_channel_getnameinfo __pyx_string_tab[79]
#define __pyx_n_u_channel_set_servers __pyx_string_tab[80]
#define __pyx_n_u_class __pyx_string_tab[81]
#define __pyx_n_u_cline_in_traceback __pyx_string_tab[82]
#define __pyx_n_u_close __pyx_string_tab[83]
#define __pyx_n_u_cls __pyx_string_tab[84]
#define __pyx_n_u_destroy __pyx_string_tab[85]
#define __pyx_n_u_doc __pyx_string_tab[86]
#define __pyx_n_u_encode __pyx_string_tab[87]
#define __pyx_n_u_error __pyx_string_tab[88]
#define __pyx_n_u_events __pyx_string_tab[89]
#define __pyx_n_u_exc_info __pyx_string_tab[90]
#define __pyx_n_u_exception __pyx_string_tab[91]
#define __pyx_n_u_family __pyx_string_tab[92]
#define __pyx_n_u_fd __pyx_string_tab[93]
#define __pyx_n_u_flags __pyx_string_tab[94]
#define __pyx_n_u_func __pyx_string_tab[95]
#define __pyx_n_u_gaierror __pyx_string_tab[96]
#define __pyx_n_u_get __pyx_string_tab[97]
#define __pyx_n_u_getaddrinfo __pyx_string_tab[98]
#define __pyx_n_u_gethostbyaddr __pyx_string_tab[99]
#define __pyx_n_u_gethostbyname __pyx_string_tab[100]
#define __pyx_n_u_getnameinfo __pyx_string_tab[101]
#define __pyx_n_u_getnameinfo_2 __pyx_string_tab[102]
#define __pyx_n_u_getnewargs __pyx_string_tab[103]
#define __pyx_n_u_gevent__compat __pyx_string_tab[104]
#define __pyx_n_u_gevent_resolver_cares __pyx_string_tab[105]
#define __pyx_n_u_handle_error __pyx_string_tab[106]
#define __pyx_n_u_herror __pyx_string_tab[107]
#define __pyx_n_u_hints __pyx_string_tab[108]
#define __pyx_n_u_id __pyx_string_tab[109]
#define __pyx_n_u_io __pyx_string_tab[110]
#define __pyx_n_u_is_coroutine __pyx_string_tab[111]
#define __pyx_n_u_items __pyx_string_tab[112]
#define __pyx_n_u_iterable __pyx_string_tab[113]
#define __pyx_n_u_length __pyx_string_tab[114]
#define __pyx_n_u_loop __pyx_string_tab[115]
#define __pyx_n_u_main __pyx_string_tab[116]
#define __pyx_n_u_metaclass __pyx_string_tab[117]
#define __pyx_n_u_module __pyx_string_tab[118]
#define __pyx_n_u_mro_entries __pyx_string_tab[119]
#define __pyx_n_u_name __pyx_string_tab[120]
#define __pyx_n_u_name_2 __pyx_string_tab[121]
#define __pyx_n_u_ndots __pyx_string_tab[122]
#define __pyx_n_u_new __pyx_string_tab[123]
#define __pyx_n_u_on_timer __pyx_string_tab[124]
#define __pyx_n_u_pass_events __pyx_string_tab[125]
#define __pyx_n_u_pop __pyx_string_tab[126]
#define __pyx_n_u_prepare __pyx_string_tab[127]
#define __pyx_n_u_process_fd __pyx_string_tab[128]
#define __pyx_n_u_proto __pyx_string_tab[129]
#define __pyx_n_u_pyx_vtable __pyx_string_tab[130]
#define __pyx_n_u_qualname __pyx_string_tab[131]
#define __pyx_n_u_read_fd __pyx_string_tab[132]
#define __pyx_n_u_self __pyx_string_tab[133]
#define __pyx_n_u_servers __pyx_string_tab[134]
#define __pyx_n_u_service __pyx_string_tab[135]
#define __pyx_n_u_set_name __pyx_string_tab[136]
#define __pyx_n_u_set_servers __pyx_string_tab[137]
#define __pyx_n_u_setdefault __pyx_string_tab[138]
#define __pyx_n_u_sockaddr __pyx_string_tab[139]
#define __pyx_n_u_socket __pyx_string_tab[140]
#define __pyx_n_u_split __pyx_string_tab[141]
#define __pyx_n_u_start __pyx_string_tab[142]
#define __pyx_n_u_stop __pyx_string_tab[143]
#define __pyx_n_u_successful __pyx_string_tab[144]
#define __pyx_n_u_sys __pyx_string_tab[145]
#define __pyx_n_u_tcp_port __pyx_string_tab[146]
#define __pyx_n_u_test __pyx_string_tab[147]
#define __pyx_n_u_timeout __pyx_string_tab[148]
#define __pyx_n_u_timer __pyx_string_tab[149]
#define __pyx_n_u_tries __pyx_string_tab[150]
#define __pyx_n_u_type __pyx_string_tab[151]
#define __pyx_n_u_udp_port __pyx_string_tab[152]
#define __pyx_n_u_value __pyx_string_tab[153]
#define __pyx_n_u_values __pyx_string_tab[154]
#define __pyx_n_u_watcher __pyx_string_tab[155]
#define __pyx_n_u_write_fd __pyx_string_tab[156]
#define __pyx_kp_b_iso88591_A_4_a_t1 __pyx_string_tab[157]
#define __pyx_kp_b_iso88591_A_4t1_4A_1_A_A_4_AQ_1_9AWAV1Jaq __pyx_string_tab[158]
#define __pyx_kp_b_iso88591_A_4t1_4A_4q_a_Qiq_gV1A_Qa_7_Q_1 __pyx_string_tab[159]
#define __pyx_kp_b_iso88591_A_4t1_4A_aq_s_8__A__A_6_a_HCz_Q __pyx_string_tab[160]
#define __pyx_kp_b_iso88591_A_4t1_4A_q_Ba_Q_Q_F_r_Q_Q_1D_6_Z __pyx_string_tab[161]
#define __pyx_kp_b_iso88591_A_4t1_7_A_5_r_1_5_r_A_Qd_IQ __pyx_string_tab[162]
#define __pyx_kp_b_iso88591_A_5_a_Ja_q __pyx_string_tab[163]
#define __pyx_kp_b_iso88591_A_IU_1 __pyx_string_tab[164]
#define __pyx_kp_b_iso88591_A_Ja __pyx_string_tab[165]
#define __pyx_kp_b_iso88591_A_Qd_1H __pyx_string_tab[166]
#define __pyx_kp_b_iso88591_A_q_t_Q __pyx_string_tab[167]
#define __pyx_kp_b_iso88591_A_t_c __pyx_string_tab[168]
#define __pyx_kp_b_iso88591_DA_4t1_4A_6_ZvQ_MWTU __pyx_string_tab[169]
#define __pyx_int_0 __pyx_number_tab[0]
/* #### Code section: module_state_clear ### */
#if CYTHON_USE_MODULE_STATE
static CYTHON_SMALL_CODE int __pyx_m_clear(PyObject *m) {
  __pyx_mstatetype *clear_module_state = __Pyx_PyModule_GetState(m);
  if (!clear_module_state) return 0;
  Py_CLEAR(clear_module_state->__pyx_d);
  Py_CLEAR(clear_module_state->__pyx_b);
  Py_CLEAR(clear_module_state->__pyx_cython_runtime);
  Py_CLEAR(clear_module_state->__pyx_empty_tuple);
  Py_CLEAR(clear_module_state->__pyx_empty_bytes);
  Py_CLEAR(clear_module_state->__pyx_empty_unicode);
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __Pyx_State_RemoveModule(NULL);
  #endif
  Py_CLEAR(clear_module_state->__pyx_ptype_7cpython_4type_type);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_8resolver_5cares_Result);
  Py_CLEAR(clear_module_state->__pyx_type_6gevent_8resolver_5cares_Result);
  Py_CLEAR(clear_module_state->__pyx_ptype_6gevent_8resolver_5cares_channel);
  Py_CLEAR(clear_module_state->__pyx_type_6gevent_8resolver_5cares_channel);
  for (int i=0; i<2; ++i) { Py_CLEAR(clear_module_state->__pyx_tuple[i]); }
  for (int i=0; i<13; ++i) { Py_CLEAR(clear_module_state->__pyx_codeobj_tab[i]); }
  for (int i=0; i<170; ++i) { Py_CLEAR(clear_module_state->__pyx_string_tab[i]); }
  for (int i=0; i<1; ++i) { Py_CLEAR(clear_module_state->__pyx_number_tab[i]); }
/* #### Code section: module_state_clear_contents ### */
/* CommonTypesMetaclass.module_state_clear */
Py_CLEAR(clear_module_state->__pyx_CommonTypesMetaclassType);

/* CythonFunctionShared.module_state_clear */
Py_CLEAR(clear_module_state->__pyx_CyFunctionType);

/* #### Code section: module_state_clear_end ### */
return 0;
}
#endif
/* #### Code section: module_state_traverse ### */
#if CYTHON_USE_MODULE_STATE
static CYTHON_SMALL_CODE int __pyx_m_traverse(PyObject *m, visitproc visit, void *arg) {
  __pyx_mstatetype *traverse_module_state = __Pyx_PyModule_GetState(m);
  if (!traverse_module_state) return 0;
  Py_VISIT(traverse_module_state->__pyx_d);
  Py_VISIT(traverse_module_state->__pyx_b);
  Py_VISIT(traverse_module_state->__pyx_cython_runtime);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_tuple);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_bytes);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_unicode);
  Py_VISIT(traverse_module_state->__pyx_ptype_7cpython_4type_type);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_8resolver_5cares_Result);
  Py_VISIT(traverse_module_state->__pyx_type_6gevent_8resolver_5cares_Result);
  Py_VISIT(traverse_module_state->__pyx_ptype_6gevent_8resolver_5cares_channel);
  Py_VISIT(traverse_module_state->__pyx_type_6gevent_8resolver_5cares_channel);
  for (int i=0; i<2; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_tuple[i]); }
  for (int i=0; i<13; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_codeobj_tab[i]); }
  for (int i=0; i<170; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_string_tab[i]); }
  for (int i=0; i<1; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_number_tab[i]); }
/* #### Code section: module_state_traverse_contents ### */
/* CommonTypesMetaclass.module_state_traverse */
Py_VISIT(traverse_module_state->__pyx_CommonTypesMetaclassType);

/* CythonFunctionShared.module_state_traverse */
Py_VISIT(traverse_module_state->__pyx_CyFunctionType);

/* #### Code section: module_state_traverse_end ### */
return 0;
}
#endif
/* #### Code section: module_code ### */

/* "gevent/resolver/cares.pyx":186
 * }
 * 
 * cdef _gevent_gai_strerror(code):             # <<<<<<<<<<<<<<
 *     cdef const char* err_str
 *     cdef object result = None
*/

static PyObject *__pyx_f_6gevent_8resolver_5cares__gevent_gai_strerror(PyObject *__pyx_v_code) {
  char const *__pyx_v_err_str;
  PyObject *__pyx_v_result = 0;
  int __pyx_v_system;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12[3];
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_gevent_gai_strerror", 0);

  /* "gevent/resolver/cares.pyx":188
 * cdef _gevent_gai_strerror(code):
 *     cdef const char* err_str
 *     cdef object result = None             # <<<<<<<<<<<<<<
 *     cdef int system
 *     try:
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_result = Py_None;

  /* "gevent/resolver/cares.pyx":190
 *     cdef object result = None
 *     cdef int system
 *     try:             # <<<<<<<<<<<<<<
 *         system = _ares_to_gai_system[code]
 *     except KeyError:
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "gevent/resolver/cares.pyx":191
 *     cdef int system
 *     try:
 *         system = _ares_to_gai_system[code]             # <<<<<<<<<<<<<<
 *     except KeyError:
 *         err_str = cares.ares_strerror(code)
*/
      if (unlikely(__pyx_v_6gevent_8resolver_5cares__ares_to_gai_system == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 191, __pyx_L3_error)
      }
      __pyx_t_4 = __Pyx_PyDict_GetItem(__pyx_v_6gevent_8resolver_5cares__ares_to_gai_system, __pyx_v_code); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 191, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyLong_As_int(__pyx_t_4); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 191, __pyx_L3_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_v_system = __pyx_t_5;

      /* "gevent/resolver/cares.pyx":190
 *     cdef object result = None
 *     cdef int system
 *     try:             # <<<<<<<<<<<<<<
 *         system = _ares_to_gai_system[code]
 *     except KeyError:
*/
    }

    /* "gevent/resolver/cares.pyx":196
 *         result = '%s: %s' % (_ares_errors.get(code) or code, _as_str(err_str))
 *     else:
 *         err_str = cares.gai_strerror(system)             # <<<<<<<<<<<<<<
 *         result = _as_str(err_str)
 *     return result
*/
    /*else:*/ {
      __pyx_v_err_str = gai_strerror(__pyx_v_system);

      /* "gevent/resolver/cares.pyx":197
 *     else:
 *         err_str = cares.gai_strerror(system)
 *         result = _as_str(err_str)             # <<<<<<<<<<<<<<
 *     return result
 * 
*/
      __pyx_t_4 = __pyx_f_6gevent_8resolver_5cares__as_str(__pyx_v_err_str); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 197, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF_SET(__pyx_v_result, __pyx_t_4);
      __pyx_t_4 = 0;
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "gevent/resolver/cares.pyx":192
 *     try:
 *         system = _ares_to_gai_system[code]
 *     except KeyError:             # <<<<<<<<<<<<<<
 *         err_str = cares.ares_strerror(code)
 *         result = '%s: %s' % (_ares_errors.get(code) or code, _as_str(err_str))
*/
    __pyx_t_5 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_KeyError))));
    if (__pyx_t_5) {
      __Pyx_AddTraceback("gevent.resolver.cares._gevent_gai_strerror", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(0, 192, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);

      /* "gevent/resolver/cares.pyx":193
 *         system = _ares_to_gai_system[code]
 *     except KeyError:
 *         err_str = cares.ares_strerror(code)             # <<<<<<<<<<<<<<
 *         result = '%s: %s' % (_ares_errors.get(code) or code, _as_str(err_str))
 *     else:
*/
      __pyx_t_5 = __Pyx_PyLong_As_int(__pyx_v_code); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 193, __pyx_L5_except_error)
      __pyx_v_err_str = ares_strerror(__pyx_t_5);

      /* "gevent/resolver/cares.pyx":194
 *     except KeyError:
 *         err_str = cares.ares_strerror(code)
 *         result = '%s: %s' % (_ares_errors.get(code) or code, _as_str(err_str))             # <<<<<<<<<<<<<<
 *     else:
 *         err_str = cares.gai_strerror(system)
*/
      if (unlikely(__pyx_v_6gevent_8resolver_5cares__ares_errors == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "get");
        __PYX_ERR(0, 194, __pyx_L5_except_error)
      }
      __pyx_t_9 = __Pyx_PyDict_GetItemDefault(__pyx_v_6gevent_8resolver_5cares__ares_errors, __pyx_v_code, Py_None); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 194, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 194, __pyx_L5_except_error)
      if (!__pyx_t_10) {
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else {
        __Pyx_INCREF(__pyx_t_9);
        __pyx_t_8 = __pyx_t_9;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        goto __pyx_L11_bool_binop_done;
      }
      __Pyx_INCREF(__pyx_v_code);
      __pyx_t_8 = __pyx_v_code;
      __pyx_L11_bool_binop_done:;
      __pyx_t_9 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_8), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 194, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __pyx_f_6gevent_8resolver_5cares__as_str(__pyx_v_err_str); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 194, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_11 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_8), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 194, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_12[0] = __pyx_t_9;
      __pyx_t_12[1] = __pyx_mstate_global->__pyx_kp_u_;
      __pyx_t_12[2] = __pyx_t_11;
      __pyx_t_8 = __Pyx_PyUnicode_Join(__pyx_t_12, 3, __Pyx_PyUnicode_GET_LENGTH(__pyx_t_9) + 2 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_11), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_9) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_11));
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 194, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF_SET(__pyx_v_result, __pyx_t_8);
      __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;

    /* "gevent/resolver/cares.pyx":190
 *     cdef object result = None
 *     cdef int system
 *     try:             # <<<<<<<<<<<<<<
 *         system = _ares_to_gai_system[code]
 *     except KeyError:
*/
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    __pyx_L8_try_end:;
  }

  /* "gevent/resolver/cares.pyx":198
 *         err_str = cares.gai_strerror(system)
 *         result = _as_str(err_str)
 *     return result             # <<<<<<<<<<<<<<
 * 
 * cdef object _gevent_gaierror_from_status(int ares_status):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "gevent/resolver/cares.pyx":186
 * }
 * 
 * cdef _gevent_gai_strerror(code):             # <<<<<<<<<<<<<<
 *     cdef const char* err_str
 *     cdef object result = None
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("gevent.resolver.cares._gevent_gai_strerror", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/resolver/cares.pyx":200
 *     return result
 * 
 * cdef object _gevent_gaierror_from_status(int ares_status):             # <<<<<<<<<<<<<<
 *     cdef object code = _ares_to_gai_system.get(ares_status, ares_status)
 *     cdef object message = _gevent_gai_strerror(ares_status)
*/

static PyObject *__pyx_f_6gevent_8resolver_5cares__gevent_gaierror_from_status(int __pyx_v_ares_status) {
  PyObject *__pyx_v_code = 0;
  PyObject *__pyx_v_message = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_gevent_gaierror_from_status", 0);

  /* "gevent/resolver/cares.pyx":201
 * 
 * cdef object _gevent_gaierror_from_status(int ares_status):
 *     cdef object code = _ares_to_gai_system.get(ares_status, ares_status)             # <<<<<<<<<<<<<<
 *     cdef object message = _gevent_gai_strerror(ares_status)
 *     return gaierror(code, message)
*/
  if (unlikely(__pyx_v_6gevent_8resolver_5cares__ares_to_gai_system == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "get");
    __PYX_ERR(0, 201, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyLong_From_int(__pyx_v_ares_status); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyLong_From_int(__pyx_v_ares_status); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyDict_GetItemDefault(__pyx_v_6gevent_8resolver_5cares__ares_to_gai_system, __pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_code = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "gevent/resolver/cares.pyx":202
 * cdef object _gevent_gaierror_from_status(int ares_status):
 *     cdef object code = _ares_to_gai_system.get(ares_status, ares_status)
 *     cdef object message = _gevent_gai_strerror(ares_status)             # <<<<<<<<<<<<<<
 *     return gaierror(code, message)
 * 
*/
  __pyx_t_3 = __Pyx_PyLong_From_int(__pyx_v_ares_status); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 202, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __pyx_f_6gevent_8resolver_5cares__gevent_gai_strerror(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 202, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_message = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "gevent/resolver/cares.pyx":203
 *     cdef object code = _ares_to_gai_system.get(ares_status, ares_status)
 *     cdef object message = _gevent_gai_strerror(ares_status)
 *     return gaierror(code, message)             # <<<<<<<<<<<<<<
 * 
 * cdef dict _ares_to_host_system = {
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_gaierror); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 203, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    assert(__pyx_t_3);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_1);
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_1, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_code, __pyx_v_message};
    __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_1, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 203, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "gevent/resolver/cares.pyx":200
 *     return result
 * 
 * cdef object _gevent_gaierror_from_status(int ares_status):             # <<<<<<<<<<<<<<
 *     cdef object code = _ares_to_gai_system.get(ares_status, ares_status)
 *     cdef object message = _gevent_gai_strerror(ares_status)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("gevent.resolver.cares._gevent_gaierror_from_status", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_code);
  __Pyx_XDECREF(__pyx_v_message);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/resolver/cares.pyx":211
 * }
 * 
 * cdef _gevent_herror_strerror(code):             # <<<<<<<<<<<<<<
 *     cdef const char* err_str
 *     cdef object result = None
*/

static PyObject *__pyx_f_6gevent_8resolver_5cares__gevent_herror_strerror(PyObject *__pyx_v_code) {
  char const *__pyx_v_err_str;
  PyObject *__pyx_v_result = 0;
  int __pyx_v_system;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12[3];
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_gevent_herror_strerror", 0);

  /* "gevent/resolver/cares.pyx":213
 * cdef _gevent_herror_strerror(code):
 *     cdef const char* err_str
 *     cdef object result = None             # <<<<<<<<<<<<<<
 *     cdef int system
 *     try:
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_result = Py_None;

  /* "gevent/resolver/cares.pyx":215
 *     cdef object result = None
 *     cdef int system
 *     try:             # <<<<<<<<<<<<<<
 *         system = _ares_to_host_system[code]
 *     except KeyError:
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "gevent/resolver/cares.pyx":216
 *     cdef int system
 *     try:
 *         system = _ares_to_host_system[code]             # <<<<<<<<<<<<<<
 *     except KeyError:
 *         err_str = cares.ares_strerror(code)
*/
      if (unlikely(__pyx_v_6gevent_8resolver_5cares__ares_to_host_system == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 216, __pyx_L3_error)
      }
      __pyx_t_4 = __Pyx_PyDict_GetItem(__pyx_v_6gevent_8resolver_5cares__ares_to_host_system, __pyx_v_code); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 216, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyLong_As_int(__pyx_t_4); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 216, __pyx_L3_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_v_system = __pyx_t_5;

      /* "gevent/resolver/cares.pyx":215
 *     cdef object result = None
 *     cdef int system
 *     try:             # <<<<<<<<<<<<<<
 *         system = _ares_to_host_system[code]
 *     except KeyError:
*/
    }

    /* "gevent/resolver/cares.pyx":221
 *         result = '%s: %s' % (_ares_errors.get(code) or code, _as_str(err_str))
 *     else:
 *         err_str = cares.hstrerror(system)             # <<<<<<<<<<<<<<
 *         result = _as_str(err_str)
 *     return result
*/
    /*else:*/ {
      __pyx_v_err_str = hstrerror(__pyx_v_system);

      /* "gevent/resolver/cares.pyx":222
 *     else:
 *         err_str = cares.hstrerror(system)
 *         result = _as_str(err_str)             # <<<<<<<<<<<<<<
 *     return result
 * 
*/
      __pyx_t_4 = __pyx_f_6gevent_8resolver_5cares__as_str(__pyx_v_err_str); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 222, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF_SET(__pyx_v_result, __pyx_t_4);
      __pyx_t_4 = 0;
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "gevent/resolver/cares.pyx":217
 *     try:
 *         system = _ares_to_host_system[code]
 *     except KeyError:             # <<<<<<<<<<<<<<
 *         err_str = cares.ares_strerror(code)
 *         result = '%s: %s' % (_ares_errors.get(code) or code, _as_str(err_str))
*/
    __pyx_t_5 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_KeyError))));
    if (__pyx_t_5) {
      __Pyx_AddTraceback("gevent.resolver.cares._gevent_herror_strerror", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(0, 217, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);

      /* "gevent/resolver/cares.pyx":218
 *         system = _ares_to_host_system[code]
 *     except KeyError:
 *         err_str = cares.ares_strerror(code)             # <<<<<<<<<<<<<<
 *         result = '%s: %s' % (_ares_errors.get(code) or code, _as_str(err_str))
 *     else:
*/
      __pyx_t_5 = __Pyx_PyLong_As_int(__pyx_v_code); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 218, __pyx_L5_except_error)
      __pyx_v_err_str = ares_strerror(__pyx_t_5);

      /* "gevent/resolver/cares.pyx":219
 *     except KeyError:
 *         err_str = cares.ares_strerror(code)
 *         result = '%s: %s' % (_ares_errors.get(code) or code, _as_str(err_str))             # <<<<<<<<<<<<<<
 *     else:
 *         err_str = cares.hstrerror(system)
*/
      if (unlikely(__pyx_v_6gevent_8resolver_5cares__ares_errors == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "get");
        __PYX_ERR(0, 219, __pyx_L5_except_error)
      }
      __pyx_t_9 = __Pyx_PyDict_GetItemDefault(__pyx_v_6gevent_8resolver_5cares__ares_errors, __pyx_v_code, Py_None); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 219, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 219, __pyx_L5_except_error)
      if (!__pyx_t_10) {
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else {
        __Pyx_INCREF(__pyx_t_9);
        __pyx_t_8 = __pyx_t_9;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        goto __pyx_L11_bool_binop_done;
      }
      __Pyx_INCREF(__pyx_v_code);
      __pyx_t_8 = __pyx_v_code;
      __pyx_L11_bool_binop_done:;
      __pyx_t_9 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_8), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 219, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __pyx_f_6gevent_8resolver_5cares__as_str(__pyx_v_err_str); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 219, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_11 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_8), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 219, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_12[0] = __pyx_t_9;
      __pyx_t_12[1] = __pyx_mstate_global->__pyx_kp_u_;
      __pyx_t_12[2] = __pyx_t_11;
      __pyx_t_8 = __Pyx_PyUnicode_Join(__pyx_t_12, 3, __Pyx_PyUnicode_GET_LENGTH(__pyx_t_9) + 2 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_11), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_9) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_11));
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 219, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF_SET(__pyx_v_result, __pyx_t_8);
      __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;

    /* "gevent/resolver/cares.pyx":215
 *     cdef object result = None
 *     cdef int system
 *     try:             # <<<<<<<<<<<<<<
 *         system = _ares_to_host_system[code]
 *     except KeyError:
*/
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    __pyx_L8_try_end:;
  }

  /* "gevent/resolver/cares.pyx":223
 *         err_str = cares.hstrerror(system)
 *         result = _as_str(err_str)
 *     return result             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "gevent/resolver/cares.pyx":211
 * }
 * 
 * cdef _gevent_herror_strerror(code):             # <<<<<<<<<<<<<<
 *     cdef const char* err_str
 *     cdef object result = None
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("gevent.resolver.cares._gevent_herror_strerror", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/resolver/cares.pyx":226
 * 
 * 
 * cdef object _gevent_herror_from_status(int ares_status):             # <<<<<<<<<<<<<<
 *     cdef object code = _ares_to_host_system.get(ares_status, ares_status)
 *     cdef object message = _gevent_herror_strerror(ares_status)
*/

static PyObject *__pyx_f_6gevent_8resolver_5cares__gevent_herror_from_status(int __pyx_v_ares_status) {
  PyObject *__pyx_v_code = 0;
  PyObject *__pyx_v_message = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_gevent_herror_from_status", 0);

  /* "gevent/resolver/cares.pyx":227
 * 
 * cdef object _gevent_herror_from_status(int ares_status):
 *     cdef object code = _ares_to_host_system.get(ares_status, ares_status)             # <<<<<<<<<<<<<<
 *     cdef object message = _gevent_herror_strerror(ares_status)
 *     return herror(code, message)
*/
  if (unlikely(__pyx_v_6gevent_8resolver_5cares__ares_to_host_system == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "get");
    __PYX_ERR(0, 227, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyLong_From_int(__pyx_v_ares_status); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyLong_From_int(__pyx_v_ares_status); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyDict_GetItemDefault(__pyx_v_6gevent_8resolver_5cares__ares_to_host_system, __pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_code = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "gevent/resolver/cares.pyx":228
 * cdef object _gevent_herror_from_status(int ares_status):
 *     cdef object code = _ares_to_host_system.get(ares_status, ares_status)
 *     cdef object message = _gevent_herror_strerror(ares_status)             # <<<<<<<<<<<<<<
 *     return herror(code, message)
 * 
*/
  __pyx_t_3 = __Pyx_PyLong_From_int(__pyx_v_ares_status); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __pyx_f_6gevent_8resolver_5cares__gevent_herror_strerror(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_message = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "gevent/resolver/cares.pyx":229
 *     cdef object code = _ares_to_host_system.get(ares_status, ares_status)
 *     cdef object message = _gevent_herror_strerror(ares_status)
 *     return herror(code, message)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_herror); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 229, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    assert(__pyx_t_3);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_1);
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_1, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_code, __pyx_v_message};
    __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_1, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 229, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "gevent/resolver/cares.pyx":226
 * 
 * 
 * cdef object _gevent_herror_from_status(int ares_status):             # <<<<<<<<<<<<<<
 *     cdef object code = _ares_to_host_system.get(ares_status, ares_status)
 *     cdef object message = _gevent_herror_strerror(ares_status)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("gevent.resolver.cares._gevent_herror_from_status", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_code);
  __Pyx_XDECREF(__pyx_v_message);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/resolver/cares.pyx":236
 * 
 * 
 * cdef void gevent_sock_state_callback(void *data, int s, int read, int write):             # <<<<<<<<<<<<<<
 *     if not data:
 *         return
*/

static void __pyx_f_6gevent_8resolver_5cares_gevent_sock_state_callback(void *__pyx_v_data, int __pyx_v_s, int __pyx_v_read, int __pyx_v_write) {
  struct __pyx_obj_6gevent_8resolver_5cares_channel *__pyx_v_ch = 0;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("gevent_sock_state_callback", 0);

  /* "gevent/resolver/cares.pyx":237
 * 
 * cdef void gevent_sock_state_callback(void *data, int s, int read, int write):
 *     if not data:             # <<<<<<<<<<<<<<
 *         return
 *     cdef channel ch = <channel>data
*/
  __pyx_t_1 = (!(__pyx_v_data != 0));
  if (__pyx_t_1) {

    /* "gevent/resolver/cares.pyx":238
 * cdef void gevent_sock_state_callback(void *data, int s, int read, int write):
 *     if not data:
 *         return             # <<<<<<<<<<<<<<
 *     cdef channel ch = <channel>data
 *     ch._sock_state_callback(s, read, write)
*/
    goto __pyx_L0;

    /* "gevent/resolver/cares.pyx":237
 * 
 * cdef void gevent_sock_state_callback(void *data, int s, int read, int write):
 *     if not data:             # <<<<<<<<<<<<<<
 *         return
 *     cdef channel ch = <channel>data
*/
  }

  /* "gevent/resolver/cares.pyx":239
 *     if not data:
 *         return
 *     cdef channel ch = <channel>data             # <<<<<<<<<<<<<<
 *     ch._sock_state_callback(s, read, write)
 * 
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_data);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_v_ch = ((struct __pyx_obj_6gevent_8resolver_5cares_channel *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "gevent/resolver/cares.pyx":240
 *         return
 *     cdef channel ch = <channel>data
 *     ch._sock_state_callback(s, read, write)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_2 = ((struct __pyx_vtabstruct_6gevent_8resolver_5cares_channel *)__pyx_v_ch->__pyx_vtab)->_sock_state_callback(__pyx_v_ch, __pyx_v_s, __pyx_v_read, __pyx_v_write); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "gevent/resolver/cares.pyx":236
 * 
 * 
 * cdef void gevent_sock_state_callback(void *data, int s, int read, int write):             # <<<<<<<<<<<<<<
 *     if not data:
 *         return
*/

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("gevent.resolver.cares.gevent_sock_state_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_ch);
  __Pyx_RefNannyFinishContext();
}

/* "gevent/resolver/cares.pyx":247
 *     cdef public object exception
 * 
 *     def __init__(self, object value=None, object exception=None):             # <<<<<<<<<<<<<<
 *         self.value = value
 *         self.exception = exception
*/

/* Python wrapper */
static int __pyx_pw_6gevent_8resolver_5cares_6Result_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6gevent_8resolver_5cares_6Result_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_v_exception = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_value,&__pyx_mstate_global->__pyx_n_u_exception,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 247, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 247, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 247, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__init__", 0) < (0)) __PYX_ERR(0, 247, __pyx_L3_error)
      if (!values[0]) values[0] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
    } else {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 247, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 247, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[0]) values[0] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_value = values[0];
    __pyx_v_exception = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 0, 2, __pyx_nargs); __PYX_ERR(0, 247, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("gevent.resolver.cares.Result.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6gevent_8resolver_5cares_6Result___init__(((struct __pyx_obj_6gevent_8resolver_5cares_Result *)__pyx_v_self), __pyx_v_value, __pyx_v_exception);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6gevent_8resolver_5cares_6Result___init__(struct __pyx_obj_6gevent_8resolver_5cares_Result *__pyx_v_self, PyObject *__pyx_v_value, PyObject *__pyx_v_exception) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "gevent/resolver/cares.pyx":248
 * 
 *     def __init__(self, object value=None, object exception=None):
 *         self.value = value             # <<<<<<<<<<<<<<
 *         self.exception = exception
 * 
*/
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->value);
  __Pyx_DECREF(__pyx_v_self->value);
  __pyx_v_self->value = __pyx_v_value;

  /* "gevent/resolver/cares.pyx":249
 *     def __init__(self, object value=None, object exception=None):
 *         self.value = value
 *         self.exception = exception             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
*/
  __Pyx_INCREF(__pyx_v_exception);
  __Pyx_GIVEREF(__pyx_v_exception);
  __Pyx_GOTREF(__pyx_v_self->exception);
  __Pyx_DECREF(__pyx_v_self->exception);
  __pyx_v_self->exception = __pyx_v_exception;

  /* "gevent/resolver/cares.pyx":247
 *     cdef public object exception
 * 
 *     def __init__(self, object value=None, object exception=None):             # <<<<<<<<<<<<<<
 *         self.value = value
 *         self.exception = exception
*/

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/resolver/cares.pyx":251
 *         self.exception = exception
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         if self.exception is None:
 *             return '%s(%r)' % (self.__class__.__name__, self.value)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_8resolver_5cares_6Result_3__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6gevent_8resolver_5cares_6Result_3__repr__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_8resolver_5cares_6Result_2__repr__(((struct __pyx_obj_6gevent_8resolver_5cares_Result *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_8resolver_5cares_6Result_2__repr__(struct __pyx_obj_6gevent_8resolver_5cares_Result *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4[4];
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6[6];
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "gevent/resolver/cares.pyx":252
 * 
 *     def __repr__(self):
 *         if self.exception is None:             # <<<<<<<<<<<<<<
 *             return '%s(%r)' % (self.__class__.__name__, self.value)
 *         elif self.value is None:
*/
  __pyx_t_1 = (__pyx_v_self->exception == Py_None);
  if (__pyx_t_1) {

    /* "gevent/resolver/cares.pyx":253
 *     def __repr__(self):
 *         if self.exception is None:
 *             return '%s(%r)' % (self.__class__.__name__, self.value)             # <<<<<<<<<<<<<<
 *         elif self.value is None:
 *             return '%s(exception=%r)' % (self.__class__.__name__, self.exception)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_class); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 253, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 253, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_3), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 253, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_self->value), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 253, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4[0] = __pyx_t_2;
    __pyx_t_4[1] = __pyx_mstate_global->__pyx_kp_u__2;
    __pyx_t_4[2] = __pyx_t_3;
    __pyx_t_4[3] = __pyx_mstate_global->__pyx_kp_u__3;
    __pyx_t_5 = __Pyx_PyUnicode_Join(__pyx_t_4, 4, __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2) + 1 * 2 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3));
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 253, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "gevent/resolver/cares.pyx":252
 * 
 *     def __repr__(self):
 *         if self.exception is None:             # <<<<<<<<<<<<<<
 *             return '%s(%r)' % (self.__class__.__name__, self.value)
 *         elif self.value is None:
*/
  }

  /* "gevent/resolver/cares.pyx":254
 *         if self.exception is None:
 *             return '%s(%r)' % (self.__class__.__name__, self.value)
 *         elif self.value is None:             # <<<<<<<<<<<<<<
 *             return '%s(exception=%r)' % (self.__class__.__name__, self.exception)
 *         else:
*/
  __pyx_t_1 = (__pyx_v_self->value == Py_None);
  if (__pyx_t_1) {

    /* "gevent/resolver/cares.pyx":255
 *             return '%s(%r)' % (self.__class__.__name__, self.value)
 *         elif self.value is None:
 *             return '%s(exception=%r)' % (self.__class__.__name__, self.exception)             # <<<<<<<<<<<<<<
 *         else:
 *             return '%s(value=%r, exception=%r)' % (self.__class__.__name__, self.value, self.exception)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_class); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 255, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 255, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_3), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 255, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_self->exception), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 255, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4[0] = __pyx_t_5;
    __pyx_t_4[1] = __pyx_mstate_global->__pyx_kp_u_exception_2;
    __pyx_t_4[2] = __pyx_t_3;
    __pyx_t_4[3] = __pyx_mstate_global->__pyx_kp_u__3;
    __pyx_t_2 = __Pyx_PyUnicode_Join(__pyx_t_4, 4, __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5) + 11 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3) + 1, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3));
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 255, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "gevent/resolver/cares.pyx":254
 *         if self.exception is None:
 *             return '%s(%r)' % (self.__class__.__name__, self.value)
 *         elif self.value is None:             # <<<<<<<<<<<<<<
 *             return '%s(exception=%r)' % (self.__class__.__name__, self.exception)
 *         else:
*/
  }

  /* "gevent/resolver/cares.pyx":257
 *             return '%s(exception=%r)' % (self.__class__.__name__, self.exception)
 *         else:
 *             return '%s(value=%r, exception=%r)' % (self.__class__.__name__, self.value, self.exception)             # <<<<<<<<<<<<<<
 *         # add repr_recursive precaution
 * 
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_class); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 257, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 257, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_3), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 257, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_self->value), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 257, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_self->exception), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 257, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6[0] = __pyx_t_2;
    __pyx_t_6[1] = __pyx_mstate_global->__pyx_kp_u_value_2;
    __pyx_t_6[2] = __pyx_t_3;
    __pyx_t_6[3] = __pyx_mstate_global->__pyx_kp_u_exception_3;
    __pyx_t_6[4] = __pyx_t_5;
    __pyx_t_6[5] = __pyx_mstate_global->__pyx_kp_u__3;
    __pyx_t_7 = __Pyx_PyUnicode_Join(__pyx_t_6, 6, __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2) + 7 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3) + 12 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5) + 1, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5));
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 257, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_r = __pyx_t_7;
    __pyx_t_7 = 0;
    goto __pyx_L0;
  }

  /* "gevent/resolver/cares.pyx":251
 *         self.exception = exception
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         if self.exception is None:
 *             return '%s(%r)' % (self.__class__.__name__, self.value)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("gevent.resolver.cares.Result.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/resolver/cares.pyx":260
 *         # add repr_recursive precaution
 * 
 *     def successful(self):             # <<<<<<<<<<<<<<
 *         return self.exception is None
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_8resolver_5cares_6Result_5successful(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_6gevent_8resolver_5cares_6Result_5successful = {"successful", (PyCFunction)__pyx_pw_6gevent_8resolver_5cares_6Result_5successful, METH_NOARGS, 0};
static PyObject *__pyx_pw_6gevent_8resolver_5cares_6Result_5successful(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("successful (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_8resolver_5cares_6Result_4successful(((struct __pyx_obj_6gevent_8resolver_5cares_Result *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_8resolver_5cares_6Result_4successful(struct __pyx_obj_6gevent_8resolver_5cares_Result *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("successful", 0);

  /* "gevent/resolver/cares.pyx":261
 * 
 *     def successful(self):
 *         return self.exception is None             # <<<<<<<<<<<<<<
 * 
 *     def get(self):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = (__pyx_v_self->exception == Py_None);
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 261, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "gevent/resolver/cares.pyx":260
 *         # add repr_recursive precaution
 * 
 *     def successful(self):             # <<<<<<<<<<<<<<
 *         return self.exception is None
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("gevent.resolver.cares.Result.successful", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/resolver/cares.pyx":263
 *         return self.exception is None
 * 
 *     def get(self):             # <<<<<<<<<<<<<<
 *         if self.exception is not None:
 *             raise self.exception
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_8resolver_5cares_6Result_7get(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_6gevent_8resolver_5cares_6Result_7get = {"get", (PyCFunction)__pyx_pw_6gevent_8resolver_5cares_6Result_7get, METH_NOARGS, 0};
static PyObject *__pyx_pw_6gevent_8resolver_5cares_6Result_7get(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_8resolver_5cares_6Result_6get(((struct __pyx_obj_6gevent_8resolver_5cares_Result *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_8resolver_5cares_6Result_6get(struct __pyx_obj_6gevent_8resolver_5cares_Result *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get", 0);

  /* "gevent/resolver/cares.pyx":264
 * 
 *     def get(self):
 *         if self.exception is not None:             # <<<<<<<<<<<<<<
 *             raise self.exception
 *         return self.value
*/
  __pyx_t_1 = (__pyx_v_self->exception != Py_None);
  if (unlikely(__pyx_t_1)) {

    /* "gevent/resolver/cares.pyx":265
 *     def get(self):
 *         if self.exception is not None:
 *             raise self.exception             # <<<<<<<<<<<<<<
 *         return self.value
 * 
*/
    __Pyx_Raise(__pyx_v_self->exception, 0, 0, 0);
    __PYX_ERR(0, 265, __pyx_L1_error)

    /* "gevent/resolver/cares.pyx":264
 * 
 *     def get(self):
 *         if self.exception is not None:             # <<<<<<<<<<<<<<
 *             raise self.exception
 *         return self.value
*/
  }

  /* "gevent/resolver/cares.pyx":266
 *         if self.exception is not None:
 *             raise self.exception
 *         return self.value             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->value);
  __pyx_r = __pyx_v_self->value;
  goto __pyx_L0;

  /* "gevent/resolver/cares.pyx":263
 *         return self.exception is None
 * 
 *     def get(self):             # <<<<<<<<<<<<<<
 *         if self.exception is not None:
 *             raise self.exception
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("gevent.resolver.cares.Result.get", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/resolver/cares.pyx":244
 * 
 * cdef class Result(object):
 *     cdef public object value             # <<<<<<<<<<<<<<
 *     cdef public object exception
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_8resolver_5cares_6Result_5value_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6gevent_8resolver_5cares_6Result_5value_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_8resolver_5cares_6Result_5value___get__(((struct __pyx_obj_6gevent_8resolver_5cares_Result *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_8resolver_5cares_6Result_5value___get__(struct __pyx_obj_6gevent_8resolver_5cares_Result *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->value);
  __pyx_r = __pyx_v_self->value;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6gevent_8resolver_5cares_6Result_5value_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6gevent_8resolver_5cares_6Result_5value_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_8resolver_5cares_6Result_5value_2__set__(((struct __pyx_obj_6gevent_8resolver_5cares_Result *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6gevent_8resolver_5cares_6Result_5value_2__set__(struct __pyx_obj_6gevent_8resolver_5cares_Result *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->value);
  __Pyx_DECREF(__pyx_v_self->value);
  __pyx_v_self->value = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6gevent_8resolver_5cares_6Result_5value_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6gevent_8resolver_5cares_6Result_5value_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_8resolver_5cares_6Result_5value_4__del__(((struct __pyx_obj_6gevent_8resolver_5cares_Result *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6gevent_8resolver_5cares_6Result_5value_4__del__(struct __pyx_obj_6gevent_8resolver_5cares_Result *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->value);
  __Pyx_DECREF(__pyx_v_self->value);
  __pyx_v_self->value = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/resolver/cares.pyx":245
 * cdef class Result(object):
 *     cdef public object value
 *     cdef public object exception             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, object value=None, object exception=None):
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_8resolver_5cares_6Result_9exception_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6gevent_8resolver_5cares_6Result_9exception_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_8resolver_5cares_6Result_9exception___get__(((struct __pyx_obj_6gevent_8resolver_5cares_Result *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_8resolver_5cares_6Result_9exception___get__(struct __pyx_obj_6gevent_8resolver_5cares_Result *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->exception);
  __pyx_r = __pyx_v_self->exception;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6gevent_8resolver_5cares_6Result_9exception_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6gevent_8resolver_5cares_6Result_9exception_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_8resolver_5cares_6Result_9exception_2__set__(((struct __pyx_obj_6gevent_8resolver_5cares_Result *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6gevent_8resolver_5cares_6Result_9exception_2__set__(struct __pyx_obj_6gevent_8resolver_5cares_Result *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->exception);
  __Pyx_DECREF(__pyx_v_self->exception);
  __pyx_v_self->exception = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6gevent_8resolver_5cares_6Result_9exception_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6gevent_8resolver_5cares_6Result_9exception_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_8resolver_5cares_6Result_9exception_4__del__(((struct __pyx_obj_6gevent_8resolver_5cares_Result *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6gevent_8resolver_5cares_6Result_9exception_4__del__(struct __pyx_obj_6gevent_8resolver_5cares_Result *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->exception);
  __Pyx_DECREF(__pyx_v_self->exception);
  __pyx_v_self->exception = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/resolver/cares.pyx":271
 * class ares_host_result(tuple):
 * 
 *     def __new__(cls, family, iterable):             # <<<<<<<<<<<<<<
 *         cdef object self = tuple.__new__(cls, iterable)
 *         self.family = family
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_8resolver_5cares_16ares_host_result_1__new__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6gevent_8resolver_5cares_16ares_host_result_1__new__ = {"__new__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6gevent_8resolver_5cares_16ares_host_result_1__new__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6gevent_8resolver_5cares_16ares_host_result_1__new__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_cls = 0;
  PyObject *__pyx_v_family = 0;
  PyObject *__pyx_v_iterable = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__new__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_cls,&__pyx_mstate_global->__pyx_n_u_family,&__pyx_mstate_global->__pyx_n_u_iterable,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 271, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 271, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 271, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 271, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__new__", 0) < (0)) __PYX_ERR(0, 271, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__new__", 1, 3, 3, i); __PYX_ERR(0, 271, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 271, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 271, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 271, __pyx_L3_error)
    }
    __pyx_v_cls = values[0];
    __pyx_v_family = values[1];
    __pyx_v_iterable = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__new__", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 271, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("gevent.resolver.cares.ares_host_result.__new__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6gevent_8resolver_5cares_16ares_host_result___new__(__pyx_self, __pyx_v_cls, __pyx_v_family, __pyx_v_iterable);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_8resolver_5cares_16ares_host_result___new__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls, PyObject *__pyx_v_family, PyObject *__pyx_v_iterable) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__new__", 0);

  /* "gevent/resolver/cares.pyx":272
 * 
 *     def __new__(cls, family, iterable):
 *         cdef object self = tuple.__new__(cls, iterable)             # <<<<<<<<<<<<<<
 *         self.family = family
 *         return self
*/
  __pyx_t_2 = ((PyObject *)(&PyTuple_Type));
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_cls, __pyx_v_iterable};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_new, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 272, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_self = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "gevent/resolver/cares.pyx":273
 *     def __new__(cls, family, iterable):
 *         cdef object self = tuple.__new__(cls, iterable)
 *         self.family = family             # <<<<<<<<<<<<<<
 *         return self
 * 
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_family, __pyx_v_family) < (0)) __PYX_ERR(0, 273, __pyx_L1_error)

  /* "gevent/resolver/cares.pyx":274
 *         cdef object self = tuple.__new__(cls, iterable)
 *         self.family = family
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def __getnewargs__(self):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "gevent/resolver/cares.pyx":271
 * class ares_host_result(tuple):
 * 
 *     def __new__(cls, family, iterable):             # <<<<<<<<<<<<<<
 *         cdef object self = tuple.__new__(cls, iterable)
 *         self.family = family
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("gevent.resolver.cares.ares_host_result.__new__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_self);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/resolver/cares.pyx":276
 *         return self
 * 
 *     def __getnewargs__(self):             # <<<<<<<<<<<<<<
 *         return (self.family, tuple(self))
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_8resolver_5cares_16ares_host_result_3__getnewargs__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_6gevent_8resolver_5cares_16ares_host_result_3__getnewargs__ = {"__getnewargs__", (PyCFunction)__pyx_pw_6gevent_8resolver_5cares_16ares_host_result_3__getnewargs__, METH_O, 0};
static PyObject *__pyx_pw_6gevent_8resolver_5cares_16ares_host_result_3__getnewargs__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getnewargs__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_8resolver_5cares_16ares_host_result_2__getnewargs__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_8resolver_5cares_16ares_host_result_2__getnewargs__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getnewargs__", 0);

  /* "gevent/resolver/cares.pyx":277
 * 
 *     def __getnewargs__(self):
 *         return (self.family, tuple(self))             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_family); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 277, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PySequence_Tuple(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 277, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 277, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1) != (0)) __PYX_ERR(0, 277, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_2) != (0)) __PYX_ERR(0, 277, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "gevent/resolver/cares.pyx":276
 *         return self
 * 
 *     def __getnewargs__(self):             # <<<<<<<<<<<<<<
 *         return (self.family, tuple(self))
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("gevent.resolver.cares.ares_host_result.__getnewargs__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/resolver/cares.pyx":280
 * 
 * 
 * cdef list _parse_h_aliases(hostent* host):             # <<<<<<<<<<<<<<
 *     cdef list result = []
 *     cdef char** aliases = host.h_aliases
*/

static PyObject *__pyx_f_6gevent_8resolver_5cares__parse_h_aliases(struct hostent *__pyx_v_host) {
  PyObject *__pyx_v_result = 0;
  char **__pyx_v_aliases;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  char **__pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_parse_h_aliases", 0);

  /* "gevent/resolver/cares.pyx":281
 * 
 * cdef list _parse_h_aliases(hostent* host):
 *     cdef list result = []             # <<<<<<<<<<<<<<
 *     cdef char** aliases = host.h_aliases
 * 
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 281, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_result = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "gevent/resolver/cares.pyx":282
 * cdef list _parse_h_aliases(hostent* host):
 *     cdef list result = []
 *     cdef char** aliases = host.h_aliases             # <<<<<<<<<<<<<<
 * 
 *     if not aliases or not aliases[0]:
*/
  __pyx_t_2 = __pyx_v_host->h_aliases;
  __pyx_v_aliases = __pyx_t_2;

  /* "gevent/resolver/cares.pyx":284
 *     cdef char** aliases = host.h_aliases
 * 
 *     if not aliases or not aliases[0]:             # <<<<<<<<<<<<<<
 *         return result
 * 
*/
  __pyx_t_4 = (!(__pyx_v_aliases != 0));
  if (!__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = (!((__pyx_v_aliases[0]) != 0));
  __pyx_t_3 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_3) {

    /* "gevent/resolver/cares.pyx":285
 * 
 *     if not aliases or not aliases[0]:
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     while aliases[0]: # *aliases
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_result);
    __pyx_r = __pyx_v_result;
    goto __pyx_L0;

    /* "gevent/resolver/cares.pyx":284
 *     cdef char** aliases = host.h_aliases
 * 
 *     if not aliases or not aliases[0]:             # <<<<<<<<<<<<<<
 *         return result
 * 
*/
  }

  /* "gevent/resolver/cares.pyx":287
 *         return result
 * 
 *     while aliases[0]: # *aliases             # <<<<<<<<<<<<<<
 *         # The old C version of this excluded an alias if
 *         # it matched the host name. I don't think the stdlib does that?
*/
  while (1) {
    __pyx_t_3 = ((__pyx_v_aliases[0]) != 0);
    if (!__pyx_t_3) break;

    /* "gevent/resolver/cares.pyx":290
 *         # The old C version of this excluded an alias if
 *         # it matched the host name. I don't think the stdlib does that?
 *         result.append(_as_str(aliases[0]))             # <<<<<<<<<<<<<<
 *         aliases += 1
 *     return result
*/
    __pyx_t_1 = __pyx_f_6gevent_8resolver_5cares__as_str((__pyx_v_aliases[0])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 290, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyList_Append(__pyx_v_result, __pyx_t_1); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 290, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "gevent/resolver/cares.pyx":291
 *         # it matched the host name. I don't think the stdlib does that?
 *         result.append(_as_str(aliases[0]))
 *         aliases += 1             # <<<<<<<<<<<<<<
 *     return result
 * 
*/
    __pyx_v_aliases = (__pyx_v_aliases + 1);
  }

  /* "gevent/resolver/cares.pyx":292
 *         result.append(_as_str(aliases[0]))
 *         aliases += 1
 *     return result             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "gevent/resolver/cares.pyx":280
 * 
 * 
 * cdef list _parse_h_aliases(hostent* host):             # <<<<<<<<<<<<<<
 *     cdef list result = []
 *     cdef char** aliases = host.h_aliases
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent.resolver.cares._parse_h_aliases", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/resolver/cares.pyx":295
 * 
 * 
 * cdef list _parse_h_addr_list(hostent* host):             # <<<<<<<<<<<<<<
 *     cdef list result = []
 *     cdef char** addr_list = host.h_addr_list
*/

static PyObject *__pyx_f_6gevent_8resolver_5cares__parse_h_addr_list(struct hostent *__pyx_v_host) {
  PyObject *__pyx_v_result = 0;
  char **__pyx_v_addr_list;
  CYTHON_UNUSED int __pyx_v_addr_type;
  char __pyx_v_tmpbuf[46];
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  char **__pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  size_t __pyx_t_9;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_parse_h_addr_list", 0);

  /* "gevent/resolver/cares.pyx":296
 * 
 * cdef list _parse_h_addr_list(hostent* host):
 *     cdef list result = []             # <<<<<<<<<<<<<<
 *     cdef char** addr_list = host.h_addr_list
 *     cdef int addr_type = host.h_addrtype
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_result = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "gevent/resolver/cares.pyx":297
 * cdef list _parse_h_addr_list(hostent* host):
 *     cdef list result = []
 *     cdef char** addr_list = host.h_addr_list             # <<<<<<<<<<<<<<
 *     cdef int addr_type = host.h_addrtype
 *     # INET6_ADDRSTRLEN is 46, but we can't use that named constant
*/
  __pyx_t_2 = __pyx_v_host->h_addr_list;
  __pyx_v_addr_list = __pyx_t_2;

  /* "gevent/resolver/cares.pyx":298
 *     cdef list result = []
 *     cdef char** addr_list = host.h_addr_list
 *     cdef int addr_type = host.h_addrtype             # <<<<<<<<<<<<<<
 *     # INET6_ADDRSTRLEN is 46, but we can't use that named constant
 *     # here; cython doesn't like it.
*/
  __pyx_t_3 = __pyx_v_host->h_addrtype;
  __pyx_v_addr_type = __pyx_t_3;

  /* "gevent/resolver/cares.pyx":303
 *     cdef char tmpbuf[46]
 * 
 *     if not addr_list or not addr_list[0]:             # <<<<<<<<<<<<<<
 *         return result
 * 
*/
  __pyx_t_5 = (!(__pyx_v_addr_list != 0));
  if (!__pyx_t_5) {
  } else {
    __pyx_t_4 = __pyx_t_5;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = (!((__pyx_v_addr_list[0]) != 0));
  __pyx_t_4 = __pyx_t_5;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_4) {

    /* "gevent/resolver/cares.pyx":304
 * 
 *     if not addr_list or not addr_list[0]:
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     while addr_list[0]:
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_result);
    __pyx_r = __pyx_v_result;
    goto __pyx_L0;

    /* "gevent/resolver/cares.pyx":303
 *     cdef char tmpbuf[46]
 * 
 *     if not addr_list or not addr_list[0]:             # <<<<<<<<<<<<<<
 *         return result
 * 
*/
  }

  /* "gevent/resolver/cares.pyx":306
 *         return result
 * 
 *     while addr_list[0]:             # <<<<<<<<<<<<<<
 *         if not cares.ares_inet_ntop(host.h_addrtype, addr_list[0], tmpbuf, INET6_ADDRSTRLEN):
 *             raise _socket.error("Failed in ares_inet_ntop")
*/
  while (1) {
    __pyx_t_4 = ((__pyx_v_addr_list[0]) != 0);
    if (!__pyx_t_4) break;

    /* "gevent/resolver/cares.pyx":307
 * 
 *     while addr_list[0]:
 *         if not cares.ares_inet_ntop(host.h_addrtype, addr_list[0], tmpbuf, INET6_ADDRSTRLEN):             # <<<<<<<<<<<<<<
 *             raise _socket.error("Failed in ares_inet_ntop")
 * 
*/
    __pyx_t_4 = (!(ares_inet_ntop(__pyx_v_host->h_addrtype, (__pyx_v_addr_list[0]), __pyx_v_tmpbuf, INET6_ADDRSTRLEN) != 0));
    if (unlikely(__pyx_t_4)) {

      /* "gevent/resolver/cares.pyx":308
 *     while addr_list[0]:
 *         if not cares.ares_inet_ntop(host.h_addrtype, addr_list[0], tmpbuf, INET6_ADDRSTRLEN):
 *             raise _socket.error("Failed in ares_inet_ntop")             # <<<<<<<<<<<<<<
 * 
 *         result.append(_as_str(tmpbuf))
*/
      __pyx_t_6 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_socket); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 308, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_error); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 308, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_9 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
        assert(__pyx_t_6);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_8, __pyx__function);
        __pyx_t_9 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_mstate_global->__pyx_kp_u_Failed_in_ares_inet_ntop};
        __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_8, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (__pyx_t_9*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 308, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(0, 308, __pyx_L1_error)

      /* "gevent/resolver/cares.pyx":307
 * 
 *     while addr_list[0]:
 *         if not cares.ares_inet_ntop(host.h_addrtype, addr_list[0], tmpbuf, INET6_ADDRSTRLEN):             # <<<<<<<<<<<<<<
 *             raise _socket.error("Failed in ares_inet_ntop")
 * 
*/
    }

    /* "gevent/resolver/cares.pyx":310
 *             raise _socket.error("Failed in ares_inet_ntop")
 * 
 *         result.append(_as_str(tmpbuf))             # <<<<<<<<<<<<<<
 *         addr_list += 1
 * 
*/
    __pyx_t_1 = __pyx_f_6gevent_8resolver_5cares__as_str(__pyx_v_tmpbuf); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 310, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_10 = __Pyx_PyList_Append(__pyx_v_result, __pyx_t_1); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 310, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "gevent/resolver/cares.pyx":311
 * 
 *         result.append(_as_str(tmpbuf))
 *         addr_list += 1             # <<<<<<<<<<<<<<
 * 
 *     return result
*/
    __pyx_v_addr_list = (__pyx_v_addr_list + 1);
  }

  /* "gevent/resolver/cares.pyx":313
 *         addr_list += 1
 * 
 *     return result             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "gevent/resolver/cares.pyx":295
 * 
 * 
 * cdef list _parse_h_addr_list(hostent* host):             # <<<<<<<<<<<<<<
 *     cdef list result = []
 *     cdef char** addr_list = host.h_addr_list
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("gevent.resolver.cares._parse_h_addr_list", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/resolver/cares.pyx":316
 * 
 * 
 * cdef object _as_str(const char* val):             # <<<<<<<<<<<<<<
 *     if not val:
 *         return None
*/

static PyObject *__pyx_f_6gevent_8resolver_5cares__as_str(char const *__pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_as_str", 0);

  /* "gevent/resolver/cares.pyx":317
 * 
 * cdef object _as_str(const char* val):
 *     if not val:             # <<<<<<<<<<<<<<
 *         return None
 *     return val.decode('utf-8')
*/
  __pyx_t_1 = (!(__pyx_v_val != 0));
  if (__pyx_t_1) {

    /* "gevent/resolver/cares.pyx":318
 * cdef object _as_str(const char* val):
 *     if not val:
 *         return None             # <<<<<<<<<<<<<<
 *     return val.decode('utf-8')
 * 
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "gevent/resolver/cares.pyx":317
 * 
 * cdef object _as_str(const char* val):
 *     if not val:             # <<<<<<<<<<<<<<
 *         return None
 *     return val.decode('utf-8')
*/
  }

  /* "gevent/resolver/cares.pyx":319
 *     if not val:
 *         return None
 *     return val.decode('utf-8')             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_ssize_strlen(__pyx_v_val); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(0, 319, __pyx_L1_error)
  __pyx_t_3 = __Pyx_decode_c_string(__pyx_v_val, 0, __pyx_t_2, NULL, NULL, PyUnicode_DecodeUTF8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 319, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "gevent/resolver/cares.pyx":316
 * 
 * 
 * cdef object _as_str(const char* val):             # <<<<<<<<<<<<<<
 *     if not val:
 *         return None
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("gevent.resolver.cares._as_str", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/resolver/cares.pyx":322
 * 
 * 
 * cdef void gevent_ares_nameinfo_callback(void *arg, int status, int timeouts, char *c_node, char *c_service):             # <<<<<<<<<<<<<<
 *     cdef channel channel
 *     cdef object callback
*/

static void __pyx_f_6gevent_8resolver_5cares_gevent_ares_nameinfo_callback(void *__pyx_v_arg, int __pyx_v_status, CYTHON_UNUSED int __pyx_v_timeouts, char *__pyx_v_c_node, char *__pyx_v_c_service) {
  struct __pyx_obj_6gevent_8resolver_5cares_channel *__pyx_v_channel = 0;
  PyObject *__pyx_v_callback = 0;
  PyObject *__pyx_v_node = 0;
  PyObject *__pyx_v_service = 0;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  size_t __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("gevent_ares_nameinfo_callback", 0);

  /* "gevent/resolver/cares.pyx":325
 *     cdef channel channel
 *     cdef object callback
 *     channel, callback = <tuple>arg             # <<<<<<<<<<<<<<
 *     Py_DECREF(<tuple>arg)
 *     cdef object node
*/
  __pyx_t_1 = ((PyObject *)__pyx_v_arg);
  __Pyx_INCREF(__pyx_t_1);
  if (likely(__pyx_t_1 != Py_None)) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 325, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1);
    __Pyx_INCREF(__pyx_t_3);
    #else
    __pyx_t_2 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 325, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 325, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(0, 325, __pyx_L1_error)
  }
  if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_mstate_global->__pyx_ptype_6gevent_8resolver_5cares_channel))))) __PYX_ERR(0, 325, __pyx_L1_error)
  __pyx_v_channel = ((struct __pyx_obj_6gevent_8resolver_5cares_channel *)__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_v_callback = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "gevent/resolver/cares.pyx":326
 *     cdef object callback
 *     channel, callback = <tuple>arg
 *     Py_DECREF(<tuple>arg)             # <<<<<<<<<<<<<<
 *     cdef object node
 *     cdef object service
*/
  Py_DECREF(((PyObject *)__pyx_v_arg));

  /* "gevent/resolver/cares.pyx":329
 *     cdef object node
 *     cdef object service
 *     try:             # <<<<<<<<<<<<<<
 *         if status:
 *             callback(Result(None, _gevent_gaierror_from_status(status)))
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    /*try:*/ {

      /* "gevent/resolver/cares.pyx":330
 *     cdef object service
 *     try:
 *         if status:             # <<<<<<<<<<<<<<
 *             callback(Result(None, _gevent_gaierror_from_status(status)))
 *         else:
*/
      __pyx_t_7 = (__pyx_v_status != 0);
      if (__pyx_t_7) {

        /* "gevent/resolver/cares.pyx":331
 *     try:
 *         if status:
 *             callback(Result(None, _gevent_gaierror_from_status(status)))             # <<<<<<<<<<<<<<
 *         else:
 *             node = _as_str(c_node)
*/
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_v_callback);
        __pyx_t_2 = __pyx_v_callback; 
        __pyx_t_9 = NULL;
        __pyx_t_10 = __pyx_f_6gevent_8resolver_5cares__gevent_gaierror_from_status(__pyx_v_status); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 331, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_11 = 1;
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_9, Py_None, __pyx_t_10};
          __pyx_t_8 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6gevent_8resolver_5cares_Result, __pyx_callargs+__pyx_t_11, (3-__pyx_t_11) | (__pyx_t_11*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 331, __pyx_L3_error)
          __Pyx_GOTREF((PyObject *)__pyx_t_8);
        }
        __pyx_t_11 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_2))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
          __pyx_t_11 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, ((PyObject *)__pyx_t_8)};
          __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_11, (2-__pyx_t_11) | (__pyx_t_11*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF((PyObject *)__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 331, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "gevent/resolver/cares.pyx":330
 *     cdef object service
 *     try:
 *         if status:             # <<<<<<<<<<<<<<
 *             callback(Result(None, _gevent_gaierror_from_status(status)))
 *         else:
*/
        goto __pyx_L9;
      }

      /* "gevent/resolver/cares.pyx":333
 *             callback(Result(None, _gevent_gaierror_from_status(status)))
 *         else:
 *             node = _as_str(c_node)             # <<<<<<<<<<<<<<
 *             service = _as_str(c_service)
 *             callback(Result((node, service)))
*/
      /*else*/ {
        __pyx_t_1 = __pyx_f_6gevent_8resolver_5cares__as_str(__pyx_v_c_node); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 333, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_v_node = __pyx_t_1;
        __pyx_t_1 = 0;

        /* "gevent/resolver/cares.pyx":334
 *         else:
 *             node = _as_str(c_node)
 *             service = _as_str(c_service)             # <<<<<<<<<<<<<<
 *             callback(Result((node, service)))
 *     except:
*/
        __pyx_t_1 = __pyx_f_6gevent_8resolver_5cares__as_str(__pyx_v_c_service); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 334, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_v_service = __pyx_t_1;
        __pyx_t_1 = 0;

        /* "gevent/resolver/cares.pyx":335
 *             node = _as_str(c_node)
 *             service = _as_str(c_service)
 *             callback(Result((node, service)))             # <<<<<<<<<<<<<<
 *     except:
 *         channel.loop.handle_error(callback, *sys.exc_info())
*/
        __pyx_t_2 = NULL;
        __Pyx_INCREF(__pyx_v_callback);
        __pyx_t_8 = __pyx_v_callback; 
        __pyx_t_10 = NULL;
        __pyx_t_9 = PyTuple_New(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 335, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_INCREF(__pyx_v_node);
        __Pyx_GIVEREF(__pyx_v_node);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_v_node) != (0)) __PYX_ERR(0, 335, __pyx_L3_error);
        __Pyx_INCREF(__pyx_v_service);
        __Pyx_GIVEREF(__pyx_v_service);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_v_service) != (0)) __PYX_ERR(0, 335, __pyx_L3_error);
        __pyx_t_11 = 1;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_t_9};
          __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6gevent_8resolver_5cares_Result, __pyx_callargs+__pyx_t_11, (2-__pyx_t_11) | (__pyx_t_11*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 335, __pyx_L3_error)
          __Pyx_GOTREF((PyObject *)__pyx_t_3);
        }
        __pyx_t_11 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_8);
          assert(__pyx_t_2);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_8, __pyx__function);
          __pyx_t_11 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_2, ((PyObject *)__pyx_t_3)};
          __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_8, __pyx_callargs+__pyx_t_11, (2-__pyx_t_11) | (__pyx_t_11*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF((PyObject *)__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 335, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __pyx_L9:;

      /* "gevent/resolver/cares.pyx":329
 *     cdef object node
 *     cdef object service
 *     try:             # <<<<<<<<<<<<<<
 *         if status:
 *             callback(Result(None, _gevent_gaierror_from_status(status)))
*/
    }
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "gevent/resolver/cares.pyx":336
 *             service = _as_str(c_service)
 *             callback(Result((node, service)))
 *     except:             # <<<<<<<<<<<<<<
 *         channel.loop.handle_error(callback, *sys.exc_info())
 * 
*/
    /*except:*/ {
      __Pyx_AddTraceback("gevent.resolver.cares.gevent_ares_nameinfo_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_8, &__pyx_t_3) < 0) __PYX_ERR(0, 336, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_1);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_3);

      /* "gevent/resolver/cares.pyx":337
 *             callback(Result((node, service)))
 *     except:
 *         channel.loop.handle_error(callback, *sys.exc_info())             # <<<<<<<<<<<<<<
 * 
 * 
*/
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_channel->loop, __pyx_mstate_global->__pyx_n_u_handle_error); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 337, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_9 = PyTuple_New(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 337, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_INCREF(__pyx_v_callback);
      __Pyx_GIVEREF(__pyx_v_callback);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_v_callback) != (0)) __PYX_ERR(0, 337, __pyx_L5_except_error);
      __pyx_t_12 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_mstate_global->__pyx_n_u_sys); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 337, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_13);
      __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_mstate_global->__pyx_n_u_exc_info); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 337, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __pyx_t_11 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_14))) {
        __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_14);
        assert(__pyx_t_12);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_14);
        __Pyx_INCREF(__pyx_t_12);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_14, __pyx__function);
        __pyx_t_11 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_12, NULL};
        __pyx_t_10 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_14, __pyx_callargs+__pyx_t_11, (1-__pyx_t_11) | (__pyx_t_11*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 337, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_10);
      }
      __pyx_t_14 = __Pyx_PySequence_Tuple(__pyx_t_10); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 337, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = PyNumber_Add(__pyx_t_9, __pyx_t_14); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 337, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __pyx_t_14 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_10, NULL); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 337, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      goto __pyx_L4_exception_handled;
    }

    /* "gevent/resolver/cares.pyx":329
 *     cdef object node
 *     cdef object service
 *     try:             # <<<<<<<<<<<<<<
 *         if status:
 *             callback(Result(None, _gevent_gaierror_from_status(status)))
*/
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    __pyx_L8_try_end:;
  }

  /* "gevent/resolver/cares.pyx":322
 * 
 * 
 * cdef void gevent_ares_nameinfo_callback(void *arg, int status, int timeouts, char *c_node, char *c_service):             # <<<<<<<<<<<<<<
 *     cdef channel channel
 *     cdef object callback
*/

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_AddTraceback("gevent.resolver.cares.gevent_ares_nameinfo_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_channel);
  __Pyx_XDECREF(__pyx_v_callback);
  __Pyx_XDECREF(__pyx_v_node);
  __Pyx_XDECREF(__pyx_v_service);
  __Pyx_RefNannyFinishContext();
}

/* "gevent/resolver/cares.pyx":341
 * 
 * 
 * cdef int _make_sockaddr(const char* hostp, int port, int flowinfo, int scope_id, sockaddr_in6* sa6):             # <<<<<<<<<<<<<<
 *     if cares.ares_inet_pton(AF_INET, hostp, &(<sockaddr_in*>sa6).sin_addr.s_addr) > 0:
 *         (<sockaddr_in*>sa6).sin_family = AF_INET
*/

static int __pyx_f_6gevent_8resolver_5cares__make_sockaddr(char const *__pyx_v_hostp, int __pyx_v_port, int __pyx_v_flowinfo, int __pyx_v_scope_id, struct sockaddr_in6 *__pyx_v_sa6) {
  int __pyx_r;
  int __pyx_t_1;

  /* "gevent/resolver/cares.pyx":342
 * 
 * cdef int _make_sockaddr(const char* hostp, int port, int flowinfo, int scope_id, sockaddr_in6* sa6):
 *     if cares.ares_inet_pton(AF_INET, hostp, &(<sockaddr_in*>sa6).sin_addr.s_addr) > 0:             # <<<<<<<<<<<<<<
 *         (<sockaddr_in*>sa6).sin_family = AF_INET
 *         (<sockaddr_in*>sa6).sin_port = htons(port)
*/
  __pyx_t_1 = (ares_inet_pton(AF_INET, __pyx_v_hostp, (&((struct sockaddr_in *)__pyx_v_sa6)->sin_addr.s_addr)) > 0);
  if (__pyx_t_1) {

    /* "gevent/resolver/cares.pyx":343
 * cdef int _make_sockaddr(const char* hostp, int port, int flowinfo, int scope_id, sockaddr_in6* sa6):
 *     if cares.ares_inet_pton(AF_INET, hostp, &(<sockaddr_in*>sa6).sin_addr.s_addr) > 0:
 *         (<sockaddr_in*>sa6).sin_family = AF_INET             # <<<<<<<<<<<<<<
 *         (<sockaddr_in*>sa6).sin_port = htons(port)
 *         return sizeof(sockaddr_in)
*/
    ((struct sockaddr_in *)__pyx_v_sa6)->sin_family = AF_INET;

    /* "gevent/resolver/cares.pyx":344
 *     if cares.ares_inet_pton(AF_INET, hostp, &(<sockaddr_in*>sa6).sin_addr.s_addr) > 0:
 *         (<sockaddr_in*>sa6).sin_family = AF_INET
 *         (<sockaddr_in*>sa6).sin_port = htons(port)             # <<<<<<<<<<<<<<
 *         return sizeof(sockaddr_in)
 * 
*/
    ((struct sockaddr_in *)__pyx_v_sa6)->sin_port = htons(__pyx_v_port);

    /* "gevent/resolver/cares.pyx":345
 *         (<sockaddr_in*>sa6).sin_family = AF_INET
 *         (<sockaddr_in*>sa6).sin_port = htons(port)
 *         return sizeof(sockaddr_in)             # <<<<<<<<<<<<<<
 * 
 *     if cares.ares_inet_pton(AF_INET6, hostp, &(sa6.sin6_addr).s6_addr) > 0:
*/
    __pyx_r = (sizeof(struct sockaddr_in));
    goto __pyx_L0;

    /* "gevent/resolver/cares.pyx":342
 * 
 * cdef int _make_sockaddr(const char* hostp, int port, int flowinfo, int scope_id, sockaddr_in6* sa6):
 *     if cares.ares_inet_pton(AF_INET, hostp, &(<sockaddr_in*>sa6).sin_addr.s_addr) > 0:             # <<<<<<<<<<<<<<
 *         (<sockaddr_in*>sa6).sin_family = AF_INET
 *         (<sockaddr_in*>sa6).sin_port = htons(port)
*/
  }

  /* "gevent/resolver/cares.pyx":347
 *         return sizeof(sockaddr_in)
 * 
 *     if cares.ares_inet_pton(AF_INET6, hostp, &(sa6.sin6_addr).s6_addr) > 0:             # <<<<<<<<<<<<<<
 *         sa6.sin6_family = AF_INET6
 *         sa6.sin6_port = htons(port)
*/
  __pyx_t_1 = (ares_inet_pton(AF_INET6, __pyx_v_hostp, (&__pyx_v_sa6->sin6_addr.s6_addr)) > 0);
  if (__pyx_t_1) {

    /* "gevent/resolver/cares.pyx":348
 * 
 *     if cares.ares_inet_pton(AF_INET6, hostp, &(sa6.sin6_addr).s6_addr) > 0:
 *         sa6.sin6_family = AF_INET6             # <<<<<<<<<<<<<<
 *         sa6.sin6_port = htons(port)
 *         sa6.sin6_flowinfo = flowinfo
*/
    __pyx_v_sa6->sin6_family = AF_INET6;

    /* "gevent/resolver/cares.pyx":349
 *     if cares.ares_inet_pton(AF_INET6, hostp, &(sa6.sin6_addr).s6_addr) > 0:
 *         sa6.sin6_family = AF_INET6
 *         sa6.sin6_port = htons(port)             # <<<<<<<<<<<<<<
 *         sa6.sin6_flowinfo = flowinfo
 *         sa6.sin6_scope_id = scope_id
*/
    __pyx_v_sa6->sin6_port = htons(__pyx_v_port);

    /* "gevent/resolver/cares.pyx":350
 *         sa6.sin6_family = AF_INET6
 *         sa6.sin6_port = htons(port)
 *         sa6.sin6_flowinfo = flowinfo             # <<<<<<<<<<<<<<
 *         sa6.sin6_scope_id = scope_id
 *         return sizeof(sockaddr_in6);
*/
    __pyx_v_sa6->sin6_flowinfo = __pyx_v_flowinfo;

    /* "gevent/resolver/cares.pyx":351
 *         sa6.sin6_port = htons(port)
 *         sa6.sin6_flowinfo = flowinfo
 *         sa6.sin6_scope_id = scope_id             # <<<<<<<<<<<<<<
 *         return sizeof(sockaddr_in6);
 * 
*/
    __pyx_v_sa6->sin6_scope_id = __pyx_v_scope_id;

    /* "gevent/resolver/cares.pyx":352
 *         sa6.sin6_flowinfo = flowinfo
 *         sa6.sin6_scope_id = scope_id
 *         return sizeof(sockaddr_in6);             # <<<<<<<<<<<<<<
 * 
 *     return -1;
*/
    __pyx_r = (sizeof(struct sockaddr_in6));
    goto __pyx_L0;

    /* "gevent/resolver/cares.pyx":347
 *         return sizeof(sockaddr_in)
 * 
 *     if cares.ares_inet_pton(AF_INET6, hostp, &(sa6.sin6_addr).s6_addr) > 0:             # <<<<<<<<<<<<<<
 *         sa6.sin6_family = AF_INET6
 *         sa6.sin6_port = htons(port)
*/
  }

  /* "gevent/resolver/cares.pyx":354
 *         return sizeof(sockaddr_in6);
 * 
 *     return -1;             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_r = -1;
  goto __pyx_L0;

  /* "gevent/resolver/cares.pyx":341
 * 
 * 
 * cdef int _make_sockaddr(const char* hostp, int port, int flowinfo, int scope_id, sockaddr_in6* sa6):             # <<<<<<<<<<<<<<
 *     if cares.ares_inet_pton(AF_INET, hostp, &(<sockaddr_in*>sa6).sin_addr.s_addr) > 0:
 *         (<sockaddr_in*>sa6).sin_family = AF_INET
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "gevent/resolver/cares.pyx":365
 *     cdef object _timer
 * 
 *     def __init__(self, object loop, flags=None, timeout=None, tries=None, ndots=None,             # <<<<<<<<<<<<<<
 *                  udp_port=None, tcp_port=None, servers=None):
 *         cdef ares_channeldata* channel = NULL
*/

/* Python wrapper */
static int __pyx_pw_6gevent_8resolver_5cares_7channel_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6gevent_8resolver_5cares_7channel_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_loop = 0;
  PyObject *__pyx_v_flags = 0;
  PyObject *__pyx_v_timeout = 0;
  PyObject *__pyx_v_tries = 0;
  PyObject *__pyx_v_ndots = 0;
  PyObject *__pyx_v_udp_port = 0;
  PyObject *__pyx_v_tcp_port = 0;
  PyObject *__pyx_v_servers = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[8] = {0,0,0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_loop,&__pyx_mstate_global->__pyx_n_u_flags,&__pyx_mstate_global->__pyx_n_u_timeout,&__pyx_mstate_global->__pyx_n_u_tries,&__pyx_mstate_global->__pyx_n_u_ndots,&__pyx_mstate_global->__pyx_n_u_udp_port,&__pyx_mstate_global->__pyx_n_u_tcp_port,&__pyx_mstate_global->__pyx_n_u_servers,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 365, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  8:
        values[7] = __Pyx_ArgRef_VARARGS(__pyx_args, 7);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[7])) __PYX_ERR(0, 365, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  7:
        values[6] = __Pyx_ArgRef_VARARGS(__pyx_args, 6);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[6])) __PYX_ERR(0, 365, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  6:
        values[5] = __Pyx_ArgRef_VARARGS(__pyx_args, 5);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[5])) __PYX_ERR(0, 365, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  5:
        values[4] = __Pyx_ArgRef_VARARGS(__pyx_args, 4);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[4])) __PYX_ERR(0, 365, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  4:
        values[3] = __Pyx_ArgRef_VARARGS(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 365, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_VARARGS(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 365, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 365, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 365, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__init__", 0) < (0)) __PYX_ERR(0, 365, __pyx_L3_error)
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[3]) values[3] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[4]) values[4] = __Pyx_NewRef(((PyObject *)Py_None));

      /* "gevent/resolver/cares.pyx":366
 * 
 *     def __init__(self, object loop, flags=None, timeout=None, tries=None, ndots=None,
 *                  udp_port=None, tcp_port=None, servers=None):             # <<<<<<<<<<<<<<
 *         cdef ares_channeldata* channel = NULL
 *         cdef cares.ares_options options
*/
      if (!values[5]) values[5] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[6]) values[6] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[7]) values[7] = __Pyx_NewRef(((PyObject *)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__init__", 0, 1, 8, i); __PYX_ERR(0, 365, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  8:
        values[7] = __Pyx_ArgRef_VARARGS(__pyx_args, 7);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[7])) __PYX_ERR(0, 365, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  7:
        values[6] = __Pyx_ArgRef_VARARGS(__pyx_args, 6);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[6])) __PYX_ERR(0, 365, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  6:
        values[5] = __Pyx_ArgRef_VARARGS(__pyx_args, 5);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[5])) __PYX_ERR(0, 365, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  5:
        values[4] = __Pyx_ArgRef_VARARGS(__pyx_args, 4);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[4])) __PYX_ERR(0, 365, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  4:
        values[3] = __Pyx_ArgRef_VARARGS(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 365, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_VARARGS(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 365, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 365, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 365, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }

      /* "gevent/resolver/cares.pyx":365
 *     cdef object _timer
 * 
 *     def __init__(self, object loop, flags=None, timeout=None, tries=None, ndots=None,             # <<<<<<<<<<<<<<
 *                  udp_port=None, tcp_port=None, servers=None):
 *         cdef ares_channeldata* channel = NULL
*/
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[3]) values[3] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[4]) values[4] = __Pyx_NewRef(((PyObject *)Py_None));

      /* "gevent/resolver/cares.pyx":366
 * 
 *     def __init__(self, object loop, flags=None, timeout=None, tries=None, ndots=None,
 *                  udp_port=None, tcp_port=None, servers=None):             # <<<<<<<<<<<<<<
 *         cdef ares_channeldata* channel = NULL
 *         cdef cares.ares_options options
*/
      if (!values[5]) values[5] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[6]) values[6] = __Pyx_NewRef(((PyObject *)Py_None));
      if (!values[7]) values[7] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_loop = values[0];
    __pyx_v_flags = values[1];
    __pyx_v_timeout = values[2];
    __pyx_v_tries = values[3];
    __pyx_v_ndots = values[4];
    __pyx_v_udp_port = values[5];
    __pyx_v_tcp_port = values[6];
    __pyx_v_servers = values[7];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 1, 8, __pyx_nargs); __PYX_ERR(0, 365, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("gevent.resolver.cares.channel.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6gevent_8resolver_5cares_7channel___init__(((struct __pyx_obj_6gevent_8resolver_5cares_channel *)__pyx_v_self), __pyx_v_loop, __pyx_v_flags, __pyx_v_timeout, __pyx_v_tries, __pyx_v_ndots, __pyx_v_udp_port, __pyx_v_tcp_port, __pyx_v_servers);

  /* "gevent/resolver/cares.pyx":365
 *     cdef object _timer
 * 
 *     def __init__(self, object loop, flags=None, timeout=None, tries=None, ndots=None,             # <<<<<<<<<<<<<<
 *                  udp_port=None, tcp_port=None, servers=None):
 *         cdef ares_channeldata* channel = NULL
*/

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6gevent_8resolver_5cares_7channel___init__(struct __pyx_obj_6gevent_8resolver_5cares_channel *__pyx_v_self, PyObject *__pyx_v_loop, PyObject *__pyx_v_flags, PyObject *__pyx_v_timeout, PyObject *__pyx_v_tries, PyObject *__pyx_v_ndots, PyObject *__pyx_v_udp_port, PyObject *__pyx_v_tcp_port, PyObject *__pyx_v_servers) {
  struct ares_channeldata *__pyx_v_channel;
  struct ares_options __pyx_v_options;
  int __pyx_v_optmask;
  int __pyx_v_result;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  double __pyx_t_4;
  unsigned short __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  size_t __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  struct __pyx_opt_args_6gevent_8resolver_5cares_7channel_set_servers __pyx_t_15;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "gevent/resolver/cares.pyx":367
 *     def __init__(self, object loop, flags=None, timeout=None, tries=None, ndots=None,
 *                  udp_port=None, tcp_port=None, servers=None):
 *         cdef ares_channeldata* channel = NULL             # <<<<<<<<<<<<<<
 *         cdef cares.ares_options options
 *         memset(&options, 0, sizeof(cares.ares_options))
*/
  __pyx_v_channel = NULL;

  /* "gevent/resolver/cares.pyx":369
 *         cdef ares_channeldata* channel = NULL
 *         cdef cares.ares_options options
 *         memset(&options, 0, sizeof(cares.ares_options))             # <<<<<<<<<<<<<<
 *         cdef int optmask = cares.ARES_OPT_SOCK_STATE_CB
 * 
*/
  (void)(memset((&__pyx_v_options), 0, (sizeof(struct ares_options))));

  /* "gevent/resolver/cares.pyx":370
 *         cdef cares.ares_options options
 *         memset(&options, 0, sizeof(cares.ares_options))
 *         cdef int optmask = cares.ARES_OPT_SOCK_STATE_CB             # <<<<<<<<<<<<<<
 * 
 *         options.sock_state_cb = <void*>gevent_sock_state_callback
*/
  __pyx_v_optmask = ARES_OPT_SOCK_STATE_CB;

  /* "gevent/resolver/cares.pyx":372
 *         cdef int optmask = cares.ARES_OPT_SOCK_STATE_CB
 * 
 *         options.sock_state_cb = <void*>gevent_sock_state_callback             # <<<<<<<<<<<<<<
 *         options.sock_state_cb_data = <void*>self
 * 
*/
  __pyx_v_options.sock_state_cb = ((void *)__pyx_f_6gevent_8resolver_5cares_gevent_sock_state_callback);

  /* "gevent/resolver/cares.pyx":373
 * 
 *         options.sock_state_cb = <void*>gevent_sock_state_callback
 *         options.sock_state_cb_data = <void*>self             # <<<<<<<<<<<<<<
 * 
 *         if flags is not None:
*/
  __pyx_v_options.sock_state_cb_data = ((void *)__pyx_v_self);

  /* "gevent/resolver/cares.pyx":375
 *         options.sock_state_cb_data = <void*>self
 * 
 *         if flags is not None:             # <<<<<<<<<<<<<<
 *             options.flags = int(flags)
 *             optmask |= cares.ARES_OPT_FLAGS
*/
  __pyx_t_1 = (__pyx_v_flags != Py_None);
  if (__pyx_t_1) {

    /* "gevent/resolver/cares.pyx":376
 * 
 *         if flags is not None:
 *             options.flags = int(flags)             # <<<<<<<<<<<<<<
 *             optmask |= cares.ARES_OPT_FLAGS
 * 
*/
    __pyx_t_2 = __Pyx_PyNumber_Int(__pyx_v_flags); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 376, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyLong_As_int(__pyx_t_2); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 376, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_options.flags = __pyx_t_3;

    /* "gevent/resolver/cares.pyx":377
 *         if flags is not None:
 *             options.flags = int(flags)
 *             optmask |= cares.ARES_OPT_FLAGS             # <<<<<<<<<<<<<<
 * 
 *         if timeout is not None:
*/
    __pyx_v_optmask = (__pyx_v_optmask | ARES_OPT_FLAGS);

    /* "gevent/resolver/cares.pyx":375
 *         options.sock_state_cb_data = <void*>self
 * 
 *         if flags is not None:             # <<<<<<<<<<<<<<
 *             options.flags = int(flags)
 *             optmask |= cares.ARES_OPT_FLAGS
*/
  }

  /* "gevent/resolver/cares.pyx":379
 *             optmask |= cares.ARES_OPT_FLAGS
 * 
 *         if timeout is not None:             # <<<<<<<<<<<<<<
 *             options.timeout = int(float(timeout) * 1000)
 *             optmask |= cares.ARES_OPT_TIMEOUTMS
*/
  __pyx_t_1 = (__pyx_v_timeout != Py_None);
  if (__pyx_t_1) {

    /* "gevent/resolver/cares.pyx":380
 * 
 *         if timeout is not None:
 *             options.timeout = int(float(timeout) * 1000)             # <<<<<<<<<<<<<<
 *             optmask |= cares.ARES_OPT_TIMEOUTMS
 * 
*/
    __pyx_t_4 = __Pyx_PyObject_AsDouble(__pyx_v_timeout); if (unlikely(__PYX_CHECK_FLOAT_EXCEPTION(__pyx_t_4, ((double)((double)-1))) && PyErr_Occurred())) __PYX_ERR(0, 380, __pyx_L1_error)
    __pyx_v_options.timeout = ((int)(__pyx_t_4 * 1000.0));

    /* "gevent/resolver/cares.pyx":381
 *         if timeout is not None:
 *             options.timeout = int(float(timeout) * 1000)
 *             optmask |= cares.ARES_OPT_TIMEOUTMS             # <<<<<<<<<<<<<<
 * 
 *         if tries is not None:
*/
    __pyx_v_optmask = (__pyx_v_optmask | ARES_OPT_TIMEOUTMS);

    /* "gevent/resolver/cares.pyx":379
 *             optmask |= cares.ARES_OPT_FLAGS
 * 
 *         if timeout is not None:             # <<<<<<<<<<<<<<
 *             options.timeout = int(float(timeout) * 1000)
 *             optmask |= cares.ARES_OPT_TIMEOUTMS
*/
  }

  /* "gevent/resolver/cares.pyx":383
 *             optmask |= cares.ARES_OPT_TIMEOUTMS
 * 
 *         if tries is not None:             # <<<<<<<<<<<<<<
 *             options.tries = int(tries)
 *             optmask |= cares.ARES_OPT_TRIES
*/
  __pyx_t_1 = (__pyx_v_tries != Py_None);
  if (__pyx_t_1) {

    /* "gevent/resolver/cares.pyx":384
 * 
 *         if tries is not None:
 *             options.tries = int(tries)             # <<<<<<<<<<<<<<
 *             optmask |= cares.ARES_OPT_TRIES
 * 
*/
    __pyx_t_2 = __Pyx_PyNumber_Int(__pyx_v_tries); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 384, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyLong_As_int(__pyx_t_2); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 384, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_options.tries = __pyx_t_3;

    /* "gevent/resolver/cares.pyx":385
 *         if tries is not None:
 *             options.tries = int(tries)
 *             optmask |= cares.ARES_OPT_TRIES             # <<<<<<<<<<<<<<
 * 
 *         if ndots is not None:
*/
    __pyx_v_optmask = (__pyx_v_optmask | ARES_OPT_TRIES);

    /* "gevent/resolver/cares.pyx":383
 *             optmask |= cares.ARES_OPT_TIMEOUTMS
 * 
 *         if tries is not None:             # <<<<<<<<<<<<<<
 *             options.tries = int(tries)
 *             optmask |= cares.ARES_OPT_TRIES
*/
  }

  /* "gevent/resolver/cares.pyx":387
 *             optmask |= cares.ARES_OPT_TRIES
 * 
 *         if ndots is not None:             # <<<<<<<<<<<<<<
 *             options.ndots = int(ndots)
 *             optmask |= cares.ARES_OPT_NDOTS
*/
  __pyx_t_1 = (__pyx_v_ndots != Py_None);
  if (__pyx_t_1) {

    /* "gevent/resolver/cares.pyx":388
 * 
 *         if ndots is not None:
 *             options.ndots = int(ndots)             # <<<<<<<<<<<<<<
 *             optmask |= cares.ARES_OPT_NDOTS
 * 
*/
    __pyx_t_2 = __Pyx_PyNumber_Int(__pyx_v_ndots); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 388, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyLong_As_int(__pyx_t_2); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 388, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_options.ndots = __pyx_t_3;

    /* "gevent/resolver/cares.pyx":389
 *         if ndots is not None:
 *             options.ndots = int(ndots)
 *             optmask |= cares.ARES_OPT_NDOTS             # <<<<<<<<<<<<<<
 * 
 *         if udp_port is not None:
*/
    __pyx_v_optmask = (__pyx_v_optmask | ARES_OPT_NDOTS);

    /* "gevent/resolver/cares.pyx":387
 *             optmask |= cares.ARES_OPT_TRIES
 * 
 *         if ndots is not None:             # <<<<<<<<<<<<<<
 *             options.ndots = int(ndots)
 *             optmask |= cares.ARES_OPT_NDOTS
*/
  }

  /* "gevent/resolver/cares.pyx":391
 *             optmask |= cares.ARES_OPT_NDOTS
 * 
 *         if udp_port is not None:             # <<<<<<<<<<<<<<
 *             options.udp_port = int(udp_port)
 *             optmask |= cares.ARES_OPT_UDP_PORT
*/
  __pyx_t_1 = (__pyx_v_udp_port != Py_None);
  if (__pyx_t_1) {

    /* "gevent/resolver/cares.pyx":392
 * 
 *         if udp_port is not None:
 *             options.udp_port = int(udp_port)             # <<<<<<<<<<<<<<
 *             optmask |= cares.ARES_OPT_UDP_PORT
 * 
*/
    __pyx_t_2 = __Pyx_PyNumber_Int(__pyx_v_udp_port); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 392, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyLong_As_unsigned_short(__pyx_t_2); if (unlikely((__pyx_t_5 == (unsigned short)-1) && PyErr_Occurred())) __PYX_ERR(0, 392, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_options.udp_port = __pyx_t_5;

    /* "gevent/resolver/cares.pyx":393
 *         if udp_port is not None:
 *             options.udp_port = int(udp_port)
 *             optmask |= cares.ARES_OPT_UDP_PORT             # <<<<<<<<<<<<<<
 * 
 *         if tcp_port is not None:
*/
    __pyx_v_optmask = (__pyx_v_optmask | ARES_OPT_UDP_PORT);

    /* "gevent/resolver/cares.pyx":391
 *             optmask |= cares.ARES_OPT_NDOTS
 * 
 *         if udp_port is not None:             # <<<<<<<<<<<<<<
 *             options.udp_port = int(udp_port)
 *             optmask |= cares.ARES_OPT_UDP_PORT
*/
  }

  /* "gevent/resolver/cares.pyx":395
 *             optmask |= cares.ARES_OPT_UDP_PORT
 * 
 *         if tcp_port is not None:             # <<<<<<<<<<<<<<
 *             options.tcp_port = int(tcp_port)
 *             optmask |= cares.ARES_OPT_TCP_PORT
*/
  __pyx_t_1 = (__pyx_v_tcp_port != Py_None);
  if (__pyx_t_1) {

    /* "gevent/resolver/cares.pyx":396
 * 
 *         if tcp_port is not None:
 *             options.tcp_port = int(tcp_port)             # <<<<<<<<<<<<<<
 *             optmask |= cares.ARES_OPT_TCP_PORT
 * 
*/
    __pyx_t_2 = __Pyx_PyNumber_Int(__pyx_v_tcp_port); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 396, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyLong_As_unsigned_short(__pyx_t_2); if (unlikely((__pyx_t_5 == (unsigned short)-1) && PyErr_Occurred())) __PYX_ERR(0, 396, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_options.tcp_port = __pyx_t_5;

    /* "gevent/resolver/cares.pyx":397
 *         if tcp_port is not None:
 *             options.tcp_port = int(tcp_port)
 *             optmask |= cares.ARES_OPT_TCP_PORT             # <<<<<<<<<<<<<<
 * 
 *         cdef int result = cares.ares_library_init(cares.ARES_LIB_INIT_ALL)  # ARES_LIB_INIT_WIN32 -DUSE_WINSOCK?
*/
    __pyx_v_optmask = (__pyx_v_optmask | ARES_OPT_TCP_PORT);

    /* "gevent/resolver/cares.pyx":395
 *             optmask |= cares.ARES_OPT_UDP_PORT
 * 
 *         if tcp_port is not None:             # <<<<<<<<<<<<<<
 *             options.tcp_port = int(tcp_port)
 *             optmask |= cares.ARES_OPT_TCP_PORT
*/
  }

  /* "gevent/resolver/cares.pyx":399
 *             optmask |= cares.ARES_OPT_TCP_PORT
 * 
 *         cdef int result = cares.ares_library_init(cares.ARES_LIB_INIT_ALL)  # ARES_LIB_INIT_WIN32 -DUSE_WINSOCK?             # <<<<<<<<<<<<<<
 *         if result:
 *             raise gaierror(result, _gevent_gai_strerror(result))
*/
  __pyx_v_result = ares_library_init(ARES_LIB_INIT_ALL);

  /* "gevent/resolver/cares.pyx":400
 * 
 *         cdef int result = cares.ares_library_init(cares.ARES_LIB_INIT_ALL)  # ARES_LIB_INIT_WIN32 -DUSE_WINSOCK?
 *         if result:             # <<<<<<<<<<<<<<
 *             raise gaierror(result, _gevent_gai_strerror(result))
 *         result = cares.ares_init_options(&channel, &options, optmask)
*/
  __pyx_t_1 = (__pyx_v_result != 0);
  if (unlikely(__pyx_t_1)) {

    /* "gevent/resolver/cares.pyx":401
 *         cdef int result = cares.ares_library_init(cares.ARES_LIB_INIT_ALL)  # ARES_LIB_INIT_WIN32 -DUSE_WINSOCK?
 *         if result:
 *             raise gaierror(result, _gevent_gai_strerror(result))             # <<<<<<<<<<<<<<
 *         result = cares.ares_init_options(&channel, &options, optmask)
 *         if result:
*/
    __pyx_t_6 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_gaierror); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 401, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __Pyx_PyLong_From_int(__pyx_v_result); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 401, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = __Pyx_PyLong_From_int(__pyx_v_result); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 401, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_10 = __pyx_f_6gevent_8resolver_5cares__gevent_gai_strerror(__pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 401, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_11 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
      assert(__pyx_t_6);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
      __pyx_t_11 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_t_8, __pyx_t_10};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_11, (3-__pyx_t_11) | (__pyx_t_11*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 401, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 401, __pyx_L1_error)

    /* "gevent/resolver/cares.pyx":400
 * 
 *         cdef int result = cares.ares_library_init(cares.ARES_LIB_INIT_ALL)  # ARES_LIB_INIT_WIN32 -DUSE_WINSOCK?
 *         if result:             # <<<<<<<<<<<<<<
 *             raise gaierror(result, _gevent_gai_strerror(result))
 *         result = cares.ares_init_options(&channel, &options, optmask)
*/
  }

  /* "gevent/resolver/cares.pyx":402
 *         if result:
 *             raise gaierror(result, _gevent_gai_strerror(result))
 *         result = cares.ares_init_options(&channel, &options, optmask)             # <<<<<<<<<<<<<<
 *         if result:
 *             raise gaierror(result, _gevent_gai_strerror(result))
*/
  __pyx_v_result = ares_init_options((&__pyx_v_channel), (&__pyx_v_options), __pyx_v_optmask);

  /* "gevent/resolver/cares.pyx":403
 *             raise gaierror(result, _gevent_gai_strerror(result))
 *         result = cares.ares_init_options(&channel, &options, optmask)
 *         if result:             # <<<<<<<<<<<<<<
 *             raise gaierror(result, _gevent_gai_strerror(result))
 *         self._timer = loop.timer(TIMEOUT, TIMEOUT)
*/
  __pyx_t_1 = (__pyx_v_result != 0);
  if (unlikely(__pyx_t_1)) {

    /* "gevent/resolver/cares.pyx":404
 *         result = cares.ares_init_options(&channel, &options, optmask)
 *         if result:
 *             raise gaierror(result, _gevent_gai_strerror(result))             # <<<<<<<<<<<<<<
 *         self._timer = loop.timer(TIMEOUT, TIMEOUT)
 *         self._watchers = {}
*/
    __pyx_t_7 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_mstate_global->__pyx_n_u_gaierror); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 404, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_8 = __Pyx_PyLong_From_int(__pyx_v_result); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 404, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_6 = __Pyx_PyLong_From_int(__pyx_v_result); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 404, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_9 = __pyx_f_6gevent_8resolver_5cares__gevent_gai_strerror(__pyx_t_6); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 404, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_11 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_10))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_10);
      assert(__pyx_t_7);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_10, __pyx__function);
      __pyx_t_11 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_7, __pyx_t_8, __pyx_t_9};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_10, __pyx_callargs+__pyx_t_11, (3-__pyx_t_11) | (__pyx_t_11*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 404, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 404, __pyx_L1_error)

    /* "gevent/resolver/cares.pyx":403
 *             raise gaierror(result, _gevent_gai_strerror(result))
 *         result = cares.ares_init_options(&channel, &options, optmask)
 *         if result:             # <<<<<<<<<<<<<<
 *             raise gaierror(result, _gevent_gai_strerror(result))
 *         self._timer = loop.timer(TIMEOUT, TIMEOUT)
*/
  }

  /* "gevent/resolver/cares.pyx":405
 *         if result:
 *             raise gaierror(result, _gevent_gai_strerror(result))
 *         self._timer = loop.timer(TIMEOUT, TIMEOUT)             # <<<<<<<<<<<<<<
 *         self._watchers = {}
 *         self.channel = channel
*/
  __pyx_t_10 = __pyx_v_loop;
  __Pyx_INCREF(__pyx_t_10);
  __pyx_t_9 = __Pyx_PyLong_From_int(TIMEOUT); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_8 = __Pyx_PyLong_From_int(TIMEOUT); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_11 = 0;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_10, __pyx_t_9, __pyx_t_8};
    __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_timer, __pyx_callargs+__pyx_t_11, (3-__pyx_t_11) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 405, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_self->_timer);
  __Pyx_DECREF(__pyx_v_self->_timer);
  __pyx_v_self->_timer = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "gevent/resolver/cares.pyx":406
 *             raise gaierror(result, _gevent_gai_strerror(result))
 *         self._timer = loop.timer(TIMEOUT, TIMEOUT)
 *         self._watchers = {}             # <<<<<<<<<<<<<<
 *         self.channel = channel
 *         try:
*/
  __pyx_t_2 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 406, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_self->_watchers);
  __Pyx_DECREF(__pyx_v_self->_watchers);
  __pyx_v_self->_watchers = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "gevent/resolver/cares.pyx":407
 *         self._timer = loop.timer(TIMEOUT, TIMEOUT)
 *         self._watchers = {}
 *         self.channel = channel             # <<<<<<<<<<<<<<
 *         try:
 *             if servers is not None:
*/
  __pyx_v_self->channel = __pyx_v_channel;

  /* "gevent/resolver/cares.pyx":408
 *         self._watchers = {}
 *         self.channel = channel
 *         try:             # <<<<<<<<<<<<<<
 *             if servers is not None:
 *                 self.set_servers(servers)
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14);
    __Pyx_XGOTREF(__pyx_t_12);
    __Pyx_XGOTREF(__pyx_t_13);
    __Pyx_XGOTREF(__pyx_t_14);
    /*try:*/ {

      /* "gevent/resolver/cares.pyx":409
 *         self.channel = channel
 *         try:
 *             if servers is not None:             # <<<<<<<<<<<<<<
 *                 self.set_servers(servers)
 *             self.loop = loop
*/
      __pyx_t_1 = (__pyx_v_servers != Py_None);
      if (__pyx_t_1) {

        /* "gevent/resolver/cares.pyx":410
 *         try:
 *             if servers is not None:
 *                 self.set_servers(servers)             # <<<<<<<<<<<<<<
 *             self.loop = loop
 *         except:
*/
        __pyx_t_15.__pyx_n = 1;
        __pyx_t_15.servers = __pyx_v_servers;
        __pyx_t_2 = ((struct __pyx_vtabstruct_6gevent_8resolver_5cares_channel *)__pyx_v_self->__pyx_vtab)->set_servers(__pyx_v_self, 0, &__pyx_t_15); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 410, __pyx_L11_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "gevent/resolver/cares.pyx":409
 *         self.channel = channel
 *         try:
 *             if servers is not None:             # <<<<<<<<<<<<<<
 *                 self.set_servers(servers)
 *             self.loop = loop
*/
      }

      /* "gevent/resolver/cares.pyx":411
 *             if servers is not None:
 *                 self.set_servers(servers)
 *             self.loop = loop             # <<<<<<<<<<<<<<
 *         except:
 *             self.destroy()
*/
      __Pyx_INCREF(__pyx_v_loop);
      __Pyx_GIVEREF(__pyx_v_loop);
      __Pyx_GOTREF(__pyx_v_self->loop);
      __Pyx_DECREF(__pyx_v_self->loop);
      __pyx_v_self->loop = __pyx_v_loop;

      /* "gevent/resolver/cares.pyx":408
 *         self._watchers = {}
 *         self.channel = channel
 *         try:             # <<<<<<<<<<<<<<
 *             if servers is not None:
 *                 self.set_servers(servers)
*/
    }
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
    goto __pyx_L16_try_end;
    __pyx_L11_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "gevent/resolver/cares.pyx":412
 *                 self.set_servers(servers)
 *             self.loop = loop
 *         except:             # <<<<<<<<<<<<<<
 *             self.destroy()
 *             raise
*/
    /*except:*/ {
      __Pyx_AddTraceback("gevent.resolver.cares.channel.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_8, &__pyx_t_9) < 0) __PYX_ERR(0, 412, __pyx_L13_except_error)
      __Pyx_XGOTREF(__pyx_t_2);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);

      /* "gevent/resolver/cares.pyx":413
 *             self.loop = loop
 *         except:
 *             self.destroy()             # <<<<<<<<<<<<<<
 *             raise
 * 
*/
      __pyx_t_7 = ((PyObject *)__pyx_v_self);
      __Pyx_INCREF(__pyx_t_7);
      __pyx_t_11 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
        __pyx_t_10 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_destroy, __pyx_callargs+__pyx_t_11, (1-__pyx_t_11) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 413, __pyx_L13_except_error)
        __Pyx_GOTREF(__pyx_t_10);
      }
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

      /* "gevent/resolver/cares.pyx":414
 *         except:
 *             self.destroy()
 *             raise             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
*/
      __Pyx_GIVEREF(__pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_ErrRestoreWithState(__pyx_t_2, __pyx_t_8, __pyx_t_9);
      __pyx_t_2 = 0;  __pyx_t_8 = 0;  __pyx_t_9 = 0; 
      __PYX_ERR(0, 414, __pyx_L13_except_error)
    }

    /* "gevent/resolver/cares.pyx":408
 *         self._watchers = {}
 *         self.channel = channel
 *         try:             # <<<<<<<<<<<<<<
 *             if servers is not None:
 *                 self.set_servers(servers)
*/
    __pyx_L13_except_error:;
    __Pyx_XGIVEREF(__pyx_t_12);
    __Pyx_XGIVEREF(__pyx_t_13);
    __Pyx_XGIVEREF(__pyx_t_14);
    __Pyx_ExceptionReset(__pyx_t_12, __pyx_t_13, __pyx_t_14);
    goto __pyx_L1_error;
    __pyx_L16_try_end:;
  }

  /* "gevent/resolver/cares.pyx":365
 *     cdef object _timer
 * 
 *     def __init__(self, object loop, flags=None, timeout=None, tries=None, ndots=None,             # <<<<<<<<<<<<<<
 *                  udp_port=None, tcp_port=None, servers=None):
 *         cdef ares_channeldata* channel = NULL
*/

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("gevent.resolver.cares.channel.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/resolver/cares.pyx":416
 *             raise
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         args = (self.__class__.__name__, id(self), self._timer, len(self._watchers))
 *         return '<%s at 0x%x _timer=%r _watchers[%s]>' % args
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_8resolver_5cares_7channel_3__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6gevent_8resolver_5cares_7channel_3__repr__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_8resolver_5cares_7channel_2__repr__(((struct __pyx_obj_6gevent_8resolver_5cares_channel *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_8resolver_5cares_7channel_2__repr__(struct __pyx_obj_6gevent_8resolver_5cares_channel *__pyx_v_self) {
  PyObject *__pyx_v_args = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "gevent/resolver/cares.pyx":417
 * 
 *     def __repr__(self):
 *         args = (self.__class__.__name__, id(self), self._timer, len(self._watchers))             # <<<<<<<<<<<<<<
 *         return '<%s at 0x%x _timer=%r _watchers[%s]>' % args
 * 
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_class); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 417, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 417, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_4 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, ((PyObject *)__pyx_v_self)};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_id, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 417, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_t_3 = __pyx_v_self->_watchers;
  __Pyx_INCREF(__pyx_t_3);
  if (unlikely(__pyx_t_3 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 417, __pyx_L1_error)
  }
  __pyx_t_5 = PyDict_Size(__pyx_t_3); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 417, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyLong_FromSsize_t(__pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 417, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = PyTuple_New(4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 417, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_2) != (0)) __PYX_ERR(0, 417, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_1) != (0)) __PYX_ERR(0, 417, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->_timer);
  __Pyx_GIVEREF(__pyx_v_self->_timer);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_v_self->_timer) != (0)) __PYX_ERR(0, 417, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 3, __pyx_t_3) != (0)) __PYX_ERR(0, 417, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_1 = 0;
  __pyx_t_3 = 0;
  __pyx_v_args = ((PyObject*)__pyx_t_6);
  __pyx_t_6 = 0;

  /* "gevent/resolver/cares.pyx":418
 *     def __repr__(self):
 *         args = (self.__class__.__name__, id(self), self._timer, len(self._watchers))
 *         return '<%s at 0x%x _timer=%r _watchers[%s]>' % args             # <<<<<<<<<<<<<<
 * 
 *     def destroy(self):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = PyUnicode_Format(__pyx_mstate_global->__pyx_kp_u_s_at_0x_x__timer_r__watchers_s, __pyx_v_args); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 418, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "gevent/resolver/cares.pyx":416
 *             raise
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         args = (self.__class__.__name__, id(self), self._timer, len(self._watchers))
 *         return '<%s at 0x%x _timer=%r _watchers[%s]>' % args
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("gevent.resolver.cares.channel.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/resolver/cares.pyx":420
 *         return '<%s at 0x%x _timer=%r _watchers[%s]>' % args
 * 
 *     def destroy(self):             # <<<<<<<<<<<<<<
 *         self.__destroy()
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_8resolver_5cares_7channel_5destroy(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_6gevent_8resolver_5cares_7channel_5destroy = {"destroy", (PyCFunction)__pyx_pw_6gevent_8resolver_5cares_7channel_5destroy, METH_NOARGS, 0};
static PyObject *__pyx_pw_6gevent_8resolver_5cares_7channel_5destroy(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("destroy (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_8resolver_5cares_7channel_4destroy(((struct __pyx_obj_6gevent_8resolver_5cares_channel *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_8resolver_5cares_7channel_4destroy(struct __pyx_obj_6gevent_8resolver_5cares_channel *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("destroy", 0);

  /* "gevent/resolver/cares.pyx":421
 * 
 *     def destroy(self):
 *         self.__destroy()             # <<<<<<<<<<<<<<
 * 
 *     cdef __destroy(self):
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6gevent_8resolver_5cares_channel *)__pyx_v_self->__pyx_vtab)->_channel__destroy(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 421, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "gevent/resolver/cares.pyx":420
 *         return '<%s at 0x%x _timer=%r _watchers[%s]>' % args
 * 
 *     def destroy(self):             # <<<<<<<<<<<<<<
 *         self.__destroy()
 * 
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent.resolver.cares.channel.destroy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/resolver/cares.pyx":423
 *         self.__destroy()
 * 
 *     cdef __destroy(self):             # <<<<<<<<<<<<<<
 *         if self.channel:
 *             # XXX ares_library_cleanup?
*/

static PyObject *__pyx_f_6gevent_8resolver_5cares_7channel__channel__destroy(struct __pyx_obj_6gevent_8resolver_5cares_channel *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_channel__destroy", 0);

  /* "gevent/resolver/cares.pyx":424
 * 
 *     cdef __destroy(self):
 *         if self.channel:             # <<<<<<<<<<<<<<
 *             # XXX ares_library_cleanup?
 *             cares.ares_destroy(self.channel)
*/
  __pyx_t_1 = (__pyx_v_self->channel != 0);
  if (__pyx_t_1) {

    /* "gevent/resolver/cares.pyx":426
 *         if self.channel:
 *             # XXX ares_library_cleanup?
 *             cares.ares_destroy(self.channel)             # <<<<<<<<<<<<<<
 *             self.channel = NULL
 *             self._watchers.clear()
*/
    ares_destroy(__pyx_v_self->channel);

    /* "gevent/resolver/cares.pyx":427
 *             # XXX ares_library_cleanup?
 *             cares.ares_destroy(self.channel)
 *             self.channel = NULL             # <<<<<<<<<<<<<<
 *             self._watchers.clear()
 *             self._timer.stop()
*/
    __pyx_v_self->channel = NULL;

    /* "gevent/resolver/cares.pyx":428
 *             cares.ares_destroy(self.channel)
 *             self.channel = NULL
 *             self._watchers.clear()             # <<<<<<<<<<<<<<
 *             self._timer.stop()
 *             self.loop = None
*/
    if (unlikely(__pyx_v_self->_watchers == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "clear");
      __PYX_ERR(0, 428, __pyx_L1_error)
    }
    __pyx_t_2 = __Pyx_PyDict_Clear(__pyx_v_self->_watchers); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 428, __pyx_L1_error)

    /* "gevent/resolver/cares.pyx":429
 *             self.channel = NULL
 *             self._watchers.clear()
 *             self._timer.stop()             # <<<<<<<<<<<<<<
 *             self.loop = None
 * 
*/
    __pyx_t_4 = __pyx_v_self->_timer;
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_stop, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 429, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "gevent/resolver/cares.pyx":430
 *             self._watchers.clear()
 *             self._timer.stop()
 *             self.loop = None             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
*/
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_self->loop);
    __Pyx_DECREF(__pyx_v_self->loop);
    __pyx_v_self->loop = Py_None;

    /* "gevent/resolver/cares.pyx":424
 * 
 *     cdef __destroy(self):
 *         if self.channel:             # <<<<<<<<<<<<<<
 *             # XXX ares_library_cleanup?
 *             cares.ares_destroy(self.channel)
*/
  }

  /* "gevent/resolver/cares.pyx":423
 *         self.__destroy()
 * 
 *     cdef __destroy(self):             # <<<<<<<<<<<<<<
 *         if self.channel:
 *             # XXX ares_library_cleanup?
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("gevent.resolver.cares.channel._channel__destroy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/resolver/cares.pyx":432
 *             self.loop = None
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         self.__destroy()
 * 
*/

/* Python wrapper */
static void __pyx_pw_6gevent_8resolver_5cares_7channel_7__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_6gevent_8resolver_5cares_7channel_7__dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_pf_6gevent_8resolver_5cares_7channel_6__dealloc__(((struct __pyx_obj_6gevent_8resolver_5cares_channel *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_6gevent_8resolver_5cares_7channel_6__dealloc__(struct __pyx_obj_6gevent_8resolver_5cares_channel *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__dealloc__", 0);

  /* "gevent/resolver/cares.pyx":433
 * 
 *     def __dealloc__(self):
 *         self.__destroy()             # <<<<<<<<<<<<<<
 * 
 *     cpdef set_servers(self, servers=None):
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6gevent_8resolver_5cares_channel *)__pyx_v_self->__pyx_vtab)->_channel__destroy(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "gevent/resolver/cares.pyx":432
 *             self.loop = None
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         self.__destroy()
 * 
*/

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_WriteUnraisable("gevent.resolver.cares.channel.__dealloc__", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* "gevent/resolver/cares.pyx":435
 *         self.__destroy()
 * 
 *     cpdef set_servers(self, servers=None):             # <<<<<<<<<<<<<<
 *         if not self.channel:
 *             raise gaierror(cares.ARES_EDESTRUCTION, 'this ares channel has been destroyed')
*/

static PyObject *__pyx_pw_6gevent_8resolver_5cares_7channel_9set_servers(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6gevent_8resolver_5cares_7channel_set_servers(struct __pyx_obj_6gevent_8resolver_5cares_channel *__pyx_v_self, int __pyx_skip_dispatch, struct __pyx_opt_args_6gevent_8resolver_5cares_7channel_set_servers *__pyx_optional_args) {
  PyObject *__pyx_v_servers = ((PyObject *)Py_None);
  int __pyx_v_length;
  CYTHON_UNUSED int __pyx_v_result;
  int __pyx_v_index;
  char *__pyx_v_string;
  struct ares_addr_node *__pyx_v_c_servers;
  PyObject *__pyx_v_server = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  PyObject *(*__pyx_t_9)(PyObject *);
  char *__pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_t_13;
  int __pyx_t_14;
  char const *__pyx_t_15;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_servers", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_servers = __pyx_optional_args->servers;
    }
  }
  __Pyx_INCREF(__pyx_v_servers);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (
  #if !CYTHON_USE_TYPE_SLOTS
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_6gevent_8resolver_5cares_channel &&
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
  #else
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
  #endif
  ) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_set_servers); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 435, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_6gevent_8resolver_5cares_7channel_9set_servers)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_servers};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 435, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "gevent/resolver/cares.pyx":436
 * 
 *     cpdef set_servers(self, servers=None):
 *         if not self.channel:             # <<<<<<<<<<<<<<
 *             raise gaierror(cares.ARES_EDESTRUCTION, 'this ares channel has been destroyed')
 *         if not servers:
*/
  __pyx_t_6 = (!(__pyx_v_self->channel != 0));
  if (unlikely(__pyx_t_6)) {

    /* "gevent/resolver/cares.pyx":437
 *     cpdef set_servers(self, servers=None):
 *         if not self.channel:
 *             raise gaierror(cares.ARES_EDESTRUCTION, 'this ares channel has been destroyed')             # <<<<<<<<<<<<<<
 *         if not servers:
 *             servers = []
*/
    __pyx_t_2 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_gaierror); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 437, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyLong_From_int(ARES_EDESTRUCTION); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 437, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
      assert(__pyx_t_2);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
      __pyx_t_5 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_t_3, __pyx_mstate_global->__pyx_kp_u_this_ares_channel_has_been_destr};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 437, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 437, __pyx_L1_error)

    /* "gevent/resolver/cares.pyx":436
 * 
 *     cpdef set_servers(self, servers=None):
 *         if not self.channel:             # <<<<<<<<<<<<<<
 *             raise gaierror(cares.ARES_EDESTRUCTION, 'this ares channel has been destroyed')
 *         if not servers:
*/
  }

  /* "gevent/resolver/cares.pyx":438
 *         if not self.channel:
 *             raise gaierror(cares.ARES_EDESTRUCTION, 'this ares channel has been destroyed')
 *         if not servers:             # <<<<<<<<<<<<<<
 *             servers = []
 *         if isinstance(servers, str):
*/
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_servers); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 438, __pyx_L1_error)
  __pyx_t_7 = (!__pyx_t_6);
  if (__pyx_t_7) {

    /* "gevent/resolver/cares.pyx":439
 *             raise gaierror(cares.ARES_EDESTRUCTION, 'this ares channel has been destroyed')
 *         if not servers:
 *             servers = []             # <<<<<<<<<<<<<<
 *         if isinstance(servers, str):
 *             servers = servers.split(',')
*/
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 439, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_servers, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "gevent/resolver/cares.pyx":438
 *         if not self.channel:
 *             raise gaierror(cares.ARES_EDESTRUCTION, 'this ares channel has been destroyed')
 *         if not servers:             # <<<<<<<<<<<<<<
 *             servers = []
 *         if isinstance(servers, str):
*/
  }

  /* "gevent/resolver/cares.pyx":440
 *         if not servers:
 *             servers = []
 *         if isinstance(servers, str):             # <<<<<<<<<<<<<<
 *             servers = servers.split(',')
 *         cdef int length = len(servers)
*/
  __pyx_t_7 = PyUnicode_Check(__pyx_v_servers); 
  if (__pyx_t_7) {

    /* "gevent/resolver/cares.pyx":441
 *             servers = []
 *         if isinstance(servers, str):
 *             servers = servers.split(',')             # <<<<<<<<<<<<<<
 *         cdef int length = len(servers)
 *         cdef int result, index
*/
    __pyx_t_4 = __pyx_v_servers;
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_mstate_global->__pyx_kp_u__4};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_split, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 441, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF_SET(__pyx_v_servers, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "gevent/resolver/cares.pyx":440
 *         if not servers:
 *             servers = []
 *         if isinstance(servers, str):             # <<<<<<<<<<<<<<
 *             servers = servers.split(',')
 *         cdef int length = len(servers)
*/
  }

  /* "gevent/resolver/cares.pyx":442
 *         if isinstance(servers, str):
 *             servers = servers.split(',')
 *         cdef int length = len(servers)             # <<<<<<<<<<<<<<
 *         cdef int result, index
 *         cdef char* string
*/
  __pyx_t_8 = PyObject_Length(__pyx_v_servers); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 442, __pyx_L1_error)
  __pyx_v_length = __pyx_t_8;

  /* "gevent/resolver/cares.pyx":446
 *         cdef char* string
 *         cdef cares.ares_addr_node* c_servers
 *         if length <= 0:             # <<<<<<<<<<<<<<
 *             result = cares.ares_set_servers(self.channel, NULL)
 *         else:
*/
  __pyx_t_7 = (__pyx_v_length <= 0);
  if (__pyx_t_7) {

    /* "gevent/resolver/cares.pyx":447
 *         cdef cares.ares_addr_node* c_servers
 *         if length <= 0:
 *             result = cares.ares_set_servers(self.channel, NULL)             # <<<<<<<<<<<<<<
 *         else:
 *             c_servers = <cares.ares_addr_node*>PyMem_Malloc(sizeof(cares.ares_addr_node) * length)
*/
    __pyx_v_result = ares_set_servers(__pyx_v_self->channel, NULL);

    /* "gevent/resolver/cares.pyx":446
 *         cdef char* string
 *         cdef cares.ares_addr_node* c_servers
 *         if length <= 0:             # <<<<<<<<<<<<<<
 *             result = cares.ares_set_servers(self.channel, NULL)
 *         else:
*/
    goto __pyx_L6;
  }

  /* "gevent/resolver/cares.pyx":449
 *             result = cares.ares_set_servers(self.channel, NULL)
 *         else:
 *             c_servers = <cares.ares_addr_node*>PyMem_Malloc(sizeof(cares.ares_addr_node) * length)             # <<<<<<<<<<<<<<
 *             if not c_servers:
 *                 raise MemoryError
*/
  /*else*/ {
    __pyx_v_c_servers = ((struct ares_addr_node *)PyMem_Malloc(((sizeof(struct ares_addr_node)) * __pyx_v_length)));

    /* "gevent/resolver/cares.pyx":450
 *         else:
 *             c_servers = <cares.ares_addr_node*>PyMem_Malloc(sizeof(cares.ares_addr_node) * length)
 *             if not c_servers:             # <<<<<<<<<<<<<<
 *                 raise MemoryError
 *             try:
*/
    __pyx_t_7 = (!(__pyx_v_c_servers != 0));
    if (unlikely(__pyx_t_7)) {

      /* "gevent/resolver/cares.pyx":451
 *             c_servers = <cares.ares_addr_node*>PyMem_Malloc(sizeof(cares.ares_addr_node) * length)
 *             if not c_servers:
 *                 raise MemoryError             # <<<<<<<<<<<<<<
 *             try:
 *                 index = 0
*/
      PyErr_NoMemory(); __PYX_ERR(0, 451, __pyx_L1_error)

      /* "gevent/resolver/cares.pyx":450
 *         else:
 *             c_servers = <cares.ares_addr_node*>PyMem_Malloc(sizeof(cares.ares_addr_node) * length)
 *             if not c_servers:             # <<<<<<<<<<<<<<
 *                 raise MemoryError
 *             try:
*/
    }

    /* "gevent/resolver/cares.pyx":452
 *             if not c_servers:
 *                 raise MemoryError
 *             try:             # <<<<<<<<<<<<<<
 *                 index = 0
 *                 for server in servers:
*/
    /*try:*/ {

      /* "gevent/resolver/cares.pyx":453
 *                 raise MemoryError
 *             try:
 *                 index = 0             # <<<<<<<<<<<<<<
 *                 for server in servers:
 *                     if isinstance(server, unicode):
*/
      __pyx_v_index = 0;

      /* "gevent/resolver/cares.pyx":454
 *             try:
 *                 index = 0
 *                 for server in servers:             # <<<<<<<<<<<<<<
 *                     if isinstance(server, unicode):
 *                         server = server.encode('ascii')
*/
      if (likely(PyList_CheckExact(__pyx_v_servers)) || PyTuple_CheckExact(__pyx_v_servers)) {
        __pyx_t_1 = __pyx_v_servers; __Pyx_INCREF(__pyx_t_1);
        __pyx_t_8 = 0;
        __pyx_t_9 = NULL;
      } else {
        __pyx_t_8 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_servers); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 454, __pyx_L9_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_9 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 454, __pyx_L9_error)
      }
      for (;;) {
        if (likely(!__pyx_t_9)) {
          if (likely(PyList_CheckExact(__pyx_t_1))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
              #if !CYTHON_ASSUME_SAFE_SIZE
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 454, __pyx_L9_error)
              #endif
              if (__pyx_t_8 >= __pyx_temp) break;
            }
            __pyx_t_4 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_8, __Pyx_ReferenceSharing_OwnStrongReference);
            ++__pyx_t_8;
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
              #if !CYTHON_ASSUME_SAFE_SIZE
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 454, __pyx_L9_error)
              #endif
              if (__pyx_t_8 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_4 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_8));
            #else
            __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_8);
            #endif
            ++__pyx_t_8;
          }
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 454, __pyx_L9_error)
        } else {
          __pyx_t_4 = __pyx_t_9(__pyx_t_1);
          if (unlikely(!__pyx_t_4)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 454, __pyx_L9_error)
              PyErr_Clear();
            }
            break;
          }
        }
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_XDECREF_SET(__pyx_v_server, __pyx_t_4);
        __pyx_t_4 = 0;

        /* "gevent/resolver/cares.pyx":455
 *                 index = 0
 *                 for server in servers:
 *                     if isinstance(server, unicode):             # <<<<<<<<<<<<<<
 *                         server = server.encode('ascii')
 *                     string = <char*?>server
*/
        __pyx_t_7 = PyUnicode_Check(__pyx_v_server); 
        if (__pyx_t_7) {

          /* "gevent/resolver/cares.pyx":456
 *                 for server in servers:
 *                     if isinstance(server, unicode):
 *                         server = server.encode('ascii')             # <<<<<<<<<<<<<<
 *                     string = <char*?>server
 *                     if cares.ares_inet_pton(AF_INET, string, &c_servers[index].addr) > 0:
*/
          __pyx_t_3 = __pyx_v_server;
          __Pyx_INCREF(__pyx_t_3);
          __pyx_t_5 = 0;
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_n_u_ascii};
            __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_encode, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
            if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 456, __pyx_L9_error)
            __Pyx_GOTREF(__pyx_t_4);
          }
          __Pyx_DECREF_SET(__pyx_v_server, __pyx_t_4);
          __pyx_t_4 = 0;

          /* "gevent/resolver/cares.pyx":455
 *                 index = 0
 *                 for server in servers:
 *                     if isinstance(server, unicode):             # <<<<<<<<<<<<<<
 *                         server = server.encode('ascii')
 *                     string = <char*?>server
*/
        }

        /* "gevent/resolver/cares.pyx":457
 *                     if isinstance(server, unicode):
 *                         server = server.encode('ascii')
 *                     string = <char*?>server             # <<<<<<<<<<<<<<
 *                     if cares.ares_inet_pton(AF_INET, string, &c_servers[index].addr) > 0:
 *                         c_servers[index].family = AF_INET
*/
        __pyx_t_10 = __Pyx_PyObject_AsWritableString(__pyx_v_server); if (unlikely((!__pyx_t_10) && PyErr_Occurred())) __PYX_ERR(0, 457, __pyx_L9_error)
        __pyx_v_string = ((char *)__pyx_t_10);

        /* "gevent/resolver/cares.pyx":458
 *                         server = server.encode('ascii')
 *                     string = <char*?>server
 *                     if cares.ares_inet_pton(AF_INET, string, &c_servers[index].addr) > 0:             # <<<<<<<<<<<<<<
 *                         c_servers[index].family = AF_INET
 *                     elif cares.ares_inet_pton(AF_INET6, string, &c_servers[index].addr) > 0:
*/
        __pyx_t_7 = (ares_inet_pton(AF_INET, __pyx_v_string, (&(__pyx_v_c_servers[__pyx_v_index]).addr)) > 0);
        if (__pyx_t_7) {

          /* "gevent/resolver/cares.pyx":459
 *                     string = <char*?>server
 *                     if cares.ares_inet_pton(AF_INET, string, &c_servers[index].addr) > 0:
 *                         c_servers[index].family = AF_INET             # <<<<<<<<<<<<<<
 *                     elif cares.ares_inet_pton(AF_INET6, string, &c_servers[index].addr) > 0:
 *                         c_servers[index].family = AF_INET6
*/
          (__pyx_v_c_servers[__pyx_v_index]).family = AF_INET;

          /* "gevent/resolver/cares.pyx":458
 *                         server = server.encode('ascii')
 *                     string = <char*?>server
 *                     if cares.ares_inet_pton(AF_INET, string, &c_servers[index].addr) > 0:             # <<<<<<<<<<<<<<
 *                         c_servers[index].family = AF_INET
 *                     elif cares.ares_inet_pton(AF_INET6, string, &c_servers[index].addr) > 0:
*/
          goto __pyx_L14;
        }

        /* "gevent/resolver/cares.pyx":460
 *                     if cares.ares_inet_pton(AF_INET, string, &c_servers[index].addr) > 0:
 *                         c_servers[index].family = AF_INET
 *                     elif cares.ares_inet_pton(AF_INET6, string, &c_servers[index].addr) > 0:             # <<<<<<<<<<<<<<
 *                         c_servers[index].family = AF_INET6
 *                     else:
*/
        __pyx_t_7 = (ares_inet_pton(AF_INET6, __pyx_v_string, (&(__pyx_v_c_servers[__pyx_v_index]).addr)) > 0);
        if (likely(__pyx_t_7)) {

          /* "gevent/resolver/cares.pyx":461
 *                         c_servers[index].family = AF_INET
 *                     elif cares.ares_inet_pton(AF_INET6, string, &c_servers[index].addr) > 0:
 *                         c_servers[index].family = AF_INET6             # <<<<<<<<<<<<<<
 *                     else:
 *                         raise InvalidIP(repr(string))
*/
          (__pyx_v_c_servers[__pyx_v_index]).family = AF_INET6;

          /* "gevent/resolver/cares.pyx":460
 *                     if cares.ares_inet_pton(AF_INET, string, &c_servers[index].addr) > 0:
 *                         c_servers[index].family = AF_INET
 *                     elif cares.ares_inet_pton(AF_INET6, string, &c_servers[index].addr) > 0:             # <<<<<<<<<<<<<<
 *                         c_servers[index].family = AF_INET6
 *                     else:
*/
          goto __pyx_L14;
        }

        /* "gevent/resolver/cares.pyx":463
 *                         c_servers[index].family = AF_INET6
 *                     else:
 *                         raise InvalidIP(repr(string))             # <<<<<<<<<<<<<<
 *                     c_servers[index].next = &c_servers[index] + 1
 *                     index += 1
*/
        /*else*/ {
          __pyx_t_3 = NULL;
          __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_InvalidIP); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 463, __pyx_L9_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_11 = __Pyx_PyBytes_FromString(__pyx_v_string); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 463, __pyx_L9_error)
          __Pyx_GOTREF(__pyx_t_11);
          __pyx_t_12 = PyObject_Repr(__pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 463, __pyx_L9_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __pyx_t_5 = 1;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_2))) {
            __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
            assert(__pyx_t_3);
            PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
            __Pyx_INCREF(__pyx_t_3);
            __Pyx_INCREF(__pyx__function);
            __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
            __pyx_t_5 = 0;
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_12};
            __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 463, __pyx_L9_error)
            __Pyx_GOTREF(__pyx_t_4);
          }
          __Pyx_Raise(__pyx_t_4, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __PYX_ERR(0, 463, __pyx_L9_error)
        }
        __pyx_L14:;

        /* "gevent/resolver/cares.pyx":464
 *                     else:
 *                         raise InvalidIP(repr(string))
 *                     c_servers[index].next = &c_servers[index] + 1             # <<<<<<<<<<<<<<
 *                     index += 1
 *                     if index >= length:
*/
        (__pyx_v_c_servers[__pyx_v_index]).next = ((&(__pyx_v_c_servers[__pyx_v_index])) + 1);

        /* "gevent/resolver/cares.pyx":465
 *                         raise InvalidIP(repr(string))
 *                     c_servers[index].next = &c_servers[index] + 1
 *                     index += 1             # <<<<<<<<<<<<<<
 *                     if index >= length:
 *                         break
*/
        __pyx_v_index = (__pyx_v_index + 1);

        /* "gevent/resolver/cares.pyx":466
 *                     c_servers[index].next = &c_servers[index] + 1
 *                     index += 1
 *                     if index >= length:             # <<<<<<<<<<<<<<
 *                         break
 *                 c_servers[length - 1].next = NULL
*/
        __pyx_t_7 = (__pyx_v_index >= __pyx_v_length);
        if (__pyx_t_7) {

          /* "gevent/resolver/cares.pyx":467
 *                     index += 1
 *                     if index >= length:
 *                         break             # <<<<<<<<<<<<<<
 *                 c_servers[length - 1].next = NULL
 *                 index = cares.ares_set_servers(self.channel, c_servers)
*/
          goto __pyx_L12_break;

          /* "gevent/resolver/cares.pyx":466
 *                     c_servers[index].next = &c_servers[index] + 1
 *                     index += 1
 *                     if index >= length:             # <<<<<<<<<<<<<<
 *                         break
 *                 c_servers[length - 1].next = NULL
*/
        }

        /* "gevent/resolver/cares.pyx":454
 *             try:
 *                 index = 0
 *                 for server in servers:             # <<<<<<<<<<<<<<
 *                     if isinstance(server, unicode):
 *                         server = server.encode('ascii')
*/
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L16_for_end;
      __pyx_L12_break:;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L16_for_end;
      __pyx_L16_for_end:;

      /* "gevent/resolver/cares.pyx":468
 *                     if index >= length:
 *                         break
 *                 c_servers[length - 1].next = NULL             # <<<<<<<<<<<<<<
 *                 index = cares.ares_set_servers(self.channel, c_servers)
 *                 if index:
*/
      (__pyx_v_c_servers[(__pyx_v_length - 1)]).next = NULL;

      /* "gevent/resolver/cares.pyx":469
 *                         break
 *                 c_servers[length - 1].next = NULL
 *                 index = cares.ares_set_servers(self.channel, c_servers)             # <<<<<<<<<<<<<<
 *                 if index:
 *                     raise ValueError(_gevent_gai_strerror(index))
*/
      __pyx_v_index = ares_set_servers(__pyx_v_self->channel, __pyx_v_c_servers);

      /* "gevent/resolver/cares.pyx":470
 *                 c_servers[length - 1].next = NULL
 *                 index = cares.ares_set_servers(self.channel, c_servers)
 *                 if index:             # <<<<<<<<<<<<<<
 *                     raise ValueError(_gevent_gai_strerror(index))
 *             finally:
*/
      __pyx_t_7 = (__pyx_v_index != 0);
      if (unlikely(__pyx_t_7)) {

        /* "gevent/resolver/cares.pyx":471
 *                 index = cares.ares_set_servers(self.channel, c_servers)
 *                 if index:
 *                     raise ValueError(_gevent_gai_strerror(index))             # <<<<<<<<<<<<<<
 *             finally:
 *                 PyMem_Free(c_servers)
*/
        __pyx_t_4 = NULL;
        __pyx_t_2 = __Pyx_PyLong_From_int(__pyx_v_index); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 471, __pyx_L9_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_12 = __pyx_f_6gevent_8resolver_5cares__gevent_gai_strerror(__pyx_t_2); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 471, __pyx_L9_error)
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_5 = 1;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_12};
          __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_ValueError)), __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 471, __pyx_L9_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_Raise(__pyx_t_1, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __PYX_ERR(0, 471, __pyx_L9_error)

        /* "gevent/resolver/cares.pyx":470
 *                 c_servers[length - 1].next = NULL
 *                 index = cares.ares_set_servers(self.channel, c_servers)
 *                 if index:             # <<<<<<<<<<<<<<
 *                     raise ValueError(_gevent_gai_strerror(index))
 *             finally:
*/
      }
    }

    /* "gevent/resolver/cares.pyx":473
 *                     raise ValueError(_gevent_gai_strerror(index))
 *             finally:
 *                 PyMem_Free(c_servers)             # <<<<<<<<<<<<<<
 * 
 *     # this crashes c-ares
*/
    /*finally:*/ {
      /*normal exit:*/{
        PyMem_Free(__pyx_v_c_servers);
        goto __pyx_L10;
      }
      __pyx_L9_error:;
      /*exception exit:*/{
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
         __Pyx_ExceptionSwap(&__pyx_t_19, &__pyx_t_20, &__pyx_t_21);
        if ( unlikely(__Pyx_GetException(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18) < 0)) __Pyx_ErrFetch(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18);
        __Pyx_XGOTREF(__pyx_t_16);
        __Pyx_XGOTREF(__pyx_t_17);
        __Pyx_XGOTREF(__pyx_t_18);
        __Pyx_XGOTREF(__pyx_t_19);
        __Pyx_XGOTREF(__pyx_t_20);
        __Pyx_XGOTREF(__pyx_t_21);
        __pyx_t_13 = __pyx_lineno; __pyx_t_14 = __pyx_clineno; __pyx_t_15 = __pyx_filename;
        {
          PyMem_Free(__pyx_v_c_servers);
        }
        __Pyx_XGIVEREF(__pyx_t_19);
        __Pyx_XGIVEREF(__pyx_t_20);
        __Pyx_XGIVEREF(__pyx_t_21);
        __Pyx_ExceptionReset(__pyx_t_19, __pyx_t_20, __pyx_t_21);
        __Pyx_XGIVEREF(__pyx_t_16);
        __Pyx_XGIVEREF(__pyx_t_17);
        __Pyx_XGIVEREF(__pyx_t_18);
        __Pyx_ErrRestore(__pyx_t_16, __pyx_t_17, __pyx_t_18);
        __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0;
        __pyx_lineno = __pyx_t_13; __pyx_clineno = __pyx_t_14; __pyx_filename = __pyx_t_15;
        goto __pyx_L1_error;
      }
      __pyx_L10:;
    }
  }
  __pyx_L6:;

  /* "gevent/resolver/cares.pyx":435
 *         self.__destroy()
 * 
 *     cpdef set_servers(self, servers=None):             # <<<<<<<<<<<<<<
 *         if not self.channel:
 *             raise gaierror(cares.ARES_EDESTRUCTION, 'this ares channel has been destroyed')
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("gevent.resolver.cares.channel.set_servers", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_server);
  __Pyx_XDECREF(__pyx_v_servers);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_8resolver_5cares_7channel_9set_servers(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6gevent_8resolver_5cares_7channel_9set_servers = {"set_servers", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6gevent_8resolver_5cares_7channel_9set_servers, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6gevent_8resolver_5cares_7channel_9set_servers(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_servers = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_servers (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_servers,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 435, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 435, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "set_servers", 0) < (0)) __PYX_ERR(0, 435, __pyx_L3_error)
      if (!values[0]) values[0] = __Pyx_NewRef(((PyObject *)Py_None));
    } else {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 435, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[0]) values[0] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_servers = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_servers", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 435, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("gevent.resolver.cares.channel.set_servers", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6gevent_8resolver_5cares_7channel_8set_servers(((struct __pyx_obj_6gevent_8resolver_5cares_channel *)__pyx_v_self), __pyx_v_servers);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_8resolver_5cares_7channel_8set_servers(struct __pyx_obj_6gevent_8resolver_5cares_channel *__pyx_v_self, PyObject *__pyx_v_servers) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_6gevent_8resolver_5cares_7channel_set_servers __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_servers", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.servers = __pyx_v_servers;
  __pyx_t_1 = __pyx_vtabptr_6gevent_8resolver_5cares_channel->set_servers(__pyx_v_self, 1, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent.resolver.cares.channel.set_servers", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/resolver/cares.pyx":479
 *     #    cares.ares_cancel(self.channel)
 * 
 *     cdef _sock_state_callback(self, int socket, int read, int write):             # <<<<<<<<<<<<<<
 *         if not self.channel:
 *             return
*/

static PyObject *__pyx_f_6gevent_8resolver_5cares_7channel__sock_state_callback(struct __pyx_obj_6gevent_8resolver_5cares_channel *__pyx_v_self, int __pyx_v_socket, int __pyx_v_read, int __pyx_v_write) {
  PyObject *__pyx_v_watcher = 0;
  int __pyx_v_events;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_sock_state_callback", 0);

  /* "gevent/resolver/cares.pyx":480
 * 
 *     cdef _sock_state_callback(self, int socket, int read, int write):
 *         if not self.channel:             # <<<<<<<<<<<<<<
 *             return
 *         cdef object watcher = self._watchers.get(socket)
*/
  __pyx_t_1 = (!(__pyx_v_self->channel != 0));
  if (__pyx_t_1) {

    /* "gevent/resolver/cares.pyx":481
 *     cdef _sock_state_callback(self, int socket, int read, int write):
 *         if not self.channel:
 *             return             # <<<<<<<<<<<<<<
 *         cdef object watcher = self._watchers.get(socket)
 *         cdef int events = 0
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "gevent/resolver/cares.pyx":480
 * 
 *     cdef _sock_state_callback(self, int socket, int read, int write):
 *         if not self.channel:             # <<<<<<<<<<<<<<
 *             return
 *         cdef object watcher = self._watchers.get(socket)
*/
  }

  /* "gevent/resolver/cares.pyx":482
 *         if not self.channel:
 *             return
 *         cdef object watcher = self._watchers.get(socket)             # <<<<<<<<<<<<<<
 *         cdef int events = 0
 *         if read:
*/
  if (unlikely(__pyx_v_self->_watchers == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "get");
    __PYX_ERR(0, 482, __pyx_L1_error)
  }
  __pyx_t_2 = __Pyx_PyLong_From_int(__pyx_v_socket); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyDict_GetItemDefault(__pyx_v_self->_watchers, __pyx_t_2, Py_None); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_watcher = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "gevent/resolver/cares.pyx":483
 *             return
 *         cdef object watcher = self._watchers.get(socket)
 *         cdef int events = 0             # <<<<<<<<<<<<<<
 *         if read:
 *             events |= EV_READ
*/
  __pyx_v_events = 0;

  /* "gevent/resolver/cares.pyx":484
 *         cdef object watcher = self._watchers.get(socket)
 *         cdef int events = 0
 *         if read:             # <<<<<<<<<<<<<<
 *             events |= EV_READ
 *         if write:
*/
  __pyx_t_1 = (__pyx_v_read != 0);
  if (__pyx_t_1) {

    /* "gevent/resolver/cares.pyx":485
 *         cdef int events = 0
 *         if read:
 *             events |= EV_READ             # <<<<<<<<<<<<<<
 *         if write:
 *             events |= EV_WRITE
*/
    __pyx_v_events = (__pyx_v_events | EV_READ);

    /* "gevent/resolver/cares.pyx":484
 *         cdef object watcher = self._watchers.get(socket)
 *         cdef int events = 0
 *         if read:             # <<<<<<<<<<<<<<
 *             events |= EV_READ
 *         if write:
*/
  }

  /* "gevent/resolver/cares.pyx":486
 *         if read:
 *             events |= EV_READ
 *         if write:             # <<<<<<<<<<<<<<
 *             events |= EV_WRITE
 *         if watcher is None:
*/
  __pyx_t_1 = (__pyx_v_write != 0);
  if (__pyx_t_1) {

    /* "gevent/resolver/cares.pyx":487
 *             events |= EV_READ
 *         if write:
 *             events |= EV_WRITE             # <<<<<<<<<<<<<<
 *         if watcher is None:
 *             if not events:
*/
    __pyx_v_events = (__pyx_v_events | EV_WRITE);

    /* "gevent/resolver/cares.pyx":486
 *         if read:
 *             events |= EV_READ
 *         if write:             # <<<<<<<<<<<<<<
 *             events |= EV_WRITE
 *         if watcher is None:
*/
  }

  /* "gevent/resolver/cares.pyx":488
 *         if write:
 *             events |= EV_WRITE
 *         if watcher is None:             # <<<<<<<<<<<<<<
 *             if not events:
 *                 return
*/
  __pyx_t_1 = (__pyx_v_watcher == Py_None);
  if (__pyx_t_1) {

    /* "gevent/resolver/cares.pyx":489
 *             events |= EV_WRITE
 *         if watcher is None:
 *             if not events:             # <<<<<<<<<<<<<<
 *                 return
 *             watcher = self.loop.io(socket, events)
*/
    __pyx_t_1 = (!(__pyx_v_events != 0));
    if (__pyx_t_1) {

      /* "gevent/resolver/cares.pyx":490
 *         if watcher is None:
 *             if not events:
 *                 return             # <<<<<<<<<<<<<<
 *             watcher = self.loop.io(socket, events)
 *             self._watchers[socket] = watcher
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      goto __pyx_L0;

      /* "gevent/resolver/cares.pyx":489
 *             events |= EV_WRITE
 *         if watcher is None:
 *             if not events:             # <<<<<<<<<<<<<<
 *                 return
 *             watcher = self.loop.io(socket, events)
*/
    }

    /* "gevent/resolver/cares.pyx":491
 *             if not events:
 *                 return
 *             watcher = self.loop.io(socket, events)             # <<<<<<<<<<<<<<
 *             self._watchers[socket] = watcher
 *         elif events:
*/
    __pyx_t_2 = __pyx_v_self->loop;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyLong_From_int(__pyx_v_socket); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 491, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyLong_From_int(__pyx_v_events); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 491, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = 0;
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_t_4, __pyx_t_5};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_io, __pyx_callargs+__pyx_t_6, (3-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 491, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF_SET(__pyx_v_watcher, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "gevent/resolver/cares.pyx":492
 *                 return
 *             watcher = self.loop.io(socket, events)
 *             self._watchers[socket] = watcher             # <<<<<<<<<<<<<<
 *         elif events:
 *             if watcher.events == events:
*/
    if (unlikely(__pyx_v_self->_watchers == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 492, __pyx_L1_error)
    }
    __pyx_t_3 = __Pyx_PyLong_From_int(__pyx_v_socket); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 492, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (unlikely((PyDict_SetItem(__pyx_v_self->_watchers, __pyx_t_3, __pyx_v_watcher) < 0))) __PYX_ERR(0, 492, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "gevent/resolver/cares.pyx":488
 *         if write:
 *             events |= EV_WRITE
 *         if watcher is None:             # <<<<<<<<<<<<<<
 *             if not events:
 *                 return
*/
    goto __pyx_L6;
  }

  /* "gevent/resolver/cares.pyx":493
 *             watcher = self.loop.io(socket, events)
 *             self._watchers[socket] = watcher
 *         elif events:             # <<<<<<<<<<<<<<
 *             if watcher.events == events:
 *                 return
*/
  __pyx_t_1 = (__pyx_v_events != 0);
  if (__pyx_t_1) {

    /* "gevent/resolver/cares.pyx":494
 *             self._watchers[socket] = watcher
 *         elif events:
 *             if watcher.events == events:             # <<<<<<<<<<<<<<
 *                 return
 *             watcher.stop()
*/
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_watcher, __pyx_mstate_global->__pyx_n_u_events); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 494, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = __Pyx_PyLong_From_int(__pyx_v_events); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 494, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = PyObject_RichCompare(__pyx_t_3, __pyx_t_5, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 494, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 494, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_1) {

      /* "gevent/resolver/cares.pyx":495
 *         elif events:
 *             if watcher.events == events:
 *                 return             # <<<<<<<<<<<<<<
 *             watcher.stop()
 *             watcher.events = events
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      goto __pyx_L0;

      /* "gevent/resolver/cares.pyx":494
 *             self._watchers[socket] = watcher
 *         elif events:
 *             if watcher.events == events:             # <<<<<<<<<<<<<<
 *                 return
 *             watcher.stop()
*/
    }

    /* "gevent/resolver/cares.pyx":496
 *             if watcher.events == events:
 *                 return
 *             watcher.stop()             # <<<<<<<<<<<<<<
 *             watcher.events = events
 *         else:
*/
    __pyx_t_5 = __pyx_v_watcher;
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_6 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
      __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_stop, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 496, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "gevent/resolver/cares.pyx":497
 *                 return
 *             watcher.stop()
 *             watcher.events = events             # <<<<<<<<<<<<<<
 *         else:
 *             watcher.stop()
*/
    __pyx_t_4 = __Pyx_PyLong_From_int(__pyx_v_events); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 497, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_watcher, __pyx_mstate_global->__pyx_n_u_events, __pyx_t_4) < (0)) __PYX_ERR(0, 497, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "gevent/resolver/cares.pyx":493
 *             watcher = self.loop.io(socket, events)
 *             self._watchers[socket] = watcher
 *         elif events:             # <<<<<<<<<<<<<<
 *             if watcher.events == events:
 *                 return
*/
    goto __pyx_L6;
  }

  /* "gevent/resolver/cares.pyx":499
 *             watcher.events = events
 *         else:
 *             watcher.stop()             # <<<<<<<<<<<<<<
 *             watcher.close()
 *             self._watchers.pop(socket, None)
*/
  /*else*/ {
    __pyx_t_5 = __pyx_v_watcher;
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_6 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
      __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_stop, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 499, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "gevent/resolver/cares.pyx":500
 *         else:
 *             watcher.stop()
 *             watcher.close()             # <<<<<<<<<<<<<<
 *             self._watchers.pop(socket, None)
 *             if not self._watchers:
*/
    __pyx_t_5 = __pyx_v_watcher;
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_6 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
      __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_close, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 500, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "gevent/resolver/cares.pyx":501
 *             watcher.stop()
 *             watcher.close()
 *             self._watchers.pop(socket, None)             # <<<<<<<<<<<<<<
 *             if not self._watchers:
 *                 self._timer.stop()
*/
    if (unlikely(__pyx_v_self->_watchers == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "pop");
      __PYX_ERR(0, 501, __pyx_L1_error)
    }
    __pyx_t_4 = __Pyx_PyLong_From_int(__pyx_v_socket); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 501, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = __Pyx_PyDict_Pop_ignore(__pyx_v_self->_watchers, __pyx_t_4, Py_None); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 501, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "gevent/resolver/cares.pyx":502
 *             watcher.close()
 *             self._watchers.pop(socket, None)
 *             if not self._watchers:             # <<<<<<<<<<<<<<
 *                 self._timer.stop()
 *             return
*/
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_self->_watchers); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 502, __pyx_L1_error)
    __pyx_t_8 = (!__pyx_t_1);
    if (__pyx_t_8) {

      /* "gevent/resolver/cares.pyx":503
 *             self._watchers.pop(socket, None)
 *             if not self._watchers:
 *                 self._timer.stop()             # <<<<<<<<<<<<<<
 *             return
 *         watcher.start(self._process_fd, watcher, pass_events=True)
*/
      __pyx_t_5 = __pyx_v_self->_timer;
      __Pyx_INCREF(__pyx_t_5);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
        __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_stop, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 503, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "gevent/resolver/cares.pyx":502
 *             watcher.close()
 *             self._watchers.pop(socket, None)
 *             if not self._watchers:             # <<<<<<<<<<<<<<
 *                 self._timer.stop()
 *             return
*/
    }

    /* "gevent/resolver/cares.pyx":504
 *             if not self._watchers:
 *                 self._timer.stop()
 *             return             # <<<<<<<<<<<<<<
 *         watcher.start(self._process_fd, watcher, pass_events=True)
 *         self._timer.again(self._on_timer)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;
  }
  __pyx_L6:;

  /* "gevent/resolver/cares.pyx":505
 *                 self._timer.stop()
 *             return
 *         watcher.start(self._process_fd, watcher, pass_events=True)             # <<<<<<<<<<<<<<
 *         self._timer.again(self._on_timer)
 * 
*/
  __pyx_t_5 = __pyx_v_watcher;
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_process_fd); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 505, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[3 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_5, __pyx_t_3, __pyx_v_watcher};
    __pyx_t_2 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 505, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_pass_events, Py_True, __pyx_t_2, __pyx_callargs+3, 0) < (0)) __PYX_ERR(0, 505, __pyx_L1_error)
    __pyx_t_4 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_start, __pyx_callargs+__pyx_t_6, (3-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_2);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 505, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "gevent/resolver/cares.pyx":506
 *             return
 *         watcher.start(self._process_fd, watcher, pass_events=True)
 *         self._timer.again(self._on_timer)             # <<<<<<<<<<<<<<
 * 
 *     def _on_timer(self):
*/
  __pyx_t_2 = __pyx_v_self->_timer;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_on_timer); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 506, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_3};
    __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_again, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 506, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "gevent/resolver/cares.pyx":479
 *     #    cares.ares_cancel(self.channel)
 * 
 *     cdef _sock_state_callback(self, int socket, int read, int write):             # <<<<<<<<<<<<<<
 *         if not self.channel:
 *             return
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("gevent.resolver.cares.channel._sock_state_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_watcher);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/resolver/cares.pyx":508
 *         self._timer.again(self._on_timer)
 * 
 *     def _on_timer(self):             # <<<<<<<<<<<<<<
 *         cares.ares_process_fd(self.channel, cares.ARES_SOCKET_BAD, cares.ARES_SOCKET_BAD)
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_8resolver_5cares_7channel_11_on_timer(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_6gevent_8resolver_5cares_7channel_11_on_timer = {"_on_timer", (PyCFunction)__pyx_pw_6gevent_8resolver_5cares_7channel_11_on_timer, METH_NOARGS, 0};
static PyObject *__pyx_pw_6gevent_8resolver_5cares_7channel_11_on_timer(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_on_timer (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_8resolver_5cares_7channel_10_on_timer(((struct __pyx_obj_6gevent_8resolver_5cares_channel *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_8resolver_5cares_7channel_10_on_timer(struct __pyx_obj_6gevent_8resolver_5cares_channel *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_on_timer", 0);

  /* "gevent/resolver/cares.pyx":509
 * 
 *     def _on_timer(self):
 *         cares.ares_process_fd(self.channel, cares.ARES_SOCKET_BAD, cares.ARES_SOCKET_BAD)             # <<<<<<<<<<<<<<
 * 
 *     def _process_fd(self, int events, object watcher):
*/
  ares_process_fd(__pyx_v_self->channel, ARES_SOCKET_BAD, ARES_SOCKET_BAD);

  /* "gevent/resolver/cares.pyx":508
 *         self._timer.again(self._on_timer)
 * 
 *     def _on_timer(self):             # <<<<<<<<<<<<<<
 *         cares.ares_process_fd(self.channel, cares.ARES_SOCKET_BAD, cares.ARES_SOCKET_BAD)
 * 
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/resolver/cares.pyx":511
 *         cares.ares_process_fd(self.channel, cares.ARES_SOCKET_BAD, cares.ARES_SOCKET_BAD)
 * 
 *     def _process_fd(self, int events, object watcher):             # <<<<<<<<<<<<<<
 *         if not self.channel:
 *             return
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_8resolver_5cares_7channel_13_process_fd(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6gevent_8resolver_5cares_7channel_13_process_fd = {"_process_fd", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6gevent_8resolver_5cares_7channel_13_process_fd, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6gevent_8resolver_5cares_7channel_13_process_fd(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  int __pyx_v_events;
  PyObject *__pyx_v_watcher = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_process_fd (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_events,&__pyx_mstate_global->__pyx_n_u_watcher,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 511, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 511, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 511, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_process_fd", 0) < (0)) __PYX_ERR(0, 511, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_process_fd", 1, 2, 2, i); __PYX_ERR(0, 511, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 511, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 511, __pyx_L3_error)
    }
    __pyx_v_events = __Pyx_PyLong_As_int(values[0]); if (unlikely((__pyx_v_events == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 511, __pyx_L3_error)
    __pyx_v_watcher = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_process_fd", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 511, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("gevent.resolver.cares.channel._process_fd", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6gevent_8resolver_5cares_7channel_12_process_fd(((struct __pyx_obj_6gevent_8resolver_5cares_channel *)__pyx_v_self), __pyx_v_events, __pyx_v_watcher);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_8resolver_5cares_7channel_12_process_fd(struct __pyx_obj_6gevent_8resolver_5cares_channel *__pyx_v_self, int __pyx_v_events, PyObject *__pyx_v_watcher) {
  int __pyx_v_read_fd;
  int __pyx_v_write_fd;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_process_fd", 0);

  /* "gevent/resolver/cares.pyx":512
 * 
 *     def _process_fd(self, int events, object watcher):
 *         if not self.channel:             # <<<<<<<<<<<<<<
 *             return
 *         cdef int read_fd = watcher.fd
*/
  __pyx_t_1 = (!(__pyx_v_self->channel != 0));
  if (__pyx_t_1) {

    /* "gevent/resolver/cares.pyx":513
 *     def _process_fd(self, int events, object watcher):
 *         if not self.channel:
 *             return             # <<<<<<<<<<<<<<
 *         cdef int read_fd = watcher.fd
 *         cdef int write_fd = read_fd
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "gevent/resolver/cares.pyx":512
 * 
 *     def _process_fd(self, int events, object watcher):
 *         if not self.channel:             # <<<<<<<<<<<<<<
 *             return
 *         cdef int read_fd = watcher.fd
*/
  }

  /* "gevent/resolver/cares.pyx":514
 *         if not self.channel:
 *             return
 *         cdef int read_fd = watcher.fd             # <<<<<<<<<<<<<<
 *         cdef int write_fd = read_fd
 *         if not (events & EV_READ):
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_watcher, __pyx_mstate_global->__pyx_n_u_fd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyLong_As_int(__pyx_t_2); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 514, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_read_fd = __pyx_t_3;

  /* "gevent/resolver/cares.pyx":515
 *             return
 *         cdef int read_fd = watcher.fd
 *         cdef int write_fd = read_fd             # <<<<<<<<<<<<<<
 *         if not (events & EV_READ):
 *             read_fd = cares.ARES_SOCKET_BAD
*/
  __pyx_v_write_fd = __pyx_v_read_fd;

  /* "gevent/resolver/cares.pyx":516
 *         cdef int read_fd = watcher.fd
 *         cdef int write_fd = read_fd
 *         if not (events & EV_READ):             # <<<<<<<<<<<<<<
 *             read_fd = cares.ARES_SOCKET_BAD
 *         if not (events & EV_WRITE):
*/
  __pyx_t_1 = (!((__pyx_v_events & EV_READ) != 0));
  if (__pyx_t_1) {

    /* "gevent/resolver/cares.pyx":517
 *         cdef int write_fd = read_fd
 *         if not (events & EV_READ):
 *             read_fd = cares.ARES_SOCKET_BAD             # <<<<<<<<<<<<<<
 *         if not (events & EV_WRITE):
 *             write_fd = cares.ARES_SOCKET_BAD
*/
    __pyx_v_read_fd = ARES_SOCKET_BAD;

    /* "gevent/resolver/cares.pyx":516
 *         cdef int read_fd = watcher.fd
 *         cdef int write_fd = read_fd
 *         if not (events & EV_READ):             # <<<<<<<<<<<<<<
 *             read_fd = cares.ARES_SOCKET_BAD
 *         if not (events & EV_WRITE):
*/
  }

  /* "gevent/resolver/cares.pyx":518
 *         if not (events & EV_READ):
 *             read_fd = cares.ARES_SOCKET_BAD
 *         if not (events & EV_WRITE):             # <<<<<<<<<<<<<<
 *             write_fd = cares.ARES_SOCKET_BAD
 *         cares.ares_process_fd(self.channel, read_fd, write_fd)
*/
  __pyx_t_1 = (!((__pyx_v_events & EV_WRITE) != 0));
  if (__pyx_t_1) {

    /* "gevent/resolver/cares.pyx":519
 *             read_fd = cares.ARES_SOCKET_BAD
 *         if not (events & EV_WRITE):
 *             write_fd = cares.ARES_SOCKET_BAD             # <<<<<<<<<<<<<<
 *         cares.ares_process_fd(self.channel, read_fd, write_fd)
 * 
*/
    __pyx_v_write_fd = ARES_SOCKET_BAD;

    /* "gevent/resolver/cares.pyx":518
 *         if not (events & EV_READ):
 *             read_fd = cares.ARES_SOCKET_BAD
 *         if not (events & EV_WRITE):             # <<<<<<<<<<<<<<
 *             write_fd = cares.ARES_SOCKET_BAD
 *         cares.ares_process_fd(self.channel, read_fd, write_fd)
*/
  }

  /* "gevent/resolver/cares.pyx":520
 *         if not (events & EV_WRITE):
 *             write_fd = cares.ARES_SOCKET_BAD
 *         cares.ares_process_fd(self.channel, read_fd, write_fd)             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/
  ares_process_fd(__pyx_v_self->channel, __pyx_v_read_fd, __pyx_v_write_fd);

  /* "gevent/resolver/cares.pyx":511
 *         cares.ares_process_fd(self.channel, cares.ARES_SOCKET_BAD, cares.ARES_SOCKET_BAD)
 * 
 *     def _process_fd(self, int events, object watcher):             # <<<<<<<<<<<<<<
 *         if not self.channel:
 *             return
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("gevent.resolver.cares.channel._process_fd", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/resolver/cares.pyx":522
 *         cares.ares_process_fd(self.channel, read_fd, write_fd)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     cdef void _gethostbyname_or_byaddr_cb(void *arg, int status, int timeouts, hostent* host):
 *         cdef channel channel
*/

static void __pyx_f_6gevent_8resolver_5cares_7channel__gethostbyname_or_byaddr_cb(void *__pyx_v_arg, int __pyx_v_status, CYTHON_UNUSED int __pyx_v_timeouts, struct hostent *__pyx_v_host) {
  struct __pyx_obj_6gevent_8resolver_5cares_channel *__pyx_v_channel = 0;
  PyObject *__pyx_v_callback = 0;
  PyObject *__pyx_v_host_result = 0;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  size_t __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_gethostbyname_or_byaddr_cb", 0);

  /* "gevent/resolver/cares.pyx":526
 *         cdef channel channel
 *         cdef object callback
 *         channel, callback = <tuple>arg             # <<<<<<<<<<<<<<
 *         Py_DECREF(<tuple>arg)
 *         cdef object host_result
*/
  __pyx_t_1 = ((PyObject *)__pyx_v_arg);
  __Pyx_INCREF(__pyx_t_1);
  if (likely(__pyx_t_1 != Py_None)) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 526, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1);
    __Pyx_INCREF(__pyx_t_3);
    #else
    __pyx_t_2 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 526, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 526, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(0, 526, __pyx_L1_error)
  }
  if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_mstate_global->__pyx_ptype_6gevent_8resolver_5cares_channel))))) __PYX_ERR(0, 526, __pyx_L1_error)
  __pyx_v_channel = ((struct __pyx_obj_6gevent_8resolver_5cares_channel *)__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_v_callback = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "gevent/resolver/cares.pyx":527
 *         cdef object callback
 *         channel, callback = <tuple>arg
 *         Py_DECREF(<tuple>arg)             # <<<<<<<<<<<<<<
 *         cdef object host_result
 *         try:
*/
  Py_DECREF(((PyObject *)__pyx_v_arg));

  /* "gevent/resolver/cares.pyx":529
 *         Py_DECREF(<tuple>arg)
 *         cdef object host_result
 *         try:             # <<<<<<<<<<<<<<
 *             if status or not host:
 *                 callback(Result(None, _gevent_herror_from_status(status)))
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    /*try:*/ {

      /* "gevent/resolver/cares.pyx":530
 *         cdef object host_result
 *         try:
 *             if status or not host:             # <<<<<<<<<<<<<<
 *                 callback(Result(None, _gevent_herror_from_status(status)))
 *             else:
*/
      __pyx_t_8 = (__pyx_v_status != 0);
      if (!__pyx_t_8) {
      } else {
        __pyx_t_7 = __pyx_t_8;
        goto __pyx_L10_bool_binop_done;
      }
      __pyx_t_8 = (!(__pyx_v_host != 0));
      __pyx_t_7 = __pyx_t_8;
      __pyx_L10_bool_binop_done:;
      if (__pyx_t_7) {

        /* "gevent/resolver/cares.pyx":531
 *         try:
 *             if status or not host:
 *                 callback(Result(None, _gevent_herror_from_status(status)))             # <<<<<<<<<<<<<<
 *             else:
 *                 try:
*/
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_v_callback);
        __pyx_t_2 = __pyx_v_callback; 
        __pyx_t_10 = NULL;
        __pyx_t_11 = __pyx_f_6gevent_8resolver_5cares__gevent_herror_from_status(__pyx_v_status); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 531, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_12 = 1;
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_10, Py_None, __pyx_t_11};
          __pyx_t_9 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6gevent_8resolver_5cares_Result, __pyx_callargs+__pyx_t_12, (3-__pyx_t_12) | (__pyx_t_12*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 531, __pyx_L3_error)
          __Pyx_GOTREF((PyObject *)__pyx_t_9);
        }
        __pyx_t_12 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_2))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
          __pyx_t_12 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, ((PyObject *)__pyx_t_9)};
          __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_12, (2-__pyx_t_12) | (__pyx_t_12*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF((PyObject *)__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 531, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "gevent/resolver/cares.pyx":530
 *         cdef object host_result
 *         try:
 *             if status or not host:             # <<<<<<<<<<<<<<
 *                 callback(Result(None, _gevent_herror_from_status(status)))
 *             else:
*/
        goto __pyx_L9;
      }

      /* "gevent/resolver/cares.pyx":533
 *                 callback(Result(None, _gevent_herror_from_status(status)))
 *             else:
 *                 try:             # <<<<<<<<<<<<<<
 *                     host_result = ares_host_result(host.h_addrtype,
 *                                                    (_as_str(host.h_name),
*/
      /*else*/ {
        {
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __Pyx_ExceptionSave(&__pyx_t_13, &__pyx_t_14, &__pyx_t_15);
          __Pyx_XGOTREF(__pyx_t_13);
          __Pyx_XGOTREF(__pyx_t_14);
          __Pyx_XGOTREF(__pyx_t_15);
          /*try:*/ {

            /* "gevent/resolver/cares.pyx":534
 *             else:
 *                 try:
 *                     host_result = ares_host_result(host.h_addrtype,             # <<<<<<<<<<<<<<
 *                                                    (_as_str(host.h_name),
 *                                                     _parse_h_aliases(host),
*/
            __pyx_t_2 = NULL;
            __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_ares_host_result); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 534, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_9);
            __pyx_t_3 = __Pyx_PyLong_From_int(__pyx_v_host->h_addrtype); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 534, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_3);

            /* "gevent/resolver/cares.pyx":535
 *                 try:
 *                     host_result = ares_host_result(host.h_addrtype,
 *                                                    (_as_str(host.h_name),             # <<<<<<<<<<<<<<
 *                                                     _parse_h_aliases(host),
 *                                                     _parse_h_addr_list(host)))
*/
            __pyx_t_11 = __pyx_f_6gevent_8resolver_5cares__as_str(__pyx_v_host->h_name); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 535, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_11);

            /* "gevent/resolver/cares.pyx":536
 *                     host_result = ares_host_result(host.h_addrtype,
 *                                                    (_as_str(host.h_name),
 *                                                     _parse_h_aliases(host),             # <<<<<<<<<<<<<<
 *                                                     _parse_h_addr_list(host)))
 *                 except:
*/
            __pyx_t_10 = __pyx_f_6gevent_8resolver_5cares__parse_h_aliases(__pyx_v_host); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 536, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_10);

            /* "gevent/resolver/cares.pyx":537
 *                                                    (_as_str(host.h_name),
 *                                                     _parse_h_aliases(host),
 *                                                     _parse_h_addr_list(host)))             # <<<<<<<<<<<<<<
 *                 except:
 *                     callback(Result(None, sys.exc_info()[1]))
*/
            __pyx_t_16 = __pyx_f_6gevent_8resolver_5cares__parse_h_addr_list(__pyx_v_host); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 537, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_16);

            /* "gevent/resolver/cares.pyx":535
 *                 try:
 *                     host_result = ares_host_result(host.h_addrtype,
 *                                                    (_as_str(host.h_name),             # <<<<<<<<<<<<<<
 *                                                     _parse_h_aliases(host),
 *                                                     _parse_h_addr_list(host)))
*/
            __pyx_t_17 = PyTuple_New(3); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 535, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_17);
            __Pyx_GIVEREF(__pyx_t_11);
            if (__Pyx_PyTuple_SET_ITEM(__pyx_t_17, 0, __pyx_t_11) != (0)) __PYX_ERR(0, 535, __pyx_L12_error);
            __Pyx_GIVEREF(__pyx_t_10);
            if (__Pyx_PyTuple_SET_ITEM(__pyx_t_17, 1, __pyx_t_10) != (0)) __PYX_ERR(0, 535, __pyx_L12_error);
            __Pyx_GIVEREF(__pyx_t_16);
            if (__Pyx_PyTuple_SET_ITEM(__pyx_t_17, 2, __pyx_t_16) != (0)) __PYX_ERR(0, 535, __pyx_L12_error);
            __pyx_t_11 = 0;
            __pyx_t_10 = 0;
            __pyx_t_16 = 0;
            __pyx_t_12 = 1;
            #if CYTHON_UNPACK_METHODS
            if (unlikely(PyMethod_Check(__pyx_t_9))) {
              __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_9);
              assert(__pyx_t_2);
              PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_9);
              __Pyx_INCREF(__pyx_t_2);
              __Pyx_INCREF(__pyx__function);
              __Pyx_DECREF_SET(__pyx_t_9, __pyx__function);
              __pyx_t_12 = 0;
            }
            #endif
            {
              PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_t_3, __pyx_t_17};
              __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_9, __pyx_callargs+__pyx_t_12, (3-__pyx_t_12) | (__pyx_t_12*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
              __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
              __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
              __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
              if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 534, __pyx_L12_error)
              __Pyx_GOTREF(__pyx_t_1);
            }
            __pyx_v_host_result = __pyx_t_1;
            __pyx_t_1 = 0;

            /* "gevent/resolver/cares.pyx":533
 *                 callback(Result(None, _gevent_herror_from_status(status)))
 *             else:
 *                 try:             # <<<<<<<<<<<<<<
 *                     host_result = ares_host_result(host.h_addrtype,
 *                                                    (_as_str(host.h_name),
*/
          }

          /* "gevent/resolver/cares.pyx":541
 *                     callback(Result(None, sys.exc_info()[1]))
 *                 else:
 *                     callback(Result(host_result))             # <<<<<<<<<<<<<<
 *         except:
 *             channel.loop.handle_error(callback, *sys.exc_info())
*/
          /*else:*/ {
            __pyx_t_9 = NULL;
            __Pyx_INCREF(__pyx_v_callback);
            __pyx_t_17 = __pyx_v_callback; 
            __pyx_t_2 = NULL;
            __pyx_t_12 = 1;
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_host_result};
              __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6gevent_8resolver_5cares_Result, __pyx_callargs+__pyx_t_12, (2-__pyx_t_12) | (__pyx_t_12*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
              __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
              if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 541, __pyx_L14_except_error)
              __Pyx_GOTREF((PyObject *)__pyx_t_3);
            }
            __pyx_t_12 = 1;
            #if CYTHON_UNPACK_METHODS
            if (unlikely(PyMethod_Check(__pyx_t_17))) {
              __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_17);
              assert(__pyx_t_9);
              PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_17);
              __Pyx_INCREF(__pyx_t_9);
              __Pyx_INCREF(__pyx__function);
              __Pyx_DECREF_SET(__pyx_t_17, __pyx__function);
              __pyx_t_12 = 0;
            }
            #endif
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_9, ((PyObject *)__pyx_t_3)};
              __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_17, __pyx_callargs+__pyx_t_12, (2-__pyx_t_12) | (__pyx_t_12*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
              __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
              __Pyx_DECREF((PyObject *)__pyx_t_3); __pyx_t_3 = 0;
              __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
              if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 541, __pyx_L14_except_error)
              __Pyx_GOTREF(__pyx_t_1);
            }
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          }
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
          __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
          goto __pyx_L17_try_end;
          __pyx_L12_error:;
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
          __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

          /* "gevent/resolver/cares.pyx":538
 *                                                     _parse_h_aliases(host),
 *                                                     _parse_h_addr_list(host)))
 *                 except:             # <<<<<<<<<<<<<<
 *                     callback(Result(None, sys.exc_info()[1]))
 *                 else:
*/
          /*except:*/ {
            __Pyx_AddTraceback("gevent.resolver.cares.channel._gethostbyname_or_byaddr_cb", __pyx_clineno, __pyx_lineno, __pyx_filename);
            if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_17, &__pyx_t_3) < 0) __PYX_ERR(0, 538, __pyx_L14_except_error)
            __Pyx_XGOTREF(__pyx_t_1);
            __Pyx_XGOTREF(__pyx_t_17);
            __Pyx_XGOTREF(__pyx_t_3);

            /* "gevent/resolver/cares.pyx":539
 *                                                     _parse_h_addr_list(host)))
 *                 except:
 *                     callback(Result(None, sys.exc_info()[1]))             # <<<<<<<<<<<<<<
 *                 else:
 *                     callback(Result(host_result))
*/
            __pyx_t_2 = NULL;
            __Pyx_INCREF(__pyx_v_callback);
            __pyx_t_16 = __pyx_v_callback; 
            __pyx_t_11 = NULL;
            __pyx_t_19 = NULL;
            __Pyx_GetModuleGlobalName(__pyx_t_20, __pyx_mstate_global->__pyx_n_u_sys); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 539, __pyx_L14_except_error)
            __Pyx_GOTREF(__pyx_t_20);
            __pyx_t_21 = __Pyx_PyObject_GetAttrStr(__pyx_t_20, __pyx_mstate_global->__pyx_n_u_exc_info); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 539, __pyx_L14_except_error)
            __Pyx_GOTREF(__pyx_t_21);
            __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;
            __pyx_t_12 = 1;
            #if CYTHON_UNPACK_METHODS
            if (unlikely(PyMethod_Check(__pyx_t_21))) {
              __pyx_t_19 = PyMethod_GET_SELF(__pyx_t_21);
              assert(__pyx_t_19);
              PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_21);
              __Pyx_INCREF(__pyx_t_19);
              __Pyx_INCREF(__pyx__function);
              __Pyx_DECREF_SET(__pyx_t_21, __pyx__function);
              __pyx_t_12 = 0;
            }
            #endif
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_19, NULL};
              __pyx_t_18 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_21, __pyx_callargs+__pyx_t_12, (1-__pyx_t_12) | (__pyx_t_12*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
              __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
              __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
              if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 539, __pyx_L14_except_error)
              __Pyx_GOTREF(__pyx_t_18);
            }
            __pyx_t_21 = __Pyx_GetItemInt(__pyx_t_18, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 539, __pyx_L14_except_error)
            __Pyx_GOTREF(__pyx_t_21);
            __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
            __pyx_t_12 = 1;
            {
              PyObject *__pyx_callargs[3] = {__pyx_t_11, Py_None, __pyx_t_21};
              __pyx_t_10 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6gevent_8resolver_5cares_Result, __pyx_callargs+__pyx_t_12, (3-__pyx_t_12) | (__pyx_t_12*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
              __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
              __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
              if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 539, __pyx_L14_except_error)
              __Pyx_GOTREF((PyObject *)__pyx_t_10);
            }
            __pyx_t_12 = 1;
            #if CYTHON_UNPACK_METHODS
            if (unlikely(PyMethod_Check(__pyx_t_16))) {
              __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_16);
              assert(__pyx_t_2);
              PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_16);
              __Pyx_INCREF(__pyx_t_2);
              __Pyx_INCREF(__pyx__function);
              __Pyx_DECREF_SET(__pyx_t_16, __pyx__function);
              __pyx_t_12 = 0;
            }
            #endif
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_2, ((PyObject *)__pyx_t_10)};
              __pyx_t_9 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_16, __pyx_callargs+__pyx_t_12, (2-__pyx_t_12) | (__pyx_t_12*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
              __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
              __Pyx_DECREF((PyObject *)__pyx_t_10); __pyx_t_10 = 0;
              __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
              if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 539, __pyx_L14_except_error)
              __Pyx_GOTREF(__pyx_t_9);
            }
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
            __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
            goto __pyx_L13_exception_handled;
          }

          /* "gevent/resolver/cares.pyx":533
 *                 callback(Result(None, _gevent_herror_from_status(status)))
 *             else:
 *                 try:             # <<<<<<<<<<<<<<
 *                     host_result = ares_host_result(host.h_addrtype,
 *                                                    (_as_str(host.h_name),
*/
          __pyx_L14_except_error:;
          __Pyx_XGIVEREF(__pyx_t_13);
          __Pyx_XGIVEREF(__pyx_t_14);
          __Pyx_XGIVEREF(__pyx_t_15);
          __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_14, __pyx_t_15);
          goto __pyx_L3_error;
          __pyx_L13_exception_handled:;
          __Pyx_XGIVEREF(__pyx_t_13);
          __Pyx_XGIVEREF(__pyx_t_14);
          __Pyx_XGIVEREF(__pyx_t_15);
          __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_14, __pyx_t_15);
          __pyx_L17_try_end:;
        }
      }
      __pyx_L9:;

      /* "gevent/resolver/cares.pyx":529
 *         Py_DECREF(<tuple>arg)
 *         cdef object host_result
 *         try:             # <<<<<<<<<<<<<<
 *             if status or not host:
 *                 callback(Result(None, _gevent_herror_from_status(status)))
*/
    }
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
    __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
    __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
    __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_20); __pyx_t_20 = 0;
    __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "gevent/resolver/cares.pyx":542
 *                 else:
 *                     callback(Result(host_result))
 *         except:             # <<<<<<<<<<<<<<
 *             channel.loop.handle_error(callback, *sys.exc_info())
 * 
*/
    /*except:*/ {
      __Pyx_AddTraceback("gevent.resolver.cares.channel._gethostbyname_or_byaddr_cb", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_17, &__pyx_t_1) < 0) __PYX_ERR(0, 542, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_17);
      __Pyx_XGOTREF(__pyx_t_1);

      /* "gevent/resolver/cares.pyx":543
 *                     callback(Result(host_result))
 *         except:
 *             channel.loop.handle_error(callback, *sys.exc_info())             # <<<<<<<<<<<<<<
 * 
 * 
*/
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_channel->loop, __pyx_mstate_global->__pyx_n_u_handle_error); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 543, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_16 = PyTuple_New(1); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 543, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_16);
      __Pyx_INCREF(__pyx_v_callback);
      __Pyx_GIVEREF(__pyx_v_callback);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_16, 0, __pyx_v_callback) != (0)) __PYX_ERR(0, 543, __pyx_L5_except_error);
      __pyx_t_2 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_21, __pyx_mstate_global->__pyx_n_u_sys); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 543, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_21);
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_21, __pyx_mstate_global->__pyx_n_u_exc_info); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 543, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
      __pyx_t_12 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_11))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_11);
        assert(__pyx_t_2);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_11);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_11, __pyx__function);
        __pyx_t_12 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
        __pyx_t_10 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_11, __pyx_callargs+__pyx_t_12, (1-__pyx_t_12) | (__pyx_t_12*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 543, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_10);
      }
      __pyx_t_11 = __Pyx_PySequence_Tuple(__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 543, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = PyNumber_Add(__pyx_t_16, __pyx_t_11); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 543, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_11 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_10, NULL); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 543, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L4_exception_handled;
    }

    /* "gevent/resolver/cares.pyx":529
 *         Py_DECREF(<tuple>arg)
 *         cdef object host_result
 *         try:             # <<<<<<<<<<<<<<
 *             if status or not host:
 *                 callback(Result(None, _gevent_herror_from_status(status)))
*/
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    __pyx_L8_try_end:;
  }

  /* "gevent/resolver/cares.pyx":522
 *         cares.ares_process_fd(self.channel, read_fd, write_fd)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     cdef void _gethostbyname_or_byaddr_cb(void *arg, int status, int timeouts, hostent* host):
 *         cdef channel channel
*/

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_XDECREF(__pyx_t_18);
  __Pyx_XDECREF(__pyx_t_19);
  __Pyx_XDECREF(__pyx_t_20);
  __Pyx_XDECREF(__pyx_t_21);
  __Pyx_AddTraceback("gevent.resolver.cares.channel._gethostbyname_or_byaddr_cb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_channel);
  __Pyx_XDECREF(__pyx_v_callback);
  __Pyx_XDECREF(__pyx_v_host_result);
  __Pyx_RefNannyFinishContext();
}

/* "gevent/resolver/cares.pyx":546
 * 
 * 
 *     def gethostbyname(self, object callback, char* name, int family=AF_INET):             # <<<<<<<<<<<<<<
 *         if not self.channel:
 *             raise gaierror(cares.ARES_EDESTRUCTION, 'this ares channel has been destroyed')
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_8resolver_5cares_7channel_15gethostbyname(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6gevent_8resolver_5cares_7channel_15gethostbyname = {"gethostbyname", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6gevent_8resolver_5cares_7channel_15gethostbyname, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6gevent_8resolver_5cares_7channel_15gethostbyname(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_callback = 0;
  char *__pyx_v_name;
  int __pyx_v_family;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("gethostbyname (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_callback,&__pyx_mstate_global->__pyx_n_u_name_2,&__pyx_mstate_global->__pyx_n_u_family,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 546, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 546, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 546, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 546, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "gethostbyname", 0) < (0)) __PYX_ERR(0, 546, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("gethostbyname", 0, 2, 3, i); __PYX_ERR(0, 546, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 546, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 546, __pyx_L3_error)
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 546, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_callback = values[0];
    __pyx_v_name = __Pyx_PyObject_AsWritableString(values[1]); if (unlikely((!__pyx_v_name) && PyErr_Occurred())) __PYX_ERR(0, 546, __pyx_L3_error)
    if (values[2]) {
      __pyx_v_family = __Pyx_PyLong_As_int(values[2]); if (unlikely((__pyx_v_family == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 546, __pyx_L3_error)
    } else {
      __pyx_v_family = __pyx_mstate_global->__pyx_k__5;
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("gethostbyname", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 546, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("gevent.resolver.cares.channel.gethostbyname", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6gevent_8resolver_5cares_7channel_14gethostbyname(((struct __pyx_obj_6gevent_8resolver_5cares_channel *)__pyx_v_self), __pyx_v_callback, __pyx_v_name, __pyx_v_family);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_8resolver_5cares_7channel_14gethostbyname(struct __pyx_obj_6gevent_8resolver_5cares_channel *__pyx_v_self, PyObject *__pyx_v_callback, char *__pyx_v_name, int __pyx_v_family) {
  PyObject *__pyx_v_arg = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("gethostbyname", 0);

  /* "gevent/resolver/cares.pyx":547
 * 
 *     def gethostbyname(self, object callback, char* name, int family=AF_INET):
 *         if not self.channel:             # <<<<<<<<<<<<<<
 *             raise gaierror(cares.ARES_EDESTRUCTION, 'this ares channel has been destroyed')
 *         # note that for file lookups still AF_INET can be returned for AF_INET6 request
*/
  __pyx_t_1 = (!(__pyx_v_self->channel != 0));
  if (unlikely(__pyx_t_1)) {

    /* "gevent/resolver/cares.pyx":548
 *     def gethostbyname(self, object callback, char* name, int family=AF_INET):
 *         if not self.channel:
 *             raise gaierror(cares.ARES_EDESTRUCTION, 'this ares channel has been destroyed')             # <<<<<<<<<<<<<<
 *         # note that for file lookups still AF_INET can be returned for AF_INET6 request
 *         cdef object arg = (self, callback)
*/
    __pyx_t_3 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_gaierror); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 548, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyLong_From_int(ARES_EDESTRUCTION); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 548, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      assert(__pyx_t_3);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
      __pyx_t_6 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_t_5, __pyx_mstate_global->__pyx_kp_u_this_ares_channel_has_been_destr};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_6, (3-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 548, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 548, __pyx_L1_error)

    /* "gevent/resolver/cares.pyx":547
 * 
 *     def gethostbyname(self, object callback, char* name, int family=AF_INET):
 *         if not self.channel:             # <<<<<<<<<<<<<<
 *             raise gaierror(cares.ARES_EDESTRUCTION, 'this ares channel has been destroyed')
 *         # note that for file lookups still AF_INET can be returned for AF_INET6 request
*/
  }

  /* "gevent/resolver/cares.pyx":550
 *             raise gaierror(cares.ARES_EDESTRUCTION, 'this ares channel has been destroyed')
 *         # note that for file lookups still AF_INET can be returned for AF_INET6 request
 *         cdef object arg = (self, callback)             # <<<<<<<<<<<<<<
 *         Py_INCREF(arg)
 *         cares.ares_gethostbyname(self.channel, name, family,
*/
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 550, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_self)) != (0)) __PYX_ERR(0, 550, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_callback);
  __Pyx_GIVEREF(__pyx_v_callback);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_callback) != (0)) __PYX_ERR(0, 550, __pyx_L1_error);
  __pyx_v_arg = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "gevent/resolver/cares.pyx":551
 *         # note that for file lookups still AF_INET can be returned for AF_INET6 request
 *         cdef object arg = (self, callback)
 *         Py_INCREF(arg)             # <<<<<<<<<<<<<<
 *         cares.ares_gethostbyname(self.channel, name, family,
 *                                  <void*>channel._gethostbyname_or_byaddr_cb, <void*>arg)
*/
  Py_INCREF(__pyx_v_arg);

  /* "gevent/resolver/cares.pyx":552
 *         cdef object arg = (self, callback)
 *         Py_INCREF(arg)
 *         cares.ares_gethostbyname(self.channel, name, family,             # <<<<<<<<<<<<<<
 *                                  <void*>channel._gethostbyname_or_byaddr_cb, <void*>arg)
 * 
*/
  ares_gethostbyname(__pyx_v_self->channel, __pyx_v_name, __pyx_v_family, ((void *)__pyx_f_6gevent_8resolver_5cares_7channel__gethostbyname_or_byaddr_cb), ((void *)__pyx_v_arg));

  /* "gevent/resolver/cares.pyx":546
 * 
 * 
 *     def gethostbyname(self, object callback, char* name, int family=AF_INET):             # <<<<<<<<<<<<<<
 *         if not self.channel:
 *             raise gaierror(cares.ARES_EDESTRUCTION, 'this ares channel has been destroyed')
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("gevent.resolver.cares.channel.gethostbyname", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_arg);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/resolver/cares.pyx":555
 *                                  <void*>channel._gethostbyname_or_byaddr_cb, <void*>arg)
 * 
 *     def gethostbyaddr(self, object callback, char* addr):             # <<<<<<<<<<<<<<
 *         if not self.channel:
 *             raise gaierror(cares.ARES_EDESTRUCTION, 'this ares channel has been destroyed')
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_8resolver_5cares_7channel_17gethostbyaddr(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6gevent_8resolver_5cares_7channel_17gethostbyaddr = {"gethostbyaddr", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6gevent_8resolver_5cares_7channel_17gethostbyaddr, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6gevent_8resolver_5cares_7channel_17gethostbyaddr(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_callback = 0;
  char *__pyx_v_addr;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("gethostbyaddr (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_callback,&__pyx_mstate_global->__pyx_n_u_addr,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 555, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 555, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 555, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "gethostbyaddr", 0) < (0)) __PYX_ERR(0, 555, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("gethostbyaddr", 1, 2, 2, i); __PYX_ERR(0, 555, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 555, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 555, __pyx_L3_error)
    }
    __pyx_v_callback = values[0];
    __pyx_v_addr = __Pyx_PyObject_AsWritableString(values[1]); if (unlikely((!__pyx_v_addr) && PyErr_Occurred())) __PYX_ERR(0, 555, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("gethostbyaddr", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 555, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("gevent.resolver.cares.channel.gethostbyaddr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6gevent_8resolver_5cares_7channel_16gethostbyaddr(((struct __pyx_obj_6gevent_8resolver_5cares_channel *)__pyx_v_self), __pyx_v_callback, __pyx_v_addr);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_8resolver_5cares_7channel_16gethostbyaddr(struct __pyx_obj_6gevent_8resolver_5cares_channel *__pyx_v_self, PyObject *__pyx_v_callback, char *__pyx_v_addr) {
  char __pyx_v_addr_packed[16];
  int __pyx_v_family;
  int __pyx_v_length;
  PyObject *__pyx_v_arg = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("gethostbyaddr", 0);

  /* "gevent/resolver/cares.pyx":556
 * 
 *     def gethostbyaddr(self, object callback, char* addr):
 *         if not self.channel:             # <<<<<<<<<<<<<<
 *             raise gaierror(cares.ARES_EDESTRUCTION, 'this ares channel has been destroyed')
 *         # will guess the family
*/
  __pyx_t_1 = (!(__pyx_v_self->channel != 0));
  if (unlikely(__pyx_t_1)) {

    /* "gevent/resolver/cares.pyx":557
 *     def gethostbyaddr(self, object callback, char* addr):
 *         if not self.channel:
 *             raise gaierror(cares.ARES_EDESTRUCTION, 'this ares channel has been destroyed')             # <<<<<<<<<<<<<<
 *         # will guess the family
 *         cdef char addr_packed[16]
*/
    __pyx_t_3 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_gaierror); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 557, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyLong_From_int(ARES_EDESTRUCTION); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 557, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      assert(__pyx_t_3);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
      __pyx_t_6 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_t_5, __pyx_mstate_global->__pyx_kp_u_this_ares_channel_has_been_destr};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_6, (3-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 557, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 557, __pyx_L1_error)

    /* "gevent/resolver/cares.pyx":556
 * 
 *     def gethostbyaddr(self, object callback, char* addr):
 *         if not self.channel:             # <<<<<<<<<<<<<<
 *             raise gaierror(cares.ARES_EDESTRUCTION, 'this ares channel has been destroyed')
 *         # will guess the family
*/
  }

  /* "gevent/resolver/cares.pyx":562
 *         cdef int family
 *         cdef int length
 *         if cares.ares_inet_pton(AF_INET, addr, addr_packed) > 0:             # <<<<<<<<<<<<<<
 *             family = AF_INET
 *             length = 4
*/
  __pyx_t_1 = (ares_inet_pton(AF_INET, __pyx_v_addr, __pyx_v_addr_packed) > 0);
  if (__pyx_t_1) {

    /* "gevent/resolver/cares.pyx":563
 *         cdef int length
 *         if cares.ares_inet_pton(AF_INET, addr, addr_packed) > 0:
 *             family = AF_INET             # <<<<<<<<<<<<<<
 *             length = 4
 *         elif cares.ares_inet_pton(AF_INET6, addr, addr_packed) > 0:
*/
    __pyx_v_family = AF_INET;

    /* "gevent/resolver/cares.pyx":564
 *         if cares.ares_inet_pton(AF_INET, addr, addr_packed) > 0:
 *             family = AF_INET
 *             length = 4             # <<<<<<<<<<<<<<
 *         elif cares.ares_inet_pton(AF_INET6, addr, addr_packed) > 0:
 *             family = AF_INET6
*/
    __pyx_v_length = 4;

    /* "gevent/resolver/cares.pyx":562
 *         cdef int family
 *         cdef int length
 *         if cares.ares_inet_pton(AF_INET, addr, addr_packed) > 0:             # <<<<<<<<<<<<<<
 *             family = AF_INET
 *             length = 4
*/
    goto __pyx_L4;
  }

  /* "gevent/resolver/cares.pyx":565
 *             family = AF_INET
 *             length = 4
 *         elif cares.ares_inet_pton(AF_INET6, addr, addr_packed) > 0:             # <<<<<<<<<<<<<<
 *             family = AF_INET6
 *             length = 16
*/
  __pyx_t_1 = (ares_inet_pton(AF_INET6, __pyx_v_addr, __pyx_v_addr_packed) > 0);
  if (likely(__pyx_t_1)) {

    /* "gevent/resolver/cares.pyx":566
 *             length = 4
 *         elif cares.ares_inet_pton(AF_INET6, addr, addr_packed) > 0:
 *             family = AF_INET6             # <<<<<<<<<<<<<<
 *             length = 16
 *         else:
*/
    __pyx_v_family = AF_INET6;

    /* "gevent/resolver/cares.pyx":567
 *         elif cares.ares_inet_pton(AF_INET6, addr, addr_packed) > 0:
 *             family = AF_INET6
 *             length = 16             # <<<<<<<<<<<<<<
 *         else:
 *             raise InvalidIP(repr(addr))
*/
    __pyx_v_length = 16;

    /* "gevent/resolver/cares.pyx":565
 *             family = AF_INET
 *             length = 4
 *         elif cares.ares_inet_pton(AF_INET6, addr, addr_packed) > 0:             # <<<<<<<<<<<<<<
 *             family = AF_INET6
 *             length = 16
*/
    goto __pyx_L4;
  }

  /* "gevent/resolver/cares.pyx":569
 *             length = 16
 *         else:
 *             raise InvalidIP(repr(addr))             # <<<<<<<<<<<<<<
 *         cdef object arg = (self, callback)
 *         Py_INCREF(arg)
*/
  /*else*/ {
    __pyx_t_4 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_InvalidIP); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 569, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = __Pyx_PyBytes_FromString(__pyx_v_addr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 569, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = PyObject_Repr(__pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 569, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_6 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      assert(__pyx_t_4);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
      __pyx_t_6 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_7};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 569, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 569, __pyx_L1_error)
  }
  __pyx_L4:;

  /* "gevent/resolver/cares.pyx":570
 *         else:
 *             raise InvalidIP(repr(addr))
 *         cdef object arg = (self, callback)             # <<<<<<<<<<<<<<
 *         Py_INCREF(arg)
 *         cares.ares_gethostbyaddr(self.channel, addr_packed, length, family,
*/
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 570, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_self)) != (0)) __PYX_ERR(0, 570, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_callback);
  __Pyx_GIVEREF(__pyx_v_callback);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_callback) != (0)) __PYX_ERR(0, 570, __pyx_L1_error);
  __pyx_v_arg = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "gevent/resolver/cares.pyx":571
 *             raise InvalidIP(repr(addr))
 *         cdef object arg = (self, callback)
 *         Py_INCREF(arg)             # <<<<<<<<<<<<<<
 *         cares.ares_gethostbyaddr(self.channel, addr_packed, length, family,
 *                                  <void*>channel._gethostbyname_or_byaddr_cb, <void*>arg)
*/
  Py_INCREF(__pyx_v_arg);

  /* "gevent/resolver/cares.pyx":572
 *         cdef object arg = (self, callback)
 *         Py_INCREF(arg)
 *         cares.ares_gethostbyaddr(self.channel, addr_packed, length, family,             # <<<<<<<<<<<<<<
 *                                  <void*>channel._gethostbyname_or_byaddr_cb, <void*>arg)
 * 
*/
  ares_gethostbyaddr(__pyx_v_self->channel, __pyx_v_addr_packed, __pyx_v_length, __pyx_v_family, ((void *)__pyx_f_6gevent_8resolver_5cares_7channel__gethostbyname_or_byaddr_cb), ((void *)__pyx_v_arg));

  /* "gevent/resolver/cares.pyx":555
 *                                  <void*>channel._gethostbyname_or_byaddr_cb, <void*>arg)
 * 
 *     def gethostbyaddr(self, object callback, char* addr):             # <<<<<<<<<<<<<<
 *         if not self.channel:
 *             raise gaierror(cares.ARES_EDESTRUCTION, 'this ares channel has been destroyed')
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("gevent.resolver.cares.channel.gethostbyaddr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_arg);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/resolver/cares.pyx":575
 *                                  <void*>channel._gethostbyname_or_byaddr_cb, <void*>arg)
 * 
 *     cpdef _getnameinfo(self, object callback, tuple sockaddr, int flags):             # <<<<<<<<<<<<<<
 *         if not self.channel:
 *             raise gaierror(cares.ARES_EDESTRUCTION, 'this ares channel has been destroyed')
*/

static PyObject *__pyx_pw_6gevent_8resolver_5cares_7channel_19_getnameinfo(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6gevent_8resolver_5cares_7channel__getnameinfo(struct __pyx_obj_6gevent_8resolver_5cares_channel *__pyx_v_self, PyObject *__pyx_v_callback, PyObject *__pyx_v_sockaddr, int __pyx_v_flags, int __pyx_skip_dispatch) {
  char *__pyx_v_hostp;
  int __pyx_v_port;
  int __pyx_v_flowinfo;
  int __pyx_v_scope_id;
  struct sockaddr_in6 __pyx_v_sa6;
  int __pyx_v_length;
  PyObject *__pyx_v_arg = 0;
  struct sockaddr *__pyx_v_x;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_getnameinfo", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (
  #if !CYTHON_USE_TYPE_SLOTS
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_6gevent_8resolver_5cares_channel &&
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
  #else
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
  #endif
  ) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_getnameinfo); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 575, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_6gevent_8resolver_5cares_7channel_19_getnameinfo)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; 
        __pyx_t_5 = __Pyx_PyLong_From_int(__pyx_v_flags); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 575, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_6 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_6 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[4] = {__pyx_t_3, __pyx_v_callback, __pyx_v_sockaddr, __pyx_t_5};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_6, (4-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 575, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "gevent/resolver/cares.pyx":576
 * 
 *     cpdef _getnameinfo(self, object callback, tuple sockaddr, int flags):
 *         if not self.channel:             # <<<<<<<<<<<<<<
 *             raise gaierror(cares.ARES_EDESTRUCTION, 'this ares channel has been destroyed')
 *         cdef char* hostp = NULL
*/
  __pyx_t_7 = (!(__pyx_v_self->channel != 0));
  if (unlikely(__pyx_t_7)) {

    /* "gevent/resolver/cares.pyx":577
 *     cpdef _getnameinfo(self, object callback, tuple sockaddr, int flags):
 *         if not self.channel:
 *             raise gaierror(cares.ARES_EDESTRUCTION, 'this ares channel has been destroyed')             # <<<<<<<<<<<<<<
 *         cdef char* hostp = NULL
 *         cdef int port = 0
*/
    __pyx_t_2 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_gaierror); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 577, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyLong_From_int(ARES_EDESTRUCTION); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 577, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
      assert(__pyx_t_2);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
      __pyx_t_6 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_t_5, __pyx_mstate_global->__pyx_kp_u_this_ares_channel_has_been_destr};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_6, (3-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 577, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 577, __pyx_L1_error)

    /* "gevent/resolver/cares.pyx":576
 * 
 *     cpdef _getnameinfo(self, object callback, tuple sockaddr, int flags):
 *         if not self.channel:             # <<<<<<<<<<<<<<
 *             raise gaierror(cares.ARES_EDESTRUCTION, 'this ares channel has been destroyed')
 *         cdef char* hostp = NULL
*/
  }

  /* "gevent/resolver/cares.pyx":578
 *         if not self.channel:
 *             raise gaierror(cares.ARES_EDESTRUCTION, 'this ares channel has been destroyed')
 *         cdef char* hostp = NULL             # <<<<<<<<<<<<<<
 *         cdef int port = 0
 *         cdef int flowinfo = 0
*/
  __pyx_v_hostp = NULL;

  /* "gevent/resolver/cares.pyx":579
 *             raise gaierror(cares.ARES_EDESTRUCTION, 'this ares channel has been destroyed')
 *         cdef char* hostp = NULL
 *         cdef int port = 0             # <<<<<<<<<<<<<<
 *         cdef int flowinfo = 0
 *         cdef int scope_id = 0
*/
  __pyx_v_port = 0;

  /* "gevent/resolver/cares.pyx":580
 *         cdef char* hostp = NULL
 *         cdef int port = 0
 *         cdef int flowinfo = 0             # <<<<<<<<<<<<<<
 *         cdef int scope_id = 0
 *         cdef sockaddr_in6 sa6
*/
  __pyx_v_flowinfo = 0;

  /* "gevent/resolver/cares.pyx":581
 *         cdef int port = 0
 *         cdef int flowinfo = 0
 *         cdef int scope_id = 0             # <<<<<<<<<<<<<<
 *         cdef sockaddr_in6 sa6
 *         if not PyTuple_Check(sockaddr):
*/
  __pyx_v_scope_id = 0;

  /* "gevent/resolver/cares.pyx":583
 *         cdef int scope_id = 0
 *         cdef sockaddr_in6 sa6
 *         if not PyTuple_Check(sockaddr):             # <<<<<<<<<<<<<<
 *             raise TypeError('expected a tuple, got %r' % (sockaddr, ))
 *         PyArg_ParseTuple(sockaddr, "si|ii", &hostp, &port, &flowinfo, &scope_id)
*/
  __pyx_t_7 = (!PyTuple_Check(__pyx_v_sockaddr));
  if (unlikely(__pyx_t_7)) {

    /* "gevent/resolver/cares.pyx":584
 *         cdef sockaddr_in6 sa6
 *         if not PyTuple_Check(sockaddr):
 *             raise TypeError('expected a tuple, got %r' % (sockaddr, ))             # <<<<<<<<<<<<<<
 *         PyArg_ParseTuple(sockaddr, "si|ii", &hostp, &port, &flowinfo, &scope_id)
 *         # if port < 0 or port > 65535:
*/
    __pyx_t_4 = NULL;
    __pyx_t_5 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_sockaddr), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 584, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_2 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_expected_a_tuple_got, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 584, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_TypeError)), __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 584, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 584, __pyx_L1_error)

    /* "gevent/resolver/cares.pyx":583
 *         cdef int scope_id = 0
 *         cdef sockaddr_in6 sa6
 *         if not PyTuple_Check(sockaddr):             # <<<<<<<<<<<<<<
 *             raise TypeError('expected a tuple, got %r' % (sockaddr, ))
 *         PyArg_ParseTuple(sockaddr, "si|ii", &hostp, &port, &flowinfo, &scope_id)
*/
  }

  /* "gevent/resolver/cares.pyx":585
 *         if not PyTuple_Check(sockaddr):
 *             raise TypeError('expected a tuple, got %r' % (sockaddr, ))
 *         PyArg_ParseTuple(sockaddr, "si|ii", &hostp, &port, &flowinfo, &scope_id)             # <<<<<<<<<<<<<<
 *         # if port < 0 or port > 65535:
 *         #     raise gaierror(-8, 'Invalid value for port: %r' % port)
*/
  __pyx_t_8 = PyArg_ParseTuple(__pyx_v_sockaddr, ((char *)"si|ii"), (&__pyx_v_hostp), (&__pyx_v_port), (&__pyx_v_flowinfo), (&__pyx_v_scope_id)); if (unlikely(__pyx_t_8 == ((int)0))) __PYX_ERR(0, 585, __pyx_L1_error)

  /* "gevent/resolver/cares.pyx":588
 *         # if port < 0 or port > 65535:
 *         #     raise gaierror(-8, 'Invalid value for port: %r' % port)
 *         cdef int length = _make_sockaddr(hostp, port, flowinfo, scope_id, &sa6)             # <<<<<<<<<<<<<<
 *         if length <= 0:
 *             raise InvalidIP(repr(hostp))
*/
  __pyx_t_8 = __pyx_f_6gevent_8resolver_5cares__make_sockaddr(__pyx_v_hostp, __pyx_v_port, __pyx_v_flowinfo, __pyx_v_scope_id, (&__pyx_v_sa6)); if (unlikely(__pyx_t_8 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 588, __pyx_L1_error)
  __pyx_v_length = __pyx_t_8;

  /* "gevent/resolver/cares.pyx":589
 *         #     raise gaierror(-8, 'Invalid value for port: %r' % port)
 *         cdef int length = _make_sockaddr(hostp, port, flowinfo, scope_id, &sa6)
 *         if length <= 0:             # <<<<<<<<<<<<<<
 *             raise InvalidIP(repr(hostp))
 *         cdef object arg = (self, callback)
*/
  __pyx_t_7 = (__pyx_v_length <= 0);
  if (unlikely(__pyx_t_7)) {

    /* "gevent/resolver/cares.pyx":590
 *         cdef int length = _make_sockaddr(hostp, port, flowinfo, scope_id, &sa6)
 *         if length <= 0:
 *             raise InvalidIP(repr(hostp))             # <<<<<<<<<<<<<<
 *         cdef object arg = (self, callback)
 *         Py_INCREF(arg)
*/
    __pyx_t_2 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_InvalidIP); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 590, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyBytes_FromString(__pyx_v_hostp); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 590, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = PyObject_Repr(__pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 590, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
      assert(__pyx_t_2);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
      __pyx_t_6 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 590, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 590, __pyx_L1_error)

    /* "gevent/resolver/cares.pyx":589
 *         #     raise gaierror(-8, 'Invalid value for port: %r' % port)
 *         cdef int length = _make_sockaddr(hostp, port, flowinfo, scope_id, &sa6)
 *         if length <= 0:             # <<<<<<<<<<<<<<
 *             raise InvalidIP(repr(hostp))
 *         cdef object arg = (self, callback)
*/
  }

  /* "gevent/resolver/cares.pyx":591
 *         if length <= 0:
 *             raise InvalidIP(repr(hostp))
 *         cdef object arg = (self, callback)             # <<<<<<<<<<<<<<
 *         Py_INCREF(arg)
 *         cdef sockaddr_t* x = <sockaddr_t*>&sa6
*/
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 591, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self)) != (0)) __PYX_ERR(0, 591, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_callback);
  __Pyx_GIVEREF(__pyx_v_callback);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_callback) != (0)) __PYX_ERR(0, 591, __pyx_L1_error);
  __pyx_v_arg = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "gevent/resolver/cares.pyx":592
 *             raise InvalidIP(repr(hostp))
 *         cdef object arg = (self, callback)
 *         Py_INCREF(arg)             # <<<<<<<<<<<<<<
 *         cdef sockaddr_t* x = <sockaddr_t*>&sa6
 *         cares.ares_getnameinfo(self.channel, x, length, flags, <void*>gevent_ares_nameinfo_callback, <void*>arg)
*/
  Py_INCREF(__pyx_v_arg);

  /* "gevent/resolver/cares.pyx":593
 *         cdef object arg = (self, callback)
 *         Py_INCREF(arg)
 *         cdef sockaddr_t* x = <sockaddr_t*>&sa6             # <<<<<<<<<<<<<<
 *         cares.ares_getnameinfo(self.channel, x, length, flags, <void*>gevent_ares_nameinfo_callback, <void*>arg)
 * 
*/
  __pyx_v_x = ((struct sockaddr *)(&__pyx_v_sa6));

  /* "gevent/resolver/cares.pyx":594
 *         Py_INCREF(arg)
 *         cdef sockaddr_t* x = <sockaddr_t*>&sa6
 *         cares.ares_getnameinfo(self.channel, x, length, flags, <void*>gevent_ares_nameinfo_callback, <void*>arg)             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/
  ares_getnameinfo(__pyx_v_self->channel, __pyx_v_x, __pyx_v_length, __pyx_v_flags, ((void *)__pyx_f_6gevent_8resolver_5cares_gevent_ares_nameinfo_callback), ((void *)__pyx_v_arg));

  /* "gevent/resolver/cares.pyx":575
 *                                  <void*>channel._gethostbyname_or_byaddr_cb, <void*>arg)
 * 
 *     cpdef _getnameinfo(self, object callback, tuple sockaddr, int flags):             # <<<<<<<<<<<<<<
 *         if not self.channel:
 *             raise gaierror(cares.ARES_EDESTRUCTION, 'this ares channel has been destroyed')
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("gevent.resolver.cares.channel._getnameinfo", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_arg);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_8resolver_5cares_7channel_19_getnameinfo(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6gevent_8resolver_5cares_7channel_19_getnameinfo = {"_getnameinfo", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6gevent_8resolver_5cares_7channel_19_getnameinfo, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6gevent_8resolver_5cares_7channel_19_getnameinfo(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_callback = 0;
  PyObject *__pyx_v_sockaddr = 0;
  int __pyx_v_flags;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_getnameinfo (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_callback,&__pyx_mstate_global->__pyx_n_u_sockaddr,&__pyx_mstate_global->__pyx_n_u_flags,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 575, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 575, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 575, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 575, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_getnameinfo", 0) < (0)) __PYX_ERR(0, 575, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_getnameinfo", 1, 3, 3, i); __PYX_ERR(0, 575, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 575, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 575, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 575, __pyx_L3_error)
    }
    __pyx_v_callback = values[0];
    __pyx_v_sockaddr = ((PyObject*)values[1]);
    __pyx_v_flags = __Pyx_PyLong_As_int(values[2]); if (unlikely((__pyx_v_flags == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 575, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_getnameinfo", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 575, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("gevent.resolver.cares.channel._getnameinfo", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_sockaddr), (&PyTuple_Type), 1, "sockaddr", 1))) __PYX_ERR(0, 575, __pyx_L1_error)
  __pyx_r = __pyx_pf_6gevent_8resolver_5cares_7channel_18_getnameinfo(((struct __pyx_obj_6gevent_8resolver_5cares_channel *)__pyx_v_self), __pyx_v_callback, __pyx_v_sockaddr, __pyx_v_flags);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_8resolver_5cares_7channel_18_getnameinfo(struct __pyx_obj_6gevent_8resolver_5cares_channel *__pyx_v_self, PyObject *__pyx_v_callback, PyObject *__pyx_v_sockaddr, int __pyx_v_flags) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_getnameinfo", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6gevent_8resolver_5cares_7channel__getnameinfo(__pyx_v_self, __pyx_v_callback, __pyx_v_sockaddr, __pyx_v_flags, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 575, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("gevent.resolver.cares.channel._getnameinfo", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/resolver/cares.pyx":596
 *         cares.ares_getnameinfo(self.channel, x, length, flags, <void*>gevent_ares_nameinfo_callback, <void*>arg)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     cdef int _convert_cares_ni_flags(int flags):
 *         cdef int cares_flags = cares.ARES_NI_LOOKUPHOST | cares.ARES_NI_LOOKUPSERVICE
*/

static int __pyx_f_6gevent_8resolver_5cares_7channel__convert_cares_ni_flags(int __pyx_v_flags) {
  int __pyx_v_cares_flags;
  int __pyx_r;
  int __pyx_t_1;

  /* "gevent/resolver/cares.pyx":598
 *     @staticmethod
 *     cdef int _convert_cares_ni_flags(int flags):
 *         cdef int cares_flags = cares.ARES_NI_LOOKUPHOST | cares.ARES_NI_LOOKUPSERVICE             # <<<<<<<<<<<<<<
 *         if flags & NI_NUMERICHOST:
 *             cares_flags |= cares.ARES_NI_NUMERICHOST
*/
  __pyx_v_cares_flags = (ARES_NI_LOOKUPHOST | ARES_NI_LOOKUPSERVICE);

  /* "gevent/resolver/cares.pyx":599
 *     cdef int _convert_cares_ni_flags(int flags):
 *         cdef int cares_flags = cares.ARES_NI_LOOKUPHOST | cares.ARES_NI_LOOKUPSERVICE
 *         if flags & NI_NUMERICHOST:             # <<<<<<<<<<<<<<
 *             cares_flags |= cares.ARES_NI_NUMERICHOST
 *         if flags & NI_NUMERICSERV:
*/
  __pyx_t_1 = ((__pyx_v_flags & __pyx_v_6gevent_8resolver_5cares_NI_NUMERICHOST) != 0);
  if (__pyx_t_1) {

    /* "gevent/resolver/cares.pyx":600
 *         cdef int cares_flags = cares.ARES_NI_LOOKUPHOST | cares.ARES_NI_LOOKUPSERVICE
 *         if flags & NI_NUMERICHOST:
 *             cares_flags |= cares.ARES_NI_NUMERICHOST             # <<<<<<<<<<<<<<
 *         if flags & NI_NUMERICSERV:
 *             cares_flags |= cares.ARES_NI_NUMERICSERV
*/
    __pyx_v_cares_flags = (__pyx_v_cares_flags | ARES_NI_NUMERICHOST);

    /* "gevent/resolver/cares.pyx":599
 *     cdef int _convert_cares_ni_flags(int flags):
 *         cdef int cares_flags = cares.ARES_NI_LOOKUPHOST | cares.ARES_NI_LOOKUPSERVICE
 *         if flags & NI_NUMERICHOST:             # <<<<<<<<<<<<<<
 *             cares_flags |= cares.ARES_NI_NUMERICHOST
 *         if flags & NI_NUMERICSERV:
*/
  }

  /* "gevent/resolver/cares.pyx":601
 *         if flags & NI_NUMERICHOST:
 *             cares_flags |= cares.ARES_NI_NUMERICHOST
 *         if flags & NI_NUMERICSERV:             # <<<<<<<<<<<<<<
 *             cares_flags |= cares.ARES_NI_NUMERICSERV
 *         if flags & NI_NOFQDN:
*/
  __pyx_t_1 = ((__pyx_v_flags & __pyx_v_6gevent_8resolver_5cares_NI_NUMERICSERV) != 0);
  if (__pyx_t_1) {

    /* "gevent/resolver/cares.pyx":602
 *             cares_flags |= cares.ARES_NI_NUMERICHOST
 *         if flags & NI_NUMERICSERV:
 *             cares_flags |= cares.ARES_NI_NUMERICSERV             # <<<<<<<<<<<<<<
 *         if flags & NI_NOFQDN:
 *             cares_flags |= cares.ARES_NI_NOFQDN
*/
    __pyx_v_cares_flags = (__pyx_v_cares_flags | ARES_NI_NUMERICSERV);

    /* "gevent/resolver/cares.pyx":601
 *         if flags & NI_NUMERICHOST:
 *             cares_flags |= cares.ARES_NI_NUMERICHOST
 *         if flags & NI_NUMERICSERV:             # <<<<<<<<<<<<<<
 *             cares_flags |= cares.ARES_NI_NUMERICSERV
 *         if flags & NI_NOFQDN:
*/
  }

  /* "gevent/resolver/cares.pyx":603
 *         if flags & NI_NUMERICSERV:
 *             cares_flags |= cares.ARES_NI_NUMERICSERV
 *         if flags & NI_NOFQDN:             # <<<<<<<<<<<<<<
 *             cares_flags |= cares.ARES_NI_NOFQDN
 *         if flags & NI_NAMEREQD:
*/
  __pyx_t_1 = ((__pyx_v_flags & __pyx_v_6gevent_8resolver_5cares_NI_NOFQDN) != 0);
  if (__pyx_t_1) {

    /* "gevent/resolver/cares.pyx":604
 *             cares_flags |= cares.ARES_NI_NUMERICSERV
 *         if flags & NI_NOFQDN:
 *             cares_flags |= cares.ARES_NI_NOFQDN             # <<<<<<<<<<<<<<
 *         if flags & NI_NAMEREQD:
 *             cares_flags |= cares.ARES_NI_NAMEREQD
*/
    __pyx_v_cares_flags = (__pyx_v_cares_flags | ARES_NI_NOFQDN);

    /* "gevent/resolver/cares.pyx":603
 *         if flags & NI_NUMERICSERV:
 *             cares_flags |= cares.ARES_NI_NUMERICSERV
 *         if flags & NI_NOFQDN:             # <<<<<<<<<<<<<<
 *             cares_flags |= cares.ARES_NI_NOFQDN
 *         if flags & NI_NAMEREQD:
*/
  }

  /* "gevent/resolver/cares.pyx":605
 *         if flags & NI_NOFQDN:
 *             cares_flags |= cares.ARES_NI_NOFQDN
 *         if flags & NI_NAMEREQD:             # <<<<<<<<<<<<<<
 *             cares_flags |= cares.ARES_NI_NAMEREQD
 *         if flags & NI_DGRAM:
*/
  __pyx_t_1 = ((__pyx_v_flags & __pyx_v_6gevent_8resolver_5cares_NI_NAMEREQD) != 0);
  if (__pyx_t_1) {

    /* "gevent/resolver/cares.pyx":606
 *             cares_flags |= cares.ARES_NI_NOFQDN
 *         if flags & NI_NAMEREQD:
 *             cares_flags |= cares.ARES_NI_NAMEREQD             # <<<<<<<<<<<<<<
 *         if flags & NI_DGRAM:
 *             cares_flags |= cares.ARES_NI_DGRAM
*/
    __pyx_v_cares_flags = (__pyx_v_cares_flags | ARES_NI_NAMEREQD);

    /* "gevent/resolver/cares.pyx":605
 *         if flags & NI_NOFQDN:
 *             cares_flags |= cares.ARES_NI_NOFQDN
 *         if flags & NI_NAMEREQD:             # <<<<<<<<<<<<<<
 *             cares_flags |= cares.ARES_NI_NAMEREQD
 *         if flags & NI_DGRAM:
*/
  }

  /* "gevent/resolver/cares.pyx":607
 *         if flags & NI_NAMEREQD:
 *             cares_flags |= cares.ARES_NI_NAMEREQD
 *         if flags & NI_DGRAM:             # <<<<<<<<<<<<<<
 *             cares_flags |= cares.ARES_NI_DGRAM
 *         return cares_flags
*/
  __pyx_t_1 = ((__pyx_v_flags & __pyx_v_6gevent_8resolver_5cares_NI_DGRAM) != 0);
  if (__pyx_t_1) {

    /* "gevent/resolver/cares.pyx":608
 *             cares_flags |= cares.ARES_NI_NAMEREQD
 *         if flags & NI_DGRAM:
 *             cares_flags |= cares.ARES_NI_DGRAM             # <<<<<<<<<<<<<<
 *         return cares_flags
 * 
*/
    __pyx_v_cares_flags = (__pyx_v_cares_flags | ARES_NI_DGRAM);

    /* "gevent/resolver/cares.pyx":607
 *         if flags & NI_NAMEREQD:
 *             cares_flags |= cares.ARES_NI_NAMEREQD
 *         if flags & NI_DGRAM:             # <<<<<<<<<<<<<<
 *             cares_flags |= cares.ARES_NI_DGRAM
 *         return cares_flags
*/
  }

  /* "gevent/resolver/cares.pyx":609
 *         if flags & NI_DGRAM:
 *             cares_flags |= cares.ARES_NI_DGRAM
 *         return cares_flags             # <<<<<<<<<<<<<<
 * 
 *     def getnameinfo(self, object callback, tuple sockaddr, int flags):
*/
  __pyx_r = __pyx_v_cares_flags;
  goto __pyx_L0;

  /* "gevent/resolver/cares.pyx":596
 *         cares.ares_getnameinfo(self.channel, x, length, flags, <void*>gevent_ares_nameinfo_callback, <void*>arg)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     cdef int _convert_cares_ni_flags(int flags):
 *         cdef int cares_flags = cares.ARES_NI_LOOKUPHOST | cares.ARES_NI_LOOKUPSERVICE
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "gevent/resolver/cares.pyx":611
 *         return cares_flags
 * 
 *     def getnameinfo(self, object callback, tuple sockaddr, int flags):             # <<<<<<<<<<<<<<
 *         flags = channel._convert_cares_ni_flags(flags)
 *         return self._getnameinfo(callback, sockaddr, flags)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_8resolver_5cares_7channel_21getnameinfo(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6gevent_8resolver_5cares_7channel_21getnameinfo = {"getnameinfo", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6gevent_8resolver_5cares_7channel_21getnameinfo, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6gevent_8resolver_5cares_7channel_21getnameinfo(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_callback = 0;
  PyObject *__pyx_v_sockaddr = 0;
  int __pyx_v_flags;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getnameinfo (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_callback,&__pyx_mstate_global->__pyx_n_u_sockaddr,&__pyx_mstate_global->__pyx_n_u_flags,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 611, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 611, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 611, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 611, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "getnameinfo", 0) < (0)) __PYX_ERR(0, 611, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("getnameinfo", 1, 3, 3, i); __PYX_ERR(0, 611, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 611, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 611, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 611, __pyx_L3_error)
    }
    __pyx_v_callback = values[0];
    __pyx_v_sockaddr = ((PyObject*)values[1]);
    __pyx_v_flags = __Pyx_PyLong_As_int(values[2]); if (unlikely((__pyx_v_flags == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 611, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("getnameinfo", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 611, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("gevent.resolver.cares.channel.getnameinfo", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_sockaddr), (&PyTuple_Type), 1, "sockaddr", 1))) __PYX_ERR(0, 611, __pyx_L1_error)
  __pyx_r = __pyx_pf_6gevent_8resolver_5cares_7channel_20getnameinfo(((struct __pyx_obj_6gevent_8resolver_5cares_channel *)__pyx_v_self), __pyx_v_callback, __pyx_v_sockaddr, __pyx_v_flags);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_8resolver_5cares_7channel_20getnameinfo(struct __pyx_obj_6gevent_8resolver_5cares_channel *__pyx_v_self, PyObject *__pyx_v_callback, PyObject *__pyx_v_sockaddr, int __pyx_v_flags) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getnameinfo", 0);

  /* "gevent/resolver/cares.pyx":612
 * 
 *     def getnameinfo(self, object callback, tuple sockaddr, int flags):
 *         flags = channel._convert_cares_ni_flags(flags)             # <<<<<<<<<<<<<<
 *         return self._getnameinfo(callback, sockaddr, flags)
 * 
*/
  __pyx_t_1 = __pyx_f_6gevent_8resolver_5cares_7channel__convert_cares_ni_flags(__pyx_v_flags); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 612, __pyx_L1_error)
  __pyx_v_flags = __pyx_t_1;

  /* "gevent/resolver/cares.pyx":613
 *     def getnameinfo(self, object callback, tuple sockaddr, int flags):
 *         flags = channel._convert_cares_ni_flags(flags)
 *         return self._getnameinfo(callback, sockaddr, flags)             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((struct __pyx_vtabstruct_6gevent_8resolver_5cares_channel *)__pyx_v_self->__pyx_vtab)->_getnameinfo(__pyx_v_self, __pyx_v_callback, __pyx_v_sockaddr, __pyx_v_flags, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 613, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "gevent/resolver/cares.pyx":611
 *         return cares_flags
 * 
 *     def getnameinfo(self, object callback, tuple sockaddr, int flags):             # <<<<<<<<<<<<<<
 *         flags = channel._convert_cares_ni_flags(flags)
 *         return self._getnameinfo(callback, sockaddr, flags)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("gevent.resolver.cares.channel.getnameinfo", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/resolver/cares.pyx":615
 *         return self._getnameinfo(callback, sockaddr, flags)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     cdef int _convert_cares_ai_flags(int flags):
 *         # c-ares supports a limited set of flags.
*/

static int __pyx_f_6gevent_8resolver_5cares_7channel__convert_cares_ai_flags(int __pyx_v_flags) {
  int __pyx_v_cares_flags;
  int __pyx_r;
  int __pyx_t_1;

  /* "gevent/resolver/cares.pyx":620
 *         # We always want NOSORT, because that implies that
 *         # c-ares will not connect to resolved addresses.
 *         cdef int cares_flags = cares.ARES_AI_NOSORT             # <<<<<<<<<<<<<<
 *         if flags & AI_CANONNAME:
 *             cares_flags |= cares.ARES_AI_CANONNAME
*/
  __pyx_v_cares_flags = ARES_AI_NOSORT;

  /* "gevent/resolver/cares.pyx":621
 *         # c-ares will not connect to resolved addresses.
 *         cdef int cares_flags = cares.ARES_AI_NOSORT
 *         if flags & AI_CANONNAME:             # <<<<<<<<<<<<<<
 *             cares_flags |= cares.ARES_AI_CANONNAME
 *         if flags & AI_NUMERICSERV:
*/
  __pyx_t_1 = ((__pyx_v_flags & __pyx_v_6gevent_8resolver_5cares_AI_CANONNAME) != 0);
  if (__pyx_t_1) {

    /* "gevent/resolver/cares.pyx":622
 *         cdef int cares_flags = cares.ARES_AI_NOSORT
 *         if flags & AI_CANONNAME:
 *             cares_flags |= cares.ARES_AI_CANONNAME             # <<<<<<<<<<<<<<
 *         if flags & AI_NUMERICSERV:
 *             cares_flags |= cares.ARES_AI_NUMERICSERV
*/
    __pyx_v_cares_flags = (__pyx_v_cares_flags | ARES_AI_CANONNAME);

    /* "gevent/resolver/cares.pyx":621
 *         # c-ares will not connect to resolved addresses.
 *         cdef int cares_flags = cares.ARES_AI_NOSORT
 *         if flags & AI_CANONNAME:             # <<<<<<<<<<<<<<
 *             cares_flags |= cares.ARES_AI_CANONNAME
 *         if flags & AI_NUMERICSERV:
*/
  }

  /* "gevent/resolver/cares.pyx":623
 *         if flags & AI_CANONNAME:
 *             cares_flags |= cares.ARES_AI_CANONNAME
 *         if flags & AI_NUMERICSERV:             # <<<<<<<<<<<<<<
 *             cares_flags |= cares.ARES_AI_NUMERICSERV
 *         return cares_flags
*/
  __pyx_t_1 = ((__pyx_v_flags & __pyx_v_6gevent_8resolver_5cares_AI_NUMERICSERV) != 0);
  if (__pyx_t_1) {

    /* "gevent/resolver/cares.pyx":624
 *             cares_flags |= cares.ARES_AI_CANONNAME
 *         if flags & AI_NUMERICSERV:
 *             cares_flags |= cares.ARES_AI_NUMERICSERV             # <<<<<<<<<<<<<<
 *         return cares_flags
 * 
*/
    __pyx_v_cares_flags = (__pyx_v_cares_flags | ARES_AI_NUMERICSERV);

    /* "gevent/resolver/cares.pyx":623
 *         if flags & AI_CANONNAME:
 *             cares_flags |= cares.ARES_AI_CANONNAME
 *         if flags & AI_NUMERICSERV:             # <<<<<<<<<<<<<<
 *             cares_flags |= cares.ARES_AI_NUMERICSERV
 *         return cares_flags
*/
  }

  /* "gevent/resolver/cares.pyx":625
 *         if flags & AI_NUMERICSERV:
 *             cares_flags |= cares.ARES_AI_NUMERICSERV
 *         return cares_flags             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/
  __pyx_r = __pyx_v_cares_flags;
  goto __pyx_L0;

  /* "gevent/resolver/cares.pyx":615
 *         return self._getnameinfo(callback, sockaddr, flags)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     cdef int _convert_cares_ai_flags(int flags):
 *         # c-ares supports a limited set of flags.
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "gevent/resolver/cares.pyx":627
 *         return cares_flags
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     cdef void _getaddrinfo_cb(void *arg,
 *                               int status,
*/

static void __pyx_f_6gevent_8resolver_5cares_7channel__getaddrinfo_cb(void *__pyx_v_arg, int __pyx_v_status, CYTHON_UNUSED int __pyx_v_timeouts, struct ares_addrinfo *__pyx_v_result) {
  struct ares_addrinfo_node *__pyx_v_nodes;
  struct ares_addrinfo_cname *__pyx_v_cnames;
  struct sockaddr_in *__pyx_v_sadr4;
  struct sockaddr_in6 *__pyx_v_sadr6;
  PyObject *__pyx_v_canonname = 0;
  struct __pyx_obj_6gevent_8resolver_5cares_channel *__pyx_v_channel = 0;
  PyObject *__pyx_v_callback = 0;
  char __pyx_v_tmpbuf[46];
  PyObject *__pyx_v_addrs = NULL;
  PyObject *__pyx_v_sockaddr = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  size_t __pyx_t_11;
  struct ares_addrinfo_cname *__pyx_t_12;
  struct ares_addrinfo_node *__pyx_t_13;
  int __pyx_t_14;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  int __pyx_t_18;
  int __pyx_t_19;
  char const *__pyx_t_20;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  PyObject *__pyx_t_23 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_getaddrinfo_cb", 0);

  /* "gevent/resolver/cares.pyx":636
 *         cdef sockaddr_in* sadr4
 *         cdef sockaddr_in6* sadr6
 *         cdef object canonname = ''             # <<<<<<<<<<<<<<
 * 
 *         cdef channel channel
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_u__6);
  __pyx_v_canonname = __pyx_mstate_global->__pyx_kp_u__6;

  /* "gevent/resolver/cares.pyx":644
 *         cdef char tmpbuf[46]
 * 
 *         channel, callback = <tuple>arg             # <<<<<<<<<<<<<<
 *         Py_DECREF(<tuple>arg)
 * 
*/
  __pyx_t_1 = ((PyObject *)__pyx_v_arg);
  __Pyx_INCREF(__pyx_t_1);
  if (likely(__pyx_t_1 != Py_None)) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 644, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1);
    __Pyx_INCREF(__pyx_t_3);
    #else
    __pyx_t_2 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 644, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 644, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(0, 644, __pyx_L1_error)
  }
  if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_mstate_global->__pyx_ptype_6gevent_8resolver_5cares_channel))))) __PYX_ERR(0, 644, __pyx_L1_error)
  __pyx_v_channel = ((struct __pyx_obj_6gevent_8resolver_5cares_channel *)__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_v_callback = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "gevent/resolver/cares.pyx":645
 * 
 *         channel, callback = <tuple>arg
 *         Py_DECREF(<tuple>arg)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  Py_DECREF(((PyObject *)__pyx_v_arg));

  /* "gevent/resolver/cares.pyx":655
 *         # (address, port, flow info, scope id)
 *         # TODO: Check the canonnames.
 *         addrs = []             # <<<<<<<<<<<<<<
 *         try:
 *             if status != cares.ARES_SUCCESS:
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 655, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_addrs = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "gevent/resolver/cares.pyx":656
 *         # TODO: Check the canonnames.
 *         addrs = []
 *         try:             # <<<<<<<<<<<<<<
 *             if status != cares.ARES_SUCCESS:
 *                 callback(Result(None, _gevent_gaierror_from_status(status)))
*/
  /*try:*/ {
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);
      /*try:*/ {

        /* "gevent/resolver/cares.pyx":657
 *         addrs = []
 *         try:
 *             if status != cares.ARES_SUCCESS:             # <<<<<<<<<<<<<<
 *                 callback(Result(None, _gevent_gaierror_from_status(status)))
 *                 return
*/
        __pyx_t_7 = (__pyx_v_status != ARES_SUCCESS);
        if (__pyx_t_7) {

          /* "gevent/resolver/cares.pyx":658
 *         try:
 *             if status != cares.ARES_SUCCESS:
 *                 callback(Result(None, _gevent_gaierror_from_status(status)))             # <<<<<<<<<<<<<<
 *                 return
 *             if result.cnames:
*/
          __pyx_t_3 = NULL;
          __Pyx_INCREF(__pyx_v_callback);
          __pyx_t_2 = __pyx_v_callback; 
          __pyx_t_9 = NULL;
          __pyx_t_10 = __pyx_f_6gevent_8resolver_5cares__gevent_gaierror_from_status(__pyx_v_status); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 658, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_11 = 1;
          {
            PyObject *__pyx_callargs[3] = {__pyx_t_9, Py_None, __pyx_t_10};
            __pyx_t_8 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6gevent_8resolver_5cares_Result, __pyx_callargs+__pyx_t_11, (3-__pyx_t_11) | (__pyx_t_11*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 658, __pyx_L6_error)
            __Pyx_GOTREF((PyObject *)__pyx_t_8);
          }
          __pyx_t_11 = 1;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_2))) {
            __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
            assert(__pyx_t_3);
            PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
            __Pyx_INCREF(__pyx_t_3);
            __Pyx_INCREF(__pyx__function);
            __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
            __pyx_t_11 = 0;
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_3, ((PyObject *)__pyx_t_8)};
            __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_11, (2-__pyx_t_11) | (__pyx_t_11*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
            __Pyx_DECREF((PyObject *)__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 658, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_1);
          }
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

          /* "gevent/resolver/cares.pyx":659
 *             if status != cares.ARES_SUCCESS:
 *                 callback(Result(None, _gevent_gaierror_from_status(status)))
 *                 return             # <<<<<<<<<<<<<<
 *             if result.cnames:
 *                 # These tend to come in pairs:
*/
          goto __pyx_L10_try_return;

          /* "gevent/resolver/cares.pyx":657
 *         addrs = []
 *         try:
 *             if status != cares.ARES_SUCCESS:             # <<<<<<<<<<<<<<
 *                 callback(Result(None, _gevent_gaierror_from_status(status)))
 *                 return
*/
        }

        /* "gevent/resolver/cares.pyx":660
 *                 callback(Result(None, _gevent_gaierror_from_status(status)))
 *                 return
 *             if result.cnames:             # <<<<<<<<<<<<<<
 *                 # These tend to come in pairs:
 *                 #
*/
        __pyx_t_7 = (__pyx_v_result->cnames != 0);
        if (__pyx_t_7) {

          /* "gevent/resolver/cares.pyx":668
 *                 # The standard library returns the last name so we do too.
 * 
 *                 cnames = result.cnames             # <<<<<<<<<<<<<<
 *                 while cnames:
 *                     canonname = _as_str(cnames.name)
*/
          __pyx_t_12 = __pyx_v_result->cnames;
          __pyx_v_cnames = __pyx_t_12;

          /* "gevent/resolver/cares.pyx":669
 * 
 *                 cnames = result.cnames
 *                 while cnames:             # <<<<<<<<<<<<<<
 *                     canonname = _as_str(cnames.name)
 *                     cnames = cnames.next
*/
          while (1) {
            __pyx_t_7 = (__pyx_v_cnames != 0);
            if (!__pyx_t_7) break;

            /* "gevent/resolver/cares.pyx":670
 *                 cnames = result.cnames
 *                 while cnames:
 *                     canonname = _as_str(cnames.name)             # <<<<<<<<<<<<<<
 *                     cnames = cnames.next
 * 
*/
            __pyx_t_1 = __pyx_f_6gevent_8resolver_5cares__as_str(__pyx_v_cnames->name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 670, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF_SET(__pyx_v_canonname, __pyx_t_1);
            __pyx_t_1 = 0;

            /* "gevent/resolver/cares.pyx":671
 *                 while cnames:
 *                     canonname = _as_str(cnames.name)
 *                     cnames = cnames.next             # <<<<<<<<<<<<<<
 * 
 *             nodes = result.nodes
*/
            __pyx_t_12 = __pyx_v_cnames->next;
            __pyx_v_cnames = __pyx_t_12;
          }

          /* "gevent/resolver/cares.pyx":660
 *                 callback(Result(None, _gevent_gaierror_from_status(status)))
 *                 return
 *             if result.cnames:             # <<<<<<<<<<<<<<
 *                 # These tend to come in pairs:
 *                 #
*/
        }

        /* "gevent/resolver/cares.pyx":673
 *                     cnames = cnames.next
 * 
 *             nodes = result.nodes             # <<<<<<<<<<<<<<
 *             while nodes:
 *                 if nodes.ai_family == AF_INET:
*/
        __pyx_t_13 = __pyx_v_result->nodes;
        __pyx_v_nodes = __pyx_t_13;

        /* "gevent/resolver/cares.pyx":674
 * 
 *             nodes = result.nodes
 *             while nodes:             # <<<<<<<<<<<<<<
 *                 if nodes.ai_family == AF_INET:
 *                     sadr4 = <sockaddr_in*>nodes.ai_addr
*/
        while (1) {
          __pyx_t_7 = (__pyx_v_nodes != 0);
          if (!__pyx_t_7) break;

          /* "gevent/resolver/cares.pyx":675
 *             nodes = result.nodes
 *             while nodes:
 *                 if nodes.ai_family == AF_INET:             # <<<<<<<<<<<<<<
 *                     sadr4 = <sockaddr_in*>nodes.ai_addr
 *                     cares.ares_inet_ntop(nodes.ai_family, &sadr4.sin_addr, tmpbuf,
*/
          __pyx_t_7 = (__pyx_v_nodes->ai_family == AF_INET);
          if (__pyx_t_7) {

            /* "gevent/resolver/cares.pyx":676
 *             while nodes:
 *                 if nodes.ai_family == AF_INET:
 *                     sadr4 = <sockaddr_in*>nodes.ai_addr             # <<<<<<<<<<<<<<
 *                     cares.ares_inet_ntop(nodes.ai_family, &sadr4.sin_addr, tmpbuf,
 *                                             INET6_ADDRSTRLEN)
*/
            __pyx_v_sadr4 = ((struct sockaddr_in *)__pyx_v_nodes->ai_addr);

            /* "gevent/resolver/cares.pyx":677
 *                 if nodes.ai_family == AF_INET:
 *                     sadr4 = <sockaddr_in*>nodes.ai_addr
 *                     cares.ares_inet_ntop(nodes.ai_family, &sadr4.sin_addr, tmpbuf,             # <<<<<<<<<<<<<<
 *                                             INET6_ADDRSTRLEN)
 *                     sockaddr = (
*/
            (void)(ares_inet_ntop(__pyx_v_nodes->ai_family, (&__pyx_v_sadr4->sin_addr), __pyx_v_tmpbuf, INET6_ADDRSTRLEN));

            /* "gevent/resolver/cares.pyx":680
 *                                             INET6_ADDRSTRLEN)
 *                     sockaddr = (
 *                         _as_str(tmpbuf),             # <<<<<<<<<<<<<<
 *                         ntohs(sadr4.sin_port),
 *                     )
*/
            __pyx_t_1 = __pyx_f_6gevent_8resolver_5cares__as_str(__pyx_v_tmpbuf); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 680, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_1);

            /* "gevent/resolver/cares.pyx":681
 *                     sockaddr = (
 *                         _as_str(tmpbuf),
 *                         ntohs(sadr4.sin_port),             # <<<<<<<<<<<<<<
 *                     )
 *                 elif nodes.ai_family == AF_INET6:
*/
            __pyx_t_2 = __Pyx_PyLong_From_unsigned_int(ntohs(__pyx_v_sadr4->sin_port)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 681, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_2);

            /* "gevent/resolver/cares.pyx":680
 *                                             INET6_ADDRSTRLEN)
 *                     sockaddr = (
 *                         _as_str(tmpbuf),             # <<<<<<<<<<<<<<
 *                         ntohs(sadr4.sin_port),
 *                     )
*/
            __pyx_t_8 = PyTuple_New(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 680, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_GIVEREF(__pyx_t_1);
            if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_1) != (0)) __PYX_ERR(0, 680, __pyx_L6_error);
            __Pyx_GIVEREF(__pyx_t_2);
            if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_t_2) != (0)) __PYX_ERR(0, 680, __pyx_L6_error);
            __pyx_t_1 = 0;
            __pyx_t_2 = 0;
            __Pyx_XDECREF_SET(__pyx_v_sockaddr, ((PyObject*)__pyx_t_8));
            __pyx_t_8 = 0;

            /* "gevent/resolver/cares.pyx":675
 *             nodes = result.nodes
 *             while nodes:
 *                 if nodes.ai_family == AF_INET:             # <<<<<<<<<<<<<<
 *                     sadr4 = <sockaddr_in*>nodes.ai_addr
 *                     cares.ares_inet_ntop(nodes.ai_family, &sadr4.sin_addr, tmpbuf,
*/
            goto __pyx_L18;
          }

          /* "gevent/resolver/cares.pyx":683
 *                         ntohs(sadr4.sin_port),
 *                     )
 *                 elif nodes.ai_family == AF_INET6:             # <<<<<<<<<<<<<<
 *                     sadr6 = <sockaddr_in6*>nodes.ai_addr
 *                     cares.ares_inet_ntop(nodes.ai_family, &sadr6.sin6_addr, tmpbuf,
*/
          __pyx_t_7 = (__pyx_v_nodes->ai_family == AF_INET6);
          if (__pyx_t_7) {

            /* "gevent/resolver/cares.pyx":684
 *                     )
 *                 elif nodes.ai_family == AF_INET6:
 *                     sadr6 = <sockaddr_in6*>nodes.ai_addr             # <<<<<<<<<<<<<<
 *                     cares.ares_inet_ntop(nodes.ai_family, &sadr6.sin6_addr, tmpbuf,
 *                                             INET6_ADDRSTRLEN)
*/
            __pyx_v_sadr6 = ((struct sockaddr_in6 *)__pyx_v_nodes->ai_addr);

            /* "gevent/resolver/cares.pyx":685
 *                 elif nodes.ai_family == AF_INET6:
 *                     sadr6 = <sockaddr_in6*>nodes.ai_addr
 *                     cares.ares_inet_ntop(nodes.ai_family, &sadr6.sin6_addr, tmpbuf,             # <<<<<<<<<<<<<<
 *                                             INET6_ADDRSTRLEN)
 * 
*/
            (void)(ares_inet_ntop(__pyx_v_nodes->ai_family, (&__pyx_v_sadr6->sin6_addr), __pyx_v_tmpbuf, INET6_ADDRSTRLEN));

            /* "gevent/resolver/cares.pyx":689
 * 
 *                     sockaddr = (
 *                         _as_str(tmpbuf),             # <<<<<<<<<<<<<<
 *                         ntohs(sadr6.sin6_port),
 *                         sadr6.sin6_flowinfo,
*/
            __pyx_t_8 = __pyx_f_6gevent_8resolver_5cares__as_str(__pyx_v_tmpbuf); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 689, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_8);

            /* "gevent/resolver/cares.pyx":690
 *                     sockaddr = (
 *                         _as_str(tmpbuf),
 *                         ntohs(sadr6.sin6_port),             # <<<<<<<<<<<<<<
 *                         sadr6.sin6_flowinfo,
 *                         sadr6.sin6_scope_id,
*/
            __pyx_t_2 = __Pyx_PyLong_From_unsigned_int(ntohs(__pyx_v_sadr6->sin6_port)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 690, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_2);

            /* "gevent/resolver/cares.pyx":691
 *                         _as_str(tmpbuf),
 *                         ntohs(sadr6.sin6_port),
 *                         sadr6.sin6_flowinfo,             # <<<<<<<<<<<<<<
 *                         sadr6.sin6_scope_id,
 *                     )
*/
            __pyx_t_1 = __Pyx_PyLong_From_unsigned_int(__pyx_v_sadr6->sin6_flowinfo); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 691, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_1);

            /* "gevent/resolver/cares.pyx":692
 *                         ntohs(sadr6.sin6_port),
 *                         sadr6.sin6_flowinfo,
 *                         sadr6.sin6_scope_id,             # <<<<<<<<<<<<<<
 *                     )
 *                 addrs.append((
*/
            __pyx_t_3 = __Pyx_PyLong_From_unsigned_int(__pyx_v_sadr6->sin6_scope_id); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 692, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_3);

            /* "gevent/resolver/cares.pyx":689
 * 
 *                     sockaddr = (
 *                         _as_str(tmpbuf),             # <<<<<<<<<<<<<<
 *                         ntohs(sadr6.sin6_port),
 *                         sadr6.sin6_flowinfo,
*/
            __pyx_t_10 = PyTuple_New(4); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 689, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_10);
            __Pyx_GIVEREF(__pyx_t_8);
            if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_8) != (0)) __PYX_ERR(0, 689, __pyx_L6_error);
            __Pyx_GIVEREF(__pyx_t_2);
            if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_t_2) != (0)) __PYX_ERR(0, 689, __pyx_L6_error);
            __Pyx_GIVEREF(__pyx_t_1);
            if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 2, __pyx_t_1) != (0)) __PYX_ERR(0, 689, __pyx_L6_error);
            __Pyx_GIVEREF(__pyx_t_3);
            if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 3, __pyx_t_3) != (0)) __PYX_ERR(0, 689, __pyx_L6_error);
            __pyx_t_8 = 0;
            __pyx_t_2 = 0;
            __pyx_t_1 = 0;
            __pyx_t_3 = 0;
            __Pyx_XDECREF_SET(__pyx_v_sockaddr, ((PyObject*)__pyx_t_10));
            __pyx_t_10 = 0;

            /* "gevent/resolver/cares.pyx":683
 *                         ntohs(sadr4.sin_port),
 *                     )
 *                 elif nodes.ai_family == AF_INET6:             # <<<<<<<<<<<<<<
 *                     sadr6 = <sockaddr_in6*>nodes.ai_addr
 *                     cares.ares_inet_ntop(nodes.ai_family, &sadr6.sin6_addr, tmpbuf,
*/
          }
          __pyx_L18:;

          /* "gevent/resolver/cares.pyx":695
 *                     )
 *                 addrs.append((
 *                     nodes.ai_family,             # <<<<<<<<<<<<<<
 *                     nodes.ai_socktype,
 *                     nodes.ai_protocol,
*/
          __pyx_t_10 = __Pyx_PyLong_From_int(__pyx_v_nodes->ai_family); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 695, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_10);

          /* "gevent/resolver/cares.pyx":696
 *                 addrs.append((
 *                     nodes.ai_family,
 *                     nodes.ai_socktype,             # <<<<<<<<<<<<<<
 *                     nodes.ai_protocol,
 *                     canonname,
*/
          __pyx_t_3 = __Pyx_PyLong_From_int(__pyx_v_nodes->ai_socktype); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 696, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_3);

          /* "gevent/resolver/cares.pyx":697
 *                     nodes.ai_family,
 *                     nodes.ai_socktype,
 *                     nodes.ai_protocol,             # <<<<<<<<<<<<<<
 *                     canonname,
 *                     sockaddr,
*/
          __pyx_t_1 = __Pyx_PyLong_From_int(__pyx_v_nodes->ai_protocol); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 697, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_1);

          /* "gevent/resolver/cares.pyx":699
 *                     nodes.ai_protocol,
 *                     canonname,
 *                     sockaddr,             # <<<<<<<<<<<<<<
 *                 ))
 *                 nodes = nodes.ai_next
*/
          if (unlikely(!__pyx_v_sockaddr)) { __Pyx_RaiseUnboundLocalError("sockaddr"); __PYX_ERR(0, 699, __pyx_L6_error) }

          /* "gevent/resolver/cares.pyx":695
 *                     )
 *                 addrs.append((
 *                     nodes.ai_family,             # <<<<<<<<<<<<<<
 *                     nodes.ai_socktype,
 *                     nodes.ai_protocol,
*/
          __pyx_t_2 = PyTuple_New(5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 695, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_GIVEREF(__pyx_t_10);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_10) != (0)) __PYX_ERR(0, 695, __pyx_L6_error);
          __Pyx_GIVEREF(__pyx_t_3);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_3) != (0)) __PYX_ERR(0, 695, __pyx_L6_error);
          __Pyx_GIVEREF(__pyx_t_1);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_t_1) != (0)) __PYX_ERR(0, 695, __pyx_L6_error);
          __Pyx_INCREF(__pyx_v_canonname);
          __Pyx_GIVEREF(__pyx_v_canonname);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 3, __pyx_v_canonname) != (0)) __PYX_ERR(0, 695, __pyx_L6_error);
          __Pyx_INCREF(__pyx_v_sockaddr);
          __Pyx_GIVEREF(__pyx_v_sockaddr);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 4, __pyx_v_sockaddr) != (0)) __PYX_ERR(0, 695, __pyx_L6_error);
          __pyx_t_10 = 0;
          __pyx_t_3 = 0;
          __pyx_t_1 = 0;

          /* "gevent/resolver/cares.pyx":694
 *                         sadr6.sin6_scope_id,
 *                     )
 *                 addrs.append((             # <<<<<<<<<<<<<<
 *                     nodes.ai_family,
 *                     nodes.ai_socktype,
*/
          __pyx_t_14 = __Pyx_PyList_Append(__pyx_v_addrs, __pyx_t_2); if (unlikely(__pyx_t_14 == ((int)-1))) __PYX_ERR(0, 694, __pyx_L6_error)
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

          /* "gevent/resolver/cares.pyx":701
 *                     sockaddr,
 *                 ))
 *                 nodes = nodes.ai_next             # <<<<<<<<<<<<<<
 * 
 *             callback(Result(addrs, None))
*/
          __pyx_t_13 = __pyx_v_nodes->ai_next;
          __pyx_v_nodes = __pyx_t_13;
        }

        /* "gevent/resolver/cares.pyx":703
 *                 nodes = nodes.ai_next
 * 
 *             callback(Result(addrs, None))             # <<<<<<<<<<<<<<
 *         except:
 *             channel.loop.handle_error(callback, *sys.exc_info())
*/
        __pyx_t_1 = NULL;
        __Pyx_INCREF(__pyx_v_callback);
        __pyx_t_3 = __pyx_v_callback; 
        __pyx_t_8 = NULL;
        __pyx_t_11 = 1;
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_8, __pyx_v_addrs, Py_None};
          __pyx_t_10 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6gevent_8resolver_5cares_Result, __pyx_callargs+__pyx_t_11, (3-__pyx_t_11) | (__pyx_t_11*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 703, __pyx_L6_error)
          __Pyx_GOTREF((PyObject *)__pyx_t_10);
        }
        __pyx_t_11 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
          assert(__pyx_t_1);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
          __pyx_t_11 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_1, ((PyObject *)__pyx_t_10)};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_11, (2-__pyx_t_11) | (__pyx_t_11*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF((PyObject *)__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 703, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "gevent/resolver/cares.pyx":656
 *         # TODO: Check the canonnames.
 *         addrs = []
 *         try:             # <<<<<<<<<<<<<<
 *             if status != cares.ARES_SUCCESS:
 *                 callback(Result(None, _gevent_gaierror_from_status(status)))
*/
      }
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L11_try_end;
      __pyx_L6_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

      /* "gevent/resolver/cares.pyx":704
 * 
 *             callback(Result(addrs, None))
 *         except:             # <<<<<<<<<<<<<<
 *             channel.loop.handle_error(callback, *sys.exc_info())
 *         finally:
*/
      /*except:*/ {
        __Pyx_AddTraceback("gevent.resolver.cares.channel._getaddrinfo_cb", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_3, &__pyx_t_10) < 0) __PYX_ERR(0, 704, __pyx_L8_except_error)
        __Pyx_XGOTREF(__pyx_t_2);
        __Pyx_XGOTREF(__pyx_t_3);
        __Pyx_XGOTREF(__pyx_t_10);

        /* "gevent/resolver/cares.pyx":705
 *             callback(Result(addrs, None))
 *         except:
 *             channel.loop.handle_error(callback, *sys.exc_info())             # <<<<<<<<<<<<<<
 *         finally:
 *             if result:
*/
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_channel->loop, __pyx_mstate_global->__pyx_n_u_handle_error); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 705, __pyx_L8_except_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_8 = PyTuple_New(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 705, __pyx_L8_except_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_INCREF(__pyx_v_callback);
        __Pyx_GIVEREF(__pyx_v_callback);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_v_callback) != (0)) __PYX_ERR(0, 705, __pyx_L8_except_error);
        __pyx_t_15 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_16, __pyx_mstate_global->__pyx_n_u_sys); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 705, __pyx_L8_except_error)
        __Pyx_GOTREF(__pyx_t_16);
        __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_16, __pyx_mstate_global->__pyx_n_u_exc_info); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 705, __pyx_L8_except_error)
        __Pyx_GOTREF(__pyx_t_17);
        __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
        __pyx_t_11 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_17))) {
          __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_17);
          assert(__pyx_t_15);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_17);
          __Pyx_INCREF(__pyx_t_15);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_17, __pyx__function);
          __pyx_t_11 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_15, NULL};
          __pyx_t_9 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_17, __pyx_callargs+__pyx_t_11, (1-__pyx_t_11) | (__pyx_t_11*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
          __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
          if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 705, __pyx_L8_except_error)
          __Pyx_GOTREF(__pyx_t_9);
        }
        __pyx_t_17 = __Pyx_PySequence_Tuple(__pyx_t_9); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 705, __pyx_L8_except_error)
        __Pyx_GOTREF(__pyx_t_17);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_t_9 = PyNumber_Add(__pyx_t_8, __pyx_t_17); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 705, __pyx_L8_except_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
        __pyx_t_17 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_9, NULL); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 705, __pyx_L8_except_error)
        __Pyx_GOTREF(__pyx_t_17);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        goto __pyx_L7_exception_handled;
      }

      /* "gevent/resolver/cares.pyx":656
 *         # TODO: Check the canonnames.
 *         addrs = []
 *         try:             # <<<<<<<<<<<<<<
 *             if status != cares.ARES_SUCCESS:
 *                 callback(Result(None, _gevent_gaierror_from_status(status)))
*/
      __pyx_L8_except_error:;
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
      goto __pyx_L4_error;
      __pyx_L10_try_return:;
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
      goto __pyx_L3_return;
      __pyx_L7_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
      __pyx_L11_try_end:;
    }
  }

  /* "gevent/resolver/cares.pyx":707
 *             channel.loop.handle_error(callback, *sys.exc_info())
 *         finally:
 *             if result:             # <<<<<<<<<<<<<<
 *                 cares.ares_freeaddrinfo(result)
 * 
*/
  /*finally:*/ {
    /*normal exit:*/{
      __pyx_t_7 = (__pyx_v_result != 0);
      if (__pyx_t_7) {

        /* "gevent/resolver/cares.pyx":708
 *         finally:
 *             if result:
 *                 cares.ares_freeaddrinfo(result)             # <<<<<<<<<<<<<<
 * 
 *     def getaddrinfo(self,
*/
        ares_freeaddrinfo(__pyx_v_result);

        /* "gevent/resolver/cares.pyx":707
 *             channel.loop.handle_error(callback, *sys.exc_info())
 *         finally:
 *             if result:             # <<<<<<<<<<<<<<
 *                 cares.ares_freeaddrinfo(result)
 * 
*/
      }
      goto __pyx_L5;
    }
    __pyx_L4_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_6 = 0; __pyx_t_5 = 0; __pyx_t_4 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
      __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
      __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
       __Pyx_ExceptionSwap(&__pyx_t_21, &__pyx_t_22, &__pyx_t_23);
      if ( unlikely(__Pyx_GetException(&__pyx_t_6, &__pyx_t_5, &__pyx_t_4) < 0)) __Pyx_ErrFetch(&__pyx_t_6, &__pyx_t_5, &__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_21);
      __Pyx_XGOTREF(__pyx_t_22);
      __Pyx_XGOTREF(__pyx_t_23);
      __pyx_t_18 = __pyx_lineno; __pyx_t_19 = __pyx_clineno; __pyx_t_20 = __pyx_filename;
      {
        __pyx_t_7 = (__pyx_v_result != 0);
        if (__pyx_t_7) {

          /* "gevent/resolver/cares.pyx":708
 *         finally:
 *             if result:
 *                 cares.ares_freeaddrinfo(result)             # <<<<<<<<<<<<<<
 * 
 *     def getaddrinfo(self,
*/
          ares_freeaddrinfo(__pyx_v_result);

          /* "gevent/resolver/cares.pyx":707
 *             channel.loop.handle_error(callback, *sys.exc_info())
 *         finally:
 *             if result:             # <<<<<<<<<<<<<<
 *                 cares.ares_freeaddrinfo(result)
 * 
*/
        }
      }
      __Pyx_XGIVEREF(__pyx_t_21);
      __Pyx_XGIVEREF(__pyx_t_22);
      __Pyx_XGIVEREF(__pyx_t_23);
      __Pyx_ExceptionReset(__pyx_t_21, __pyx_t_22, __pyx_t_23);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_ErrRestore(__pyx_t_6, __pyx_t_5, __pyx_t_4);
      __pyx_t_6 = 0; __pyx_t_5 = 0; __pyx_t_4 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0;
      __pyx_lineno = __pyx_t_18; __pyx_clineno = __pyx_t_19; __pyx_filename = __pyx_t_20;
      goto __pyx_L1_error;
    }
    __pyx_L3_return: {
      __pyx_t_7 = (__pyx_v_result != 0);
      if (__pyx_t_7) {

        /* "gevent/resolver/cares.pyx":708
 *         finally:
 *             if result:
 *                 cares.ares_freeaddrinfo(result)             # <<<<<<<<<<<<<<
 * 
 *     def getaddrinfo(self,
*/
        ares_freeaddrinfo(__pyx_v_result);

        /* "gevent/resolver/cares.pyx":707
 *             channel.loop.handle_error(callback, *sys.exc_info())
 *         finally:
 *             if result:             # <<<<<<<<<<<<<<
 *                 cares.ares_freeaddrinfo(result)
 * 
*/
      }
      goto __pyx_L0;
    }
    __pyx_L5:;
  }

  /* "gevent/resolver/cares.pyx":627
 *         return cares_flags
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     cdef void _getaddrinfo_cb(void *arg,
 *                               int status,
*/

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_AddTraceback("gevent.resolver.cares.channel._getaddrinfo_cb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_canonname);
  __Pyx_XDECREF((PyObject *)__pyx_v_channel);
  __Pyx_XDECREF(__pyx_v_callback);
  __Pyx_XDECREF(__pyx_v_addrs);
  __Pyx_XDECREF(__pyx_v_sockaddr);
  __Pyx_RefNannyFinishContext();
}

/* "gevent/resolver/cares.pyx":710
 *                 cares.ares_freeaddrinfo(result)
 * 
 *     def getaddrinfo(self,             # <<<<<<<<<<<<<<
 *                     object callback,
 *                     const char* name,
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_8resolver_5cares_7channel_23getaddrinfo(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6gevent_8resolver_5cares_7channel_23getaddrinfo = {"getaddrinfo", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6gevent_8resolver_5cares_7channel_23getaddrinfo, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6gevent_8resolver_5cares_7channel_23getaddrinfo(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_callback = 0;
  char const *__pyx_v_name;
  PyObject *__pyx_v_service = 0;
  int __pyx_v_family;
  int __pyx_v_type;
  int __pyx_v_proto;
  int __pyx_v_flags;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[7] = {0,0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getaddrinfo (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_callback,&__pyx_mstate_global->__pyx_n_u_name_2,&__pyx_mstate_global->__pyx_n_u_service,&__pyx_mstate_global->__pyx_n_u_family,&__pyx_mstate_global->__pyx_n_u_type,&__pyx_mstate_global->__pyx_n_u_proto,&__pyx_mstate_global->__pyx_n_u_flags,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 710, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  7:
        values[6] = __Pyx_ArgRef_FASTCALL(__pyx_args, 6);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[6])) __PYX_ERR(0, 710, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  6:
        values[5] = __Pyx_ArgRef_FASTCALL(__pyx_args, 5);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[5])) __PYX_ERR(0, 710, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  5:
        values[4] = __Pyx_ArgRef_FASTCALL(__pyx_args, 4);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[4])) __PYX_ERR(0, 710, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 710, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 710, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 710, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 710, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "getaddrinfo", 0) < (0)) __PYX_ERR(0, 710, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("getaddrinfo", 0, 3, 7, i); __PYX_ERR(0, 710, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  7:
        values[6] = __Pyx_ArgRef_FASTCALL(__pyx_args, 6);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[6])) __PYX_ERR(0, 710, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  6:
        values[5] = __Pyx_ArgRef_FASTCALL(__pyx_args, 5);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[5])) __PYX_ERR(0, 710, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  5:
        values[4] = __Pyx_ArgRef_FASTCALL(__pyx_args, 4);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[4])) __PYX_ERR(0, 710, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 710, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 710, __pyx_L3_error)
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 710, __pyx_L3_error)
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 710, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_callback = values[0];
    __pyx_v_name = __Pyx_PyObject_AsString(values[1]); if (unlikely((!__pyx_v_name) && PyErr_Occurred())) __PYX_ERR(0, 712, __pyx_L3_error)
    __pyx_v_service = values[2];
    if (values[3]) {
      __pyx_v_family = __Pyx_PyLong_As_int(values[3]); if (unlikely((__pyx_v_family == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 714, __pyx_L3_error)
    } else {
      __pyx_v_family = ((int)0);
    }
    if (values[4]) {
      __pyx_v_type = __Pyx_PyLong_As_int(values[4]); if (unlikely((__pyx_v_type == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 715, __pyx_L3_error)
    } else {
      __pyx_v_type = ((int)0);
    }
    if (values[5]) {
      __pyx_v_proto = __Pyx_PyLong_As_int(values[5]); if (unlikely((__pyx_v_proto == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 716, __pyx_L3_error)
    } else {
      __pyx_v_proto = ((int)0);
    }
    if (values[6]) {
      __pyx_v_flags = __Pyx_PyLong_As_int(values[6]); if (unlikely((__pyx_v_flags == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 717, __pyx_L3_error)
    } else {
      __pyx_v_flags = ((int)0);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("getaddrinfo", 0, 3, 7, __pyx_nargs); __PYX_ERR(0, 710, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("gevent.resolver.cares.channel.getaddrinfo", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6gevent_8resolver_5cares_7channel_22getaddrinfo(((struct __pyx_obj_6gevent_8resolver_5cares_channel *)__pyx_v_self), __pyx_v_callback, __pyx_v_name, __pyx_v_service, __pyx_v_family, __pyx_v_type, __pyx_v_proto, __pyx_v_flags);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_8resolver_5cares_7channel_22getaddrinfo(struct __pyx_obj_6gevent_8resolver_5cares_channel *__pyx_v_self, PyObject *__pyx_v_callback, char const *__pyx_v_name, PyObject *__pyx_v_service, int __pyx_v_family, int __pyx_v_type, int __pyx_v_proto, int __pyx_v_flags) {
  struct ares_addrinfo_hints __pyx_v_hints;
  PyObject *__pyx_v_arg = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_t_7;
  void *__pyx_t_8;
  char *__pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getaddrinfo", 0);

  /* "gevent/resolver/cares.pyx":718
 *                     int proto=0,
 *                     int flags=0):
 *         if not self.channel:             # <<<<<<<<<<<<<<
 *             raise gaierror(cares.ARES_EDESTRUCTION, 'this ares channel has been destroyed')
 * 
*/
  __pyx_t_1 = (!(__pyx_v_self->channel != 0));
  if (unlikely(__pyx_t_1)) {

    /* "gevent/resolver/cares.pyx":719
 *                     int flags=0):
 *         if not self.channel:
 *             raise gaierror(cares.ARES_EDESTRUCTION, 'this ares channel has been destroyed')             # <<<<<<<<<<<<<<
 * 
 *         cdef cares.ares_addrinfo_hints hints
*/
    __pyx_t_3 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_gaierror); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 719, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyLong_From_int(ARES_EDESTRUCTION); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 719, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      assert(__pyx_t_3);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
      __pyx_t_6 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_t_5, __pyx_mstate_global->__pyx_kp_u_this_ares_channel_has_been_destr};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_6, (3-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 719, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 719, __pyx_L1_error)

    /* "gevent/resolver/cares.pyx":718
 *                     int proto=0,
 *                     int flags=0):
 *         if not self.channel:             # <<<<<<<<<<<<<<
 *             raise gaierror(cares.ARES_EDESTRUCTION, 'this ares channel has been destroyed')
 * 
*/
  }

  /* "gevent/resolver/cares.pyx":722
 * 
 *         cdef cares.ares_addrinfo_hints hints
 *         memset(&hints, 0, sizeof(cares.ares_addrinfo_hints))             # <<<<<<<<<<<<<<
 * 
 *         hints.ai_flags = channel._convert_cares_ai_flags(flags)
*/
  (void)(memset((&__pyx_v_hints), 0, (sizeof(struct ares_addrinfo_hints))));

  /* "gevent/resolver/cares.pyx":724
 *         memset(&hints, 0, sizeof(cares.ares_addrinfo_hints))
 * 
 *         hints.ai_flags = channel._convert_cares_ai_flags(flags)             # <<<<<<<<<<<<<<
 *         hints.ai_family = family
 *         hints.ai_socktype = type
*/
  __pyx_t_7 = __pyx_f_6gevent_8resolver_5cares_7channel__convert_cares_ai_flags(__pyx_v_flags); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 724, __pyx_L1_error)
  __pyx_v_hints.ai_flags = __pyx_t_7;

  /* "gevent/resolver/cares.pyx":725
 * 
 *         hints.ai_flags = channel._convert_cares_ai_flags(flags)
 *         hints.ai_family = family             # <<<<<<<<<<<<<<
 *         hints.ai_socktype = type
 *         hints.ai_protocol = proto
*/
  __pyx_v_hints.ai_family = __pyx_v_family;

  /* "gevent/resolver/cares.pyx":726
 *         hints.ai_flags = channel._convert_cares_ai_flags(flags)
 *         hints.ai_family = family
 *         hints.ai_socktype = type             # <<<<<<<<<<<<<<
 *         hints.ai_protocol = proto
 *         cdef object arg = (self, callback)
*/
  __pyx_v_hints.ai_socktype = __pyx_v_type;

  /* "gevent/resolver/cares.pyx":727
 *         hints.ai_family = family
 *         hints.ai_socktype = type
 *         hints.ai_protocol = proto             # <<<<<<<<<<<<<<
 *         cdef object arg = (self, callback)
 *         Py_INCREF(arg)
*/
  __pyx_v_hints.ai_protocol = __pyx_v_proto;

  /* "gevent/resolver/cares.pyx":728
 *         hints.ai_socktype = type
 *         hints.ai_protocol = proto
 *         cdef object arg = (self, callback)             # <<<<<<<<<<<<<<
 *         Py_INCREF(arg)
 * 
*/
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 728, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_self)) != (0)) __PYX_ERR(0, 728, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_callback);
  __Pyx_GIVEREF(__pyx_v_callback);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_callback) != (0)) __PYX_ERR(0, 728, __pyx_L1_error);
  __pyx_v_arg = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "gevent/resolver/cares.pyx":729
 *         hints.ai_protocol = proto
 *         cdef object arg = (self, callback)
 *         Py_INCREF(arg)             # <<<<<<<<<<<<<<
 * 
 *         cares.ares_getaddrinfo(
*/
  Py_INCREF(__pyx_v_arg);

  /* "gevent/resolver/cares.pyx":734
 *             self.channel,
 *             name,
 *             NULL if service is None else <char*>service,             # <<<<<<<<<<<<<<
 *             &hints,
 *             <void*>channel._getaddrinfo_cb,
*/
  __pyx_t_1 = (__pyx_v_service == Py_None);
  if (__pyx_t_1) {
    __pyx_t_8 = NULL;
  } else {
    __pyx_t_9 = __Pyx_PyObject_AsWritableString(__pyx_v_service); if (unlikely((!__pyx_t_9) && PyErr_Occurred())) __PYX_ERR(0, 734, __pyx_L1_error)
    __pyx_t_8 = ((char *)__pyx_t_9);
  }

  /* "gevent/resolver/cares.pyx":731
 *         Py_INCREF(arg)
 * 
 *         cares.ares_getaddrinfo(             # <<<<<<<<<<<<<<
 *             self.channel,
 *             name,
*/
  ares_getaddrinfo(__pyx_v_self->channel, __pyx_v_name, __pyx_t_8, (&__pyx_v_hints), ((void *)__pyx_f_6gevent_8resolver_5cares_7channel__getaddrinfo_cb), ((void *)__pyx_v_arg));

  /* "gevent/resolver/cares.pyx":710
 *                 cares.ares_freeaddrinfo(result)
 * 
 *     def getaddrinfo(self,             # <<<<<<<<<<<<<<
 *                     object callback,
 *                     const char* name,
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("gevent.resolver.cares.channel.getaddrinfo", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_arg);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "gevent/resolver/cares.pyx":360
 *     cdef ares_channeldata* channel
 * 
 *     cdef readonly object loop             # <<<<<<<<<<<<<<
 * 
 *     cdef dict _watchers
*/

/* Python wrapper */
static PyObject *__pyx_pw_6gevent_8resolver_5cares_7channel_4loop_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6gevent_8resolver_5cares_7channel_4loop_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6gevent_8resolver_5cares_7channel_4loop___get__(((struct __pyx_obj_6gevent_8resolver_5cares_channel *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6gevent_8resolver_5cares_7channel_4loop___get__(struct __pyx_obj_6gevent_8resolver_5cares_channel *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->loop);
  __pyx_r = __pyx_v_self->loop;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
/* #### Code section: module_exttypes ### */

static PyObject *__pyx_tp_new_6gevent_8resolver_5cares_Result(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_6gevent_8resolver_5cares_Result *p;
  PyObject *o;
  o = __Pyx_AllocateExtensionType(t, 0);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6gevent_8resolver_5cares_Result *)o);
  p->value = Py_None; Py_INCREF(Py_None);
  p->exception = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6gevent_8resolver_5cares_Result(PyObject *o) {
  struct __pyx_obj_6gevent_8resolver_5cares_Result *p = (struct __pyx_obj_6gevent_8resolver_5cares_Result *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6gevent_8resolver_5cares_Result) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->value);
  Py_CLEAR(p->exception);
  PyTypeObject *tp = Py_TYPE(o);
  #if CYTHON_USE_TYPE_SLOTS
  (*tp->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  Py_DECREF(tp);
  #endif
}

static int __pyx_tp_traverse_6gevent_8resolver_5cares_Result(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6gevent_8resolver_5cares_Result *p = (struct __pyx_obj_6gevent_8resolver_5cares_Result *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->value) {
    e = (*v)(p->value, a); if (e) return e;
  }
  if (p->exception) {
    e = (*v)(p->exception, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6gevent_8resolver_5cares_Result(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6gevent_8resolver_5cares_Result *p = (struct __pyx_obj_6gevent_8resolver_5cares_Result *)o;
  tmp = ((PyObject*)p->value);
  p->value = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->exception);
  p->exception = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6gevent_8resolver_5cares_6Result_value(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6gevent_8resolver_5cares_6Result_5value_1__get__(o);
}

static int __pyx_setprop_6gevent_8resolver_5cares_6Result_value(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6gevent_8resolver_5cares_6Result_5value_3__set__(o, v);
  }
  else {
    return __pyx_pw_6gevent_8resolver_5cares_6Result_5value_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6gevent_8resolver_5cares_6Result_exception(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6gevent_8resolver_5cares_6Result_9exception_1__get__(o);
}

static int __pyx_setprop_6gevent_8resolver_5cares_6Result_exception(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6gevent_8resolver_5cares_6Result_9exception_3__set__(o, v);
  }
  else {
    return __pyx_pw_6gevent_8resolver_5cares_6Result_9exception_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_6gevent_8resolver_5cares_Result[] = {
  {"successful", (PyCFunction)__pyx_pw_6gevent_8resolver_5cares_6Result_5successful, METH_NOARGS, 0},
  {"get", (PyCFunction)__pyx_pw_6gevent_8resolver_5cares_6Result_7get, METH_NOARGS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6gevent_8resolver_5cares_Result[] = {
  {"value", __pyx_getprop_6gevent_8resolver_5cares_6Result_value, __pyx_setprop_6gevent_8resolver_5cares_6Result_value, 0, 0},
  {"exception", __pyx_getprop_6gevent_8resolver_5cares_6Result_exception, __pyx_setprop_6gevent_8resolver_5cares_6Result_exception, 0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6gevent_8resolver_5cares_Result_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6gevent_8resolver_5cares_Result},
  {Py_tp_repr, (void *)__pyx_pw_6gevent_8resolver_5cares_6Result_3__repr__},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6gevent_8resolver_5cares_Result},
  {Py_tp_clear, (void *)__pyx_tp_clear_6gevent_8resolver_5cares_Result},
  {Py_tp_methods, (void *)__pyx_methods_6gevent_8resolver_5cares_Result},
  {Py_tp_getset, (void *)__pyx_getsets_6gevent_8resolver_5cares_Result},
  {Py_tp_init, (void *)__pyx_pw_6gevent_8resolver_5cares_6Result_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6gevent_8resolver_5cares_Result},
  {0, 0},
};
static PyType_Spec __pyx_type_6gevent_8resolver_5cares_Result_spec = {
  "gevent.resolver.cares.Result",
  sizeof(struct __pyx_obj_6gevent_8resolver_5cares_Result),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6gevent_8resolver_5cares_Result_slots,
};
#else

static PyTypeObject __pyx_type_6gevent_8resolver_5cares_Result = {
  PyVarObject_HEAD_INIT(0, 0)
  "gevent.resolver.cares.""Result", /*tp_name*/
  sizeof(struct __pyx_obj_6gevent_8resolver_5cares_Result), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6gevent_8resolver_5cares_Result, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  __pyx_pw_6gevent_8resolver_5cares_6Result_3__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6gevent_8resolver_5cares_Result, /*tp_traverse*/
  __pyx_tp_clear_6gevent_8resolver_5cares_Result, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6gevent_8resolver_5cares_Result, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6gevent_8resolver_5cares_Result, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6gevent_8resolver_5cares_6Result_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6gevent_8resolver_5cares_Result, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6gevent_8resolver_5cares_channel __pyx_vtable_6gevent_8resolver_5cares_channel;

static PyObject *__pyx_tp_new_6gevent_8resolver_5cares_channel(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_6gevent_8resolver_5cares_channel *p;
  PyObject *o;
  o = __Pyx_AllocateExtensionType(t, 0);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6gevent_8resolver_5cares_channel *)o);
  p->__pyx_vtab = __pyx_vtabptr_6gevent_8resolver_5cares_channel;
  p->loop = Py_None; Py_INCREF(Py_None);
  p->_watchers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_timer = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6gevent_8resolver_5cares_channel(PyObject *o) {
  struct __pyx_obj_6gevent_8resolver_5cares_channel *p = (struct __pyx_obj_6gevent_8resolver_5cares_channel *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6gevent_8resolver_5cares_channel) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_pw_6gevent_8resolver_5cares_7channel_7__dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->loop);
  Py_CLEAR(p->_watchers);
  Py_CLEAR(p->_timer);
  PyTypeObject *tp = Py_TYPE(o);
  #if CYTHON_USE_TYPE_SLOTS
  (*tp->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  Py_DECREF(tp);
  #endif
}

static int __pyx_tp_traverse_6gevent_8resolver_5cares_channel(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6gevent_8resolver_5cares_channel *p = (struct __pyx_obj_6gevent_8resolver_5cares_channel *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->loop) {
    e = (*v)(p->loop, a); if (e) return e;
  }
  if (p->_watchers) {
    e = (*v)(p->_watchers, a); if (e) return e;
  }
  if (p->_timer) {
    e = (*v)(p->_timer, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6gevent_8resolver_5cares_channel(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6gevent_8resolver_5cares_channel *p = (struct __pyx_obj_6gevent_8resolver_5cares_channel *)o;
  tmp = ((PyObject*)p->loop);
  p->loop = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_watchers);
  p->_watchers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_timer);
  p->_timer = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6gevent_8resolver_5cares_7channel_loop(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6gevent_8resolver_5cares_7channel_4loop_1__get__(o);
}

static PyMethodDef __pyx_methods_6gevent_8resolver_5cares_channel[] = {
  {"destroy", (PyCFunction)__pyx_pw_6gevent_8resolver_5cares_7channel_5destroy, METH_NOARGS, 0},
  {"_on_timer", (PyCFunction)__pyx_pw_6gevent_8resolver_5cares_7channel_11_on_timer, METH_NOARGS, 0},
  {"_process_fd", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6gevent_8resolver_5cares_7channel_13_process_fd, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"gethostbyname", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6gevent_8resolver_5cares_7channel_15gethostbyname, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"gethostbyaddr", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6gevent_8resolver_5cares_7channel_17gethostbyaddr, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"getnameinfo", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6gevent_8resolver_5cares_7channel_21getnameinfo, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"getaddrinfo", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6gevent_8resolver_5cares_7channel_23getaddrinfo, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6gevent_8resolver_5cares_channel[] = {
  {"loop", __pyx_getprop_6gevent_8resolver_5cares_7channel_loop, 0, 0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6gevent_8resolver_5cares_channel_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6gevent_8resolver_5cares_channel},
  {Py_tp_repr, (void *)__pyx_pw_6gevent_8resolver_5cares_7channel_3__repr__},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6gevent_8resolver_5cares_channel},
  {Py_tp_clear, (void *)__pyx_tp_clear_6gevent_8resolver_5cares_channel},
  {Py_tp_methods, (void *)__pyx_methods_6gevent_8resolver_5cares_channel},
  {Py_tp_getset, (void *)__pyx_getsets_6gevent_8resolver_5cares_channel},
  {Py_tp_init, (void *)__pyx_pw_6gevent_8resolver_5cares_7channel_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6gevent_8resolver_5cares_channel},
  {0, 0},
};
static PyType_Spec __pyx_type_6gevent_8resolver_5cares_channel_spec = {
  "gevent.resolver.cares.channel",
  sizeof(struct __pyx_obj_6gevent_8resolver_5cares_channel),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6gevent_8resolver_5cares_channel_slots,
};
#else

static PyTypeObject __pyx_type_6gevent_8resolver_5cares_channel = {
  PyVarObject_HEAD_INIT(0, 0)
  "gevent.resolver.cares.""channel", /*tp_name*/
  sizeof(struct __pyx_obj_6gevent_8resolver_5cares_channel), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6gevent_8resolver_5cares_channel, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  __pyx_pw_6gevent_8resolver_5cares_7channel_3__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6gevent_8resolver_5cares_channel, /*tp_traverse*/
  __pyx_tp_clear_6gevent_8resolver_5cares_channel, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6gevent_8resolver_5cares_channel, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6gevent_8resolver_5cares_channel, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6gevent_8resolver_5cares_7channel_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6gevent_8resolver_5cares_channel, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};
/* #### Code section: initfunc_declarations ### */
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitConstants(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_CreateCodeObjects(__pyx_mstatetype *__pyx_mstate); /*proto*/
/* #### Code section: init_module ### */

static int __Pyx_modinit_global_init_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __pyx_v_6gevent_8resolver_5cares__ares_errors = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_6gevent_8resolver_5cares__ares_to_gai_system = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_6gevent_8resolver_5cares__ares_to_host_system = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_init_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_6gevent_8resolver_5cares_Result = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6gevent_8resolver_5cares_Result_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_6gevent_8resolver_5cares_Result)) __PYX_ERR(0, 243, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6gevent_8resolver_5cares_Result_spec, __pyx_mstate->__pyx_ptype_6gevent_8resolver_5cares_Result) < (0)) __PYX_ERR(0, 243, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6gevent_8resolver_5cares_Result = &__pyx_type_6gevent_8resolver_5cares_Result;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6gevent_8resolver_5cares_Result) < (0)) __PYX_ERR(0, 243, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6gevent_8resolver_5cares_Result);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6gevent_8resolver_5cares_Result->tp_dictoffset && __pyx_mstate->__pyx_ptype_6gevent_8resolver_5cares_Result->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6gevent_8resolver_5cares_Result->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_Result, (PyObject *) __pyx_mstate->__pyx_ptype_6gevent_8resolver_5cares_Result) < (0)) __PYX_ERR(0, 243, __pyx_L1_error)
  __pyx_vtabptr_6gevent_8resolver_5cares_channel = &__pyx_vtable_6gevent_8resolver_5cares_channel;
  __pyx_vtable_6gevent_8resolver_5cares_channel._channel__destroy = (PyObject *(*)(struct __pyx_obj_6gevent_8resolver_5cares_channel *))__pyx_f_6gevent_8resolver_5cares_7channel__channel__destroy;
  __pyx_vtable_6gevent_8resolver_5cares_channel.set_servers = (PyObject *(*)(struct __pyx_obj_6gevent_8resolver_5cares_channel *, int __pyx_skip_dispatch, struct __pyx_opt_args_6gevent_8resolver_5cares_7channel_set_servers *__pyx_optional_args))__pyx_f_6gevent_8resolver_5cares_7channel_set_servers;
  __pyx_vtable_6gevent_8resolver_5cares_channel._sock_state_callback = (PyObject *(*)(struct __pyx_obj_6gevent_8resolver_5cares_channel *, int, int, int))__pyx_f_6gevent_8resolver_5cares_7channel__sock_state_callback;
  __pyx_vtable_6gevent_8resolver_5cares_channel._gethostbyname_or_byaddr_cb = (void (*)(void *, int, int, struct hostent *))__pyx_f_6gevent_8resolver_5cares_7channel__gethostbyname_or_byaddr_cb;
  __pyx_vtable_6gevent_8resolver_5cares_channel._getnameinfo = (PyObject *(*)(struct __pyx_obj_6gevent_8resolver_5cares_channel *, PyObject *, PyObject *, int, int __pyx_skip_dispatch))__pyx_f_6gevent_8resolver_5cares_7channel__getnameinfo;
  __pyx_vtable_6gevent_8resolver_5cares_channel._convert_cares_ni_flags = (int (*)(int))__pyx_f_6gevent_8resolver_5cares_7channel__convert_cares_ni_flags;
  __pyx_vtable_6gevent_8resolver_5cares_channel._convert_cares_ai_flags = (int (*)(int))__pyx_f_6gevent_8resolver_5cares_7channel__convert_cares_ai_flags;
  __pyx_vtable_6gevent_8resolver_5cares_channel._getaddrinfo_cb = (void (*)(void *, int, int, struct ares_addrinfo *))__pyx_f_6gevent_8resolver_5cares_7channel__getaddrinfo_cb;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_6gevent_8resolver_5cares_channel = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6gevent_8resolver_5cares_channel_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_6gevent_8resolver_5cares_channel)) __PYX_ERR(0, 357, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6gevent_8resolver_5cares_channel_spec, __pyx_mstate->__pyx_ptype_6gevent_8resolver_5cares_channel) < (0)) __PYX_ERR(0, 357, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6gevent_8resolver_5cares_channel = &__pyx_type_6gevent_8resolver_5cares_channel;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6gevent_8resolver_5cares_channel) < (0)) __PYX_ERR(0, 357, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6gevent_8resolver_5cares_channel);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6gevent_8resolver_5cares_channel->tp_dictoffset && __pyx_mstate->__pyx_ptype_6gevent_8resolver_5cares_channel->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6gevent_8resolver_5cares_channel->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_6gevent_8resolver_5cares_channel, __pyx_vtabptr_6gevent_8resolver_5cares_channel) < (0)) __PYX_ERR(0, 357, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_6gevent_8resolver_5cares_channel) < (0)) __PYX_ERR(0, 357, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_channel, (PyObject *) __pyx_mstate->__pyx_ptype_6gevent_8resolver_5cares_channel) < (0)) __PYX_ERR(0, 357, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __pyx_t_1 = PyImport_ImportModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_7cpython_4type_type = __Pyx_ImportType_3_2_4(__pyx_t_1, __Pyx_BUILTIN_MODULE_NAME, "type",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyTypeObject), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyTypeObject),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  0, 0,
  #else
  sizeof(PyHeapTypeObject), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyHeapTypeObject),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_7cpython_4type_type) __PYX_ERR(1, 9, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_variable_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_cares(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_cares},
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
  {Py_mod_gil, __Pyx_FREETHREADING_COMPATIBLE},
  #endif
  #if PY_VERSION_HEX >= 0x030C0000 && CYTHON_USE_MODULE_STATE
  {Py_mod_multiple_interpreters, Py_MOD_MULTIPLE_INTERPRETERS_NOT_SUPPORTED},
  #endif
  {0, NULL}
};
#endif

#ifdef __cplusplus
namespace {
  struct PyModuleDef __pyx_moduledef =
  #else
  static struct PyModuleDef __pyx_moduledef =
  #endif
  {
      PyModuleDef_HEAD_INIT,
      "cares",
      0, /* m_doc */
    #if CYTHON_USE_MODULE_STATE
      sizeof(__pyx_mstatetype), /* m_size */
    #else
      (CYTHON_PEP489_MULTI_PHASE_INIT) ? 0 : -1, /* m_size */
    #endif
      __pyx_methods /* m_methods */,
    #if CYTHON_PEP489_MULTI_PHASE_INIT
      __pyx_moduledef_slots, /* m_slots */
    #else
      NULL, /* m_reload */
    #endif
    #if CYTHON_USE_MODULE_STATE
      __pyx_m_traverse, /* m_traverse */
      __pyx_m_clear, /* m_clear */
      NULL /* m_free */
    #else
      NULL, /* m_traverse */
      NULL, /* m_clear */
      NULL /* m_free */
    #endif
  };
  #ifdef __cplusplus
} /* anonymous namespace */
#endif

/* PyModInitFuncType */
#ifndef CYTHON_NO_PYINIT_EXPORT
  #define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#else
  #ifdef __cplusplus
  #define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
  #else
  #define __Pyx_PyMODINIT_FUNC PyObject *
  #endif
#endif

__Pyx_PyMODINIT_FUNC PyInit_cares(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit_cares(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
/* ModuleCreationPEP489 */
#include "src/gevent/_generated_include/ModuleCreationPEP489_impl_e8e48a7033664eca332c0112edbc6a62057c1d998b2c8eee547bdd9088e6ab4c.h"

static CYTHON_SMALL_CODE int __pyx_pymod_exec_cares(PyObject *__pyx_pyinit_module)
#endif
{
  int stringtab_initialized = 0;
  #if CYTHON_USE_MODULE_STATE
  int pystate_addmodule_run = 0;
  #endif
  __pyx_mstatetype *__pyx_mstate = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  PyObject *__pyx_t_23 = NULL;
  PyObject *__pyx_t_24 = NULL;
  PyObject *__pyx_t_25 = NULL;
  PyObject *__pyx_t_26 = NULL;
  PyObject *__pyx_t_27 = NULL;
  PyObject *__pyx_t_28 = NULL;
  PyObject *__pyx_t_29 = NULL;
  PyObject *__pyx_t_30 = NULL;
  PyObject *__pyx_t_31 = NULL;
  PyObject *__pyx_t_32 = NULL;
  size_t __pyx_t_33;
  int __pyx_t_34;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module 'cares' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #else
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_t_1 = __pyx_pyinit_module;
  Py_INCREF(__pyx_t_1);
  #else
  __pyx_t_1 = PyModule_Create(&__pyx_moduledef); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #if CYTHON_USE_MODULE_STATE
  {
    int add_module_result = __Pyx_State_AddModule(__pyx_t_1, &__pyx_moduledef);
    __pyx_t_1 = 0; /* transfer ownership from __pyx_t_1 to "cares" pseudovariable */
    if (unlikely((add_module_result < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    pystate_addmodule_run = 1;
  }
  #else
  __pyx_m = __pyx_t_1;
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
  PyUnstable_Module_SetGIL(__pyx_m, Py_MOD_GIL_USED);
  #endif
  __pyx_mstate = __pyx_mstate_global;
  CYTHON_UNUSED_VAR(__pyx_t_1);
  __pyx_mstate->__pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_mstate->__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_mstate->__pyx_d);
  __pyx_mstate->__pyx_b = __Pyx_PyImport_AddModuleRef(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_mstate->__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_cython_runtime = __Pyx_PyImport_AddModuleRef("cython_runtime"); if (unlikely(!__pyx_mstate->__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_mstate->__pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /* ImportRefnannyAPI */
  #if CYTHON_REFNANNY
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
  if (!__Pyx_RefNanny) {
    PyErr_Clear();
    __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
    if (!__Pyx_RefNanny)
        Py_FatalError("failed to import 'refnanny' module");
  }
  #endif
  
__Pyx_RefNannySetupContext("PyInit_cares", 0);
  __Pyx_init_runtime_version();
  if (__Pyx_check_binary_version(__PYX_LIMITED_VERSION_HEX, __Pyx_get_runtime_version(), CYTHON_COMPILING_IN_LIMITED_API) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_mstate->__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_mstate->__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_mstate->__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Library function declarations ---*/
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitConstants(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  stringtab_initialized = 1;
  if (__Pyx_InitGlobals() < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__pyx_module_is_main_gevent__resolver__cares) {
    if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_name, __pyx_mstate_global->__pyx_n_u_main) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "gevent.resolver.cares")) {
      if (unlikely((PyDict_SetItemString(modules, "gevent.resolver.cares", __pyx_m) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_CreateCodeObjects(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code(__pyx_mstate);
  (void)__Pyx_modinit_variable_export_code(__pyx_mstate);
  (void)__Pyx_modinit_function_export_code(__pyx_mstate);
  if (unlikely((__Pyx_modinit_type_init_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely((__Pyx_modinit_type_import_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  (void)__Pyx_modinit_variable_import_code(__pyx_mstate);
  (void)__Pyx_modinit_function_import_code(__pyx_mstate);
  /*--- Execution code ---*/

  /* "gevent/resolver/cares.pyx":8
 * # cython: auto_pickle=False,language_level=3str
 * cimport libcares as cares
 * import sys             # <<<<<<<<<<<<<<
 * 
 * from cpython.version cimport PY_MAJOR_VERSION
*/
  __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_sys, 0, 0, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 8, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_sys, __pyx_t_2) < (0)) __PYX_ERR(0, 8, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "gevent/resolver/cares.pyx":19
 * from libc.string cimport memset
 * 
 * from gevent._compat import MAC             # <<<<<<<<<<<<<<
 * 
 * import _socket
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_MAC};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_gevent__compat, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 19, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_MAC};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 19, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 19, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "gevent/resolver/cares.pyx":21
 * from gevent._compat import MAC
 * 
 * import _socket             # <<<<<<<<<<<<<<
 * from _socket import gaierror
 * from _socket import herror
*/
  __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_socket, 0, 0, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 21, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_socket, __pyx_t_2) < (0)) __PYX_ERR(0, 21, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "gevent/resolver/cares.pyx":22
 * 
 * import _socket
 * from _socket import gaierror             # <<<<<<<<<<<<<<
 * from _socket import herror
 * 
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_gaierror};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_socket, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 22, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_gaierror};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 22, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 22, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "gevent/resolver/cares.pyx":23
 * import _socket
 * from _socket import gaierror
 * from _socket import herror             # <<<<<<<<<<<<<<
 * 
 * 
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_herror};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_socket, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 23, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_herror};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 23, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 23, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "gevent/resolver/cares.pyx":26
 * 
 * 
 * __all__ = ['channel']             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_2 = __Pyx_PyList_Pack(1, __pyx_mstate_global->__pyx_n_u_channel); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_all, __pyx_t_2) < (0)) __PYX_ERR(0, 26, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "gevent/resolver/cares.pyx":130
 *     unsigned int ntohl(unsigned int hostlong)
 * 
 * cdef int AI_NUMERICSERV = _socket.AI_NUMERICSERV             # <<<<<<<<<<<<<<
 * cdef int AI_CANONNAME = _socket.AI_CANONNAME
 * cdef int NI_NUMERICHOST = _socket.NI_NUMERICHOST
*/
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_socket); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_AI_NUMERICSERV); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = __Pyx_PyLong_As_int(__pyx_t_4); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 130, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_6gevent_8resolver_5cares_AI_NUMERICSERV = __pyx_t_5;

  /* "gevent/resolver/cares.pyx":131
 * 
 * cdef int AI_NUMERICSERV = _socket.AI_NUMERICSERV
 * cdef int AI_CANONNAME = _socket.AI_CANONNAME             # <<<<<<<<<<<<<<
 * cdef int NI_NUMERICHOST = _socket.NI_NUMERICHOST
 * cdef int NI_NUMERICSERV = _socket.NI_NUMERICSERV
*/
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_socket); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_AI_CANONNAME); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_5 = __Pyx_PyLong_As_int(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 131, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_6gevent_8resolver_5cares_AI_CANONNAME = __pyx_t_5;

  /* "gevent/resolver/cares.pyx":132
 * cdef int AI_NUMERICSERV = _socket.AI_NUMERICSERV
 * cdef int AI_CANONNAME = _socket.AI_CANONNAME
 * cdef int NI_NUMERICHOST = _socket.NI_NUMERICHOST             # <<<<<<<<<<<<<<
 * cdef int NI_NUMERICSERV = _socket.NI_NUMERICSERV
 * cdef int NI_NOFQDN = _socket.NI_NOFQDN
*/
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_socket); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_NI_NUMERICHOST); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = __Pyx_PyLong_As_int(__pyx_t_4); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 132, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_6gevent_8resolver_5cares_NI_NUMERICHOST = __pyx_t_5;

  /* "gevent/resolver/cares.pyx":133
 * cdef int AI_CANONNAME = _socket.AI_CANONNAME
 * cdef int NI_NUMERICHOST = _socket.NI_NUMERICHOST
 * cdef int NI_NUMERICSERV = _socket.NI_NUMERICSERV             # <<<<<<<<<<<<<<
 * cdef int NI_NOFQDN = _socket.NI_NOFQDN
 * cdef int NI_NAMEREQD = _socket.NI_NAMEREQD
*/
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_socket); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 133, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_NI_NUMERICSERV); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 133, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_5 = __Pyx_PyLong_As_int(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 133, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_6gevent_8resolver_5cares_NI_NUMERICSERV = __pyx_t_5;

  /* "gevent/resolver/cares.pyx":134
 * cdef int NI_NUMERICHOST = _socket.NI_NUMERICHOST
 * cdef int NI_NUMERICSERV = _socket.NI_NUMERICSERV
 * cdef int NI_NOFQDN = _socket.NI_NOFQDN             # <<<<<<<<<<<<<<
 * cdef int NI_NAMEREQD = _socket.NI_NAMEREQD
 * cdef int NI_DGRAM = _socket.NI_DGRAM
*/
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_socket); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_NI_NOFQDN); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = __Pyx_PyLong_As_int(__pyx_t_4); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 134, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_6gevent_8resolver_5cares_NI_NOFQDN = __pyx_t_5;

  /* "gevent/resolver/cares.pyx":135
 * cdef int NI_NUMERICSERV = _socket.NI_NUMERICSERV
 * cdef int NI_NOFQDN = _socket.NI_NOFQDN
 * cdef int NI_NAMEREQD = _socket.NI_NAMEREQD             # <<<<<<<<<<<<<<
 * cdef int NI_DGRAM = _socket.NI_DGRAM
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_socket); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_NI_NAMEREQD); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_5 = __Pyx_PyLong_As_int(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 135, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_6gevent_8resolver_5cares_NI_NAMEREQD = __pyx_t_5;

  /* "gevent/resolver/cares.pyx":136
 * cdef int NI_NOFQDN = _socket.NI_NOFQDN
 * cdef int NI_NAMEREQD = _socket.NI_NAMEREQD
 * cdef int NI_DGRAM = _socket.NI_DGRAM             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_socket); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_NI_DGRAM); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = __Pyx_PyLong_As_int(__pyx_t_4); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 136, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_6gevent_8resolver_5cares_NI_DGRAM = __pyx_t_5;

  /* "gevent/resolver/cares.pyx":139
 * 
 * 
 * cdef dict _ares_errors = dict([             # <<<<<<<<<<<<<<
 *     (cares.ARES_SUCCESS, 'ARES_SUCCESS'),
 * 
*/
  __pyx_t_2 = NULL;

  /* "gevent/resolver/cares.pyx":140
 * 
 * cdef dict _ares_errors = dict([
 *     (cares.ARES_SUCCESS, 'ARES_SUCCESS'),             # <<<<<<<<<<<<<<
 * 
 *     (cares.ARES_EADDRGETNETWORKPARAMS, 'ARES_EADDRGETNETWORKPARAMS'),
*/
  __pyx_t_6 = __Pyx_PyLong_From_int(ARES_SUCCESS); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = PyTuple_Pack(2, __pyx_t_6, __pyx_mstate_global->__pyx_n_u_ARES_SUCCESS); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "gevent/resolver/cares.pyx":142
 *     (cares.ARES_SUCCESS, 'ARES_SUCCESS'),
 * 
 *     (cares.ARES_EADDRGETNETWORKPARAMS, 'ARES_EADDRGETNETWORKPARAMS'),             # <<<<<<<<<<<<<<
 *     (cares.ARES_EBADFAMILY, 'ARES_EBADFAMILY'),
 *     (cares.ARES_EBADFLAGS, 'ARES_EBADFLAGS'),
*/
  __pyx_t_6 = __Pyx_PyLong_From_int(ARES_EADDRGETNETWORKPARAMS); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_8 = PyTuple_Pack(2, __pyx_t_6, __pyx_mstate_global->__pyx_n_u_ARES_EADDRGETNETWORKPARAMS); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "gevent/resolver/cares.pyx":143
 * 
 *     (cares.ARES_EADDRGETNETWORKPARAMS, 'ARES_EADDRGETNETWORKPARAMS'),
 *     (cares.ARES_EBADFAMILY, 'ARES_EBADFAMILY'),             # <<<<<<<<<<<<<<
 *     (cares.ARES_EBADFLAGS, 'ARES_EBADFLAGS'),
 *     (cares.ARES_EBADHINTS, 'ARES_EBADHINTS'),
*/
  __pyx_t_6 = __Pyx_PyLong_From_int(ARES_EBADFAMILY); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_9 = PyTuple_Pack(2, __pyx_t_6, __pyx_mstate_global->__pyx_n_u_ARES_EBADFAMILY); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "gevent/resolver/cares.pyx":144
 *     (cares.ARES_EADDRGETNETWORKPARAMS, 'ARES_EADDRGETNETWORKPARAMS'),
 *     (cares.ARES_EBADFAMILY, 'ARES_EBADFAMILY'),
 *     (cares.ARES_EBADFLAGS, 'ARES_EBADFLAGS'),             # <<<<<<<<<<<<<<
 *     (cares.ARES_EBADHINTS, 'ARES_EBADHINTS'),
 *     (cares.ARES_EBADNAME, 'ARES_EBADNAME'),
*/
  __pyx_t_6 = __Pyx_PyLong_From_int(ARES_EBADFLAGS); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 144, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_10 = PyTuple_Pack(2, __pyx_t_6, __pyx_mstate_global->__pyx_n_u_ARES_EBADFLAGS); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 144, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "gevent/resolver/cares.pyx":145
 *     (cares.ARES_EBADFAMILY, 'ARES_EBADFAMILY'),
 *     (cares.ARES_EBADFLAGS, 'ARES_EBADFLAGS'),
 *     (cares.ARES_EBADHINTS, 'ARES_EBADHINTS'),             # <<<<<<<<<<<<<<
 *     (cares.ARES_EBADNAME, 'ARES_EBADNAME'),
 *     (cares.ARES_EBADQUERY, 'ARES_EBADQUERY'),
*/
  __pyx_t_6 = __Pyx_PyLong_From_int(ARES_EBADHINTS); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_11 = PyTuple_Pack(2, __pyx_t_6, __pyx_mstate_global->__pyx_n_u_ARES_EBADHINTS); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "gevent/resolver/cares.pyx":146
 *     (cares.ARES_EBADFLAGS, 'ARES_EBADFLAGS'),
 *     (cares.ARES_EBADHINTS, 'ARES_EBADHINTS'),
 *     (cares.ARES_EBADNAME, 'ARES_EBADNAME'),             # <<<<<<<<<<<<<<
 *     (cares.ARES_EBADQUERY, 'ARES_EBADQUERY'),
 *     (cares.ARES_EBADRESP, 'ARES_EBADRESP'),
*/
  __pyx_t_6 = __Pyx_PyLong_From_int(ARES_EBADNAME); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 146, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_12 = PyTuple_Pack(2, __pyx_t_6, __pyx_mstate_global->__pyx_n_u_ARES_EBADNAME); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 146, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "gevent/resolver/cares.pyx":147
 *     (cares.ARES_EBADHINTS, 'ARES_EBADHINTS'),
 *     (cares.ARES_EBADNAME, 'ARES_EBADNAME'),
 *     (cares.ARES_EBADQUERY, 'ARES_EBADQUERY'),             # <<<<<<<<<<<<<<
 *     (cares.ARES_EBADRESP, 'ARES_EBADRESP'),
 *     (cares.ARES_EBADSTR, 'ARES_EBADSTR'),
*/
  __pyx_t_6 = __Pyx_PyLong_From_int(ARES_EBADQUERY); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 147, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_13 = PyTuple_Pack(2, __pyx_t_6, __pyx_mstate_global->__pyx_n_u_ARES_EBADQUERY); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 147, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "gevent/resolver/cares.pyx":148
 *     (cares.ARES_EBADNAME, 'ARES_EBADNAME'),
 *     (cares.ARES_EBADQUERY, 'ARES_EBADQUERY'),
 *     (cares.ARES_EBADRESP, 'ARES_EBADRESP'),             # <<<<<<<<<<<<<<
 *     (cares.ARES_EBADSTR, 'ARES_EBADSTR'),
 *     (cares.ARES_ECANCELLED, 'ARES_ECANCELLED'),
*/
  __pyx_t_6 = __Pyx_PyLong_From_int(ARES_EBADRESP); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_14 = PyTuple_Pack(2, __pyx_t_6, __pyx_mstate_global->__pyx_n_u_ARES_EBADRESP); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "gevent/resolver/cares.pyx":149
 *     (cares.ARES_EBADQUERY, 'ARES_EBADQUERY'),
 *     (cares.ARES_EBADRESP, 'ARES_EBADRESP'),
 *     (cares.ARES_EBADSTR, 'ARES_EBADSTR'),             # <<<<<<<<<<<<<<
 *     (cares.ARES_ECANCELLED, 'ARES_ECANCELLED'),
 *     (cares.ARES_ECONNREFUSED, 'ARES_ECONNREFUSED'),
*/
  __pyx_t_6 = __Pyx_PyLong_From_int(ARES_EBADSTR); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 149, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_15 = PyTuple_Pack(2, __pyx_t_6, __pyx_mstate_global->__pyx_n_u_ARES_EBADSTR); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 149, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "gevent/resolver/cares.pyx":150
 *     (cares.ARES_EBADRESP, 'ARES_EBADRESP'),
 *     (cares.ARES_EBADSTR, 'ARES_EBADSTR'),
 *     (cares.ARES_ECANCELLED, 'ARES_ECANCELLED'),             # <<<<<<<<<<<<<<
 *     (cares.ARES_ECONNREFUSED, 'ARES_ECONNREFUSED'),
 *     (cares.ARES_EDESTRUCTION, 'ARES_EDESTRUCTION'),
*/
  __pyx_t_6 = __Pyx_PyLong_From_int(ARES_ECANCELLED); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 150, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_16 = PyTuple_Pack(2, __pyx_t_6, __pyx_mstate_global->__pyx_n_u_ARES_ECANCELLED); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 150, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "gevent/resolver/cares.pyx":151
 *     (cares.ARES_EBADSTR, 'ARES_EBADSTR'),
 *     (cares.ARES_ECANCELLED, 'ARES_ECANCELLED'),
 *     (cares.ARES_ECONNREFUSED, 'ARES_ECONNREFUSED'),             # <<<<<<<<<<<<<<
 *     (cares.ARES_EDESTRUCTION, 'ARES_EDESTRUCTION'),
 *     (cares.ARES_EFILE, 'ARES_EFILE'),
*/
  __pyx_t_6 = __Pyx_PyLong_From_int(ARES_ECONNREFUSED); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_17 = PyTuple_Pack(2, __pyx_t_6, __pyx_mstate_global->__pyx_n_u_ARES_ECONNREFUSED); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "gevent/resolver/cares.pyx":152
 *     (cares.ARES_ECANCELLED, 'ARES_ECANCELLED'),
 *     (cares.ARES_ECONNREFUSED, 'ARES_ECONNREFUSED'),
 *     (cares.ARES_EDESTRUCTION, 'ARES_EDESTRUCTION'),             # <<<<<<<<<<<<<<
 *     (cares.ARES_EFILE, 'ARES_EFILE'),
 *     (cares.ARES_EFORMERR, 'ARES_EFORMERR'),
*/
  __pyx_t_6 = __Pyx_PyLong_From_int(ARES_EDESTRUCTION); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_18 = PyTuple_Pack(2, __pyx_t_6, __pyx_mstate_global->__pyx_n_u_ARES_EDESTRUCTION); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_18);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "gevent/resolver/cares.pyx":153
 *     (cares.ARES_ECONNREFUSED, 'ARES_ECONNREFUSED'),
 *     (cares.ARES_EDESTRUCTION, 'ARES_EDESTRUCTION'),
 *     (cares.ARES_EFILE, 'ARES_EFILE'),             # <<<<<<<<<<<<<<
 *     (cares.ARES_EFORMERR, 'ARES_EFORMERR'),
 *     (cares.ARES_ELOADIPHLPAPI, 'ARES_ELOADIPHLPAPI'),
*/
  __pyx_t_6 = __Pyx_PyLong_From_int(ARES_EFILE); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_19 = PyTuple_Pack(2, __pyx_t_6, __pyx_mstate_global->__pyx_n_u_ARES_EFILE); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "gevent/resolver/cares.pyx":154
 *     (cares.ARES_EDESTRUCTION, 'ARES_EDESTRUCTION'),
 *     (cares.ARES_EFILE, 'ARES_EFILE'),
 *     (cares.ARES_EFORMERR, 'ARES_EFORMERR'),             # <<<<<<<<<<<<<<
 *     (cares.ARES_ELOADIPHLPAPI, 'ARES_ELOADIPHLPAPI'),
 *     (cares.ARES_ENODATA, 'ARES_ENODATA'),
*/
  __pyx_t_6 = __Pyx_PyLong_From_int(ARES_EFORMERR); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_20 = PyTuple_Pack(2, __pyx_t_6, __pyx_mstate_global->__pyx_n_u_ARES_EFORMERR); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_20);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "gevent/resolver/cares.pyx":155
 *     (cares.ARES_EFILE, 'ARES_EFILE'),
 *     (cares.ARES_EFORMERR, 'ARES_EFORMERR'),
 *     (cares.ARES_ELOADIPHLPAPI, 'ARES_ELOADIPHLPAPI'),             # <<<<<<<<<<<<<<
 *     (cares.ARES_ENODATA, 'ARES_ENODATA'),
 *     (cares.ARES_ENOMEM, 'ARES_ENOMEM'),
*/
  __pyx_t_6 = __Pyx_PyLong_From_int(ARES_ELOADIPHLPAPI); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 155, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_21 = PyTuple_Pack(2, __pyx_t_6, __pyx_mstate_global->__pyx_n_u_ARES_ELOADIPHLPAPI); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 155, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "gevent/resolver/cares.pyx":156
 *     (cares.ARES_EFORMERR, 'ARES_EFORMERR'),
 *     (cares.ARES_ELOADIPHLPAPI, 'ARES_ELOADIPHLPAPI'),
 *     (cares.ARES_ENODATA, 'ARES_ENODATA'),             # <<<<<<<<<<<<<<
 *     (cares.ARES_ENOMEM, 'ARES_ENOMEM'),
 *     (cares.ARES_ENONAME, 'ARES_ENONAME'),
*/
  __pyx_t_6 = __Pyx_PyLong_From_int(ARES_ENODATA); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_22 = PyTuple_Pack(2, __pyx_t_6, __pyx_mstate_global->__pyx_n_u_ARES_ENODATA); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "gevent/resolver/cares.pyx":157
 *     (cares.ARES_ELOADIPHLPAPI, 'ARES_ELOADIPHLPAPI'),
 *     (cares.ARES_ENODATA, 'ARES_ENODATA'),
 *     (cares.ARES_ENOMEM, 'ARES_ENOMEM'),             # <<<<<<<<<<<<<<
 *     (cares.ARES_ENONAME, 'ARES_ENONAME'),
 *     (cares.ARES_ENOTFOUND, 'ARES_ENOTFOUND'),
*/
  __pyx_t_6 = __Pyx_PyLong_From_int(ARES_ENOMEM); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 157, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_23 = PyTuple_Pack(2, __pyx_t_6, __pyx_mstate_global->__pyx_n_u_ARES_ENOMEM); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 157, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_23);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "gevent/resolver/cares.pyx":158
 *     (cares.ARES_ENODATA, 'ARES_ENODATA'),
 *     (cares.ARES_ENOMEM, 'ARES_ENOMEM'),
 *     (cares.ARES_ENONAME, 'ARES_ENONAME'),             # <<<<<<<<<<<<<<
 *     (cares.ARES_ENOTFOUND, 'ARES_ENOTFOUND'),
 *     (cares.ARES_ENOTIMP, 'ARES_ENOTIMP'),
*/
  __pyx_t_6 = __Pyx_PyLong_From_int(ARES_ENONAME); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_24 = PyTuple_Pack(2, __pyx_t_6, __pyx_mstate_global->__pyx_n_u_ARES_ENONAME); if (unlikely(!__pyx_t_24)) __PYX_ERR(0, 158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_24);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "gevent/resolver/cares.pyx":159
 *     (cares.ARES_ENOMEM, 'ARES_ENOMEM'),
 *     (cares.ARES_ENONAME, 'ARES_ENONAME'),
 *     (cares.ARES_ENOTFOUND, 'ARES_ENOTFOUND'),             # <<<<<<<<<<<<<<
 *     (cares.ARES_ENOTIMP, 'ARES_ENOTIMP'),
 *     (cares.ARES_ENOTINITIALIZED, 'ARES_ENOTINITIALIZED'),
*/
  __pyx_t_6 = __Pyx_PyLong_From_int(ARES_ENOTFOUND); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_25 = PyTuple_Pack(2, __pyx_t_6, __pyx_mstate_global->__pyx_n_u_ARES_ENOTFOUND); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_25);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "gevent/resolver/cares.pyx":160
 *     (cares.ARES_ENONAME, 'ARES_ENONAME'),
 *     (cares.ARES_ENOTFOUND, 'ARES_ENOTFOUND'),
 *     (cares.ARES_ENOTIMP, 'ARES_ENOTIMP'),             # <<<<<<<<<<<<<<
 *     (cares.ARES_ENOTINITIALIZED, 'ARES_ENOTINITIALIZED'),
 *     (cares.ARES_EOF, 'ARES_EOF'),
*/
  __pyx_t_6 = __Pyx_PyLong_From_int(ARES_ENOTIMP); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 160, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_26 = PyTuple_Pack(2, __pyx_t_6, __pyx_mstate_global->__pyx_n_u_ARES_ENOTIMP); if (unlikely(!__pyx_t_26)) __PYX_ERR(0, 160, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_26);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "gevent/resolver/cares.pyx":161
 *     (cares.ARES_ENOTFOUND, 'ARES_ENOTFOUND'),
 *     (cares.ARES_ENOTIMP, 'ARES_ENOTIMP'),
 *     (cares.ARES_ENOTINITIALIZED, 'ARES_ENOTINITIALIZED'),             # <<<<<<<<<<<<<<
 *     (cares.ARES_EOF, 'ARES_EOF'),
 *     (cares.ARES_EREFUSED, 'ARES_EREFUSED'),
*/
  __pyx_t_6 = __Pyx_PyLong_From_int(ARES_ENOTINITIALIZED); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_27 = PyTuple_Pack(2, __pyx_t_6, __pyx_mstate_global->__pyx_n_u_ARES_ENOTINITIALIZED); if (unlikely(!__pyx_t_27)) __PYX_ERR(0, 161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_27);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "gevent/resolver/cares.pyx":162
 *     (cares.ARES_ENOTIMP, 'ARES_ENOTIMP'),
 *     (cares.ARES_ENOTINITIALIZED, 'ARES_ENOTINITIALIZED'),
 *     (cares.ARES_EOF, 'ARES_EOF'),             # <<<<<<<<<<<<<<
 *     (cares.ARES_EREFUSED, 'ARES_EREFUSED'),
 *     (cares.ARES_ESERVICE, 'ARES_ESERVICE'),
*/
  __pyx_t_6 = __Pyx_PyLong_From_int(ARES_EOF); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_28 = PyTuple_Pack(2, __pyx_t_6, __pyx_mstate_global->__pyx_n_u_ARES_EOF); if (unlikely(!__pyx_t_28)) __PYX_ERR(0, 162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_28);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "gevent/resolver/cares.pyx":163
 *     (cares.ARES_ENOTINITIALIZED, 'ARES_ENOTINITIALIZED'),
 *     (cares.ARES_EOF, 'ARES_EOF'),
 *     (cares.ARES_EREFUSED, 'ARES_EREFUSED'),             # <<<<<<<<<<<<<<
 *     (cares.ARES_ESERVICE, 'ARES_ESERVICE'),
 *     (cares.ARES_ESERVFAIL, 'ARES_ESERVFAIL'),
*/
  __pyx_t_6 = __Pyx_PyLong_From_int(ARES_EREFUSED); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_29 = PyTuple_Pack(2, __pyx_t_6, __pyx_mstate_global->__pyx_n_u_ARES_EREFUSED); if (unlikely(!__pyx_t_29)) __PYX_ERR(0, 163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_29);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "gevent/resolver/cares.pyx":164
 *     (cares.ARES_EOF, 'ARES_EOF'),
 *     (cares.ARES_EREFUSED, 'ARES_EREFUSED'),
 *     (cares.ARES_ESERVICE, 'ARES_ESERVICE'),             # <<<<<<<<<<<<<<
 *     (cares.ARES_ESERVFAIL, 'ARES_ESERVFAIL'),
 *     (cares.ARES_ETIMEOUT, 'ARES_ETIMEOUT'),
*/
  __pyx_t_6 = __Pyx_PyLong_From_int(ARES_ESERVICE); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_30 = PyTuple_Pack(2, __pyx_t_6, __pyx_mstate_global->__pyx_n_u_ARES_ESERVICE); if (unlikely(!__pyx_t_30)) __PYX_ERR(0, 164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_30);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "gevent/resolver/cares.pyx":165
 *     (cares.ARES_EREFUSED, 'ARES_EREFUSED'),
 *     (cares.ARES_ESERVICE, 'ARES_ESERVICE'),
 *     (cares.ARES_ESERVFAIL, 'ARES_ESERVFAIL'),             # <<<<<<<<<<<<<<
 *     (cares.ARES_ETIMEOUT, 'ARES_ETIMEOUT'),
 * ])
*/
  __pyx_t_6 = __Pyx_PyLong_From_int(ARES_ESERVFAIL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_31 = PyTuple_Pack(2, __pyx_t_6, __pyx_mstate_global->__pyx_n_u_ARES_ESERVFAIL); if (unlikely(!__pyx_t_31)) __PYX_ERR(0, 165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_31);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "gevent/resolver/cares.pyx":166
 *     (cares.ARES_ESERVICE, 'ARES_ESERVICE'),
 *     (cares.ARES_ESERVFAIL, 'ARES_ESERVFAIL'),
 *     (cares.ARES_ETIMEOUT, 'ARES_ETIMEOUT'),             # <<<<<<<<<<<<<<
 * ])
 * 
*/
  __pyx_t_6 = __Pyx_PyLong_From_int(ARES_ETIMEOUT); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_32 = PyTuple_Pack(2, __pyx_t_6, __pyx_mstate_global->__pyx_n_u_ARES_ETIMEOUT); if (unlikely(!__pyx_t_32)) __PYX_ERR(0, 166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_32);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "gevent/resolver/cares.pyx":139
 * 
 * 
 * cdef dict _ares_errors = dict([             # <<<<<<<<<<<<<<
 *     (cares.ARES_SUCCESS, 'ARES_SUCCESS'),
 * 
*/
  __pyx_t_6 = __Pyx_PyList_Pack(26, __pyx_t_7, __pyx_t_8, __pyx_t_9, __pyx_t_10, __pyx_t_11, __pyx_t_12, __pyx_t_13, __pyx_t_14, __pyx_t_15, __pyx_t_16, __pyx_t_17, __pyx_t_18, __pyx_t_19, __pyx_t_20, __pyx_t_21, __pyx_t_22, __pyx_t_23, __pyx_t_24, __pyx_t_25, __pyx_t_26, __pyx_t_27, __pyx_t_28, __pyx_t_29, __pyx_t_30, __pyx_t_31, __pyx_t_32); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;
  __Pyx_DECREF(__pyx_t_24); __pyx_t_24 = 0;
  __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
  __Pyx_DECREF(__pyx_t_26); __pyx_t_26 = 0;
  __Pyx_DECREF(__pyx_t_27); __pyx_t_27 = 0;
  __Pyx_DECREF(__pyx_t_28); __pyx_t_28 = 0;
  __Pyx_DECREF(__pyx_t_29); __pyx_t_29 = 0;
  __Pyx_DECREF(__pyx_t_30); __pyx_t_30 = 0;
  __Pyx_DECREF(__pyx_t_31); __pyx_t_31 = 0;
  __Pyx_DECREF(__pyx_t_32); __pyx_t_32 = 0;
  __pyx_t_33 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_6};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)(&PyDict_Type), __pyx_callargs+__pyx_t_33, (2-__pyx_t_33) | (__pyx_t_33*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 139, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  __Pyx_XGOTREF(__pyx_v_6gevent_8resolver_5cares__ares_errors);
  __Pyx_DECREF_SET(__pyx_v_6gevent_8resolver_5cares__ares_errors, ((PyObject*)__pyx_t_4));
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_t_4 = 0;

  /* "gevent/resolver/cares.pyx":170
 * 
 * cdef dict _ares_to_gai_system = {
 *     cares.ARES_EBADFAMILY: cares.EAI_ADDRFAMILY,             # <<<<<<<<<<<<<<
 *     cares.ARES_EBADFLAGS:  cares.EAI_BADFLAGS,
 *     cares.ARES_EBADHINTS:  cares.EAI_BADHINTS,
*/
  __pyx_t_4 = __Pyx_PyDict_NewPresized(9); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 170, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = __Pyx_PyLong_From_int(ARES_EBADFAMILY); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 170, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = __Pyx_PyLong_From_int(EAI_ADDRFAMILY); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 170, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_6, __pyx_t_2) < (0)) __PYX_ERR(0, 170, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "gevent/resolver/cares.pyx":171
 * cdef dict _ares_to_gai_system = {
 *     cares.ARES_EBADFAMILY: cares.EAI_ADDRFAMILY,
 *     cares.ARES_EBADFLAGS:  cares.EAI_BADFLAGS,             # <<<<<<<<<<<<<<
 *     cares.ARES_EBADHINTS:  cares.EAI_BADHINTS,
 *     cares.ARES_ENOMEM:     cares.EAI_MEMORY,
*/
  __pyx_t_2 = __Pyx_PyLong_From_int(ARES_EBADFLAGS); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 171, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyLong_From_int(EAI_BADFLAGS); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 171, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_2, __pyx_t_6) < (0)) __PYX_ERR(0, 170, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "gevent/resolver/cares.pyx":172
 *     cares.ARES_EBADFAMILY: cares.EAI_ADDRFAMILY,
 *     cares.ARES_EBADFLAGS:  cares.EAI_BADFLAGS,
 *     cares.ARES_EBADHINTS:  cares.EAI_BADHINTS,             # <<<<<<<<<<<<<<
 *     cares.ARES_ENOMEM:     cares.EAI_MEMORY,
 *     cares.ARES_ENONAME:    cares.EAI_NONAME,
*/
  __pyx_t_6 = __Pyx_PyLong_From_int(ARES_EBADHINTS); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 172, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = __Pyx_PyLong_From_int(EAI_BADHINTS); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 172, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_6, __pyx_t_2) < (0)) __PYX_ERR(0, 170, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "gevent/resolver/cares.pyx":173
 *     cares.ARES_EBADFLAGS:  cares.EAI_BADFLAGS,
 *     cares.ARES_EBADHINTS:  cares.EAI_BADHINTS,
 *     cares.ARES_ENOMEM:     cares.EAI_MEMORY,             # <<<<<<<<<<<<<<
 *     cares.ARES_ENONAME:    cares.EAI_NONAME,
 *     cares.ARES_ENOTFOUND:  cares.EAI_NONAME,
*/
  __pyx_t_2 = __Pyx_PyLong_From_int(ARES_ENOMEM); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 173, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyLong_From_int(EAI_MEMORY); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 173, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_2, __pyx_t_6) < (0)) __PYX_ERR(0, 170, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "gevent/resolver/cares.pyx":174
 *     cares.ARES_EBADHINTS:  cares.EAI_BADHINTS,
 *     cares.ARES_ENOMEM:     cares.EAI_MEMORY,
 *     cares.ARES_ENONAME:    cares.EAI_NONAME,             # <<<<<<<<<<<<<<
 *     cares.ARES_ENOTFOUND:  cares.EAI_NONAME,
 *     cares.ARES_ENOTIMP:    cares.EAI_FAMILY,
*/
  __pyx_t_6 = __Pyx_PyLong_From_int(ARES_ENONAME); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 174, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = __Pyx_PyLong_From_int(EAI_NONAME); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 174, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_6, __pyx_t_2) < (0)) __PYX_ERR(0, 170, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "gevent/resolver/cares.pyx":175
 *     cares.ARES_ENOMEM:     cares.EAI_MEMORY,
 *     cares.ARES_ENONAME:    cares.EAI_NONAME,
 *     cares.ARES_ENOTFOUND:  cares.EAI_NONAME,             # <<<<<<<<<<<<<<
 *     cares.ARES_ENOTIMP:    cares.EAI_FAMILY,
 *     # While EAI_NODATA ("No address associated with nodename") might
*/
  __pyx_t_2 = __Pyx_PyLong_From_int(ARES_ENOTFOUND); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 175, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyLong_From_int(EAI_NONAME); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 175, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_2, __pyx_t_6) < (0)) __PYX_ERR(0, 170, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "gevent/resolver/cares.pyx":176
 *     cares.ARES_ENONAME:    cares.EAI_NONAME,
 *     cares.ARES_ENOTFOUND:  cares.EAI_NONAME,
 *     cares.ARES_ENOTIMP:    cares.EAI_FAMILY,             # <<<<<<<<<<<<<<
 *     # While EAI_NODATA ("No address associated with nodename") might
 *     # seem to be the natural mapping, typical resolvers actually
*/
  __pyx_t_6 = __Pyx_PyLong_From_int(ARES_ENOTIMP); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = __Pyx_PyLong_From_int(EAI_FAMILY); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_6, __pyx_t_2) < (0)) __PYX_ERR(0, 170, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "gevent/resolver/cares.pyx":181
 *     # return EAI_NONAME in that same situation; I've yet to find EAI_NODATA
 *     # in a test.
 *     cares.ARES_ENODATA:    cares.EAI_NONAME,             # <<<<<<<<<<<<<<
 *     # This one gets raised for unknown port/service names.
 *     cares.ARES_ESERVICE:   cares.EAI_NONAME if MAC else cares.EAI_SERVICE,
*/
  __pyx_t_2 = __Pyx_PyLong_From_int(ARES_ENODATA); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyLong_From_int(EAI_NONAME); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_2, __pyx_t_6) < (0)) __PYX_ERR(0, 170, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "gevent/resolver/cares.pyx":183
 *     cares.ARES_ENODATA:    cares.EAI_NONAME,
 *     # This one gets raised for unknown port/service names.
 *     cares.ARES_ESERVICE:   cares.EAI_NONAME if MAC else cares.EAI_SERVICE,             # <<<<<<<<<<<<<<
 * }
 * 
*/
  __pyx_t_6 = __Pyx_PyLong_From_int(ARES_ESERVICE); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GetModuleGlobalName(__pyx_t_32, __pyx_mstate_global->__pyx_n_u_MAC); if (unlikely(!__pyx_t_32)) __PYX_ERR(0, 183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_32);
  __pyx_t_34 = __Pyx_PyObject_IsTrue(__pyx_t_32); if (unlikely((__pyx_t_34 < 0))) __PYX_ERR(0, 183, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_32); __pyx_t_32 = 0;
  if (__pyx_t_34) {
    __pyx_t_32 = __Pyx_PyLong_From_int(EAI_NONAME); if (unlikely(!__pyx_t_32)) __PYX_ERR(0, 183, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_32);
    __pyx_t_2 = __pyx_t_32;
    __pyx_t_32 = 0;
  } else {
    __pyx_t_32 = __Pyx_PyLong_From_int(EAI_SERVICE); if (unlikely(!__pyx_t_32)) __PYX_ERR(0, 183, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_32);
    __pyx_t_2 = __pyx_t_32;
    __pyx_t_32 = 0;
  }
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_6, __pyx_t_2) < (0)) __PYX_ERR(0, 170, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6gevent_8resolver_5cares__ares_to_gai_system);
  __Pyx_DECREF_SET(__pyx_v_6gevent_8resolver_5cares__ares_to_gai_system, ((PyObject*)__pyx_t_4));
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_t_4 = 0;

  /* "gevent/resolver/cares.pyx":206
 * 
 * cdef dict _ares_to_host_system = {
 *     cares.ARES_ENONAME:    cares.HOST_NOT_FOUND,             # <<<<<<<<<<<<<<
 *     cares.ARES_ENOTFOUND:  cares.HOST_NOT_FOUND,
 *     cares.ARES_ENODATA:    cares.NO_DATA,
*/
  __pyx_t_4 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyLong_From_int(ARES_ENONAME); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyLong_From_int(HOST_NOT_FOUND); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_2, __pyx_t_6) < (0)) __PYX_ERR(0, 206, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "gevent/resolver/cares.pyx":207
 * cdef dict _ares_to_host_system = {
 *     cares.ARES_ENONAME:    cares.HOST_NOT_FOUND,
 *     cares.ARES_ENOTFOUND:  cares.HOST_NOT_FOUND,             # <<<<<<<<<<<<<<
 *     cares.ARES_ENODATA:    cares.NO_DATA,
 * }
*/
  __pyx_t_6 = __Pyx_PyLong_From_int(ARES_ENOTFOUND); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = __Pyx_PyLong_From_int(HOST_NOT_FOUND); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_6, __pyx_t_2) < (0)) __PYX_ERR(0, 206, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "gevent/resolver/cares.pyx":208
 *     cares.ARES_ENONAME:    cares.HOST_NOT_FOUND,
 *     cares.ARES_ENOTFOUND:  cares.HOST_NOT_FOUND,
 *     cares.ARES_ENODATA:    cares.NO_DATA,             # <<<<<<<<<<<<<<
 * }
 * 
*/
  __pyx_t_2 = __Pyx_PyLong_From_int(ARES_ENODATA); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 208, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyLong_From_int(NO_DATA); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 208, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_2, __pyx_t_6) < (0)) __PYX_ERR(0, 206, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_XGOTREF(__pyx_v_6gevent_8resolver_5cares__ares_to_host_system);
  __Pyx_DECREF_SET(__pyx_v_6gevent_8resolver_5cares__ares_to_host_system, ((PyObject*)__pyx_t_4));
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_t_4 = 0;

  /* "gevent/resolver/cares.pyx":232
 * 
 * 
 * class InvalidIP(ValueError):             # <<<<<<<<<<<<<<
 *     pass
 * 
*/
  __pyx_t_4 = PyTuple_Pack(1, ((PyObject *)(((PyTypeObject*)PyExc_ValueError)))); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = __Pyx_PEP560_update_bases(__pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_32 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_6, __pyx_mstate_global->__pyx_n_u_InvalidIP, __pyx_mstate_global->__pyx_n_u_InvalidIP, (PyObject *) NULL, __pyx_mstate_global->__pyx_n_u_gevent_resolver_cares, (PyObject *) NULL); if (unlikely(!__pyx_t_32)) __PYX_ERR(0, 232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_32);
  if (__pyx_t_6 != __pyx_t_4) {
    if (unlikely((PyDict_SetItemString(__pyx_t_32, "__orig_bases__", __pyx_t_4) < 0))) __PYX_ERR(0, 232, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_InvalidIP, __pyx_t_6, __pyx_t_32, NULL, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_InvalidIP, __pyx_t_4) < (0)) __PYX_ERR(0, 232, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_32); __pyx_t_32 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "gevent/resolver/cares.pyx":260
 *         # add repr_recursive precaution
 * 
 *     def successful(self):             # <<<<<<<<<<<<<<
 *         return self.exception is None
 * 
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_8resolver_5cares_6Result_5successful, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Result_successful, NULL, __pyx_mstate_global->__pyx_n_u_gevent_resolver_cares, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[0])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_8resolver_5cares_Result, __pyx_mstate_global->__pyx_n_u_successful, __pyx_t_6) < (0)) __PYX_ERR(0, 260, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "gevent/resolver/cares.pyx":263
 *         return self.exception is None
 * 
 *     def get(self):             # <<<<<<<<<<<<<<
 *         if self.exception is not None:
 *             raise self.exception
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_8resolver_5cares_6Result_7get, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Result_get, NULL, __pyx_mstate_global->__pyx_n_u_gevent_resolver_cares, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[1])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 263, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_8resolver_5cares_Result, __pyx_mstate_global->__pyx_n_u_get, __pyx_t_6) < (0)) __PYX_ERR(0, 263, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "gevent/resolver/cares.pyx":269
 * 
 * 
 * class ares_host_result(tuple):             # <<<<<<<<<<<<<<
 * 
 *     def __new__(cls, family, iterable):
*/
  __pyx_t_6 = PyTuple_Pack(1, ((PyObject *)(&PyTuple_Type))); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = __Pyx_PEP560_update_bases(__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_32 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_32)) __PYX_ERR(0, 269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_32);
  __pyx_t_4 = __Pyx_Py3MetaclassPrepare(__pyx_t_32, __pyx_t_2, __pyx_mstate_global->__pyx_n_u_ares_host_result, __pyx_mstate_global->__pyx_n_u_ares_host_result, (PyObject *) NULL, __pyx_mstate_global->__pyx_n_u_gevent_resolver_cares, (PyObject *) NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (__pyx_t_2 != __pyx_t_6) {
    if (unlikely((PyDict_SetItemString(__pyx_t_4, "__orig_bases__", __pyx_t_6) < 0))) __PYX_ERR(0, 269, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "gevent/resolver/cares.pyx":271
 * class ares_host_result(tuple):
 * 
 *     def __new__(cls, family, iterable):             # <<<<<<<<<<<<<<
 *         cdef object self = tuple.__new__(cls, iterable)
 *         self.family = family
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_8resolver_5cares_16ares_host_result_1__new__, __Pyx_CYFUNCTION_STATICMETHOD, __pyx_mstate_global->__pyx_n_u_ares_host_result___new, NULL, __pyx_mstate_global->__pyx_n_u_gevent_resolver_cares, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[2])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 271, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (__Pyx_SetNewInClass(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_new, __pyx_t_6) < (0)) __PYX_ERR(0, 271, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "gevent/resolver/cares.pyx":276
 *         return self
 * 
 *     def __getnewargs__(self):             # <<<<<<<<<<<<<<
 *         return (self.family, tuple(self))
 * 
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_8resolver_5cares_16ares_host_result_3__getnewargs__, 0, __pyx_mstate_global->__pyx_n_u_ares_host_result___getnewargs, NULL, __pyx_mstate_global->__pyx_n_u_gevent_resolver_cares, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[3])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_getnewargs, __pyx_t_6) < (0)) __PYX_ERR(0, 276, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "gevent/resolver/cares.pyx":269
 * 
 * 
 * class ares_host_result(tuple):             # <<<<<<<<<<<<<<
 * 
 *     def __new__(cls, family, iterable):
*/
  __pyx_t_6 = __Pyx_Py3ClassCreate(__pyx_t_32, __pyx_mstate_global->__pyx_n_u_ares_host_result, __pyx_t_2, __pyx_t_4, NULL, 0, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_ares_host_result, __pyx_t_6) < (0)) __PYX_ERR(0, 269, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_32); __pyx_t_32 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "gevent/resolver/cares.pyx":420
 *         return '<%s at 0x%x _timer=%r _watchers[%s]>' % args
 * 
 *     def destroy(self):             # <<<<<<<<<<<<<<
 *         self.__destroy()
 * 
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_8resolver_5cares_7channel_5destroy, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_channel_destroy, NULL, __pyx_mstate_global->__pyx_n_u_gevent_resolver_cares, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[4])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 420, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_8resolver_5cares_channel, __pyx_mstate_global->__pyx_n_u_destroy, __pyx_t_2) < (0)) __PYX_ERR(0, 420, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "gevent/resolver/cares.pyx":435
 *         self.__destroy()
 * 
 *     cpdef set_servers(self, servers=None):             # <<<<<<<<<<<<<<
 *         if not self.channel:
 *             raise gaierror(cares.ARES_EDESTRUCTION, 'this ares channel has been destroyed')
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_8resolver_5cares_7channel_9set_servers, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_channel_set_servers, NULL, __pyx_mstate_global->__pyx_n_u_gevent_resolver_cares, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[5])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_mstate_global->__pyx_tuple[0]);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_8resolver_5cares_channel, __pyx_mstate_global->__pyx_n_u_set_servers, __pyx_t_2) < (0)) __PYX_ERR(0, 435, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "gevent/resolver/cares.pyx":508
 *         self._timer.again(self._on_timer)
 * 
 *     def _on_timer(self):             # <<<<<<<<<<<<<<
 *         cares.ares_process_fd(self.channel, cares.ARES_SOCKET_BAD, cares.ARES_SOCKET_BAD)
 * 
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_8resolver_5cares_7channel_11_on_timer, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_channel__on_timer, NULL, __pyx_mstate_global->__pyx_n_u_gevent_resolver_cares, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[6])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 508, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_8resolver_5cares_channel, __pyx_mstate_global->__pyx_n_u_on_timer, __pyx_t_2) < (0)) __PYX_ERR(0, 508, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "gevent/resolver/cares.pyx":511
 *         cares.ares_process_fd(self.channel, cares.ARES_SOCKET_BAD, cares.ARES_SOCKET_BAD)
 * 
 *     def _process_fd(self, int events, object watcher):             # <<<<<<<<<<<<<<
 *         if not self.channel:
 *             return
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_8resolver_5cares_7channel_13_process_fd, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_channel__process_fd, NULL, __pyx_mstate_global->__pyx_n_u_gevent_resolver_cares, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[7])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 511, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_8resolver_5cares_channel, __pyx_mstate_global->__pyx_n_u_process_fd, __pyx_t_2) < (0)) __PYX_ERR(0, 511, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "gevent/resolver/cares.pyx":546
 * 
 * 
 *     def gethostbyname(self, object callback, char* name, int family=AF_INET):             # <<<<<<<<<<<<<<
 *         if not self.channel:
 *             raise gaierror(cares.ARES_EDESTRUCTION, 'this ares channel has been destroyed')
*/
  __pyx_mstate_global->__pyx_k__5 = AF_INET;
  __pyx_t_2 = __Pyx_PyLong_From_int(AF_INET); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_32 = PyTuple_Pack(1, __pyx_t_2); if (unlikely(!__pyx_t_32)) __PYX_ERR(0, 546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_32);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_8resolver_5cares_7channel_15gethostbyname, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_channel_gethostbyname, NULL, __pyx_mstate_global->__pyx_n_u_gevent_resolver_cares, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[8])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_t_32);
  __Pyx_DECREF(__pyx_t_32); __pyx_t_32 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_8resolver_5cares_channel, __pyx_mstate_global->__pyx_n_u_gethostbyname, __pyx_t_2) < (0)) __PYX_ERR(0, 546, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "gevent/resolver/cares.pyx":555
 *                                  <void*>channel._gethostbyname_or_byaddr_cb, <void*>arg)
 * 
 *     def gethostbyaddr(self, object callback, char* addr):             # <<<<<<<<<<<<<<
 *         if not self.channel:
 *             raise gaierror(cares.ARES_EDESTRUCTION, 'this ares channel has been destroyed')
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_8resolver_5cares_7channel_17gethostbyaddr, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_channel_gethostbyaddr, NULL, __pyx_mstate_global->__pyx_n_u_gevent_resolver_cares, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[9])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 555, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_8resolver_5cares_channel, __pyx_mstate_global->__pyx_n_u_gethostbyaddr, __pyx_t_2) < (0)) __PYX_ERR(0, 555, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "gevent/resolver/cares.pyx":575
 *                                  <void*>channel._gethostbyname_or_byaddr_cb, <void*>arg)
 * 
 *     cpdef _getnameinfo(self, object callback, tuple sockaddr, int flags):             # <<<<<<<<<<<<<<
 *         if not self.channel:
 *             raise gaierror(cares.ARES_EDESTRUCTION, 'this ares channel has been destroyed')
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_8resolver_5cares_7channel_19_getnameinfo, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_channel__getnameinfo, NULL, __pyx_mstate_global->__pyx_n_u_gevent_resolver_cares, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[10])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 575, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_8resolver_5cares_channel, __pyx_mstate_global->__pyx_n_u_getnameinfo, __pyx_t_2) < (0)) __PYX_ERR(0, 575, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "gevent/resolver/cares.pyx":611
 *         return cares_flags
 * 
 *     def getnameinfo(self, object callback, tuple sockaddr, int flags):             # <<<<<<<<<<<<<<
 *         flags = channel._convert_cares_ni_flags(flags)
 *         return self._getnameinfo(callback, sockaddr, flags)
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_8resolver_5cares_7channel_21getnameinfo, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_channel_getnameinfo, NULL, __pyx_mstate_global->__pyx_n_u_gevent_resolver_cares, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[11])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 611, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_8resolver_5cares_channel, __pyx_mstate_global->__pyx_n_u_getnameinfo_2, __pyx_t_2) < (0)) __PYX_ERR(0, 611, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "gevent/resolver/cares.pyx":710
 *                 cares.ares_freeaddrinfo(result)
 * 
 *     def getaddrinfo(self,             # <<<<<<<<<<<<<<
 *                     object callback,
 *                     const char* name,
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6gevent_8resolver_5cares_7channel_23getaddrinfo, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_channel_getaddrinfo, NULL, __pyx_mstate_global->__pyx_n_u_gevent_resolver_cares, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[12])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 710, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_mstate_global->__pyx_tuple[1]);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6gevent_8resolver_5cares_channel, __pyx_mstate_global->__pyx_n_u_getaddrinfo, __pyx_t_2) < (0)) __PYX_ERR(0, 710, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "gevent/resolver/cares.pyx":1
 * # Copyright (c) 2011-2012 Denis Bilenko. See LICENSE for details.             # <<<<<<<<<<<<<<
 * # Automatic pickling of cdef classes was added in 0.26. Unfortunately it
 * # seems to be buggy (at least for the `result` class) and produces code that
*/
  __pyx_t_2 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_test, __pyx_t_2) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_XDECREF(__pyx_t_18);
  __Pyx_XDECREF(__pyx_t_19);
  __Pyx_XDECREF(__pyx_t_20);
  __Pyx_XDECREF(__pyx_t_21);
  __Pyx_XDECREF(__pyx_t_22);
  __Pyx_XDECREF(__pyx_t_23);
  __Pyx_XDECREF(__pyx_t_24);
  __Pyx_XDECREF(__pyx_t_25);
  __Pyx_XDECREF(__pyx_t_26);
  __Pyx_XDECREF(__pyx_t_27);
  __Pyx_XDECREF(__pyx_t_28);
  __Pyx_XDECREF(__pyx_t_29);
  __Pyx_XDECREF(__pyx_t_30);
  __Pyx_XDECREF(__pyx_t_31);
  __Pyx_XDECREF(__pyx_t_32);
  if (__pyx_m) {
    if (__pyx_mstate->__pyx_d && stringtab_initialized) {
      __Pyx_AddTraceback("init gevent.resolver.cares", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    #if !CYTHON_USE_MODULE_STATE
    Py_CLEAR(__pyx_m);
    #else
    Py_DECREF(__pyx_m);
    if (pystate_addmodule_run) {
      PyObject *tp, *value, *tb;
      PyErr_Fetch(&tp, &value, &tb);
      PyState_RemoveModule(&__pyx_moduledef);
      PyErr_Restore(tp, value, tb);
    }
    #endif
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init gevent.resolver.cares");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #else
  return __pyx_m;
  #endif
}
/* #### Code section: pystring_table ### */
/* #### Code section: cached_builtins ### */

static int __Pyx_InitCachedBuiltins(__pyx_mstatetype *__pyx_mstate) {
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __pyx_builtin_id = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_id); if (!__pyx_builtin_id) __PYX_ERR(0, 417, __pyx_L1_error)

  /* Cached unbound methods */
  __pyx_mstate->__pyx_umethod_PyDict_Type_get.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_get.method_name = &__pyx_mstate->__pyx_n_u_get;
  __pyx_mstate->__pyx_umethod_PyDict_Type_items.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_items.method_name = &__pyx_mstate->__pyx_n_u_items;
  __pyx_mstate->__pyx_umethod_PyDict_Type_pop.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_pop.method_name = &__pyx_mstate->__pyx_n_u_pop;
  __pyx_mstate->__pyx_umethod_PyDict_Type_values.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_values.method_name = &__pyx_mstate->__pyx_n_u_values;
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cached_constants ### */

static int __Pyx_InitCachedConstants(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "gevent/resolver/cares.pyx":435
 *         self.__destroy()
 * 
 *     cpdef set_servers(self, servers=None):             # <<<<<<<<<<<<<<
 *         if not self.channel:
 *             raise gaierror(cares.ARES_EDESTRUCTION, 'this ares channel has been destroyed')
*/
  __pyx_mstate_global->__pyx_tuple[0] = PyTuple_Pack(1, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_tuple[0])) __PYX_ERR(0, 435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[0]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[0]);

  /* "gevent/resolver/cares.pyx":710
 *                 cares.ares_freeaddrinfo(result)
 * 
 *     def getaddrinfo(self,             # <<<<<<<<<<<<<<
 *                     object callback,
 *                     const char* name,
*/
  __pyx_mstate_global->__pyx_tuple[1] = PyTuple_Pack(4, __pyx_mstate_global->__pyx_int_0, __pyx_mstate_global->__pyx_int_0, __pyx_mstate_global->__pyx_int_0, __pyx_mstate_global->__pyx_int_0); if (unlikely(!__pyx_mstate_global->__pyx_tuple[1])) __PYX_ERR(0, 710, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[1]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[1]);
  #if CYTHON_IMMORTAL_CONSTANTS
  {
    PyObject **table = __pyx_mstate->__pyx_tuple;
    for (Py_ssize_t i=0; i<2; ++i) {
      #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
      #if PY_VERSION_HEX < 0x030E0000
      if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
      #else
      if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
      #endif
      {
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
      }
      #else
      Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
      #endif
    }
  }
  #endif
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}
/* #### Code section: init_constants ### */

static int __Pyx_InitConstants(__pyx_mstatetype *__pyx_mstate) {
  CYTHON_UNUSED_VAR(__pyx_mstate);
  {
    const struct { const unsigned int length: 9; } index[] = {{2},{24},{179},{1},{1},{1},{0},{1},{1},{8},{7},{6},{11},{12},{22},{2},{9},{36},{29},{36},{7},{12},{14},{26},{15},{14},{14},{13},{14},{13},{12},{15},{17},{17},{10},{13},{18},{12},{11},{12},{14},{12},{20},{8},{13},{14},{13},{13},{12},{9},{3},{8},{11},{9},{14},{14},{20},{6},{10},{17},{4},{11},{5},{7},{16},{31},{24},{3},{5},{18},{8},{7},{20},{17},{19},{15},{19},{21},{21},{19},{19},{9},{18},{5},{3},{7},{7},{6},{5},{6},{8},{9},{6},{2},{5},{8},{8},{3},{11},{13},{13},{12},{11},{14},{14},{21},{12},{6},{5},{2},{2},{13},{5},{8},{6},{4},{8},{13},{10},{15},{8},{4},{5},{7},{9},{11},{3},{11},{11},{5},{14},{12},{7},{4},{7},{7},{12},{11},{10},{8},{7},{5},{5},{4},{10},{3},{8},{8},{7},{5},{5},{4},{8},{5},{6},{7},{8},{27},{183},{348},{141},{130},{71},{27},{15},{9},{16},{27},{13},{64}};
    #if (CYTHON_COMPRESS_STRINGS) == 3 && __PYX_LIMITED_VERSION_HEX >= 0x030e0000 /* compression: zstd (1718 bytes) */
const char* const cstring = "(\265/\375`K\ne5\000\252S\334\021F\000\217l\003\374?\337{\215:^\255\204:\276F\035_\303}\353\270\337\000\376\177\263)I$\2531\006\36299\3518\247y\037\205\277\3347[`\361\304\277\370\363Qhfu\342\340\241D\324\037\360x\313|\302T?\014\370\000\004\001\r\001\227\345\255:\022+\217%\372V\236\311u\362L\335\351\204:u\242\373u&\231&\342\332H\230o\373e;\226Y1\313@k\273\226y\333\215\374`\020\304sM\334=s\220\037s-\307@ \357\036Nt\221\022\235g\031\350q\313\265\\\304\204g\026\355\257\265\211\330*X\217m\027\351\020v\r\306\254\3371;!\213$\315[L\332\262\235`Bf\320\226G\306\234\305\027\356:\3147\014\361\207\317\004\010#\237\334\305\\\323\\\207\366Al\324w\334\332c\277\307\021?\260>w;f\231\357\230\264\333\3330\347\321\322\366\315\302>\373\351\231\274y/j\332\313\302\266\355\271w,\202/Z\267\335\203\031E\3466\034\261%\321@B!\345\245\354\310\263\0075\367\335\336\304\3541\317/-\346\320vm\307-\3637\221\365X\346m\366\373Dn?^\237G}{\346\330\216\332\206Y\324\230dK\002,\033\274\237\221\006\303\",\204\335D\315\202a\027\264\345\3167\3479\207\033\034\363\275\340\016\357\355\"\230\373\0263\210\271\276<\367\353s\277\275B\330\335\234\034\367\206\215:\263\340\317\013\354y\324\236\266\371\006?[\203\343\255c\255\301\216c\367\366\030\307-y\274\367\303\257\357[&\212\370\336Q\343\030\016s\n\020\223\227\207!\026i\260\3363\010\322z\216}\274H\353y\005\313+o\313\247\353A=\262\335R\367\236Z,\324\311\211\204\032\251B\214\356w\022u\246\324\027j\021\327\306\217\305\362D\"\027\253\345By\242\257\364u$\022j\345+u_\353;\245L\337\350\344B\221Z&\317\324\265\272\021\352\364\245\272T\351$\365\215:Ti\205\362J\037\351\204\372Z\"\2277b\271H\336j\344\225J\236h\325b\245V\236K\325:}'!\272\222J\3513u\244Q\007\202e\352V]j\304\n\205\322\362N-/\304j4\352\274&J\250%TT\225\016j(eq\202<T\017\315\213'\325@Gg\350\224\360\241~h2\000d^\340\257\372\014\376G\310$\361c_\227\252\262\004\227\0074\353\314l\200\241\262\210\252\230\325LR[R\001i\006e\235%\246\377\370\207l\326\320\3519O|\220\262Sv0`\314\321/\031\224\031B.\036\027\215\034\n4\000\332qb""\316\317O\220\001 \300\213Y\016\347D\244\241\224\004\332\241(gwn0?\276'-Q\240\206>\004\325\357~\213\227\356+\310\254\230\357\221YC?\001JbU\007\177$Tz\334Ff\305e\203\222\200f\355\230\017\376\n\034\tn@f\355\\d\257yK\017i=\373{=\337\344%A\337o\235\334\034\373\356\265\230S\200\273cX\016A\r\023s\017q\346\"\246\315^\330\327\266\347\230\314\234$\311\356w8f\315\357\346Y\244\205\233\345^roQ\346cc\026yg\311^\337\256\357\326\241\326\262\233\305\360\3431\031\253\n\255\275\344F\030j\307\004?\207\222\363\303\004\203\316NP\207\332\201q9\t\251 \323c\272\376Wb\224\234\231\010\234&\263\342\323@\306\274\240B\277p\363\371\005\217\231a\343j\251(.&\220\n\362\254]\356d\305\344\260\233\227N\216\247\024P\322\031\201\200\2524\220\202H[\234\007\316\014s\3667\312N\006\000\215\027\00548\025_\364OJ\016\r\246\344h\326\227\356_\317?\201\333\244\230T\203U\355F\335d^<\277\227\002\312\031\016\3436\026\204\254! \253\307~\317\377\340t\322\r\"jgF\370\037\034\005\322\022\324\177@T\020N\212i\301$\320\371\0108+\002\217\025c\262~\r\223{\245-(FUNL\230\n\343\234\231\372\207x\274\224XQWR\324\024\225\212\001A\016\223\313\244(N\325I!d\365\240\032\247\203\024\024\025\305\245\306\\\002\270\314r:U\245)\350\207\372\n8V\225\231\362A8\326\331\211\317\026\363\200\351\361X=\347\210\3311U\224\035\034+\376\"J\016\016g\335p64k\201\r\250A\235rJ\031\241\021\221\024\244 \205t!\014\202\242\216j\351\001\0215c\n\321\210\214\202\024\024$i\014\365 \336Ku\035\2444\034\342ouR8\207lSX\014\n\346e?\361JL\354ab\222\207Q\314\032\014\251x\003\322\224f\372;\271\007\250\373\206\214\334\262:R\370\r\251\305Z\271\343\332\371X\316\340`\237\010\260\031E\035&%%\306\020\013[R}\272+\233\367\334QU\233\312[\360\306\253\365\2169\216\330,l\243\277,}\030\305\241\2411h\354E\3117 5X\304\001\342Aj\007\230\010FP\324Y\014\3024!S\317\2417d\353\324\256TDy:\036\023\363Mx\247\265\227\251\342C\271L~)\210q\212\211\351\237Lp\003\263T\007\221\020\314\224a\353\036\363\364f\264kc\224\200\025\016I4T\316\2552\266UP?\317\212\002*53\310\013.ji\244\313\311\"\006\200\374l""\004\324\226\342^\2167^$\305\345\023E\325\022|E\177Q\177`\\f P\250\243\3730l/\345;6g\256\344\315R9\005\225\001\335\205\227\003o&$\361J\027\025\300\341\342\013\\=\"\361o\324\237\006x\216hR\030,\207\206V-\351\233\3678\nvH\226?\232\"\225\\8\244\224\026\037\024_2\220\026\2048nS\023\004\370O\340\317\271\274-\3414\0248\316\262M\261\301\031\344\273\211H\010\177\322x\323t\202+I\036\313\2117\017\266+\243\035\252VC\207\344\376g\250t\010\325h}\036\251Z\333~\004Bd\253D\2306\314\215:O-Fho\367\\\244m\016v\332\234\232\372\336w\277YUyM]\254E$c\264\272zdx\030\225\214~\273x:2\201\355\032\3738\236Pf\372?\210\254\371\305Y\362\223\025e<9\265!\304\244\321\362\310x\276\260\357\335\006\352B\260\216N\035\204\002\006\225\020\314\366So-\032C\225\321@!\217\002n\256ij\335\020\244\017\202zX\003AFD0E\212\004\344\321\240\013G\310\255G{\032\225\375\003\222\275*";
    PyObject *data = __Pyx_DecompressString(cstring, 1718, 3);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #elif (CYTHON_COMPRESS_STRINGS) == 2 /* compression: bz2 (1788 bytes) */
const char* const cstring = "BZh91AY&SY\"w\360\310\000\000\376\177\377\345\376\377\377\357\377\367\377\277\377\377\376\277\377\377\376@@@@@@@@@@@@@\000@\000`\006\016lj0n\356\001\233\025G\003p\321\004SLQ\350'\232S\323L\247\243\324\302M\250\362\230'\246\221\243\324\364\021\221\221\246@=M4\3154bjm\006\232\033Q\2504\020\023 \020'\220\020\223\324\365\033H\017P\320\320\001\243@\000\000\006\200\003@=F\2004\232\021\222\2314h\323@\321\240d\000\000\r\000\000\000\000\000\000\000\000\0004\3214M@\233Sj\236\247\244\364i\2504\032\000\000\r\006\200\000\000\000\001\240\000\000\032 \300\t\200\000\000L\000&\000\000\0010\002h`\000\000\000\000\002\014\000\230\000\000\004\300\002`\000\000\023\000&\206\000\000\000\000\000-L\2326\310\\\351\266C\250v\\\270\263\270\204\260\340S7C.\224N\224;\200\027L\2003\000\002Q''\266\003Fa\353\332@\224 I\224\000\220*`\250\304Y\273\000\n:\205\"\313\240\211\204\034\200\340bX\002\321$&1\257\0019\240\020.\310\212\254\020\nL\"OPA'\322d\325\020\201\321\271\252\306\306ReF\322'\230Cu\014\300$\224\351d\241{\215\034`\360t;\004t,\316\263\325\321Z\205\245\230\3430\214\355\007\207\315x\276\226^\251]j\017/\257R\206,2\366\0014\"A\023\016.$\200\266\325\214\223\013\316\220\246\026i@I\313\211\261\261^+\301xB\313\304\010\3154\364\2034PL$g\275gGzN\006\032\333\212M\224lT$\300a\010>\364\250!\233/\231\2074U\215E\320\325\320\341\030X\235\031p\220!\372<\254\364\002\262\002$\202\205\013\256\204\275\265XK\2758Oc>\177\221\014\327e\272\334\033\224\213\204\300\251\375\224\272| *\250\337\031\002\275\177\361\207HS\031\302n\325\263\255\30226\r\250R\332\\\204\307\300s\324\362HrJ4\025\220\301X1\241\023Ty\232jnhV\344T>\236\274\004\210\277%\"e=\240\212Nm\003\0272W\205\323m\220\006\277\360,\227\303\254J!\277\006d\016\005\306\020\215\245\010\021\275w0=U)\307e\027F\242\371?1\333W\016\274z\265:\272\n\215\271\234_q\323\331d\302\010\001\235\373\326\3369\341.\256\275\242R\316,e\352\302\320\304\304\242\201O\252-\275\372M\260\313\0143\302-\202\234\3501A\223\242\3009\254cL\232r\353]s\t\035\270\341\326\336\267\t\326u\210Qn\316p""\302\2404\342\252cI\253\021\233U\314\335V\032\263V*h F\205\2107\031\016\211u3P\335cS\301\357 \215\t\234\301\002\276\352\242\375\016ABPVg\013K.\342qCx\034\037S\300<\312\312\371Ej\355\017\236\315r}\035<\004\272\034\272\t\227+QQ\237B!z\032 \010\310E\324R\214\2069\220\312u\226gp\322\232\n@\257\2764Z\340&\265\246\247\224\205\254\244\302A-\303\013ZJ\300\324\026fJ#C\034S\250'NM\273\230V)\004\004@\215\205\240)Z\201h\233\022\037AY\355|\237\361s\024D[n^_\345:\367\346\365\034\302\270\020\345\346\312`\027\255\221c\\\202\252b\030\372_X3\037\314Z\361\221\320\237G\r\334c\241\3425L3\2761^\255\002\313}r\tP\020\263\203F\376\377\203\30319\270\2401\024\326\263\333\271V\324\337\270Yn\246\324Fz\370A\302/Q}\0274\314f0\343%\215k\245@\023\205\325\311\035\024\205\023<\256\231\021\310\351\033)\335\224W\024\0318\006sW\245-j\277k?\247\302\335\344\316\311he\375\251\322\003ddA\264\266\034\207;\215\271\250\205\344\246\026W\024X\030\225 \216\210H<\233 \026\204\027\243\314\n\314\246\004\353&\260XG\2228\234LMB\031\020\276nR}p\001\376\256\030y\035\357\032\362g\211\321\211\226F\021aHf\246&\333+\3327\225*DG!\200\315\3679\347\016\036\361\363\324D \244\365\006\205A\030\032\253\331\3409cJ\210\246:\350!3P|\324\203\230\rA\231\304\213%\r\320\020\227\230\225\261\217\336l\030q\234\217L\361\004\202\014\203\035@%T\220\\8\020\314\226R\354t\304dBP6\2211\006Q\003\024\210J\004\022CX\320\264.\314\035\234\252\202\010%C\274rF\200\005\233F`\316\361\310D\004HP+\260\001\317\000\234\345#0\303\332\360\267\246\013\221\003\013\001n+Q\206\006_\0010b\351Y\225&\004\002\206\300\213\235o\001\276\314\210/2\231I\2656\327]\307\022\315x\201\010\312\202^\r\035\230\331\313\263\236\306*\365\"\004\201\340\211I\246\272t\345\322\302+8\234W0\340\201\004\211GC<F\200\014DR\312\000\246\205T\031C+\022\230\273\031R\251Z,\330 \312\036,\216\002\231m\022\255\266n8\026D\310k#\022K\215\212\020sR\002\212\320\032\025$\323\003RI\200\021^\246D\242\335J'\010\014$\223\222\255\206\315,\n\021\251(\355A\002`\301\252\241\032\252w5\225\201,\3274\007\001t\367\013""\205\0077\202\220\246\332\344ij\023\332\301(%\217\235\010q\243`!\263d\372\356\002t\227\026:M\240\257L\221+\271(e\350BB\340-\302\306\200\264\267\203\217v\357\323H\210#\237N\354\300\302\240\236\027\022x\257\326/\307NS1\341yCQ\370{)\242*\252\000[\246b\220\034!{(0FF?\202\320wT\200\2667H\0105\314\210\314pm\235>[\000\314vr\037: Y*b\231r\315\020\353o\034\223\314!\332\322y\370\270\311\000\013\274S\301\225I!\020k\2253\322\330\322H\2600\360\2342O\216\214\271\3371<})L\231\010w\036\263\2006)\003\n9\371x\240O\013\334\315\217\231\331\222\336\276\373\223\204<\336\215\2507\003\376\230H\314\313r\303O\375]\271O\332\007j\006M\003\024\274\036\311\237\277(\254\214$B\242%\314pT\217\311\252B\377?\321\202\213\016_\365I\261\022;\267\336i\267t\204o\023=q\242\342k\276\374_|/\260\344h\344\264\234X\032\362\305\261\017\213\013jN\314\330z\263\210i\310\230K\211G k\033x\363y\267w, \377\024\2600)\273\242f\007H`\001\203\25207\240\354\252\345\363\344\260A\226#C\255B(@0\320\353\241\nk'\322MY\205\265\022\260\032\037\346\233\257\201\240\314\003c\306?\305\334\221N\024$\010\235\3742\000";
    PyObject *data = __Pyx_DecompressString(cstring, 1788, 2);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #elif (CYTHON_COMPRESS_STRINGS) != 0 /* compression: zlib (1698 bytes) */
const char* const cstring = "x\332}UKs\333F\0226\253\\\016mSe\321QlY\261\024\260\022\305JbS\313-\347\245\215\263\205\360a\301\341\373a\311v\\S#`H\302\201\000\0223\224\304\354\246\312G\036q\234#\2168\362\310#\217:\342\210\243~\202\177Bz\300\247\2228U\304Lw\317L\317\327_O7\367\244\034\326\r\242I\272)a\233P\244\233\204!\223Y\235\242\305\210\304\332\230I\351>k[\246\244SI#\206~Dl\314\210\321\227(\263u\225\021[l2\245r\266\374\350\361w\217%lj\222M\336\020\225Q\211\366\216T\003SJ\250d5\245\243\236n0\270\206\365;\204&%\245)\365\255\236d\022\270\234YR\007\366-\037`mbJ\2240!H\017\260iZ\0143\3352\021\034\327\315\326\003I\323m\270D?!\342t\016\033\224$w\276x\230\374/\3264\004\233\211\246S|d\020b\212q\207\234\251\244#\316?y(-dr\326\001\037\000\000K\254\3271\310C\251e1\251\245\352trL\373a\233J\300\300\277\316\266\317$\304\364cb?\331\266%t\212\231\332&6}\265M_\377Hmu\267EN\210\311v\201@\3138!\366\256*\270Lv\372g\254\r\264\tER\201%\223\030R\033S\351\010`\001\231\300\240\325'\332\316\t6z\344\211\254\240\264\\,\025\213r!\013r\261Q\310V\225t-[}.W\2635\224\2253\231\352\323l\275\230\255\037\224\252?\227\345\252\\\250MV~\22239\271\240\344_,\324\274\374t\261\270\257\024\353\013-\364?S*\215luq\014\346\362\\\251\325\253\023\031P\245\263\371|63U\001b5\233k\324f\206L\026\2666\322u\245T\234\030rJ~zC\256T\205(\246~\362%9\243\224\367\363e\271\254L,\305RF\256\3133\271\220-\314\304\005\306b\251\236+5\212\231\271\246\024\312\013\271\250\324\0259\257\274\234A)\345&\363%|\202\302\234\254\344\027\232\222\236z\007o\331R\243\036*\265F:\235\255\325\024\023\322\241kJ\271 \247\213\n\312<\005\236a\026\210\252\331JF\210\245\034\314\305y\212\366K\265z\361R\302\020*\367\317\340\313@\201\240\"9cU\322\254\022\3323\330dL\266\310L\242=U%\2246{\006<\\[|\250\203\325_\211\206[X7\021\302\206\001\203\250\314\266E\031\262\303S\177\326\223\010\201G\223\234b\273E\377\272\035\226aM\330[\230\252\272\216i\337Tu+\251Z\266\325\203\222$T\205k\216\340\332\351#\235N\311\320+>&\272\331\264\3466Q\203\242\022\346\206\216m\211\020PS\233\231\246O{\246\202\027\021""\330\262\0270\t\200G}\261\360\027\243\270s\311\370g\010\320\026\020%6\024\032\004\0336\0141A\034\320\275\020\263\261J\302X\014\213\022\325\240S0\010i\226\212\0201UK#\304\266-;\254Y\n\335\000\t\347\363\256\320\304\307\272\321ojM\003\0132\233=\023\216A2\3023\200f)\232KQ\\B\277\314\334\222x9O\223\256\221D\252u\334\301l\252\315zH2\354!\020\261f\020\024\336\335\236\214:\200\3265\335B:E\363\014\352\214\034S\030l\321\266\014b\266X\333\260\254\016B\307\341+\202\031PO\251\002\305\322z\340UH\266\005\224@''\341B\010=\034M\315bt\372n\346)\027M\032Mh\353\010\347\035\233t\000%BKo\000$\006qB\357C'L\240\021~\273=lL|\333\004k\260\213\022\2439M\241\230t\025\226DZ'\233\226\022\014\242F\232\030^1\265\324_\303\372\020\002\001\004\206\316(\224\002\014VgQF\264O\231\332A\035\313f\0101\310=\n\261\003Ma\010a\250\342/\250\247M6\205\3157\034\350\264\255\237\332@$`|+\007\321\233\203\307\203\377\361\007n<\210\335v>sp\020\2755`Nj\266\004\242X\330\341\237\373\322\343!\030?\346\251 \272\316#A\364>\227\303\341\"\334\370;\227yEl\375\202\247\374\373{\243D\270\213o\270\337{\262w0\224\207\317G\251\321\2631\036w\337]\273r\375c\236\364\"\336\335\341\265\341\233\361\215\363\304yJ\334\366\255\363\2513s\3013n\0040\301u\337\210)\356\304\035\360\270\311_{\t/\025\254lq\314\231\273\347\325\206\321\321\007\243S?G|b\370\306\261\177\3653\367}\310\205\261\033\304\356\210\030o\016\366\234\212\243\363Po\361\347nJ\034\333\340\237\362\n\307\357\242W\256\307fh6\374\215\257\274\224\227\031\336\030%.b\353\376\372\256\367\377Q\312\377\341\205\377\342\225\377\352\227 \026\322\025\254\002\177+\301\252 fu\315y\306q\260v\327\371\315\215\273;^\"XO\270w\334S\017{\335`m\223\037\272\225`\355>/\201Wex8\252\214\364q\367\374\332y\313o\034\370\007\207bs\334\375\334\2731L\004[\217\274\212\367f\024\035G\306\367\200\244o\374\312\241\177\370\322\177\371ji\323\305\372\026\327\335\256w\025h\256\010\367\025\336t\367Ay1\304\303\323\321\3218\022\032\005\234\023^s#\301\372\275`\365\036\217C\312o\273\377v\017\341\320\352\246\277\231\004tl\2707""\002\355C\010gm\203\177\351\312\376\366\367\2438\204\275\272\301\023\034\236\004\020#%\202\315\255`\353\023\361\373;\232Ero\r\360\240\353|\340P\236\270\210\256\370+\222/}7\212\214 \215+\203\327<!&$\336\316tZN\361\205\310l\020[u\"\202\316\330\232\263\317\323\3747x(B\037\210t\300\371\330\207\357}\237\357n\\\271\036wn\361\256{\335\273\343\375>\372i\004\336>\022y\024\303m\301\332\227^n\370hd\217\343\213\205\213\177xs+\022\030\327\334\227\340l\177,\007\211]\177\267p~\340\327\033\227\020\254\210S\337\272\211iU\334\034|\r\361\333\034\356\010\353eI\027\353+\"K\032 Q\206\225\267!\003_\273Q\250\207\217<x\232\261\301\263I\025v\305\322\252s\325Qx\303M\270a\310\341\342\333\271\207]?\265\177\036\021\013w\375\273\273^\027h\n\313\367\t`\336\360\366&\336\205\341?\\u\343\376\325\314\370\357i\273xO\314'\303\312R\304\177\000\037@H\301";
    PyObject *data = __Pyx_DecompressString(cstring, 1698, 1);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #else /* compression: none (2891 bytes) */
const char* const bytes = ": Failed in ares_inet_ntopNote that Cython is deliberately stricter than PEP-484 and rejects subclasses of builtin types. If you need to pass subclasses then set the 'annotation_typing' directive to False.(),.?add_notedisableenable(exception=, exception=expected a tuple, got gcisenabled<%s at 0x%x _timer=%r _watchers[%s]>src/gevent/resolver/cares.pyxthis ares channel has been destroyed(value=AI_CANONNAMEAI_NUMERICSERVARES_EADDRGETNETWORKPARAMSARES_EBADFAMILYARES_EBADFLAGSARES_EBADHINTSARES_EBADNAMEARES_EBADQUERYARES_EBADRESPARES_EBADSTRARES_ECANCELLEDARES_ECONNREFUSEDARES_EDESTRUCTIONARES_EFILEARES_EFORMERRARES_ELOADIPHLPAPIARES_ENODATAARES_ENOMEMARES_ENONAMEARES_ENOTFOUNDARES_ENOTIMPARES_ENOTINITIALIZEDARES_EOFARES_EREFUSEDARES_ESERVFAILARES_ESERVICEARES_ETIMEOUTARES_SUCCESSInvalidIPMACNI_DGRAMNI_NAMEREQDNI_NOFQDNNI_NUMERICHOSTNI_NUMERICSERV__Pyx_PyDict_NextRefResultResult.getResult.successfuladdraddr_packedagain__all__ares_host_resultares_host_result.__getnewargs__ares_host_result.__new__argasciiasyncio.coroutinescallbackchannelchannel._getnameinfochannel._on_timerchannel._process_fdchannel.destroychannel.getaddrinfochannel.gethostbyaddrchannel.gethostbynamechannel.getnameinfochannel.set_servers__class__cline_in_tracebackcloseclsdestroy__doc__encodeerroreventsexc_infoexceptionfamilyfdflags__func__gaierrorgetgetaddrinfogethostbyaddrgethostbyname_getnameinfogetnameinfo__getnewargs__gevent._compatgevent.resolver.careshandle_errorherrorhintsidio_is_coroutineitemsiterablelengthloop__main____metaclass____module____mro_entries____name__namendots__new___on_timerpass_eventspop__prepare___process_fdproto__pyx_vtable____qualname__read_fdselfserversservice__set_name__set_serverssetdefaultsockaddr_socketsplitstartstopsuccessfulsystcp_port__test__timeouttimertriestypeudp_portvaluevalueswatcherwrite_fd\200A\330\010\013\2104\210{\230'\240\021\330\014\022\220$\220a\330\010\017\210t\2201\200A\330\010\013\2104\210t\2201\330\014\022\220(\230&\320 4\260A\330\010\033\2301\330\010\030""\230\001\330\010\034\230A\330\010\034\230A\340\010\013\2104\210}\230A\230Q\330\014\022\220)\2301\320\034:\270!\330\010\030\230\001\230\032\2409\250A\250W\260A\260V\2701\270J\300a\300q\360\006\000\t\033\230.\250\001\250\027\260\006\260j\300\n\310!\3101\330\010\013\2107\220#\220Q\330\014\022\220)\2301\230D\240\001\240\021\330\010\033\2306\240\021\330\010\021\220\021\220!\330\010\035\230]\250!\2501\330\r\036\230a\230t\240:\250S\260\010\270\007\270w\320Fe\320el\320lm\320\004$\240A\330\010\013\2104\210t\2201\330\014\022\220(\230&\320 4\260A\330\010\013\2104\210q\330\014\026\220a\330\010\013\210:\220Q\220i\230q\330\014\026\220g\230V\2401\240A\330\010\032\230#\230Q\230a\360\010\000\t\014\2107\220#\220Q\330\014\032\320\032+\2501\250D\260\n\270!\340\014\030\320\030/\250|\2701\320<Y\320Y[\320[\\\330\014\017\210t\2201\330\020\021\330\014\r\330\020\030\230\001\330\020\024\220J\230a\330\024\027\220z\240\021\240(\250!\330\030!\240\026\240w\250a\250q\330\024\035\230X\240Q\330\024\034\230O\2501\250I\260X\270Q\270i\300q\310\006\310g\320UW\320WX\330\030!\240\021\240&\250\n\260!\330\036-\250Q\250j\270\010\300\001\300\031\310!\3106\320QX\320XZ\320Z[\330\030!\240\021\240&\250\n\260!\340\030\036\230i\240q\250\004\250A\250Q\330\024\035\230Q\230f\240H\250A\250Y\260a\260w\270b\300\001\330\024\035\230Q\330\024\027\220v\230S\240\001\330\030\031\330\020\031\230\021\230'\240\022\2402\240X\250Q\330\020\035\320\035.\250a\250t\260:\270Q\330\020\023\2201\330\024\032\230*\240A\320%9\270\021\270!\340\020\032\230!\2301\200A\360\010\000 !\330\035\036\330\036\037\330\036\037\330\010\013\2104\210t\2201\330\014\022\220(\230&\320 4\260A\360\006\000\t\017\210a\210q\220\007\220s\230!\340\010\r\320\r \320 8\270\001\270\021\330\010\r\210]\230!\330\010\r\210_\230A\330\010\r\210_\230A\330\010\033\2306\240\021\330\010\021\220\021\220!\340\r\036\230a\330\014\020\220\001\330\014\r\330\014\024\220H\230C\230z\250\027\260\001\330\014\r\210Q\330\014\032\230!\330\014\023\2201\200A\330\010\013\2104\210t\2201\330\014\022""\220(\230&\320 4\260A\360\n\000\t\021\220\017\230q\240\t\250\026\250}\270B\270a\330\014\025\220Q\330\014\025\220Q\330\022!\240\021\240*\250F\260-\270r\300\021\330\014\025\220Q\330\014\025\220Q\340\014\022\220)\2301\230D\240\001\240\021\330\010\033\2306\240\021\330\010\021\220\021\220!\330\r \240\001\240\024\240Z\250}\270H\300A\330!/\320/M\310W\320TU\200A\330\010\013\2104\210t\2201\330\014\r\330\010\033\2307\240!\330\010\034\230A\330\010\013\2105\220\007\220r\230\021\330\014\033\2301\330\010\013\2105\220\007\220r\230\021\330\014\034\230A\330\r\035\230Q\230d\240*\250I\260Q\200A\330\010\033\2305\240\010\250\001\250\025\250a\330\010\014\210J\220a\330\010\017\210q\200A\330\010\020\220\004\220I\230U\240!\2401\200A\330\010\014\210J\220a\200A\330\r\035\230Q\230d\240/\3201H\310\001\200A\330\010\027\320\027/\250q\260\001\330\010\017\210t\220=\240\001\240\032\250:\260Q\200A\330\010\017\210t\220;\230c\240\021\320\004D\300A\330\010\013\2104\210t\2201\330\014\022\220(\230&\320 4\260A\340\010\033\2306\240\021\330\010\021\220\021\220!\330\r \240\001\240\024\240Z\250v\260Q\330!/\320/M\310W\320TU";
    PyObject *data = NULL;
    CYTHON_UNUSED_VAR(__Pyx_DecompressString);
    #endif
    PyObject **stringtab = __pyx_mstate->__pyx_string_tab;
    Py_ssize_t pos = 0;
    for (int i = 0; i < 157; i++) {
      Py_ssize_t bytes_length = index[i].length;
      PyObject *string = PyUnicode_DecodeUTF8(bytes + pos, bytes_length, NULL);
      if (likely(string) && i >= 21) PyUnicode_InternInPlace(&string);
      if (unlikely(!string)) {
        Py_XDECREF(data);
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
      stringtab[i] = string;
      pos += bytes_length;
    }
    for (int i = 157; i < 170; i++) {
      Py_ssize_t bytes_length = index[i].length;
      PyObject *string = PyBytes_FromStringAndSize(bytes + pos, bytes_length);
      stringtab[i] = string;
      pos += bytes_length;
      if (unlikely(!string)) {
        Py_XDECREF(data);
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
    }
    Py_XDECREF(data);
    for (Py_ssize_t i = 0; i < 170; i++) {
      if (unlikely(PyObject_Hash(stringtab[i]) == -1)) {
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
    }
    #if CYTHON_IMMORTAL_CONSTANTS
    {
      PyObject **table = stringtab + 157;
      for (Py_ssize_t i=0; i<13; ++i) {
        #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
        #if PY_VERSION_HEX < 0x030E0000
        if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
        #else
        if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
        #endif
        {
          Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
        }
        #else
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
        #endif
      }
    }
    #endif
  }
  {
    PyObject **numbertab = __pyx_mstate->__pyx_number_tab + 0;
    int8_t const cint_constants_1[] = {0};
    for (int i = 0; i < 1; i++) {
      numbertab[i] = PyLong_FromLong(cint_constants_1[i - 0]);
      if (unlikely(!numbertab[i])) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #if CYTHON_IMMORTAL_CONSTANTS
  {
    PyObject **table = __pyx_mstate->__pyx_number_tab;
    for (Py_ssize_t i=0; i<1; ++i) {
      #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
      #if PY_VERSION_HEX < 0x030E0000
      if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
      #else
      if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
      #endif
      {
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
      }
      #else
      Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
      #endif
    }
  }
  #endif
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: init_codeobjects ### */
typedef struct {
    unsigned int argcount : 4;
    unsigned int num_posonly_args : 1;
    unsigned int num_kwonly_args : 1;
    unsigned int nlocals : 4;
    unsigned int flags : 10;
    unsigned int first_line : 10;
} __Pyx_PyCode_New_function_description;
/* NewCodeObj.proto */
static PyObject* __Pyx_PyCode_New(
        const __Pyx_PyCode_New_function_description descr,
        PyObject * const *varnames,
        PyObject *filename,
        PyObject *funcname,
        PyObject *line_table,
        PyObject *tuple_dedup_map
);


static int __Pyx_CreateCodeObjects(__pyx_mstatetype *__pyx_mstate) {
  PyObject* tuple_dedup_map = PyDict_New();
  if (unlikely(!tuple_dedup_map)) return -1;
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 260};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[0] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_resolver_cares_pyx, __pyx_mstate->__pyx_n_u_successful, __pyx_mstate->__pyx_kp_b_iso88591_A_t_c, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[0])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 263};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[1] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_resolver_cares_pyx, __pyx_mstate->__pyx_n_u_get, __pyx_mstate->__pyx_kp_b_iso88591_A_4_a_t1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[1])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 271};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_cls, __pyx_mstate->__pyx_n_u_family, __pyx_mstate->__pyx_n_u_iterable, __pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[2] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_resolver_cares_pyx, __pyx_mstate->__pyx_n_u_new, __pyx_mstate->__pyx_kp_b_iso88591_A_5_a_Ja_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[2])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 276};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[3] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_resolver_cares_pyx, __pyx_mstate->__pyx_n_u_getnewargs, __pyx_mstate->__pyx_kp_b_iso88591_A_IU_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[3])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 420};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[4] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_resolver_cares_pyx, __pyx_mstate->__pyx_n_u_destroy, __pyx_mstate->__pyx_kp_b_iso88591_A_Ja, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[4])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 435};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_servers};
    __pyx_mstate_global->__pyx_codeobj_tab[5] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_resolver_cares_pyx, __pyx_mstate->__pyx_n_u_set_servers, __pyx_mstate->__pyx_kp_b_iso88591_A_4t1_4A_4q_a_Qiq_gV1A_Qa_7_Q_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[5])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 508};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[6] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_resolver_cares_pyx, __pyx_mstate->__pyx_n_u_on_timer, __pyx_mstate->__pyx_kp_b_iso88591_A_Qd_1H, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[6])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 5, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 511};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_events, __pyx_mstate->__pyx_n_u_watcher, __pyx_mstate->__pyx_n_u_read_fd, __pyx_mstate->__pyx_n_u_write_fd};
    __pyx_mstate_global->__pyx_codeobj_tab[7] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_resolver_cares_pyx, __pyx_mstate->__pyx_n_u_process_fd, __pyx_mstate->__pyx_kp_b_iso88591_A_4t1_7_A_5_r_1_5_r_A_Qd_IQ, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[7])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {4, 0, 0, 5, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 546};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_callback, __pyx_mstate->__pyx_n_u_name_2, __pyx_mstate->__pyx_n_u_family, __pyx_mstate->__pyx_n_u_arg};
    __pyx_mstate_global->__pyx_codeobj_tab[8] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_resolver_cares_pyx, __pyx_mstate->__pyx_n_u_gethostbyname, __pyx_mstate->__pyx_kp_b_iso88591_DA_4t1_4A_6_ZvQ_MWTU, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[8])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 7, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 555};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_callback, __pyx_mstate->__pyx_n_u_addr, __pyx_mstate->__pyx_n_u_addr_packed, __pyx_mstate->__pyx_n_u_family, __pyx_mstate->__pyx_n_u_length, __pyx_mstate->__pyx_n_u_arg};
    __pyx_mstate_global->__pyx_codeobj_tab[9] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_resolver_cares_pyx, __pyx_mstate->__pyx_n_u_gethostbyaddr, __pyx_mstate->__pyx_kp_b_iso88591_A_4t1_4A_q_Ba_Q_Q_F_r_Q_Q_1D_6_Z, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[9])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {4, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 575};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_callback, __pyx_mstate->__pyx_n_u_sockaddr, __pyx_mstate->__pyx_n_u_flags};
    __pyx_mstate_global->__pyx_codeobj_tab[10] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_resolver_cares_pyx, __pyx_mstate->__pyx_n_u_getnameinfo, __pyx_mstate->__pyx_kp_b_iso88591_A_4t1_4A_1_A_A_4_AQ_1_9AWAV1Jaq, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[10])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {4, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 611};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_callback, __pyx_mstate->__pyx_n_u_sockaddr, __pyx_mstate->__pyx_n_u_flags};
    __pyx_mstate_global->__pyx_codeobj_tab[11] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_resolver_cares_pyx, __pyx_mstate->__pyx_n_u_getnameinfo_2, __pyx_mstate->__pyx_kp_b_iso88591_A_q_t_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[11])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {8, 0, 0, 10, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 710};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_callback, __pyx_mstate->__pyx_n_u_name_2, __pyx_mstate->__pyx_n_u_service, __pyx_mstate->__pyx_n_u_family, __pyx_mstate->__pyx_n_u_type, __pyx_mstate->__pyx_n_u_proto, __pyx_mstate->__pyx_n_u_flags, __pyx_mstate->__pyx_n_u_hints, __pyx_mstate->__pyx_n_u_arg};
    __pyx_mstate_global->__pyx_codeobj_tab[12] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_gevent_resolver_cares_pyx, __pyx_mstate->__pyx_n_u_getaddrinfo, __pyx_mstate->__pyx_kp_b_iso88591_A_4t1_4A_aq_s_8__A__A_6_a_HCz_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[12])) goto bad;
  }
  Py_DECREF(tuple_dedup_map);
  return 0;
  bad:
  Py_DECREF(tuple_dedup_map);
  return -1;
}
/* #### Code section: init_globals ### */

static int __Pyx_InitGlobals(void) {
  /* PythonCompatibility.init */
  if (likely(__Pyx_init_co_variables() == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CommonTypesMetaclass.init */
  if (likely(__pyx_CommonTypesMetaclass_init(__pyx_m) == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CachedMethodType.init */
  #if CYTHON_COMPILING_IN_LIMITED_API
  {
      PyObject *typesModule=NULL;
      typesModule = PyImport_ImportModule("types");
      if (typesModule) {
          __pyx_mstate_global->__Pyx_CachedMethodType = PyObject_GetAttrString(typesModule, "MethodType");
          Py_DECREF(typesModule);
      }
  } // error handling follows
  #endif
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CythonFunctionShared.init */
  if (likely(__pyx_CyFunction_init(__pyx_m) == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cleanup_globals ### */
/* #### Code section: cleanup_module ### */
/* #### Code section: main_method ### */
/* #### Code section: utility_code_pragmas ### */
#ifdef _MSC_VER
#pragma warning( push )
/* Warning 4127: conditional expression is constant
 * Cython uses constant conditional expressions to allow in inline functions to be optimized at
 * compile-time, so this warning is not useful
 */
#pragma warning( disable : 4127 )
#endif



/* #### Code section: utility_code_def ### */

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyErrExceptionMatches (used by PyObjectGetAttrStrNoError) */
#include "src/gevent/_generated_include/PyErrExceptionMatches_impl_7b4f377310190df92a521563db80ecc2f42d95506fc867b739186a972ce9c8f6.h"
/* PyErrFetchRestore (used by PyObjectGetAttrStrNoError) */
#include "src/gevent/_generated_include/PyErrFetchRestore_impl_83072c493b1583a48ff3aad9f8dc7ade3be268831a2ab8ada440fe395cf916ad.h"
/* PyObjectGetAttrStr (used by PyObjectGetAttrStrNoError) */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* PyObjectGetAttrStrNoError (used by GetBuiltinName) */
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
static void __Pyx_PyObject_GetAttrStr_ClearAttributeError(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (likely(__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        __Pyx_PyErr_Clear();
}
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name) {
    PyObject *result;
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    (void) PyObject_GetOptionalAttr(obj, attr_name, &result);
    return result;
#else
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_TYPE_SLOTS
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro == PyObject_GenericGetAttr)) {
        return _PyObject_GenericGetAttrWithDict(obj, attr_name, NULL, 1);
    }
#endif
    result = __Pyx_PyObject_GetAttrStr(obj, attr_name);
    if (unlikely(!result)) {
        __Pyx_PyObject_GetAttrStr_ClearAttributeError();
    }
    return result;
#endif
}

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStrNoError(__pyx_mstate_global->__pyx_b, name);
    if (unlikely(!result) && !PyErr_Occurred()) {
        PyErr_Format(PyExc_NameError,
            "name '%U' is not defined", name);
    }
    return result;
}

/* DictGetItem */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key) {
    PyObject *value;
    if (unlikely(__Pyx_PyDict_GetItemRef(d, key, &value) == 0)) { // no value, no error
        if (unlikely(PyTuple_Check(key))) {
            PyObject* args = PyTuple_Pack(1, key);
            if (likely(args)) {
                PyErr_SetObject(PyExc_KeyError, args);
                Py_DECREF(args);
            }
        } else {
            PyErr_SetObject(PyExc_KeyError, key);
        }
    }
    return value;
}
#endif

/* GetTopmostException (used by SaveResetException) */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem *
__Pyx_PyErr_GetTopmostException(PyThreadState *tstate)
{
    _PyErr_StackItem *exc_info = tstate->exc_info;
    while ((exc_info->exc_value == NULL || exc_info->exc_value == Py_None) &&
           exc_info->previous_item != NULL)
    {
        exc_info = exc_info->previous_item;
    }
    return exc_info;
}
#endif

/* SaveResetException */
#include "src/gevent/_generated_include/SaveResetException_impl_b3e76ed9bc3819093e52b1558c2bbad485040cdc5a28b71844e50bfc92f51cf0.h"
/* GetException */
#include "src/gevent/_generated_include/GetException_impl_36bcd44414c3b1ebf6a1c0f320ee2c6e2baced19353f70d825d0fd0338e3c175.h"
/* PyObjectCall (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = Py_TYPE(func)->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallMethO (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = __Pyx_CyOrPyCFunction_GET_FUNCTION(func);
    self = __Pyx_CyOrPyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectFastCall (used by PyObjectCall2Args) */
#include "src/gevent/_generated_include/PyObjectFastCall_impl_49781168209ae59e1c56f88d63362765f980ea90cc34bbbe49d64735688b114b.h"
/* PyObjectCall2Args (used by CallUnboundCMethod1) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2) {
    PyObject *args[3] = {NULL, arg1, arg2};
    return __Pyx_PyObject_FastCall(function, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* UnpackUnboundCMethod (used by CallUnboundCMethod1) */
#include "src/gevent/_generated_include/UnpackUnboundCMethod_impl_73fbc94f885e37a7810c861231fd30d7a9eae7cde8890c6786a4ce1f346a7810.h"
/* CallUnboundCMethod1 */
#include "src/gevent/_generated_include/CallUnboundCMethod1_impl_0820fa80b637dcac9bcf44c709c1dc323f347b99ab227a86488e6c6ecf6c876e.h"
/* CallUnboundCMethod2 */
#include "src/gevent/_generated_include/CallUnboundCMethod2_impl_15aa7f0a5154a4d6051e84dd189b6dc929e7450de4be5cb5e9cc003766aec24d.h"
/* dict_getitem_default */
static PyObject* __Pyx_PyDict_GetItemDefault(PyObject* d, PyObject* key, PyObject* default_value) {
    PyObject* value;
#if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07020000
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (unlikely(PyErr_Occurred()))
            return NULL;
        value = default_value;
    }
    Py_INCREF(value);
    if ((1));
#else
    if (PyBytes_CheckExact(key) || PyUnicode_CheckExact(key) || PyLong_CheckExact(key)) {
        value = PyDict_GetItem(d, key);
        if (unlikely(!value)) {
            value = default_value;
        }
        Py_INCREF(value);
    }
#endif
    else {
        if (default_value == Py_None)
            value = __Pyx_CallUnboundCMethod1(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_get, d, key);
        else
            value = __Pyx_CallUnboundCMethod2(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_get, d, key, default_value);
    }
    return value;
}

/* PyObjectFormatAndDecref */
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatSimpleAndDecref(PyObject* s, PyObject* f) {
    if (unlikely(!s)) return NULL;
    if (likely(PyUnicode_CheckExact(s))) return s;
    return __Pyx_PyObject_FormatAndDecref(s, f);
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatAndDecref(PyObject* s, PyObject* f) {
    PyObject *result;
    if (unlikely(!s)) return NULL;
    result = PyObject_Format(s, f);
    Py_DECREF(s);
    return result;
}

/* JoinPyUnicode */
#include "src/gevent/_generated_include/JoinPyUnicode_impl_199e5554049cf0e6f79c238bd653d59e48f3389f2b94c2dd9cad4227096f0038.h"
/* PyDictVersioning (used by GetModuleGlobalName) */
#include "src/gevent/_generated_include/PyDictVersioning_impl_f179ad268abce9726a76569141f76d5dcd0550225ef9a9e9f73d478d7be0c345.h"
/* GetModuleGlobalName */
#include "src/gevent/_generated_include/GetModuleGlobalName_impl_b2394fa294c641220c991c48f5c953347ba392e1233755a6228b28d5e679fef0.h"
/* TupleAndListFromArray (used by fastcall) */
#include "src/gevent/_generated_include/TupleAndListFromArray_impl_d69ed499f68cd42feaee4b5942c18d0f8efd9989393e455f897298c58b9fa8dd.h"
/* BytesEquals (used by UnicodeEquals) */
#include "src/gevent/_generated_include/BytesEquals_impl_d48b3ef06490e9921f32936be4dcafdc3250ac7ef2252e904b8f20e24a665cc0.h"
/* UnicodeEquals (used by fastcall) */
#include "src/gevent/_generated_include/UnicodeEquals_impl_836cabebedcde255d7b2e14d2d3ec8ae093224d9992c111dd33f6f1ba2aecbef.h"
/* fastcall */
#include "src/gevent/_generated_include/fastcall_impl_2d371982e998467e5c3fa3d5d125a44afb3a07b23828be3d6b5d120f6be5ca37.h"
/* PyObjectCallOneArg (used by CallUnboundCMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *args[2] = {NULL, arg};
    return __Pyx_PyObject_FastCall(func, args+1, 1 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* CallUnboundCMethod0 */
#include "src/gevent/_generated_include/CallUnboundCMethod0_impl_506503ba83409bc78d50e6c2a64d54ddd95a836cba396a015c59c17bbf915db5.h"
/* py_dict_items (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Items(PyObject* d) {
    return __Pyx_CallUnboundCMethod0(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_items, d);
}

/* py_dict_values (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Values(PyObject* d) {
    return __Pyx_CallUnboundCMethod0(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_values, d);
}

/* OwnedDictNext (used by ParseKeywordsImpl) */
#if CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, PyObject **ppos, PyObject **pkey, PyObject **pvalue) {
    PyObject *next = NULL;
    if (!*ppos) {
        if (pvalue) {
            PyObject *dictview = pkey ? __Pyx_PyDict_Items(p) : __Pyx_PyDict_Values(p);
            if (unlikely(!dictview)) goto bad;
            *ppos = PyObject_GetIter(dictview);
            Py_DECREF(dictview);
        } else {
            *ppos = PyObject_GetIter(p);
        }
        if (unlikely(!*ppos)) goto bad;
    }
    next = PyIter_Next(*ppos);
    if (!next) {
        if (PyErr_Occurred()) goto bad;
        return 0;
    }
    if (pkey && pvalue) {
        *pkey = __Pyx_PySequence_ITEM(next, 0);
        if (unlikely(*pkey)) goto bad;
        *pvalue = __Pyx_PySequence_ITEM(next, 1);
        if (unlikely(*pvalue)) goto bad;
        Py_DECREF(next);
    } else if (pkey) {
        *pkey = next;
    } else {
        assert(pvalue);
        *pvalue = next;
    }
    return 1;
  bad:
    Py_XDECREF(next);
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d0000
    PyErr_FormatUnraisable("Exception ignored in __Pyx_PyDict_NextRef");
#else
    PyErr_WriteUnraisable(__pyx_mstate_global->__pyx_n_u_Pyx_PyDict_NextRef);
#endif
    if (pkey) *pkey = NULL;
    if (pvalue) *pvalue = NULL;
    return 0;
}
#else // !CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, Py_ssize_t *ppos, PyObject **pkey, PyObject **pvalue) {
    int result = PyDict_Next(p, ppos, pkey, pvalue);
    if (likely(result == 1)) {
        if (pkey) Py_INCREF(*pkey);
        if (pvalue) Py_INCREF(*pvalue);
    }
    return result;
}
#endif

/* RaiseDoubleKeywords (used by ParseKeywordsImpl) */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
}

/* ParseKeywordsImpl (used by ParseKeywords) */
static int __Pyx_ValidateDuplicatePosArgs(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    const char* function_name)
{
    PyObject ** const *name = argnames;
    while (name != first_kw_arg) {
        PyObject *key = **name;
        int found = PyDict_Contains(kwds, key);
        if (unlikely(found)) {
            if (found == 1) __Pyx_RaiseDoubleKeywordsError(function_name, key);
            goto bad;
        }
        name++;
    }
    return 0;
bad:
    return -1;
}
#if CYTHON_USE_UNICODE_INTERNALS
static CYTHON_INLINE int __Pyx_UnicodeKeywordsEqual(PyObject *s1, PyObject *s2) {
    int kind;
    Py_ssize_t len = PyUnicode_GET_LENGTH(s1);
    if (len != PyUnicode_GET_LENGTH(s2)) return 0;
    kind = PyUnicode_KIND(s1);
    if (kind != PyUnicode_KIND(s2)) return 0;
    const void *data1 = PyUnicode_DATA(s1);
    const void *data2 = PyUnicode_DATA(s2);
    return (memcmp(data1, data2, (size_t) len * (size_t) kind) == 0);
}
#endif
static int __Pyx_MatchKeywordArg_str(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    PyObject ** const *name;
    #if CYTHON_USE_UNICODE_INTERNALS
    Py_hash_t key_hash = ((PyASCIIObject*)key)->hash;
    if (unlikely(key_hash == -1)) {
        key_hash = PyObject_Hash(key);
        if (unlikely(key_hash == -1))
            goto bad;
    }
    #endif
    name = first_kw_arg;
    while (*name) {
        PyObject *name_str = **name;
        #if CYTHON_USE_UNICODE_INTERNALS
        if (key_hash == ((PyASCIIObject*)name_str)->hash && __Pyx_UnicodeKeywordsEqual(name_str, key)) {
            *index_found = (size_t) (name - argnames);
            return 1;
        }
        #else
        #if CYTHON_ASSUME_SAFE_SIZE
        if (PyUnicode_GET_LENGTH(name_str) == PyUnicode_GET_LENGTH(key))
        #endif
        {
            int cmp = PyUnicode_Compare(name_str, key);
            if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
            if (cmp == 0) {
                *index_found = (size_t) (name - argnames);
                return 1;
            }
        }
        #endif
        name++;
    }
    name = argnames;
    while (name != first_kw_arg) {
        PyObject *name_str = **name;
        #if CYTHON_USE_UNICODE_INTERNALS
        if (unlikely(key_hash == ((PyASCIIObject*)name_str)->hash)) {
            if (__Pyx_UnicodeKeywordsEqual(name_str, key))
                goto arg_passed_twice;
        }
        #else
        #if CYTHON_ASSUME_SAFE_SIZE
        if (PyUnicode_GET_LENGTH(name_str) == PyUnicode_GET_LENGTH(key))
        #endif
        {
            if (unlikely(name_str == key)) goto arg_passed_twice;
            int cmp = PyUnicode_Compare(name_str, key);
            if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
            if (cmp == 0) goto arg_passed_twice;
        }
        #endif
        name++;
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
bad:
    return -1;
}
static int __Pyx_MatchKeywordArg_nostr(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    PyObject ** const *name;
    if (unlikely(!PyUnicode_Check(key))) goto invalid_keyword_type;
    name = first_kw_arg;
    while (*name) {
        int cmp = PyObject_RichCompareBool(**name, key, Py_EQ);
        if (cmp == 1) {
            *index_found = (size_t) (name - argnames);
            return 1;
        }
        if (unlikely(cmp == -1)) goto bad;
        name++;
    }
    name = argnames;
    while (name != first_kw_arg) {
        int cmp = PyObject_RichCompareBool(**name, key, Py_EQ);
        if (unlikely(cmp != 0)) {
            if (cmp == 1) goto arg_passed_twice;
            else goto bad;
        }
        name++;
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
bad:
    return -1;
}
static CYTHON_INLINE int __Pyx_MatchKeywordArg(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    return likely(PyUnicode_CheckExact(key)) ?
        __Pyx_MatchKeywordArg_str(key, argnames, first_kw_arg, index_found, function_name) :
        __Pyx_MatchKeywordArg_nostr(key, argnames, first_kw_arg, index_found, function_name);
}
static void __Pyx_RejectUnknownKeyword(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    const char *function_name)
{
    #if CYTHON_AVOID_BORROWED_REFS
    PyObject *pos = NULL;
    #else
    Py_ssize_t pos = 0;
    #endif
    PyObject *key = NULL;
    __Pyx_BEGIN_CRITICAL_SECTION(kwds);
    while (
        #if CYTHON_AVOID_BORROWED_REFS
        __Pyx_PyDict_NextRef(kwds, &pos, &key, NULL)
        #else
        PyDict_Next(kwds, &pos, &key, NULL)
        #endif
    ) {
        PyObject** const *name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (!*name) {
            size_t index_found = 0;
            int cmp = __Pyx_MatchKeywordArg(key, argnames, first_kw_arg, &index_found, function_name);
            if (cmp != 1) {
                if (cmp == 0) {
                    PyErr_Format(PyExc_TypeError,
                        "%s() got an unexpected keyword argument '%U'",
                        function_name, key);
                }
                #if CYTHON_AVOID_BORROWED_REFS
                Py_DECREF(key);
                #endif
                break;
            }
        }
        #if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(key);
        #endif
    }
    __Pyx_END_CRITICAL_SECTION();
    #if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(pos);
    #endif
    assert(PyErr_Occurred());
}
static int __Pyx_ParseKeywordDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    PyObject** const *name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    Py_ssize_t extracted = 0;
#if !CYTHON_COMPILING_IN_PYPY || defined(PyArg_ValidateKeywordArguments)
    if (unlikely(!PyArg_ValidateKeywordArguments(kwds))) return -1;
#endif
    name = first_kw_arg;
    while (*name && num_kwargs > extracted) {
        PyObject * key = **name;
        PyObject *value;
        int found = 0;
        #if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
        found = PyDict_GetItemRef(kwds, key, &value);
        #else
        value = PyDict_GetItemWithError(kwds, key);
        if (value) {
            Py_INCREF(value);
            found = 1;
        } else {
            if (unlikely(PyErr_Occurred())) goto bad;
        }
        #endif
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
            extracted++;
        }
        name++;
    }
    if (num_kwargs > extracted) {
        if (ignore_unknown_kwargs) {
            if (unlikely(__Pyx_ValidateDuplicatePosArgs(kwds, argnames, first_kw_arg, function_name) == -1))
                goto bad;
        } else {
            __Pyx_RejectUnknownKeyword(kwds, argnames, first_kw_arg, function_name);
            goto bad;
        }
    }
    return 0;
bad:
    return -1;
}
static int __Pyx_ParseKeywordDictToDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject** const *name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    Py_ssize_t len;
#if !CYTHON_COMPILING_IN_PYPY || defined(PyArg_ValidateKeywordArguments)
    if (unlikely(!PyArg_ValidateKeywordArguments(kwds))) return -1;
#endif
    if (PyDict_Update(kwds2, kwds) < 0) goto bad;
    name = first_kw_arg;
    while (*name) {
        PyObject *key = **name;
        PyObject *value;
#if !CYTHON_COMPILING_IN_LIMITED_API && (PY_VERSION_HEX >= 0x030d00A2 || defined(PyDict_Pop))
        int found = PyDict_Pop(kwds2, key, &value);
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
        }
#elif __PYX_LIMITED_VERSION_HEX >= 0x030d0000
        int found = PyDict_GetItemRef(kwds2, key, &value);
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
            if (unlikely(PyDict_DelItem(kwds2, key) < 0)) goto bad;
        }
#else
    #if CYTHON_COMPILING_IN_CPYTHON
        value = _PyDict_Pop(kwds2, key, kwds2);
    #else
        value = __Pyx_CallUnboundCMethod2(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_pop, kwds2, key, kwds2);
    #endif
        if (value == kwds2) {
            Py_DECREF(value);
        } else {
            if (unlikely(!value)) goto bad;
            values[name-argnames] = value;
        }
#endif
        name++;
    }
    len = PyDict_Size(kwds2);
    if (len > 0) {
        return __Pyx_ValidateDuplicatePosArgs(kwds, argnames, first_kw_arg, function_name);
    } else if (unlikely(len == -1)) {
        goto bad;
    }
    return 0;
bad:
    return -1;
}
static int __Pyx_ParseKeywordsTuple(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    PyObject *key = NULL;
    PyObject** const * name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    for (Py_ssize_t pos = 0; pos < num_kwargs; pos++) {
#if CYTHON_AVOID_BORROWED_REFS
        key = __Pyx_PySequence_ITEM(kwds, pos);
#else
        key = __Pyx_PyTuple_GET_ITEM(kwds, pos);
#endif
#if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(!key)) goto bad;
#endif
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            PyObject *value = kwvalues[pos];
            values[name-argnames] = __Pyx_NewRef(value);
        } else {
            size_t index_found = 0;
            int cmp = __Pyx_MatchKeywordArg(key, argnames, first_kw_arg, &index_found, function_name);
            if (cmp == 1) {
                PyObject *value = kwvalues[pos];
                values[index_found] = __Pyx_NewRef(value);
            } else {
                if (unlikely(cmp == -1)) goto bad;
                if (kwds2) {
                    PyObject *value = kwvalues[pos];
                    if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
                } else if (!ignore_unknown_kwargs) {
                    goto invalid_keyword;
                }
            }
        }
        #if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(key);
        key = NULL;
        #endif
    }
    return 0;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    goto bad;
bad:
    #if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(key);
    #endif
    return -1;
}

/* ParseKeywords */
static int __Pyx_ParseKeywords(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    if (CYTHON_METH_FASTCALL && likely(PyTuple_Check(kwds)))
        return __Pyx_ParseKeywordsTuple(kwds, kwvalues, argnames, kwds2, values, num_pos_args, num_kwargs, function_name, ignore_unknown_kwargs);
    else if (kwds2)
        return __Pyx_ParseKeywordDictToDict(kwds, argnames, kwds2, values, num_pos_args, function_name);
    else
        return __Pyx_ParseKeywordDict(kwds, argnames, values, num_pos_args, num_kwargs, function_name, ignore_unknown_kwargs);
}

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* RaiseException */
#include "src/gevent/_generated_include/RaiseException_impl_5214b4470ab1cce407ca930811cfafb701053719a58763807254160af0a39f69.h"
/* PyObjectFastCallMethod */
#if !CYTHON_VECTORCALL || PY_VERSION_HEX < 0x03090000
static PyObject *__Pyx_PyObject_FastCallMethod(PyObject *name, PyObject *const *args, size_t nargsf) {
    PyObject *result;
    PyObject *attr = PyObject_GetAttr(args[0], name);
    if (unlikely(!attr))
        return NULL;
    result = __Pyx_PyObject_FastCall(attr, args+1, nargsf - 1);
    Py_DECREF(attr);
    return result;
}
#endif

/* PyObjectSetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
    return PyObject_SetAttr(obj, attr_name, value);
}
#endif

/* decode_c_string */
#include "src/gevent/_generated_include/decode_c_string_impl_45b715a4c0cd4088ca1de5233da3f10f0e1f0fa6d2804385116f73e81347b4a3.h"
/* RaiseTooManyValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

/* RaiseNeedMoreValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%.1s to unpack",
                 index, (index == 1) ? "" : "s");
}

/* RaiseNoneIterError */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
}

/* ExtTypeTest */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type) {
    __Pyx_TypeName obj_type_name;
    __Pyx_TypeName type_name;
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (likely(__Pyx_TypeCheck(obj, type)))
        return 1;
    obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    type_name = __Pyx_PyType_GetFullyQualifiedName(type);
    PyErr_Format(PyExc_TypeError,
                 "Cannot convert " __Pyx_FMT_TYPENAME " to " __Pyx_FMT_TYPENAME,
                 obj_type_name, type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    __Pyx_DECREF_TypeName(type_name);
    return 0;
}

/* pybytes_as_double (used by pyobject_as_double) */
#include "src/gevent/_generated_include/pybytes_as_double_impl_8b5b11b513dd8fa5216234b7cdd73d2bcbcf3f1875e4232b67ff864a05ce0aca.h"
/* pyobject_as_double */
#include "src/gevent/_generated_include/pyobject_as_double_impl_28f1d9fb56ab55e42a171a531e49afc9c7fb2baaa3576f0a4951ed6fdf2ffe38.h"
/* WriteUnraisableException */
#include "src/gevent/_generated_include/WriteUnraisableException_impl_bf6608ff5bd702a181e41022924c10da4d6bcbcf8e60f057fafe6369af1f9b7f.h"
/* SwapException */
#include "src/gevent/_generated_include/SwapException_impl_3529c43002b85b6a88333a1994598a58e361312e8462c9c4553bcc16b799892a.h"
/* py_dict_pop_ignore */
static CYTHON_INLINE int __Pyx_PyDict_Pop_ignore(PyObject *d, PyObject *key, PyObject *default_value) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d00A2 || defined(PyDict_Pop)
    int result = PyDict_Pop(d, key, NULL);
    CYTHON_UNUSED_VAR(default_value);
    return (unlikely(result == -1)) ? -1 : 0;
#else
    PyObject *value;
    CYTHON_UNUSED_VAR(default_value);
    #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000
    value = _PyDict_Pop(d, key, Py_None);
    #else
    value = __Pyx_CallUnboundCMethod2(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_pop, d, key, Py_None);
    #endif
    if (unlikely(value == NULL))
        return -1;
    Py_DECREF(value);
    return 0;
#endif
}

/* PyObjectVectorCallKwBuilder (used by PyObjectVectorCallMethodKwBuilder) */
#include "src/gevent/_generated_include/PyObjectVectorCallKwBuilder_impl_fd859cdb6cbc3b35f6b10f5733f06af41f621c00f218f3658f8b944bf821c5f8.h"
/* PyObjectVectorCallMethodKwBuilder */
#if !CYTHON_VECTORCALL || PY_VERSION_HEX < 0x03090000
static PyObject *__Pyx_Object_VectorcallMethod_CallFromBuilder(PyObject *name, PyObject *const *args, size_t nargsf, PyObject *kwnames) {
    PyObject *result;
    PyObject *obj = PyObject_GetAttr(args[0], name);
    if (unlikely(!obj))
        return NULL;
    result = __Pyx_Object_Vectorcall_CallFromBuilder(obj, args+1, nargsf-1, kwnames);
    Py_DECREF(obj);
    return result;
}
#endif

/* GetItemInt */
#include "src/gevent/_generated_include/GetItemInt_impl_057d6f270e739b86c6eeceee664d75d3caab665a9ec308b52b1fc08c260ccd28.h"
/* ArgTypeTestFunc (used by ArgTypeTest) */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact)
{
    __Pyx_TypeName type_name;
    __Pyx_TypeName obj_type_name;
    PyObject *extra_info = __pyx_mstate_global->__pyx_empty_unicode;
    int from_annotation_subclass = 0;
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    else if (!exact) {
        if (likely(__Pyx_TypeCheck(obj, type))) return 1;
    } else if (exact == 2) {
        if (__Pyx_TypeCheck(obj, type)) {
            from_annotation_subclass = 1;
            extra_info = __pyx_mstate_global->__pyx_kp_u_Note_that_Cython_is_deliberately;
        }
    }
    type_name = __Pyx_PyType_GetFullyQualifiedName(type);
    obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "Argument '%.200s' has incorrect type (expected " __Pyx_FMT_TYPENAME
        ", got " __Pyx_FMT_TYPENAME ")"
#if __PYX_LIMITED_VERSION_HEX < 0x030C0000
        "%s%U"
#endif
        , name, type_name, obj_type_name
#if __PYX_LIMITED_VERSION_HEX < 0x030C0000
        , (from_annotation_subclass ? ". " : ""), extra_info
#endif
        );
#if __PYX_LIMITED_VERSION_HEX >= 0x030C0000
    if (exact == 2 && from_annotation_subclass) {
        PyObject *res;
        PyObject *vargs[2];
        vargs[0] = PyErr_GetRaisedException();
        vargs[1] = extra_info;
        res = PyObject_VectorcallMethod(__pyx_mstate_global->__pyx_kp_u_add_note, vargs, 2, NULL);
        Py_XDECREF(res);
        PyErr_SetRaisedException(vargs[0]);
    }
#endif
    __Pyx_DECREF_TypeName(type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* RaiseUnboundLocalError */
static void __Pyx_RaiseUnboundLocalError(const char *varname) {
    PyErr_Format(PyExc_UnboundLocalError, "local variable '%s' referenced before assignment", varname);
}

/* AllocateExtensionType */
static PyObject *__Pyx_AllocateExtensionType(PyTypeObject *t, int is_final) {
    if (is_final || likely(!__Pyx_PyType_HasFeature(t, Py_TPFLAGS_IS_ABSTRACT))) {
        allocfunc alloc_func = __Pyx_PyType_GetSlot(t, tp_alloc, allocfunc);
        return alloc_func(t, 0);
    } else {
        newfunc tp_new = __Pyx_PyType_TryGetSlot(&PyBaseObject_Type, tp_new, newfunc);
    #if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
        if (!tp_new) {
            PyObject *new_str = PyUnicode_FromString("__new__");
            if (likely(new_str)) {
                PyObject *o = PyObject_CallMethodObjArgs((PyObject *)&PyBaseObject_Type, new_str, t, NULL);
                Py_DECREF(new_str);
                return o;
            } else
                return NULL;
        } else
    #endif
        return tp_new(t, __pyx_mstate_global->__pyx_empty_tuple, 0);
    }
}

/* CallTypeTraverse */
#if !CYTHON_USE_TYPE_SPECS || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x03090000)
#else
static int __Pyx_call_type_traverse(PyObject *o, int always_call, visitproc visit, void *arg) {
    #if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x03090000
    if (__Pyx_get_runtime_version() < 0x03090000) return 0;
    #endif
    if (!always_call) {
        PyTypeObject *base = __Pyx_PyObject_GetSlot(o, tp_base, PyTypeObject*);
        unsigned long flags = PyType_GetFlags(base);
        if (flags & Py_TPFLAGS_HEAPTYPE) {
            return 0;
        }
    }
    Py_VISIT((PyObject*)Py_TYPE(o));
    return 0;
}
#endif

/* LimitedApiGetTypeDict (used by SetItemOnTypeDict) */
#include "src/gevent/_generated_include/LimitedApiGetTypeDict_impl_fd5385b0b7d81c54e35b8e8be86f2a48fa376c140ad1a251d94cb50d5e2fb049.h"
/* SetItemOnTypeDict (used by FixUpExtensionType) */
static int __Pyx__SetItemOnTypeDict(PyTypeObject *tp, PyObject *k, PyObject *v) {
    int result;
    PyObject *tp_dict;
#if CYTHON_COMPILING_IN_LIMITED_API
    tp_dict = __Pyx_GetTypeDict(tp);
    if (unlikely(!tp_dict)) return -1;
#else
    tp_dict = tp->tp_dict;
#endif
    result = PyDict_SetItem(tp_dict, k, v);
    if (likely(!result)) {
        PyType_Modified(tp);
        if (unlikely(PyObject_HasAttr(v, __pyx_mstate_global->__pyx_n_u_set_name))) {
            PyObject *setNameResult = PyObject_CallMethodObjArgs(v, __pyx_mstate_global->__pyx_n_u_set_name,  (PyObject *) tp, k, NULL);
            if (!setNameResult) return -1;
            Py_DECREF(setNameResult);
        }
    }
    return result;
}

/* FixUpExtensionType */
#include "src/gevent/_generated_include/FixUpExtensionType_impl_968625585c074793d4236a363113043104c99af679f80b0b7d0ea5e03b43f419.h"
/* PyObjectCallNoArg (used by PyObjectCallMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
    PyObject *arg[2] = {NULL, NULL};
    return __Pyx_PyObject_FastCall(func, arg + 1, 0 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* PyObjectGetMethod (used by PyObjectCallMethod0) */
#include "src/gevent/_generated_include/PyObjectGetMethod_impl_e128eb9d3930413c3ed54abc40d4953c55ff9ea67a8c08ac7b5c2fd8494b6c00.h"
/* PyObjectCallMethod0 (used by PyType_Ready) */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name) {
#if CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000))
    PyObject *args[1] = {obj};
    (void) __Pyx_PyObject_CallOneArg;
    (void) __Pyx_PyObject_CallNoArg;
    return PyObject_VectorcallMethod(method_name, args, 1 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#else
    PyObject *method = NULL, *result = NULL;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_CallOneArg(method, obj);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) goto bad;
    result = __Pyx_PyObject_CallNoArg(method);
    Py_DECREF(method);
bad:
    return result;
#endif
}

/* ValidateBasesTuple (used by PyType_Ready) */
#include "src/gevent/_generated_include/ValidateBasesTuple_impl_3b9fdcb5e55f23d97a6405040c32f85cd06688a92f7d1964c3b28bc807f560c9.h"
/* PyType_Ready */
CYTHON_UNUSED static int __Pyx_PyType_HasMultipleInheritance(PyTypeObject *t) {
    while (t) {
        PyObject *bases = __Pyx_PyType_GetSlot(t, tp_bases, PyObject*);
        if (bases) {
            return 1;
        }
        t = __Pyx_PyType_GetSlot(t, tp_base, PyTypeObject*);
    }
    return 0;
}
static int __Pyx_PyType_Ready(PyTypeObject *t) {
#if CYTHON_USE_TYPE_SPECS || !CYTHON_COMPILING_IN_CPYTHON || defined(PYSTON_MAJOR_VERSION)
    (void)__Pyx_PyObject_CallMethod0;
#if CYTHON_USE_TYPE_SPECS
    (void)__Pyx_validate_bases_tuple;
#endif
    return PyType_Ready(t);
#else
    int r;
    if (!__Pyx_PyType_HasMultipleInheritance(t)) {
        return PyType_Ready(t);
    }
    PyObject *bases = __Pyx_PyType_GetSlot(t, tp_bases, PyObject*);
    if (bases && unlikely(__Pyx_validate_bases_tuple(t->tp_name, t->tp_dictoffset, bases) == -1))
        return -1;
#if !defined(PYSTON_MAJOR_VERSION)
    {
        int gc_was_enabled;
    #if PY_VERSION_HEX >= 0x030A00b1
        gc_was_enabled = PyGC_Disable();
        (void)__Pyx_PyObject_CallMethod0;
    #else
        PyObject *ret, *py_status;
        PyObject *gc = NULL;
        #if (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM+0 >= 0x07030400) &&\
                !CYTHON_COMPILING_IN_GRAAL
        gc = PyImport_GetModule(__pyx_mstate_global->__pyx_kp_u_gc);
        #endif
        if (unlikely(!gc)) gc = PyImport_Import(__pyx_mstate_global->__pyx_kp_u_gc);
        if (unlikely(!gc)) return -1;
        py_status = __Pyx_PyObject_CallMethod0(gc, __pyx_mstate_global->__pyx_kp_u_isenabled);
        if (unlikely(!py_status)) {
            Py_DECREF(gc);
            return -1;
        }
        gc_was_enabled = __Pyx_PyObject_IsTrue(py_status);
        Py_DECREF(py_status);
        if (gc_was_enabled > 0) {
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_mstate_global->__pyx_kp_u_disable);
            if (unlikely(!ret)) {
                Py_DECREF(gc);
                return -1;
            }
            Py_DECREF(ret);
        } else if (unlikely(gc_was_enabled == -1)) {
            Py_DECREF(gc);
            return -1;
        }
    #endif
        t->tp_flags |= Py_TPFLAGS_HEAPTYPE;
#if PY_VERSION_HEX >= 0x030A0000
        t->tp_flags |= Py_TPFLAGS_IMMUTABLETYPE;
#endif
#else
        (void)__Pyx_PyObject_CallMethod0;
#endif
    r = PyType_Ready(t);
#if !defined(PYSTON_MAJOR_VERSION)
        t->tp_flags &= ~Py_TPFLAGS_HEAPTYPE;
    #if PY_VERSION_HEX >= 0x030A00b1
        if (gc_was_enabled)
            PyGC_Enable();
    #else
        if (gc_was_enabled) {
            PyObject *tp, *v, *tb;
            PyErr_Fetch(&tp, &v, &tb);
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_mstate_global->__pyx_kp_u_enable);
            if (likely(ret || r == -1)) {
                Py_XDECREF(ret);
                PyErr_Restore(tp, v, tb);
            } else {
                Py_XDECREF(tp);
                Py_XDECREF(v);
                Py_XDECREF(tb);
                r = -1;
            }
        }
        Py_DECREF(gc);
    #endif
    }
#endif
    return r;
#endif
}

/* SetVTable */
static int __Pyx_SetVtable(PyTypeObject *type, void *vtable) {
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
    if (unlikely(!ob))
        goto bad;
#if CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(PyObject_SetAttr((PyObject *) type, __pyx_mstate_global->__pyx_n_u_pyx_vtable, ob) < 0))
#else
    if (unlikely(PyDict_SetItem(type->tp_dict, __pyx_mstate_global->__pyx_n_u_pyx_vtable, ob) < 0))
#endif
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

/* GetVTable (used by MergeVTables) */
static void* __Pyx_GetVtable(PyTypeObject *type) {
    void* ptr;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *ob = PyObject_GetAttr((PyObject *)type, __pyx_mstate_global->__pyx_n_u_pyx_vtable);
#else
    PyObject *ob = PyObject_GetItem(type->tp_dict, __pyx_mstate_global->__pyx_n_u_pyx_vtable);
#endif
    if (!ob)
        goto bad;
    ptr = PyCapsule_GetPointer(ob, 0);
    if (!ptr && !PyErr_Occurred())
        PyErr_SetString(PyExc_RuntimeError, "invalid vtable found for imported type");
    Py_DECREF(ob);
    return ptr;
bad:
    Py_XDECREF(ob);
    return NULL;
}

/* MergeVTables */
#include "src/gevent/_generated_include/MergeVTables_impl_cc0b823a0ed067bdca31ab6afca82ec940b10d68e9ecebbaec0a3d49b6244e8c.h"
/* TypeImport */
#include "src/gevent/_generated_include/TypeImport_impl_e30d056ae329ba5e94fee4709e4266a267c585bd5c229f7cd6121597afbfaa4e.h"
/* HasAttr (used by ImportImpl) */
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *o, PyObject *n) {
    PyObject *r;
    if (unlikely(!PyUnicode_Check(n))) {
        PyErr_SetString(PyExc_TypeError,
                        "hasattr(): attribute name must be string");
        return -1;
    }
    r = __Pyx_PyObject_GetAttrStrNoError(o, n);
    if (!r) {
        return (unlikely(PyErr_Occurred())) ? -1 : 0;
    } else {
        Py_DECREF(r);
        return 1;
    }
}
#endif

/* ImportImpl (used by Import) */
#include "src/gevent/_generated_include/ImportImpl_impl_54add44d3961eb3adfb567f9d1292a4ce092acafbf7b2d11f026c8e90ea281d3.h"
/* Import */
static PyObject *__Pyx_Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, int level) {
    return __Pyx__Import(name, imported_names, len_imported_names, qualname, __pyx_mstate_global->__pyx_d, level);
}

/* ImportFrom */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        const char* module_name_str = 0;
        PyObject* module_name = 0;
        PyObject* module_dot = 0;
        PyObject* full_name = 0;
        PyErr_Clear();
        module_name_str = PyModule_GetName(module);
        if (unlikely(!module_name_str)) { goto modbad; }
        module_name = PyUnicode_FromString(module_name_str);
        if (unlikely(!module_name)) { goto modbad; }
        module_dot = PyUnicode_Concat(module_name, __pyx_mstate_global->__pyx_kp_u__7);
        if (unlikely(!module_dot)) { goto modbad; }
        full_name = PyUnicode_Concat(module_dot, name);
        if (unlikely(!full_name)) { goto modbad; }
        #if (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM  < 0x07030400) ||\
                CYTHON_COMPILING_IN_GRAAL
        {
            PyObject *modules = PyImport_GetModuleDict();
            if (unlikely(!modules))
                goto modbad;
            value = PyObject_GetItem(modules, full_name);
        }
        #else
        value = PyImport_GetModule(full_name);
        #endif
      modbad:
        Py_XDECREF(full_name);
        Py_XDECREF(module_dot);
        Py_XDECREF(module_name);
    }
    if (unlikely(!value)) {
        PyErr_Format(PyExc_ImportError, "cannot import name %S", name);
    }
    return value;
}

/* ListPack */
static PyObject *__Pyx_PyList_Pack(Py_ssize_t n, ...) {
    va_list va;
    PyObject *l = PyList_New(n);
    va_start(va, n);
    if (unlikely(!l)) goto end;
    for (Py_ssize_t i=0; i<n; ++i) {
        PyObject *arg = va_arg(va, PyObject*);
        Py_INCREF(arg);
        if (__Pyx_PyList_SET_ITEM(l, i, arg) != (0)) {
            Py_CLEAR(l);
            goto end;
        }
    }
    end:
    va_end(va);
    return l;
}

/* Py3UpdateBases */
static PyObject*
__Pyx_PEP560_update_bases(PyObject *bases)
{
    Py_ssize_t i, j, size_bases;
    PyObject *base = NULL, *meth, *new_base, *result, *new_bases = NULL;
#if CYTHON_ASSUME_SAFE_SIZE
    size_bases = PyTuple_GET_SIZE(bases);
#else
    size_bases = PyTuple_Size(bases);
    if (size_bases < 0) return NULL;
#endif
    for (i = 0; i < size_bases; i++) {
#if CYTHON_AVOID_BORROWED_REFS
        Py_CLEAR(base);
#endif
#if CYTHON_ASSUME_SAFE_MACROS
        base = PyTuple_GET_ITEM(bases, i);
#else
        base = PyTuple_GetItem(bases, i);
        if (!base) goto error;
#endif
#if CYTHON_AVOID_BORROWED_REFS
        Py_INCREF(base);
#endif
        if (PyType_Check(base)) {
            if (new_bases) {
                if (PyList_Append(new_bases, base) < 0) {
                    goto error;
                }
            }
            continue;
        }
        meth = __Pyx_PyObject_GetAttrStrNoError(base, __pyx_mstate_global->__pyx_n_u_mro_entries);
        if (!meth && PyErr_Occurred()) {
            goto error;
        }
        if (!meth) {
            if (new_bases) {
                if (PyList_Append(new_bases, base) < 0) {
                    goto error;
                }
            }
            continue;
        }
        new_base = __Pyx_PyObject_CallOneArg(meth, bases);
        Py_DECREF(meth);
        if (!new_base) {
            goto error;
        }
        if (!PyTuple_Check(new_base)) {
            PyErr_SetString(PyExc_TypeError,
                            "__mro_entries__ must return a tuple");
            Py_DECREF(new_base);
            goto error;
        }
        if (!new_bases) {
            if (!(new_bases = PyList_New(i))) {
                goto error;
            }
            for (j = 0; j < i; j++) {
                PyObject *base_from_list;
#if CYTHON_ASSUME_SAFE_MACROS
                base_from_list = PyTuple_GET_ITEM(bases, j);
                PyList_SET_ITEM(new_bases, j, base_from_list);
                Py_INCREF(base_from_list);
#else
                base_from_list = PyTuple_GetItem(bases, j);
                if (!base_from_list) goto error;
                Py_INCREF(base_from_list);
                if (PyList_SetItem(new_bases, j, base_from_list) < 0) goto error;
#endif
            }
        }
#if CYTHON_ASSUME_SAFE_SIZE
        j = PyList_GET_SIZE(new_bases);
#else
        j = PyList_Size(new_bases);
        if (j < 0) goto error;
#endif
        if (PyList_SetSlice(new_bases, j, j, new_base) < 0) {
            goto error;
        }
        Py_DECREF(new_base);
    }
    if (!new_bases) {
        Py_INCREF(bases);
        return bases;
    }
    result = PyList_AsTuple(new_bases);
    Py_DECREF(new_bases);
#if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(base);
#endif
    return result;
error:
    Py_XDECREF(new_bases);
#if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(base);
#endif
    return NULL;
}

/* CalculateMetaclass */
#include "src/gevent/_generated_include/CalculateMetaclass_impl_ca07cc90a946a15d16d88876d342e5227a65e7dadf9f9a4dc4aa5ac9a76f1d83.h"
/* PyObjectLookupSpecial (used by Py3ClassCreate) */
#if CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx__PyObject_LookupSpecial(PyObject* obj, PyObject* attr_name, int with_error) {
    PyObject *res;
    PyTypeObject *tp = Py_TYPE(obj);
    res = _PyType_Lookup(tp, attr_name);
    if (likely(res)) {
        descrgetfunc f = Py_TYPE(res)->tp_descr_get;
        if (!f) {
            Py_INCREF(res);
        } else {
            res = f(res, obj, (PyObject *)tp);
        }
    } else if (with_error) {
        PyErr_SetObject(PyExc_AttributeError, attr_name);
    }
    return res;
}
#endif

/* Py3ClassCreate */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name,
                                           PyObject *qualname, PyObject *mkw, PyObject *modname, PyObject *doc) {
    PyObject *ns;
    if (metaclass) {
        PyObject *prep = __Pyx_PyObject_GetAttrStrNoError(metaclass, __pyx_mstate_global->__pyx_n_u_prepare);
        if (prep) {
            PyObject *pargs[3] = {NULL, name, bases};
            ns = __Pyx_PyObject_FastCallDict(prep, pargs+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, mkw);
            Py_DECREF(prep);
        } else {
            if (unlikely(PyErr_Occurred()))
                return NULL;
            ns = PyDict_New();
        }
    } else {
        ns = PyDict_New();
    }
    if (unlikely(!ns))
        return NULL;
    if (unlikely(PyObject_SetItem(ns, __pyx_mstate_global->__pyx_n_u_module, modname) < 0)) goto bad;
    if (unlikely(PyObject_SetItem(ns, __pyx_mstate_global->__pyx_n_u_qualname, qualname) < 0)) goto bad;
    if (unlikely(doc && PyObject_SetItem(ns, __pyx_mstate_global->__pyx_n_u_doc, doc) < 0)) goto bad;
    return ns;
bad:
    Py_DECREF(ns);
    return NULL;
}
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases,
                                      PyObject *dict, PyObject *mkw,
                                      int calculate_metaclass, int allow_py2_metaclass) {
    PyObject *result;
    PyObject *owned_metaclass = NULL;
    PyObject *margs[4] = {NULL, name, bases, dict};
    if (allow_py2_metaclass) {
        owned_metaclass = PyObject_GetItem(dict, __pyx_mstate_global->__pyx_n_u_metaclass);
        if (owned_metaclass) {
            metaclass = owned_metaclass;
        } else if (likely(PyErr_ExceptionMatches(PyExc_KeyError))) {
            PyErr_Clear();
        } else {
            return NULL;
        }
    }
    if (calculate_metaclass && (!metaclass || PyType_Check(metaclass))) {
        metaclass = __Pyx_CalculateMetaclass((PyTypeObject*) metaclass, bases);
        Py_XDECREF(owned_metaclass);
        if (unlikely(!metaclass))
            return NULL;
        owned_metaclass = metaclass;
    }
    result = __Pyx_PyObject_FastCallDict(metaclass, margs+1, 3 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, mkw);
    Py_XDECREF(owned_metaclass);
    return result;
}

/* dict_setdefault (used by FetchCommonType) */
static CYTHON_INLINE PyObject *__Pyx_PyDict_SetDefault(PyObject *d, PyObject *key, PyObject *default_value) {
    PyObject* value;
#if __PYX_LIMITED_VERSION_HEX >= 0x030F0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4)
    PyDict_SetDefaultRef(d, key, default_value, &value);
#elif CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX >= 0x030C0000
    PyObject *args[] = {d, key, default_value};
    value = PyObject_VectorcallMethod(__pyx_mstate_global->__pyx_n_u_setdefault, args, 3 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#elif CYTHON_COMPILING_IN_LIMITED_API
    value = PyObject_CallMethodObjArgs(d, __pyx_mstate_global->__pyx_n_u_setdefault, key, default_value, NULL);
#else
    value = PyDict_SetDefault(d, key, default_value);
    if (unlikely(!value)) return NULL;
    Py_INCREF(value);
#endif
    return value;
}

/* AddModuleRef (used by FetchSharedCythonModule) */
#include "src/gevent/_generated_include/AddModuleRef_impl_59efe7a55c2d1acdb632a2a6953f1ce31c634c9f98f262a8d338db6996845385.h"
/* FetchSharedCythonModule (used by FetchCommonType) */
static PyObject *__Pyx_FetchSharedCythonABIModule(void) {
    return __Pyx_PyImport_AddModuleRef(__PYX_ABI_MODULE_NAME);
}

/* FetchCommonType (used by CommonTypesMetaclass) */
#include "src/gevent/_generated_include/FetchCommonType_impl_8ddf5d6e0d45314935e4d87502d7fa32ec8f3d50d91ca9715a35d7f0fc2dda28.h"
/* CommonTypesMetaclass (used by CythonFunctionShared) */
#include "src/gevent/_generated_include/CommonTypesMetaclass_impl_5345023feb7cb35c8a99997be95973c1bfc904b959ef880ae7125f77d296af2b.h"
/* PyMethodNew (used by CythonFunctionShared) */
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    PyObject *result;
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    #if __PYX_LIMITED_VERSION_HEX >= 0x030C0000
    {
        PyObject *args[] = {func, self};
        result = PyObject_Vectorcall(__pyx_mstate_global->__Pyx_CachedMethodType, args, 2, NULL);
    }
    #else
    result = PyObject_CallFunctionObjArgs(__pyx_mstate_global->__Pyx_CachedMethodType, func, self, NULL);
    #endif
    return result;
}
#else
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    return PyMethod_New(func, self);
}
#endif

/* PyVectorcallFastCallDict (used by CythonFunctionShared) */
#include "src/gevent/_generated_include/PyVectorcallFastCallDict_impl_3616dfa798c1c336b0933a7ec9d88cb291d491f6315b48f846f69828df4619eb.h"
/* CythonFunctionShared (used by CythonFunction) */
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunctionNoMethod(PyObject *func, void (*cfunc)(void)) {
    if (__Pyx_CyFunction_Check(func)) {
        return PyCFunction_GetFunction(((__pyx_CyFunctionObject*)func)->func) == (PyCFunction) cfunc;
    } else if (PyCFunction_Check(func)) {
        return PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void (*cfunc)(void)) {
    if ((PyObject*)Py_TYPE(func) == __pyx_mstate_global->__Pyx_CachedMethodType) {
        int result;
        PyObject *newFunc = PyObject_GetAttr(func, __pyx_mstate_global->__pyx_n_u_func);
        if (unlikely(!newFunc)) {
            PyErr_Clear(); // It's only an optimization, so don't throw an error
            return 0;
        }
        result = __Pyx__IsSameCyOrCFunctionNoMethod(newFunc, cfunc);
        Py_DECREF(newFunc);
        return result;
    }
    return __Pyx__IsSameCyOrCFunctionNoMethod(func, cfunc);
}
#else
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void (*cfunc)(void)) {
    if (PyMethod_Check(func)) {
        func = PyMethod_GET_FUNCTION(func);
    }
    return __Pyx_CyOrPyCFunction_Check(func) && __Pyx_CyOrPyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
}
#endif
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj) {
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    __Pyx_Py_XDECREF_SET(
        __Pyx_CyFunction_GetClassObj(f),
            ((classobj) ? __Pyx_NewRef(classobj) : NULL));
#else
    __Pyx_Py_XDECREF_SET(
        ((PyCMethodObject *) (f))->mm_class,
        (PyTypeObject*)((classobj) ? __Pyx_NewRef(classobj) : NULL));
#endif
}
static PyObject *
__Pyx_CyFunction_get_doc_locked(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_doc == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_doc = PyObject_GetAttrString(op->func, "__doc__");
        if (unlikely(!op->func_doc)) return NULL;
#else
        if (((PyCFunctionObject*)op)->m_ml->ml_doc) {
            op->func_doc = PyUnicode_FromString(((PyCFunctionObject*)op)->m_ml->ml_doc);
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
#endif
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, void *closure) {
    PyObject *result;
    CYTHON_UNUSED_VAR(closure);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_doc_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (value == NULL) {
        value = Py_None;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_doc, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name_locked(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_name == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_name = PyObject_GetAttrString(op->func, "__name__");
#else
        op->func_name = PyUnicode_InternFromString(((PyCFunctionObject*)op)->m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op, void *context)
{
    PyObject *result = NULL;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_name_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_name, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    PyObject *result;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    Py_INCREF(op->func_qualname);
    result = op->func_qualname;
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_qualname, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
#endif
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(op);
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op, void *context)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    int result = 0;
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    #else
    op->defaults_tuple = __Pyx_PySequence_ITEM(res, 0);
    if (unlikely(!op->defaults_tuple)) result = -1;
    else {
        op->defaults_kwdict = __Pyx_PySequence_ITEM(res, 1);
        if (unlikely(!op->defaults_kwdict)) result = -1;
    }
    #endif
    Py_DECREF(res);
    return result;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyTuple_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__defaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->defaults_tuple, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_tuple;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = NULL;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_defaults_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__kwdefaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->defaults_kwdict, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_kwdict;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_kwdefaults_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value || value == Py_None) {
        value = NULL;
    } else if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_annotations, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->func_annotations;
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op, void *context) {
    PyObject *result;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_annotations_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static PyObject *
__Pyx_CyFunction_get_is_coroutine_value(__pyx_CyFunctionObject *op) {
    int is_coroutine = op->flags & __Pyx_CYFUNCTION_COROUTINE;
    if (is_coroutine) {
        PyObject *is_coroutine_value, *module, *fromlist, *marker = __pyx_mstate_global->__pyx_n_u_is_coroutine;
        fromlist = PyList_New(1);
        if (unlikely(!fromlist)) return NULL;
        Py_INCREF(marker);
#if CYTHON_ASSUME_SAFE_MACROS
        PyList_SET_ITEM(fromlist, 0, marker);
#else
        if (unlikely(PyList_SetItem(fromlist, 0, marker) < 0)) {
            Py_DECREF(marker);
            Py_DECREF(fromlist);
            return NULL;
        }
#endif
        module = PyImport_ImportModuleLevelObject(__pyx_mstate_global->__pyx_n_u_asyncio_coroutines, NULL, NULL, fromlist, 0);
        Py_DECREF(fromlist);
        if (unlikely(!module)) goto ignore;
        is_coroutine_value = __Pyx_PyObject_GetAttrStr(module, marker);
        Py_DECREF(module);
        if (likely(is_coroutine_value)) {
            return is_coroutine_value;
        }
ignore:
        PyErr_Clear();
    }
    return __Pyx_PyBool_FromLong(is_coroutine);
}
static PyObject *
__Pyx_CyFunction_get_is_coroutine(__pyx_CyFunctionObject *op, void *context) {
    PyObject *result;
    CYTHON_UNUSED_VAR(context);
    if (op->func_is_coroutine) {
        return __Pyx_NewRef(op->func_is_coroutine);
    }
    result = __Pyx_CyFunction_get_is_coroutine_value(op);
    if (unlikely(!result))
        return NULL;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    if (op->func_is_coroutine) {
        Py_DECREF(result);
        result = __Pyx_NewRef(op->func_is_coroutine);
    } else {
        op->func_is_coroutine = __Pyx_NewRef(result);
    }
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static void __Pyx_CyFunction_raise_argument_count_error(__pyx_CyFunctionObject *func, const char* message, Py_ssize_t size) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_name = __Pyx_CyFunction_get_name(func, NULL);
    if (!py_name) return;
    PyErr_Format(PyExc_TypeError,
        "%.200S() %s (%" CYTHON_FORMAT_SSIZE_T "d given)",
        py_name, message, size);
    Py_DECREF(py_name);
#else
    const char* name = ((PyCFunctionObject*)func)->m_ml->ml_name;
    PyErr_Format(PyExc_TypeError,
        "%.200s() %s (%" CYTHON_FORMAT_SSIZE_T "d given)",
        name, message, size);
#endif
}
static void __Pyx_CyFunction_raise_type_error(__pyx_CyFunctionObject *func, const char* message) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_name = __Pyx_CyFunction_get_name(func, NULL);
    if (!py_name) return;
    PyErr_Format(PyExc_TypeError,
        "%.200S() %s",
        py_name, message);
    Py_DECREF(py_name);
#else
    const char* name = ((PyCFunctionObject*)func)->m_ml->ml_name;
    PyErr_Format(PyExc_TypeError,
        "%.200s() %s",
        name, message);
#endif
}
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *
__Pyx_CyFunction_get_module(__pyx_CyFunctionObject *op, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_GetAttrString(op->func, "__module__");
}
static int
__Pyx_CyFunction_set_module(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_SetAttrString(op->func, "__module__", value);
}
#endif
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {"func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {"__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {"func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {"__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {"__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
    {"func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)PyObject_GenericSetDict, 0, 0},
    {"__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)PyObject_GenericSetDict, 0, 0},
#else
    {"func_dict", (getter)PyObject_GenericGetDict, (setter)PyObject_GenericSetDict, 0, 0},
    {"__dict__", (getter)PyObject_GenericGetDict, (setter)PyObject_GenericSetDict, 0, 0},
#endif
    {"func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {"__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {"func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {"__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {"func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {"__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {"func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {"__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {"__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {"__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {"_is_coroutine", (getter)__Pyx_CyFunction_get_is_coroutine, 0, 0, 0},
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__module__", (getter)__Pyx_CyFunction_get_module, (setter)__Pyx_CyFunction_set_module, 0, 0},
#endif
    {0, 0, 0, 0, 0}
};
static PyMemberDef __pyx_CyFunction_members[] = {
#if !CYTHON_COMPILING_IN_LIMITED_API
    {"__module__", T_OBJECT, offsetof(PyCFunctionObject, m_module), 0, 0},
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    {"__dictoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_dict), READONLY, 0},
#endif
#if CYTHON_METH_FASTCALL
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__vectorcalloffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_vectorcall), READONLY, 0},
#else
    {"__vectorcalloffset__", T_PYSSIZET, offsetof(PyCFunctionObject, vectorcall), READONLY, 0},
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__weaklistoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_weakreflist), READONLY, 0},
#else
    {"__weaklistoffset__", T_PYSSIZET, offsetof(PyCFunctionObject, m_weakreflist), READONLY, 0},
#endif
#endif
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, PyObject *args)
{
    PyObject *result = NULL;
    CYTHON_UNUSED_VAR(args);
    __Pyx_BEGIN_CRITICAL_SECTION(m);
    Py_INCREF(m->func_qualname);
    result = m->func_qualname;
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {"__reduce__", (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
#if CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func_weakreflist)
#else
#define __Pyx_CyFunction_weakreflist(cyfunc) (((PyCFunctionObject*)cyfunc)->m_weakreflist)
#endif
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject *op, PyMethodDef *ml, int flags, PyObject* qualname,
                                       PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
#if !CYTHON_COMPILING_IN_LIMITED_API
    PyCFunctionObject *cf = (PyCFunctionObject*) op;
#endif
    if (unlikely(op == NULL))
        return NULL;
#if CYTHON_COMPILING_IN_LIMITED_API
    op->func = PyCFunction_NewEx(ml, (PyObject*)op, module);
    if (unlikely(!op->func)) return NULL;
#endif
    op->flags = flags;
    __Pyx_CyFunction_weakreflist(op) = NULL;
#if !CYTHON_COMPILING_IN_LIMITED_API
    cf->m_ml = ml;
    cf->m_self = (PyObject *) op;
#endif
    Py_XINCREF(closure);
    op->func_closure = closure;
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_XINCREF(module);
    cf->m_module = module;
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    op->func_dict = NULL;
#endif
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    op->func_classobj = NULL;
#else
    ((PyCMethodObject*)op)->mm_class = NULL;
#endif
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    op->func_is_coroutine = NULL;
#if CYTHON_METH_FASTCALL
    switch (ml->ml_flags & (METH_VARARGS | METH_FASTCALL | METH_NOARGS | METH_O | METH_KEYWORDS | METH_METHOD)) {
    case METH_NOARGS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_NOARGS;
        break;
    case METH_O:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_O;
        break;
    case METH_METHOD | METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD;
        break;
    case METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS;
        break;
    case METH_VARARGS | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = NULL;
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        Py_DECREF(op);
        return NULL;
    }
#endif
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_CLEAR(m->func);
#else
    Py_CLEAR(((PyCFunctionObject*)m)->m_module);
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    Py_CLEAR(m->func_dict);
#elif PY_VERSION_HEX < 0x030d0000
    _PyObject_ClearManagedDict((PyObject*)m);
#else
    PyObject_ClearManagedDict((PyObject*)m);
#endif
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
#if PY_VERSION_HEX < 0x030900B1
    Py_CLEAR(__Pyx_CyFunction_GetClassObj(m));
#else
    {
        PyObject *cls = (PyObject*) ((PyCMethodObject *) (m))->mm_class;
        ((PyCMethodObject *) (m))->mm_class = NULL;
        Py_XDECREF(cls);
    }
#endif
#endif
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    Py_CLEAR(m->func_is_coroutine);
    Py_CLEAR(m->defaults);
    return 0;
}
static void __Pyx__CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    if (__Pyx_CyFunction_weakreflist(m) != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    __Pyx_PyHeapTypeObject_GC_Del(m);
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    __Pyx__CyFunction_dealloc(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    {
        int e = __Pyx_call_type_traverse((PyObject*)m, 1, visit, arg);
        if (e) return e;
    }
    Py_VISIT(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(m->func);
#else
    Py_VISIT(((PyCFunctionObject*)m)->m_module);
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(m->func_dict);
#else
    {
        int e =
#if PY_VERSION_HEX < 0x030d0000
            _PyObject_VisitManagedDict
#else
            PyObject_VisitManagedDict
#endif
                ((PyObject*)m, visit, arg);
        if (e != 0) return e;
    }
#endif
    __Pyx_VISIT_CONST(m->func_name);
    __Pyx_VISIT_CONST(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    __Pyx_VISIT_CONST(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(__Pyx_CyFunction_GetClassObj(m));
#endif
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    Py_VISIT(m->func_is_coroutine);
    Py_VISIT(m->defaults);
    return 0;
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
    PyObject *repr;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    repr = PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
    __Pyx_END_CRITICAL_SECTION();
    return repr;
}
static PyObject * __Pyx_CyFunction_CallMethod(PyObject *func, PyObject *self, PyObject *arg, PyObject *kw) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *f = ((__pyx_CyFunctionObject*)func)->func;
    PyCFunction meth;
    int flags;
    meth = PyCFunction_GetFunction(f);
    if (unlikely(!meth)) return NULL;
    flags = PyCFunction_GetFlags(f);
    if (unlikely(flags < 0)) return NULL;
#else
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = f->m_ml->ml_meth;
    int flags = f->m_ml->ml_flags;
#endif
    Py_ssize_t size;
    switch (flags & (METH_VARARGS | METH_KEYWORDS | METH_NOARGS | METH_O)) {
    case METH_VARARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0))
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)(void(*)(void))meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_SIZE
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 0))
                return (*meth)(self, NULL);
            __Pyx_CyFunction_raise_argument_count_error(
                (__pyx_CyFunctionObject*)func,
                "takes no arguments", size);
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_SIZE
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 1)) {
                PyObject *result, *arg0;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                arg0 = PyTuple_GET_ITEM(arg, 0);
                #else
                arg0 = __Pyx_PySequence_ITEM(arg, 0); if (unlikely(!arg0)) return NULL;
                #endif
                result = (*meth)(self, arg0);
                #if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
                Py_DECREF(arg0);
                #endif
                return result;
            }
            __Pyx_CyFunction_raise_argument_count_error(
                (__pyx_CyFunctionObject*)func,
                "takes exactly one argument", size);
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        return NULL;
    }
    __Pyx_CyFunction_raise_type_error(
        (__pyx_CyFunctionObject*)func, "takes no keyword arguments");
    return NULL;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *self, *result;
#if CYTHON_COMPILING_IN_LIMITED_API
    self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)func)->func);
    if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
    self = ((PyCFunctionObject*)func)->m_self;
#endif
    result = __Pyx_CyFunction_CallMethod(func, self, arg, kw);
    return result;
}
static PyObject *__Pyx_CyFunction_CallAsMethod(PyObject *func, PyObject *args, PyObject *kw) {
    PyObject *result;
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
     __pyx_vectorcallfunc vc = __Pyx_CyFunction_func_vectorcall(cyfunc);
    if (vc) {
#if CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE
        return __Pyx_PyVectorcall_FastCallDict(func, vc, &PyTuple_GET_ITEM(args, 0), (size_t)PyTuple_GET_SIZE(args), kw);
#else
        (void) &__Pyx_PyVectorcall_FastCallDict;
        return PyVectorcall_Call(func, args, kw);
#endif
    }
#endif
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        Py_ssize_t argc;
        PyObject *new_args;
        PyObject *self;
#if CYTHON_ASSUME_SAFE_SIZE
        argc = PyTuple_GET_SIZE(args);
#else
        argc = PyTuple_Size(args);
        if (unlikely(argc < 0)) return NULL;
#endif
        new_args = PyTuple_GetSlice(args, 1, argc);
        if (unlikely(!new_args))
            return NULL;
        self = PyTuple_GetItem(args, 0);
        if (unlikely(!self)) {
            Py_DECREF(new_args);
            PyErr_Format(PyExc_TypeError,
                         "unbound method %.200S() needs an argument",
                         cyfunc->func_qualname);
            return NULL;
        }
        result = __Pyx_CyFunction_CallMethod(func, self, new_args, kw);
        Py_DECREF(new_args);
    } else {
        result = __Pyx_CyFunction_Call(func, args, kw);
    }
    return result;
}
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
static CYTHON_INLINE int __Pyx_CyFunction_Vectorcall_CheckArgs(__pyx_CyFunctionObject *cyfunc, Py_ssize_t nargs, PyObject *kwnames)
{
    int ret = 0;
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        if (unlikely(nargs < 1)) {
            __Pyx_CyFunction_raise_type_error(
                cyfunc, "needs an argument");
            return -1;
        }
        ret = 1;
    }
    if (unlikely(kwnames) && unlikely(__Pyx_PyTuple_GET_SIZE(kwnames))) {
        __Pyx_CyFunction_raise_type_error(
            cyfunc, "takes no keyword arguments");
        return -1;
    }
    return ret;
}
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 0)) {
        __Pyx_CyFunction_raise_argument_count_error(
            cyfunc, "takes no arguments", nargs);
        return NULL;
    }
    return meth(self, NULL);
}
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 1)) {
        __Pyx_CyFunction_raise_argument_count_error(
            cyfunc, "takes exactly one argument", nargs);
        return NULL;
    }
    return meth(self, args[0]);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    return ((__Pyx_PyCFunctionFastWithKeywords)(void(*)(void))meth)(self, args, nargs, kwnames);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyTypeObject *cls = (PyTypeObject *) __Pyx_CyFunction_GetClassObj(cyfunc);
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    #if PY_VERSION_HEX < 0x030e00A6
    size_t nargs_value = (size_t) nargs;
    #else
    Py_ssize_t nargs_value = nargs;
    #endif
    return ((__Pyx_PyCMethod)(void(*)(void))meth)(self, cls, args, nargs_value, kwnames);
}
#endif
static PyType_Slot __pyx_CyFunctionType_slots[] = {
    {Py_tp_dealloc, (void *)__Pyx_CyFunction_dealloc},
    {Py_tp_repr, (void *)__Pyx_CyFunction_repr},
    {Py_tp_call, (void *)__Pyx_CyFunction_CallAsMethod},
    {Py_tp_traverse, (void *)__Pyx_CyFunction_traverse},
    {Py_tp_clear, (void *)__Pyx_CyFunction_clear},
    {Py_tp_methods, (void *)__pyx_CyFunction_methods},
    {Py_tp_members, (void *)__pyx_CyFunction_members},
    {Py_tp_getset, (void *)__pyx_CyFunction_getsets},
    {Py_tp_descr_get, (void *)__Pyx_PyMethod_New},
    {0, 0},
};
static PyType_Spec __pyx_CyFunctionType_spec = {
    __PYX_TYPE_MODULE_PREFIX "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
#ifdef Py_TPFLAGS_METHOD_DESCRIPTOR
    Py_TPFLAGS_METHOD_DESCRIPTOR |
#endif
#if CYTHON_METH_FASTCALL
#if defined(Py_TPFLAGS_HAVE_VECTORCALL)
    Py_TPFLAGS_HAVE_VECTORCALL |
#elif defined(_Py_TPFLAGS_HAVE_VECTORCALL)
    _Py_TPFLAGS_HAVE_VECTORCALL |
#endif
#endif // CYTHON_METH_FASTCALL
#if PY_VERSION_HEX >= 0x030C0000 && !CYTHON_COMPILING_IN_LIMITED_API
    Py_TPFLAGS_MANAGED_DICT |
#endif
    Py_TPFLAGS_IMMUTABLETYPE | Py_TPFLAGS_DISALLOW_INSTANTIATION |
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    __pyx_CyFunctionType_slots
};
static int __pyx_CyFunction_init(PyObject *module) {
    __pyx_mstatetype *mstate = __Pyx_PyModule_GetState(module);
    mstate->__pyx_CyFunctionType = __Pyx_FetchCommonTypeFromSpec(
        mstate->__pyx_CommonTypesMetaclassType, module, &__pyx_CyFunctionType_spec, NULL);
    if (unlikely(mstate->__pyx_CyFunctionType == NULL)) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_InitDefaults(PyObject *func, PyTypeObject *defaults_type) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyObject_CallObject((PyObject*)defaults_type, NULL); // _PyObject_New(defaults_type);
    if (unlikely(!m->defaults))
        return NULL;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

/* CythonFunction */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    PyObject *op = __Pyx_CyFunction_Init(
        PyObject_GC_New(__pyx_CyFunctionObject, __pyx_mstate_global->__pyx_CyFunctionType),
        ml, flags, qualname, closure, module, globals, code
    );
    if (likely(op)) {
        PyObject_GC_Track(op);
    }
    return op;
}

/* SetNewInClass */
#include "src/gevent/_generated_include/SetNewInClass_impl_69190a89ed1c67d173dd42f1a3b8f5888095fd539ada156df94ee7f5c54309cc.h"
/* CLineInTraceback (used by AddTraceback) */
#if CYTHON_CLINE_IN_TRACEBACK && CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
#define __Pyx_PyProbablyModule_GetDict(o) __Pyx_XNewRef(PyModule_GetDict(o))
#elif !CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyProbablyModule_GetDict(o) PyObject_GenericGetDict(o, NULL);
#else
PyObject* __Pyx_PyProbablyModule_GetDict(PyObject *o) {
    PyObject **dict_ptr = _PyObject_GetDictPtr(o);
    return dict_ptr ? __Pyx_XNewRef(*dict_ptr) : NULL;
}
#endif
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line) {
    PyObject *use_cline = NULL;
    PyObject *ptype, *pvalue, *ptraceback;
    PyObject *cython_runtime_dict;
    CYTHON_MAYBE_UNUSED_VAR(tstate);
    if (unlikely(!__pyx_mstate_global->__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
    cython_runtime_dict = __Pyx_PyProbablyModule_GetDict(__pyx_mstate_global->__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, cython_runtime_dict,
            __Pyx_PyDict_SetDefault(cython_runtime_dict, __pyx_mstate_global->__pyx_n_u_cline_in_traceback, Py_False))
    }
    if (use_cline == NULL || use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    Py_XDECREF(use_cline);
    Py_XDECREF(cython_runtime_dict);
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache (used by AddTraceback) */
#include "src/gevent/_generated_include/CodeObjectCache_impl_ffc81bf87e547a82e6009d64a2466eb1a5f6677afcbab3333a029ea24e45c012.h"
/* AddTraceback */
#include "src/gevent/_generated_include/AddTraceback_impl_5c53b964023228d90bdfcfa91919f5c3c484446268d5ef056f29421d654f5af4.h"
/* CIntFromPyVerify */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntFromPy */
#include "src/gevent/_generated_include/CIntFromPy_impl_ceb8d340f976d387a193f777f2c34549caaafc1e59b58b253b09ec2b16efbddf.h"
/* CIntToPy */
#include "src/gevent/_generated_include/CIntToPy_impl_04d273d7fd8d781e47c953336d9035c05b46b928eb9a876491735d34363bfe94.h"
/* CIntFromPy */
#include "src/gevent/_generated_include/CIntFromPy_impl_064e14b66a8818e859da0434a03895a345ebdc19f405c036641030b43374e390.h"
/* CIntToPy */
#include "src/gevent/_generated_include/CIntToPy_impl_3a4503f42bed1a339a5a77cabbacbe22d845586eaf8fe2b8bf391ccbe75ae64a.h"
/* CIntToPy */
#include "src/gevent/_generated_include/CIntToPy_impl_da54a5936606076cf9451a0a57e16cb19a13c3375d07529f14ab496937dae4f3.h"
/* FormatTypeName */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030d0000
static __Pyx_TypeName
__Pyx_PyType_GetFullyQualifiedName(PyTypeObject* tp)
{
    PyObject *module = NULL, *name = NULL, *result = NULL;
    #if __PYX_LIMITED_VERSION_HEX < 0x030b0000
    name = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_mstate_global->__pyx_n_u_qualname);
    #else
    name = PyType_GetQualName(tp);
    #endif
    if (unlikely(name == NULL) || unlikely(!PyUnicode_Check(name))) goto bad;
    module = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_mstate_global->__pyx_n_u_module);
    if (unlikely(module == NULL) || unlikely(!PyUnicode_Check(module))) goto bad;
    if (PyUnicode_CompareWithASCIIString(module, "builtins") == 0) {
        result = name;
        name = NULL;
        goto done;
    }
    result = PyUnicode_FromFormat("%U.%U", module, name);
    if (unlikely(result == NULL)) goto bad;
  done:
    Py_XDECREF(name);
    Py_XDECREF(module);
    return result;
  bad:
    PyErr_Clear();
    if (name) {
        result = name;
        name = NULL;
    } else {
        result = __Pyx_NewRef(__pyx_mstate_global->__pyx_kp_u__8);
    }
    goto done;
}
#endif

/* CIntFromPy */
#include "src/gevent/_generated_include/CIntFromPy_impl_b91de55768d50878c1454209403f531c1ef9ecfc0f5cfff0eb0b925c62c994e2.h"
/* FastTypeChecks */
#include "src/gevent/_generated_include/FastTypeChecks_impl_f9d18941833a215bcf3276e2b6a57d81e032bd85ed1fb021b834da49989898c9.h"
/* GetRuntimeVersion */
#if __PYX_LIMITED_VERSION_HEX < 0x030b0000
void __Pyx_init_runtime_version(void) {
    if (__Pyx_cached_runtime_version == 0) {
        const char* rt_version = Py_GetVersion();
        unsigned long version = 0;
        unsigned long factor = 0x01000000UL;
        unsigned int digit = 0;
        int i = 0;
        while (factor) {
            while ('0' <= rt_version[i] && rt_version[i] <= '9') {
                digit = digit * 10 + (unsigned int) (rt_version[i] - '0');
                ++i;
            }
            version += factor * digit;
            if (rt_version[i] != '.')
                break;
            digit = 0;
            factor >>= 8;
            ++i;
        }
        __Pyx_cached_runtime_version = version;
    }
}
#endif
static unsigned long __Pyx_get_runtime_version(void) {
#if __PYX_LIMITED_VERSION_HEX >= 0x030b0000
    return Py_Version & ~0xFFUL;
#else
    return __Pyx_cached_runtime_version;
#endif
}

/* CheckBinaryVersion */
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer) {
    const unsigned long MAJOR_MINOR = 0xFFFF0000UL;
    if ((rt_version & MAJOR_MINOR) == (ct_version & MAJOR_MINOR))
        return 0;
    if (likely(allow_newer && (rt_version & MAJOR_MINOR) > (ct_version & MAJOR_MINOR)))
        return 1;
    {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compile time Python version %d.%d "
                      "of module '%.100s' "
                      "%s "
                      "runtime version %d.%d",
                       (int) (ct_version >> 24), (int) ((ct_version >> 16) & 0xFF),
                       __Pyx_MODULE_NAME,
                       (allow_newer) ? "was newer than" : "does not match",
                       (int) (rt_version >> 24), (int) ((rt_version >> 16) & 0xFF)
       );
        return PyErr_WarnEx(NULL, message, 1);
    }
}

/* NewCodeObj */
#include "src/gevent/_generated_include/NewCodeObj_impl_a437ae594518b78f515ea800eae13a23abf85c5a9a57d6d2c88c6b9b215ff54c.h"
/* DecompressString */
#include "src/gevent/_generated_include/DecompressString_impl_08916ce6b33dc899db1820b9329c4da53ddc4f977613e2296edf3d94850c4279.h"
#include <string.h>
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s) {
    size_t len = strlen(s);
    if (unlikely(len > (size_t) PY_SSIZE_T_MAX)) {
        PyErr_SetString(PyExc_OverflowError, "byte string is too long");
        return -1;
    }
    return (Py_ssize_t) len;
}
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return __Pyx_PyUnicode_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return PyByteArray_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if CYTHON_COMPILING_IN_LIMITED_API
    {
        const char* result;
        Py_ssize_t unicode_length;
        CYTHON_MAYBE_UNUSED_VAR(unicode_length); // only for __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        #if __PYX_LIMITED_VERSION_HEX < 0x030A0000
        if (unlikely(PyArg_Parse(o, "s#", &result, length) < 0)) return NULL;
        #else
        result = PyUnicode_AsUTF8AndSize(o, length);
        #endif
        #if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        unicode_length = PyUnicode_GetLength(o);
        if (unlikely(unicode_length < 0)) return NULL;
        if (unlikely(unicode_length != *length)) {
            PyUnicode_AsASCIIString(o);
            return NULL;
        }
        #endif
        return result;
    }
#else
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
#endif
}
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
    if (PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
    if (PyByteArray_Check(o)) {
#if (CYTHON_ASSUME_SAFE_SIZE && CYTHON_ASSUME_SAFE_MACROS) || (CYTHON_COMPILING_IN_PYPY && (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE)))
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
#else
        *length = PyByteArray_Size(o);
        if (*length == -1) return NULL;
        return PyByteArray_AsString(o);
#endif
    } else
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_LongWrongResultType(PyObject* result) {
    __Pyx_TypeName result_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(result));
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ").  "
                "The ability to return an instance of a strict subclass of int is deprecated, "
                "and may be removed in a future version of Python.",
                result_type_name)) {
            __Pyx_DECREF_TypeName(result_type_name);
            Py_DECREF(result);
            return NULL;
        }
        __Pyx_DECREF_TypeName(result_type_name);
        return result;
    }
    PyErr_Format(PyExc_TypeError,
                 "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ")",
                 result_type_name);
    __Pyx_DECREF_TypeName(result_type_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Long(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  PyObject *res = NULL;
  if (likely(PyLong_Check(x)))
      return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  if (likely(m && m->nb_int)) {
      res = m->nb_int(x);
  }
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
      res = PyNumber_Long(x);
  }
#endif
  if (likely(res)) {
      if (unlikely(!PyLong_CheckExact(res))) {
          return __Pyx_PyNumber_LongWrongResultType(res);
      }
  }
  else if (!PyErr_Occurred()) {
      PyErr_SetString(PyExc_TypeError,
                      "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(__Pyx_PyLong_IsCompact(b))) {
        return __Pyx_PyLong_CompactValue(b);
    } else {
      const digit* digits = __Pyx_PyLong_Digits(b);
      const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(b);
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyLong_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject* o) {
  if (sizeof(Py_hash_t) == sizeof(Py_ssize_t)) {
    return (Py_hash_t) __Pyx_PyIndex_AsSsize_t(o);
  } else {
    Py_ssize_t ival;
    PyObject *x;
    x = PyNumber_Index(o);
    if (!x) return -1;
    ival = PyLong_AsLong(x);
    Py_DECREF(x);
    return ival;
  }
}
static CYTHON_INLINE PyObject *__Pyx_Owned_Py_None(int b) {
    CYTHON_UNUSED_VAR(b);
    return __Pyx_NewRef(Py_None);
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return __Pyx_NewRef(b ? Py_True: Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyLong_FromSize_t(size_t ival) {
    return PyLong_FromSize_t(ival);
}


/* MultiPhaseInitModuleState */
#include "src/gevent/_generated_include/MultiPhaseInitModuleState_impl_41d512917574f55c289a94dba0e3ef9c60f8de37a71dd41f0dd086494a351cae.h"
/* #### Code section: utility_code_pragmas_end ### */
#ifdef _MSC_VER
#pragma warning( pop )
#endif



/* #### Code section: end ### */
#endif /* Py_PYTHON_H */
